/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(yb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function wb(xb){var r=xb.a;var s=r.buffer;r.grow=ub;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=xb.abort;var M=NaN;var N=Infinity;var O=xb.b;var P=xb.c;var Q=xb.d;var R=xb.e;var S=xb.f;var T=xb.g;var U=xb.h;var V=xb.i;var W=xb.j;var X=xb.k;var Y=xb.l;var Z=xb.m;var _=xb.n;var $=xb.o;var aa=xb.p;var ba=xb.q;var ca=xb.r;var da=xb.s;var ea=xb.t;var fa=xb.u;var ga=xb.v;var ha=xb.w;var ia=xb.x;var ja=xb.y;var ka=xb.z;var la=xb.A;var ma=xb.B;var na=xb.C;var oa=xb.D;var pa=xb.E;var qa=xb.F;var ra=xb.G;var sa=xb.H;var ta=xb.I;var ua=xb.J;var va=xb.K;var wa=xb.L;var xa=xb.M;var ya=xb.N;var za=xb.O;var Aa=xb.P;var Ba=xb.Q;var Ca=xb.R;var Da=xb.S;var Ea=xb.T;var Fa=xb.U;var Ga=xb.V;var Ha=xb.W;var Ia=xb.X;var Ja=xb.Y;var Ka=xb.Z;var La=xb._;var Ma=xb.$;var Na=xb.aa;var Oa=xb.ba;var Pa=xb.ca;var Qa=xb.da;var Ra=xb.ea;var Sa=xb.fa;var Ta=xb.ga;var Ua=xb.ha;var Va=xb.ia;var Wa=xb.ja;var Xa=xb.ka;var Ya=xb.la;var Za=xb.ma;var _a=xb.na;var $a=xb.oa;var ab=xb.pa;var bb=xb.qa;var cb=xb.ra;var db=xb.sa;var eb=xb.ta;var fb=xb.ua;var gb=xb.va;var hb=xb.wa;var ib=xb.xa;var jb=xb.ya;var kb=5713008;var lb=0;var mb=0;var nb=0;
// EMSCRIPTEN_START_FUNCS
function zJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,S=0,V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=C(0),Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=C(0),_a=0;da=kb-32|0;kb=da;e=da+24|0;v[e>>2]=49532;v[e>>2]=49432;g=yJ(da+16|0);h=yJ(da+8|0);fa=b;la=c;ma=e;na=v[g>>2];Ea=w[g+4|0];oa=v[h>>2];Fa=w[h+4|0];c=0;M=kb-112|0;kb=M;d=a;pa=a+24604|0;a=pa;a:{if(!v[a+16>>2]){break a}b=v[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=v[a+28>>2];if(a>>>0>4){break a}c=23>>>a&1}if(!c){c=M+96|0;NM(c,9093,12922,220,45);a=kb-48|0;kb=a;b=yc(a+16|0,17718);v[23588]=0;U(5,a|0,1,17381);e=v[23588];v[23588]=0;b:{c:{d:{e:{if((e|0)!=1){v[23588]=0;U(2,a+32|0,b|0,a|0);e=v[23588];v[23588]=0;if((e|0)==1){break e}v[23588]=0;U(843,c|0,1,a+32|0);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;Ab(a+32|0);break d}c=P()|0;O()|0;break c}c=P()|0;O()|0}Ab(a)}Ab(b);T(c|0);L()}Ab(a+32|0);Ab(a);Ab(b);kb=a+48|0}qa=d+8204|0;ra=d+397452|0;sa=d+397448|0;aa=d+393352|0;H=d+397456|0;_=d+12|0;Ga=d+1074376|0;Ha=d+1298420|0;Ia=d+1074365|0;while(1){f:{g:{a=v[d+480208>>2];if(!(!fa|a&512)){h:{if(v[d+1074380>>2]){break h}b=a|512;i:{if(a&256){break i}j=kb-48|0;kb=j;F=kb-32|0;kb=F;k=d+1074312|0;e=d+1074992|0;h=d+1298264|0;s=d+1074424|0;o=d+484360|0;n=d+1074448|0;m=d+1074376|0;b=v[d+1074392>>2];r=d+480188|0;A=d+480180|0;q=d+484376|0;p=d+484348|0;G=d+480210|0;E=d+484364|0;j:{k:{l:while(1){m:{a=b+1|0;v[d+1074392>>2]=a;if(jl(m)>>>0>a>>>0){break m}cO(F+24|0,v[A>>2],x[r>>1],m,(v[d+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(w[d+480208|0]&32){l=v[p>>2];c=v[d+484344>>2];b=x[d+1074446>>1];break r}b=65535;J=v[d+484360>>2];i=w[q|0];a=Wb(J,i);c=v[a>>2];a=Rc(c,v[a+4>>2]);f=x[d+1074448>>1];if(a>>>0>f>>>0){b=x[dc(c,f)>>1]}u[d+1074446>>1]=b;s:{t:{c=v[d+484344>>2];l=v[p>>2];a=b&65535;if(Bf(c,l)>>>0<=a>>>0){break t}a=Zb(c,a);if(Pb(v[a>>2],v[a+4>>2])){break t}a=0;break s}a=1}while(1){u:{v:{if(!a){b=65534;u[d+1074446>>1]=65534;break v}w:{x:{y:{a=b&65535;if(Bf(c,l)>>>0<=a>>>0){z:{A:{if((a|0)==65535){g=Wb(J,i);break A}g=Wb(J,i);if(Rc(v[g>>2],v[g+4>>2])>>>0>(f&65535)>>>0){break z}}b=x[g+28>>1];if(b){c=v[g>>2];l=Rc(c,v[g+4>>2]);break x}a=f&65535;c=v[g>>2];l=Rc(c,v[g+4>>2]);if(!a|l>>>0<a>>>0){break y}while(1){b=a;a=a-1|0;if(!a){break y}if(x[dc(c,a)>>1]!=65535){continue}break}break x}f=f+1|0;u[n>>1]=f;break w}u[d+1074450>>1]=f;break r}b=0}u[d+1074448>>1]=b;v[d+480208>>2]=v[d+480208>>2]&-524289;while(1){a=b&65535;if(a>>>0>=l>>>0){break q}if(x[dc(c,a)>>1]==65534){b=b+1|0;u[n>>1]=b;continue}break}if(!Hq(g,a)){break q}f=x[d+1074448>>1];J=v[d+484360>>2];i=w[q|0];g=Wb(J,i)}b=65535;a=f&65535;if(Rc(v[g>>2],v[g+4>>2])>>>0>a>>>0){b=x[dc(v[Wb(J,i)>>2],a)>>1]}u[d+1074446>>1]=b;c=v[d+484344>>2];l=v[p>>2];a=b&65535;if(Bf(c,l)>>>0<=a>>>0){break v}a=Zb(c,a);if(!Pb(v[a>>2],v[a+4>>2])){break u}}a=1;continue}a=0;continue}}a=b&65535;if(!ye(c,l,a)){break k}b=v[s>>2];if(b>>>0>=y[Zb(c,a)+12>>2]){v[s>>2]=0;b=0}if(v[d+480208>>2]&32?v[d+480272>>2]!=-1:0){break n}if(!tt(h,x[n>>1],b,Vp(F+16|0,e),w[F+24|0])){break n}a=v[d+480272>>2];if(a){if((a|0)>0){v[d+480272>>2]=a-1}ao(h,1);tt(h,x[n>>1],v[s>>2],Vp(F+16|0,e),w[F+24|0]);break n}if(!(w[G|0]&64)){break q}b=0;if(oO(h,n,s)){break o}v[d+1074424>>2]=0;v[d+1074428>>2]=0;v[d+1074448>>2]=0;c=sj(v[d+484360>>2],v[E>>2])-1|0;a=w[q|0];if((c|0)>(a|0)){break p}Gj(o,0)}ao(h,1);break k}Gj(o,a+1&255);ao(h,1)}while(1){if((b|0)==256){DM(d);v[d+1074416>>2]=v[d+480196>>2];v[d+1074420>>2]=v[d+480204>>2];v[d+1074456>>2]=v[d+480200>>2];a=x[d+1074448>>1];u[d+1074450>>1]=a;b=v[d+1074424>>2];v[d+1074428>>2]=b;c=Wb(v[d+484360>>2],w[q|0]);g=v[c>>2];if(Rc(g,v[c+4>>2])>>>0>a>>>0){Xa=d,Ya=x[dc(g,a)>>1],u[Xa+1074446>>1]=Ya}tt(h,a,b,Vp(F+16|0,e),w[F+24|0]);if(!ye(v[d+484344>>2],v[p>>2],x[d+1074446>>1])){break k}}else{fo((B(b,872)+d|0)+1074992|0,d,b&65535,134217728);b=b+1|0;continue}break}}bO(d,m,(v[d+480208>>2]&32)>>>5|0);a=Zb(v[d+484344>>2],x[d+1074446>>1]);a=jd(v[a>>2],v[v[a+48>>2]+12>>2],v[d+1074424>>2],0);g=e+B(x[r>>1],872)|0;b=e;while(1){if((b|0)==(g|0)){B:{C:{a=v[d+484344>>2];b=x[d+1074446>>1];if(Rm(a,v[d+484348>>2],b)){a=Zb(a,b);b=v[a+16>>2];a=v[a+20>>2];if(_N(b,a)){break C}}v[d+1074408>>2]=v[d+480216>>2];a=v[d+480220>>2];break B}v[d+1074408>>2]=b}v[d+1074412>>2]=a;if(!w[F+24|0]){break m}b=v[d+1074416>>2];v[d+1074392>>2]=b;continue l}Db(F+16|0,k,82);D:{if(!Cb(v[v[F+16>>2]>>2],v[F+20>>2])|w[b+805|0]!=1){break D}c=w[a+3|0];if((c|0)!=2&(c|0)!=3){break D}Xa=b,Ya=fh(d,w[b+800|0],u[b+772>>1],v[b+704>>2]),v[Xa+700>>2]=Ya}Db(F+16|0,k,91);E:{if(!Cb(v[v[F+16>>2]>>2],v[F+20>>2])){break E}if($c(w[a|0])){break E}c=w[b+788|0];if(!$c(c)|w[b+791|0]!=19){break E}f=w[b+793|0];if((f&240)!=208|y[d+1074416>>2]>(f&15)>>>0){break E}Xa=b,Ya=fh(d,c,u[b+772>>1],0),v[Xa+700>>2]=Ya}Db(F+16|0,k,92);F:{if(!Cb(v[v[F+16>>2]>>2],v[F+20>>2])){break F}Db(F+8|0,k,5);if(Cb(v[v[F+8>>2]>>2],v[F+12>>2])|v[d+1074416>>2]!=1|w[b+791|0]!=17){break F}v[d+1074420>>2]=B(w[b+793|0],1e4)}c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+788|0]=c;t[b+789|0]=c>>>8;t[b+790|0]=c>>>16;t[b+791|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[b+792|0]=c;t[b+793|0]=c>>>8;c=v[b+676>>2];v[b+20>>2]=v[b+672>>2];v[b+24>>2]=c;v[b+88>>2]=v[b+88>>2]&-393217;Db(F+16|0,k,21);if(!Cb(v[v[F+16>>2]>>2],v[F+20>>2])){t[b+831|0]=0}v[b+860>>2]=0;t[b+805|0]=0;a=a+6|0;b=b+872|0;continue}}break}a=v[d+1074416>>2];if(!a){v[d+1074416>>2]=1;a=1}b=v[d+480208>>2];e=v[d+1074392>>2];G:{H:{if(e){c=b&-4097;v[d+480208>>2]=c;g=v[d+480180>>2];if(g&1048580|(b&2097152?0:(g|0)==1)){break G}if(jl(m)>>>0<=e>>>0){break G}if(!((e>>>0)%(v[d+1074400>>2]+a>>>0)|0)){break H}break G}c=b&-528385}v[d+480208>>2]=c|4096}q=0;i=kb-16|0;kb=i;u[d+1074444>>1]=65535;a=d+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;A=d+480180|0;$=d+1075809|0;o=d+1074312|0;Z=d+906300|0;G=d+480208|0;I=d+1074376|0;Y=d+480188|0;ba=d+480210|0;V=d+480190|0;Q=d+480192|0;while(1){I:{if(x[Y>>1]<=q>>>0){J:{if(!(w[G+1|0]&16)){break J}if(!TN(d,I,Wb(v[d+484360>>2],w[d+484376|0]),1)){break J}v[G>>2]=v[G>>2]|524288}kb=i+16|0;break I}p=B(q,872)+d|0;k=p+1075785|0;c=w[k|0];l=p+1075784|0;r=w[l|0];R=p+1075781|0;e=w[R|0];a=v[d+1074392>>2];b=v[d+1074400>>2];h=v[d+1074416>>2];X=p+1075782|0;f=w[X|0];s=p+1075783|0;J=w[s|0];g=wm(f,J);n=p+1075843|0;t[n|0]=v[G>>2]>>>12&1|w[n|0]&254;h=(a>>>0)%(b+h>>>0)|0;N=p+1075780|0;a=w[N|0];K:{L:{M:{if((a|0)==252){m=hk(f,r);E=hk(J,c);a=252;b=e-1|0;if((b&255)>>>0>249){break M}b=v[Md(Z,b)>>2];if(!b){break M}ob[v[v[b>>2]+44>>2]](b,m,C(C(E>>>0)/C(999)));a=w[N|0]}if((a&255)==251){break L}}if(z[p+1075852>>2]==C(0)|J){break K}}m=v[G>>2]&4096;N:{if(!m){b=w[p+1075862|0];break N}b=w[R|0];t[p+1075862|0]=b}if((b-1&255)>>>0>249){break K}E=Md(Z,(b&255)-1|0);b=v[E>>2];if(!b){break K}O:{if(!m){a=x[p+1075860>>1];break O}a=Vy(w[X|0],w[l|0]);u[p+1075860>>1]=a;W=C(C(Vy(w[s|0],w[k|0])>>>0)/C(999));z[p+1075856>>2]=W;Xa=p+1075852|0,Za=C(C(W-C(ob[v[v[b>>2]+48>>2]](b,a)))/C(jl(I)>>>0)),z[Xa>>2]=Za;b=v[E>>2]}k=a;a=(v[d+1074392>>2]+1|0)==(jl(I)|0);ob[v[v[b>>2]+(a?44:108)>>2]](b,k,z[(a?p+1075856|0:p+1075852|0)>>2]);a=w[N|0]}k=p+1074992|0;if(IN(a&255)){b=kb-16|0;kb=b;u[b+12>>1]=0;v[b+8>>2]=0;a=ug(b+8|0);c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[k+788|0]=c;t[k+789|0]=c>>>8;t[k+790|0]=c>>>16;t[k+791|0]=c>>>24;a=w[a+4|0]|w[a+5|0]<<8;t[k+792|0]=a;t[k+793|0]=a>>>8;kb=b+16|0;g=0;J=0;r=0;f=0;e=0;c=0}P:{if(!(w[G+1|0]&16)){iN(d,k);break P}if(!e){break P}v[p+1075752>>2]=0}Q:{R:{if((J|0)==33){Db(i+8|0,o,30);a=c>>>4|0;Gy(d,q&65535,a+(c&15)|0,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));break R}a=0;if((J-19&255)>>>0>1){break R}S:{if(!(!(v[A>>2]&16777250)|c)){c=w[p+1075825|0];break S}t[p+1075825|0]=c}b=c&240;if((b|0)==208){b=c&15;if(!b){b=v[A>>2];if(b&16777248){a=1;break R}if((b|0)==2){break Q}break R}if(b>>>0>=v[d+1074400>>2]+v[d+1074416>>2]>>>0){Db(i+8|0,o,14);a=b;if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break R}if(!e){break Q}t[p+1075795|0]=e;break Q}a=b;break R}if(!(w[G+1|0]&16)|(b|0)!=224){break R}b=v[A>>2];if(v[d+1074396>>2]?b&16777250:0){break R}m=b&2;b=c&15;if(b?0:m){break R}v[d+1074396>>2]=b+1}b=v[A>>2]==16&(J|0)==19&(c&240)==208;E=b?0:a;T:{if(!E|w[N|0]!=255|w[X|0]!=2){break T}Db(i+8|0,o,74);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break T}t[X|0]=0}K=c&15;a=v[d+1074392>>2];Db(i+8|0,o,72);U:{if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){s=0;if(E>>>0>=y[d+1074416>>2]){break U}}Db(i+8|0,o,88);s=(h|0)==(E|0)|(a|0)==(E|0);if(!(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!E)){break U}s=(a|0)==(E|0)}Db(i+8|0,o,44);b=b?K|144:c;V:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){a=w[n|0];break V}a=w[n|0]&-2|(h|0)==(E|0)}t[n|0]=a&253|(s?2:0);Db(i+8|0,o,66);g=(!E|Cb(v[v[i+8>>2]>>2],v[i+12>>2])^1)&g;W:{X:{if(!(v[d+1074392>>2]|(!(w[ba|0]&32)|!e))){v[p+1075652>>2]=0;if(s){break X}if(!yi(v[k+8>>2],v[k+12>>2])){break W}t[p+1075795|0]=e;if(x[V>>1]<e>>>0){break W}a=B(e,104)+d|0;v[p+1075680>>2]=x[a+484410>>1];u[p+1075764>>1]=t[a+484417|0];break W}if(!s){break W}}c=w[N|0];if(e){t[p+1075795|0]=e}Y:{Z:{if(!$c(c)){break Z}Db(i+8|0,o,67);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Z}a=u[p+1075762>>1];_:{if(!e|g){break _}h=vq(d,c,e);if(!h){break _}a=t[Hi(d,h)+36|0]}c=(a+c|0)-132>>>0<4294967176?0:c;break Y}if(!(v[A>>2]&25165856)){break Y}l=x[Q>>1];if(!l){break Y}if(c){a=$c(c)}else{a=1}if(!a){break Y}h=e;$:{if(!e){h=w[p+1075796|0];if(!h){break $}}if(v[((h<<2)+d|0)+900380>>2]?h>>>0<=l>>>0:0){break Y}c=0}e=0}if(!((J|0)!=25|b)){Db(i+8|0,o,55);a=Cb(v[v[i+8>>2]>>2],v[i+12>>2]);e=a?0:e;c=a?0:c}Db(i+8|0,o,65);a=(e|0)!=0;l=Cb(v[v[i+8>>2]>>2],v[i+12>>2]);ca=!c;S=1;aa:{if(v[A>>2]&16777248){break aa}Db(i+8|0,o,107);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break aa}Db(i,o,85);S=0;if(!Cb(v[v[i>>2]>>2],v[i+4>>2])){break aa}if(yi(v[k+8>>2],v[k+12>>2])){break aa}S=1;h=v[p+1075096>>2];if(!h){break aa}S=_d(v[h>>2],v[h+20>>2])^1}m=a&l;a=a&ca;ba:{ca:{da:{ea:{fa:{ga:{ha:{if(!(v[A>>2]&1048580)){break ha}ia:{if((c|0)!=255){break ia}if(!(!((f|0)==1|e)&(J|0)!=13)){Db(i+8|0,o,55);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break ia}}h=v[p+1075648>>2];if(t[h+60|0]&1?h:0){break ia}v[p+1075680>>2]=0;a=p+1075080|0;v[a>>2]=v[a>>2]|2097152;ja:{if(!(v[G>>2]&4096)){break ja}Db(i+8|0,o,86);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break ja}v[a>>2]=v[a>>2]|4096}e=0;c=0;a=0;h=0;l=1;if(m){break ca}break ba}Db(i+8|0,o,59);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|v[G>>2]&4096){break ha}if(!c){c=w[p+1075789|0]-w[p+1075762|0]|0;break ga}if(c>>>0>250){S=0;m=1;c=0;break ga}if(!e){Db(i+8|0,o,98);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break ga}}S=1;m=1;break ga}h=0;if(!a){break ea}break fa}h=c;g=0}Db(i+8|0,o,65);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break da}c=h;h=1}a=c;l=1;if(m){break ca}break ba}c=h;h=1;l=m}ka:{la:{if(!x[Q>>1]){if(x[V>>1]<e>>>0){break ka}a=(B(e,104)+d|0)+484380|0;break la}a=v[p+1075096>>2];if(!a){break ka}}ma:{if(u[a+34>>1]<0){break ma}if(v[A>>2]==2){if(!_d(v[a>>2],v[a+20>>2])){break ma}}v[p+1075680>>2]=x[a+30>>1]}if(!l){break ka}bq(k,x[a+28>>1],d)}a=c}Db(i+8|0,o,71);if(!(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!e)){t[p+1075831|0]=32}na:{if(!x[Q>>1]){break na}Db(i+8|0,o,100);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!e){break na}if($c(a&255)){break na}c=v[G>>2];oa:{if(g){if(c&8){break oa}break na}if(!(c&4)){break na}}um(k);v[p+1075688>>2]=65536;c=p+1075080|0;v[c>>2]=v[c>>2]|2097152}if(h){Db(i+8|0,o,11);pa:{qa:{ra:{if(!(Cb(v[v[i+8>>2]>>2],v[i+12>>2])|v[A>>2]==268435456)){c=x[Q>>1];break ra}Db(i+8|0,o,87);h=0;if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){h=yi(v[k+8>>2],v[k+12>>2])^1}c=x[Q>>1];sa:{if(c){if(c>>>0<e>>>0){break qa}if(v[p+1075648>>2]!=v[((e<<2)+d|0)+900380>>2]|h){break sa}break qa}if((h^-1)&v[p+1075096>>2]==((B(e,104)+d|0)+484380|0)){break pa}}a=w[p+1075789|0]}if(!(c&65535)){break pa}}if(!(v[A>>2]&1048588)){break pa}um(k);t[p+1075810|0]=0;v[p+1075748>>2]=0;v[p+1075688>>2]=65536;c=p+1075080|0;v[c>>2]=v[c>>2]&-2101249|2097152;Db(i+8|0,o,86);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break pa}v[c>>2]=v[c>>2]&-2049}e=S?e:0}l=a&255;ta:{if(l>>>0<251){break ta}Db(i+8|0,o,50);ua:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!e){break ua}c=vq(d,w[p+1075791|0],e);if(!c){break ua}c=B(c,104)+d|0;if(u[c+484414>>1]<0){break ua}v[p+1075680>>2]=x[c+484410>>1]}Db(i+8|0,o,100);if(Xa=Cb(v[v[i+8>>2]>>2],v[i+12>>2]),Ya=0,_a=v[G>>2]&4,_a?Xa:Ya){break ta}e=0}c=$c(l);if(c){t[p+1075794|0]=a;t[p+1075791|0]=a;if(!g){jN(d,q&65535,e,l,0)}zP(k)}va:{wa:{xa:{ya:{za:{if(e){h=p+1075096|0;m=v[h>>2];Up(d,k,e,g,1,1);a=v[h>>2];Aa:{if(!a|!(w[a+35|0]&2)){break Aa}S=v[d+1298300>>2];if(!Fd(S)){break Aa}qz(S,q&65535,a+68|0)}Ba:{Ca:{if(v[A>>2]==1){if(!g){break Ca}Db(i+8|0,o,85);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ca}break Ba}Db(i+8|0,o,50);if((c|Cb(v[v[i+8>>2]>>2],v[i+12>>2])^1)!=1){break Ba}}t[p+1075795|0]=0}Db(i+8|0,o,42);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!c|(m|0)==v[h>>2]){break ya}break za}if(v[A>>2]&16777248){a=0;if(c&(m|0)!=v[h>>2]){break xa}}Db(i+8|0,o,107);Da:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|((m|0)==v[h>>2]|(c^1|g)!=1)){break Da}a=p+1075068|0;if(y[a>>2]>=y[k+4>>2]){break Da}v[a>>2]=0;break ya}Db(i+8|0,o,85);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break ya}if(!yi(v[k+8>>2],v[k+12>>2])){break za}break ya}if(!l){a=g;break va}h=0;m=p+1075795|0;a=w[m|0];if(!(!a|c^1)){Up(d,k,a,g,!(v[p+1075096>>2]?1:v[p+1075648>>2]),!(v[A>>2]&1048580));t[m|0]=0;h=1}a=g;break wa}v[k>>2]=0;v[k+4>>2]=0}a=g}h=0;if(!l){break va}}c=v[p+1075096>>2];Ea:{if(!c|!(w[c+35|0]&2)){break Ea}g=v[d+1298300>>2];if(!Fd(g)){break Ea}if(!h){if(kN(g,q&65535)){break Ea}}qz(g,q&65535,c+68|0)}c=q&65535;ot(d,k,l,a,!(v[A>>2]&1048580),0,c);YN(v[A>>2],x[Y>>1],I,c);if(!(!a|(!(v[A>>2]&1048580)|!e))){e=p+1075080|0;v[e>>2]=v[e>>2]|2097152;um(k);t[p+1075810|0]=0;v[p+1075748>>2]=0}if(!(v[p+1075080>>2]&512)){break va}if(!Fd(v[d+1298300>>2])){break va}if(l>>>0<=253){if((l|0)!=253){break va}Db(i+8|0,o,99);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break va}}Db(i+8|0,o,110);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){rz(v[d+1298300>>2],c,0,1,0)}ik(v[d+1298300>>2],c)}Fa:{Ga:{switch(f-1|0){case 0:r=r>>>0<64?r:64;v[p+1075680>>2]=r<<2;c=p+1075080|0;v[c>>2]=v[c>>2]|2097152;break Fa;case 1:break Ga;default:break Fa}}vm(d,k,r,6)}if(x[Q>>1]){hN(d,q&65535)}g=a}Db(i+8|0,o,77);if(Xa=Cb(v[v[i+8>>2]>>2],v[i+12>>2]),Ya=0,_a=v[((q<<5)+d|0)+480280>>2]&1024,_a?Xa:Ya){break Q}a=v[d+1074392>>2];Db(i+8|0,o,75);e=a>>>0>=E>>>0;Ha:{Ia:{Ja:{Ka:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!E){break Ka}c=v[d+1074392>>2];if(!c){break Ja}e=1;if((c|0)!=(E|0)){break Ka}e=!w[R|0]&(f|0)!=11}a=f;if(!e|a>>>0<3){break Ja}if((a|0)==11){a=i+8|0;Zy(a,d,w[N+3|0],w[N+4|0],E);a=w[Te(a)|0];Fy(d,q&65535,x[i+8>>1]);if(a){break Ia}f=11;break Ja}Db(i+8|0,o,62);La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{if(!(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|r)){r=0;f=0;Sa:{switch(a-8|0){case 0:break Ra;case 1:break Sa;default:break Ja}}if(w[G+1|0]&16){break Ja}v[p+1075684>>2]=0;break Ja}Db(i+8|0,o,41);Ta:{if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ta}if(r){t[p+1075826|0]=r;break Ta}r=w[p+1075826|0]}Ua:{switch(a-3|0){case 0:case 1:Va:{Wa:{if(r){break Wa}Db(i+8|0,o,41);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Wa}r=w[p+1075826|0];if(r){break Va}r=0;break Ja}t[p+1075826|0]=r}Zn(d,k,((a|0)==3?r<<4:r)&255);break Ja;case 2:if((E|0)!=v[d+1074392>>2]){Db(i+8|0,o,41);f=5;if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ja}}Db(i+8|0,o,41);Yn(d,k,r,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));f=5;break Ja;case 3:if((E|0)!=v[d+1074392>>2]){Db(i+8|0,o,41);f=6;if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ja}}Db(i+8|0,o,41);Xn(d,k,r,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));f=6;break Ja;case 11:break La;case 12:break Ma;case 10:break Na;case 9:break Oa;case 7:break Pa;case 6:break Qa;case 5:break Ra;case 4:break Ua;default:break Ja}}Db(i+8|0,o,53);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){t[p+1075815|0]=r&15;f=7;break Ja}il(k,r<<4);f=7;break Ja}il(k,r);f=8;break Ja}Db(i+8|0,o,62);Ey(d,k,r,Cb(v[v[i+8>>2]>>2],v[i+12>>2])^1);f=9;break Ja}Db(i+8|0,o,62);Ey(d,k,r<<4&240,Cb(v[v[i+8>>2]>>2],v[i+12>>2])^1);f=10;break Ja}f=12;Db(i+8|0,o,12);gN(d,q&65535,r<<2&252,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));break Ja}Db(i+8|0,o,12);fN(d,q&65535,r<<2&252,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));f=13;break Ja}f=15;if(!s){break Ja}a=v[p+1075096>>2];if(!a|r>>>0>9){break Ja}Xa:{if(!r){e=v[p+1075656>>2];break Xa}e=v[Eb(a+68|0,r-1|0)>>2];v[p+1075656>>2]=e}_n(d,k,e);break Ja}f=14;if(r>>>0>1){break Ja}t[n|0]=w[n|0]&247|!r<<3}e=b;Ya:{Za:{_a:{switch(J-1|0){case 12:if(!(w[G+1|0]&16)){break Ia}a=B(q,872)+d|0;v[a+1075680>>2]=b>>>0<64?b<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ia;case 1:if(!b){e=0;if(t[A|0]&1){break Ha}}gN(d,q&65535,b,0);break Ia;case 2:if(!b){e=0;if(t[A|0]&1){break Ha}}fN(d,q&65535,b,0);break Ia;case 10:if(!b){e=0;if(v[A>>2]==1){break Ha}}Zn(d,k,b);break Ia;case 3:Fy(d,q&65535,b);break Ia;case 5:if(!(!b&v[A>>2]==1)){Zn(d,k,b)}Fy(d,q&65535,0);break Ia;case 4:il(k,b);break Ia;case 6:if(!(!b&v[A>>2]==1)){Zn(d,k,b)}il(k,0);break Ia;case 15:if(!(w[G+1|0]&16)){break Ia}break Ya;case 16:Db(i+8|0,o,5);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!(w[G+1|0]&16)|!b){break Ia}break Ya}e=Wn(d,x[d+1074446>>1],v[d+1074424>>2],q&65535,0);$a:{if(!(v[d+480180>>2]&16777250)){break $a}if(e){t[(B(q,872)+d|0)+1075827|0]=e;break $a}e=w[(B(q,872)+d|0)+1075827|0]}v[i+8>>2]=B(e,1e4);xc(i+8|0,B(v[v[d+8>>2]+24>>2],1e4));a=kb-16|0;kb=a;c=v[i+8>>2];v[a+8>>2]=c;b=v[d+8>>2];ab:{if(c>>>0>=(v[d+480180>>2]&16393?1e4:32e4)>>>0){c=v[d+480208>>2];Db(a,d+1074312|0,92);if((Cb(v[v[a>>2]>>2],v[a+4>>2])|0)==((c&4096)>>>12|0)){break ab}v[a>>2]=B(v[b+24>>2],1e4);Xa=d+1074420|0,Ya=v[Kb(a+8|0,a)>>2],v[Xa>>2]=Ya;break ab}if(w[d+480209|0]&16){break ab}g=d+1074420|0;c=(c>>>0)/1e4|0;h=B(c&15,1e4);v[g>>2]=v[g>>2]+((c&240)==16?h:0-h|0);c=v[b+20>>2];b=v[b+24>>2];Db(a,d+1074312|0,8);Qo(g,B(c,1e4),Cb(v[v[a>>2]>>2],v[a+4>>2])?255e4:B(b,1e4))}kb=a+16|0;break Ha;case 9:if(!s|v[A>>2]==4&g){break Ia}XN(d,k,q&65535,v[d+1074424>>2],x[d+1074446>>1]);break Ia;case 43:if(!s){break Ia}c=Oka(v[(B(q,872)+d|0)+1075068>>2],0,b,0);a=nb;f=a>>>8|0;_n(d,k,Ec((a&255)<<24|c>>>8,f));break Ia;case 0:if(v[d+1074392>>2]){break Ia}a=B(q,872)+d|0;bb:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break bb}a=v[a+1075648>>2];if(a){if(vj(w[a+31|0])){break bb}}Db(i+8|0,o,13);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break bb}if(v[A>>2]&16777248){break Ia}}if(!b){e=0;if(w[A|0]&5){break Ha}t[(B(q,872)+d|0)+1075797|0]=1;break Ha}a=B(q,872)+d|0;t[a+1075798|0]=b;t[a+1075797|0]=1;break Ia;case 14:if(v[A>>2]&1048580){b=b&240?b:w[(B(q,872)+d|0)+1075799|0]&240|b;if(!(b&15)){b=w[(B(q,872)+d|0)+1075799|0]&15|b}b=b|256}e=b;Db(i+8|0,o,23);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){b=d;c=q&65535;if(e){t[(B(q,872)+d|0)+1075799|0]=e;a=e}else{a=w[(B(q,872)+d|0)+1075799|0]}Dy(b,c,a&255,(f|0)==15?r+1|0:0);break Ha}cb:{if(e){t[(B(q,872)+d|0)+1075799|0]=e;break cb}e=w[(B(q,872)+d|0)+1075799|0]}Dy(d,q&65535,e,(f|0)==15?r+1|0:0);break Ha;case 17:if(!(w[G+1|0]&16)){break Ia}Db(i+8|0,o,22);db:{eb:{if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!b){b=0;break eb}if(w[G|0]&4){break eb}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;t[(B(q,872)+d|0)+1075832|0]=b;break eb}Db(i+8|0,o,71);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break db}}a=(B(q,872)+d|0)+1075831|0;t[a|0]=w[a|0]|128}a=B(q,872)+d|0;t[a+1075797|0]=18;if(!b){e=0;break Ha}t[a+1075832|0]=b;break Ia;case 22:if(!(w[G+1|0]&16)){break Ia}a=v[A>>2];e=b<<!(a&59593760);if(e>>>0<=128){v[d+1074456>>2]=e<<1;break Ha}if(a&16777250){break Ha}v[d+1074456>>2]=256;break Ha;case 23:Db(i+8|0,o,9);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){eN(d,b,(B(q,872)+d|0)+1075809|0);break Ia}eN(d,b,$);break Ia;case 8:if(!(w[G+1|0]&16)){break Ia}vm(d,k,b,8);break Ia;case 28:Ey(d,k,b,1);break Ia;case 7:PN(k,b);break Ia;case 25:QN(d,k,b);break Ia;case 18:e=kb-16|0;kb=e;h=d+1074376|0;a=q&65535;g=B(a,872);c=(h+g|0)+616|0;f=b&15;fb:{gb:{switch(b>>>4|0){case 0:a=(b&1)<<14;c=x[d+480188>>1];g=0;while(1){if((c|0)==(g|0)){break fb}h=(B(g,872)+d|0)+1075080|0;v[h>>2]=(a|v[h>>2]&-16385)^16384;g=g+1|0;continue};case 1:if(!f){f=0;if(!(v[d+480180>>2]&1048580)){break fb}}Ry(d,c,f);Db(e+8|0,d+1074312|0,117);if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break fb}Qn(d,a,b|240,1);break fb;case 2:if(!f){f=0;if(!(v[d+480180>>2]&1048580)){break fb}}Qy(d,c,f);Db(e+8|0,d+1074312|0,117);if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break fb}Qn(d,a,0-(b|240)|0,1);break fb;case 3:a=(d+g|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((f|0)!=0)<<20;break fb;case 4:t[(d+g|0)+1075814|0]=b&7;break fb;case 5:if(!(w[d+480209|0]&16)){break fb}g=v[d+480180>>2];if(g&69206025){c=B(a,872)+d|0;u[c+1075764>>1]=f<<28>>24;g=c+1075692|0;if(!v[g>>2]){break fb}if(!$c(w[c+1075780|0])){break fb}a=B(a,872)+d|0;Xa=g,Ya=fh(d,w[a+1075789|0],f<<28>>24,v[a+1075696>>2]),v[Xa>>2]=Ya;break fb}c=$c(w[(B(a,872)+d|0)+1075780|0]);if((g|0)==16){if(!c){break fb}c=B(a,872)+d|0;g=v[c+1075096>>2];if(!g){break fb}t[g+37|0]=f;u[c+1075764>>1]=f;c=c+1075692|0;if(!v[c>>2]){break fb}a=B(a,872)+d|0;Xa=c,Ya=fh(d,w[a+1075789|0],f,v[a+1075696>>2]),v[Xa>>2]=Ya;break fb}if(!c){break fb}a=B(a,872)+d|0;c=(b<<4^-128)<<24>>24;u[a+1075764>>1]=c;g=a+1075692|0;if(!v[g>>2]){break fb}Xa=g,Ya=fh(d,w[a+1075789|0],c,v[a+1075696>>2]),v[Xa>>2]=Ya;break fb;case 6:if(!(w[d+480209|0]&16)){break fb}Yy(d,h,c,f);break fb;case 7:t[(d+g|0)+1075817|0]=b&7;break fb;case 8:if(!(w[d+480209|0]&16)){break fb}vm(d,c,f,4);break fb;case 9:Dy(d,a,f,0);break fb;case 10:if(f){Yn(d,c,f,0);break fb}if(!(v[d+480180>>2]&1048580)){break fb}Yn(d,c,0,0);break fb;case 11:if(f){Xn(d,c,f,0);break fb}if(!(v[d+480180>>2]&1048580)){break fb}Xn(d,c,0,0);break fb;case 12:Gy(d,a,f,0);break fb;case 15:break gb;default:break fb}}if(v[d+480180>>2]==1){t[(B(a,872)+d|0)+1075838|0]=f;if(!(w[d+480209|0]&16)){break fb}iN(d,c);break fb}t[(B(a,872)+d|0)+1075836|0]=f}kb=e+16|0;break Ia;case 19:dN(d,q&65535,b);break Ia;case 24:Db(i+8|0,o,55);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){if(v[d+1074392>>2]!=(b|0)){break Ia}a=v[(B(q,872)+d|0)+1075648>>2];if(t[a+60|0]&1?a:0){break Za}if(!(!(w[X|0]?1:w[R|0])|b)){a=(B(q,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break Za}a=B(q,872)+d|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Za}if(!(w[G+1|0]&16)){break Ia}break Za;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Ia}if(!(1<<a&880)){if(a){if((a|0)!=1){break Ia}Py(d,k,K);Db(i+8|0,o,117);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ia}Qn(d,q&65535,-224-K|0,1);break Ia}Sy(d,k,K);Db(i+8|0,o,117);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ia}Qn(d,q&65535,K|224,1);break Ia}Db(i+8|0,o,58);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ia}dN(d,q&65535,b);break Ia;case 34:case 35:if(!(w[G+1|0]&16)&(J|0)!=36){break Ia}c=q&65535;UN(d,c,I,(J|0)==36);a=Pp(d,v[k+88>>2],v[k+656>>2]);if(!a){break Ia}ob[v[v[a>>2]+80>>2]](a,(x[k+774>>1]&65532)>>>2^8192,c);break Ia;case 20:if(!(w[G+1|0]&16)|b>>>0>64){break Ia}a=B(q,872)+d|0;v[a+1075740>>2]=b;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ia;case 21:f=v[A>>2];e=v[G>>2];a=b;hb:{if(a){t[k+816|0]=a;break hb}a=w[k+816|0]}g=a&255;h=a&240;c=a&15;ib:{jb:{if(!(!h|(c|0)!=15)){if(!(e&4096)){break ib}a=g>>>4|0;break jb}e=e&4096;if(!(!c|(h|0)!=240)){if(!e){break ib}a=0-c|0;break jb}if(e){break ib}if(c){a=0-c|0;if(!(f&25690144)|!h){break jb}break ib}if((a&255)>>>0<16){break ib}a=g>>>4|0}Xa=k,Ya=Yb(a+v[k+748>>2]|0,0,64),v[Xa+748>>2]=Ya}break Ia;case 26:NN(k,b);break Ia;case 29:if(!(w[G+1|0]&16)){break Ia}a=B(q,872)+d|0;v[a+1075716>>2]=b;Db(i+8|0,o,60);if(Xa=0,Ya=Cb(v[v[i+8>>2]>>2],v[i+12>>2]),_a=w[a+1075722|0]&4,_a?Xa:Ya){break Ia}a=B(q,872)+d|0;v[a+1075732>>2]=b;v[a+1075724>>2]=b;break Ia;case 11:SN(d,I,q&65535);break Ia;case 13:a=RN(d,I,q&65535,b);if((a|0)==-1){break Ia}v[d+1074436>>2]=a;if(!(w[d+480208|0]&32)){break Ia}u[d+1074444>>1]=x[d+1074448>>1];break Ia;case 37:case 38:case 39:case 40:EN(d,k,b,(J|0)==38|(J|0)==40,(J&254)==40);break Ia;case 41:WN(k,b);break Ia;case 42:if(v[d+1074392>>2]|K>>>0>1|b>>>0>47){break Ia}a=(b&240)==16;g=a?x[d+480188>>1]-1|0:q;e=a?0:q;a=((K|0)==1)<<26;while(1){c=e&65535;if(c>>>0>(g&65535)>>>0){break Ia}h=((c<<5)+d|0)+480280|0;v[h>>2]=a|v[h>>2]&-67108865;c=(B(c,872)+d|0)+1075080|0;v[c>>2]=a|v[c>>2]&-67108865;e=e+1|0;continue};case 44:break _a;default:break Ha}}VN(k,b);break Ia}Vn(d,k);break Ia}$N(d,I,b)}e=b}Db(i+8|0,o,78);if(!(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!e)){KN(k,e&255)}a=w[R|0];if(!a){break Q}t[p+1075796|0]=a}q=q+1|0;continue}break}a=1;break j}a=0}kb=F+32|0;N=!v[d+1074420>>2]|a^1;kb:{if(N){break kb}a=ZN(d,d+1074376|0);v[d+1074380>>2]=a;v[d+1074404>>2]=a;b=Dd(x[d+480188>>1],1,31);lb:{if(Qd(w[d+1074366|0])){a=v[d+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}s=((B(v[d+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+32160|0]|0;break lb}s=v[d+480228>>2]}u[d+480212>>1]=0;o=d+1074312|0;S=d+1074365|0;F=d+480180|0;I=d+480210|0;K=d+480209|0;R=d+1074366|0;X=d+1074364|0;Z=d+1074360|0;q=0;while(1){if((q|0)==256){b=v[d+24608>>2];g=x[d+480212>>1];if(b>>>0>g>>>0){break kb}e=kb-16|0;kb=e;v[e+8>>2]=d;a=d+1074478|0;c=a;g=a+(g<<1)|0;mb:{a=a+(b<<1)|0;if((c|0)==(a|0)){break mb}nb:{b=a-c|0;if((b|0)<3){break nb}h=b>>1;b=(h-2|0)/2|0;while(1){if((b|0)<0){break nb}ky(c,v[e+8>>2],h,c+(b<<1)|0);b=b-1|0;continue}}h=a-c>>1;b=a;while(1){if((b|0)==(g|0)){b=a-c>>1;while(1){if((b|0)>1){a=a-2|0;ly(c,a);b=b-1|0;ky(c,v[e+8>>2],b,c);continue}break}break mb}if(Kp(v[e+8>>2],x[b>>1],x[c>>1])){ly(b,c);ky(c,v[e+8>>2],h,c)}b=b+2|0;continue}}kb=e+16|0}else{m=B(q,872)+d|0;p=m+1075080|0;ob:{if(!(v[p>>2]&4096)|(v[m+1075016>>2]|(v[m+1075012>>2]|v[m+1075688>>2]))){break ob}Db(j+16|0,o,64);if(Cb(v[v[j+16>>2]>>2],v[j+20>>2])){break ob}v[m+1075068>>2]=0;a=m+1075084|0;v[a>>2]=0;v[a+4>>2]=0}a=x[d+480188>>1];b=v[p>>2];pb:{if(v[m+1075068>>2]|a>>>0>q>>>0?b&1024:1){if(a>>>0>q>>>0){tM(d,q&65535)}u[m+1075834>>1]=0;break pb}c=0;Q=m+1075712|0;v[Q>>2]=0;G=m+1075672|0;v[G>>2]=0;A=m+1075e3|0;e=A;v[e>>2]=0;v[e+4>>2]=0;v[m+1075092>>2]=0;v[j+44>>2]=1065353216;u[j+42>>1]=0;J=m+1075648|0;E=v[J>>2];v[j+36>>2]=0;f=0;l=m+1075692|0;f=v[l>>2]?v[m+1075068>>2]!=0:f;g=m+1074992|0;qb:{rb:{sb:{if(a>>>0<=q>>>0){break sb}if(w[((q<<5)+d|0)+480288|0]){break rb}if(!E){break sb}c=w[E+34|0]!=0}if((c|f)!=1){break qb}}v[j+8>>2]=v[m+1075680>>2];v[j+32>>2]=v[m+1075744>>2];Db(j+16|0,o,28);b=j+8|0;a=Cb(v[v[j+16>>2]>>2],v[j+20>>2])?j+32|0:b;c=kb-16|0;kb=c;e=d+1074312|0;Db(c+8|0,e,28);tb:{if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){v[a>>2]=v[a>>2]+u[g+776>>1];pe(a,0,64);break tb}Db(c+8|0,e,1);e=u[g+776>>1];if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){v[a>>2]=e+v[a>>2];pe(a,0,256);break tb}v[g+688>>2]=e+v[g+688>>2];pe(g+688|0,0,256);v[a>>2]=v[g+688>>2];u[g+776>>1]=0}kb=c+16|0;a=kb-16|0;kb=a;c=d+1074312|0;Db(a+8|0,c,28);ub:{vb:{if(!Cb(v[v[a+8>>2]>>2],v[a+12>>2])){Db(a,c,1);if(!Cb(v[v[a>>2]>>2],v[a+4>>2])){break vb}}v[g+684>>2]=v[g+692>>2]+u[g+778>>1];pe(g+684|0,0,256);break ub}v[g+692>>2]=v[g+692>>2]+u[g+778>>1];pe(g+692|0,0,256);u[g+778>>1]=0;v[g+684>>2]=v[g+692>>2]}kb=a+16|0;e=kb-16|0;kb=e;wb:{if(!(w[g+90|0]&4)|(v[d+480208>>2]&2101248)==2101248){break wb}xb:{if(v[b>>2]<=0){Db(e+8|0,d+1074312|0,21);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break xb}}c=5;if(!(v[d+480180>>2]&5)){Db(e+8|0,d+1074312|0,21);c=Cb(v[v[e+8>>2]>>2],v[e+12>>2])?5:6}a=oy(d,w[g+825|0],w[g+820|0]);yb:{if((w[g+825|0]&3)!=1){break yb}Db(e+8|0,d+1074312|0,89);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break yb}a=w[g+819|0];k=w[g+820|0];h=k<<2&124;a=(!(w[g+90|0]&2)|w[d+480209|0]&16?a:w[g+823|0]+a|0)&32?h^127:h;a=k&32?0-a|0:a}if(v[d+480180>>2]!=131072){a=v[b>>2]+((B(w[g+827|0],a)|0)/(1<<c)|0)|0}else{c=64-a|0;a=v[b>>2];a=((B(w[g+827|0],B(c,a))|0)/-8192|0)+a|0}v[b>>2]=a}a=v[d+480208>>2];if(!(v[d+480180>>2]&16777248)|a&4?a&4096:0){break wb}Db(e+8|0,d+1074312|0,21);a=w[g+826|0];c=w[g+820|0];h=Cb(v[v[e+8>>2]>>2],v[e+12>>2]);t[g+820|0]=(h?a<<2:c)+(h?c:a)}kb=e+16|0;e=q&65535;h=kb-16|0;kb=h;a=d+1074312|0;Db(h+8|0,a,71);zb:{if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])){a=(B(e,872)+d|0)+1075831|0;c=t[a|0];if((c|0)>=0){break zb}if(!(w[d+480209|0]&16|w[(B(e,872)+d|0)+1075797|0]!=18)){k=c&-33;t[a|0]=k;Ab:{Bb:{if((k|0)!=-64){c=c&223;if((c|0)!=128){break Bb}c=w[(B(e,872)+d|0)+1075832|0]>>>4|-64;break Ab}c=w[(B(e,872)+d|0)+1075832|0]&15|-128;break Ab}c=c-1|0}t[a|0]=c;a=(B(e,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|2097152}if((c&224)!=128){break zb}v[b>>2]=0;break zb}if(w[(B(e,872)+d|0)+1075797|0]!=18){break zb}Db(h+8|0,a,22);Cb:{if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])){n=B(e,872)+d|0;a=n+1075831|0;k=w[a|0];c=k<<24>>24;if(!((c|0)>=0|!v[n+1075068>>2])){Db:{Eb:{if((k|0)!=192){if((k|0)!=128){break Eb}c=w[(B(e,872)+d|0)+1075832|0]>>>4|-64;break Db}c=w[(B(e,872)+d|0)+1075832|0]&15|-128;break Db}c=c-1|0}t[a|0]=c}if((c&192)!=128){break Cb}v[b>>2]=0;break Cb}a=w[(B(e,872)+d|0)+1075832|0];r=a>>>4|0;i=r+(a&15)|0;k=v[d+480180>>2];if(!(w[d+480208|0]&4?0:k&16777248)){r=r+1|0;i=i+2|0}a=(B(e,872)+d|0)+1075831|0;c=w[a|0];if(!(k&4)){c=(c&255)>>>0<i>>>0?c:0;if((c&255)>>>0>=r>>>0){v[b>>2]=0}t[a|0]=c+1;break Cb}Fb:{if(w[d+480209|0]&16){c=c&255?c-1|0:0;break Fb}t[a|0]=c+1}if(((c&255)>>>0)%(i>>>0)>>>0<r>>>0){break Cb}v[b>>2]=0}a=(B(e,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|2097152}a=B(e,872)+d|0;Gb:{if(w[a+1075797|0]!=18){break Gb}c=v[a+1075648>>2];if(!c){break Gb}a=w[c+34|0];if(!a|w[c+15|0]&2){break Gb}k=B(e,872)+d|0;if(v[k+1075080>>2]&134218752){break Gb}k=k+1075791|0;n=w[k|0];if(!$c(n)){break Gb}a=v[Md(d+906300|0,a-1|0)>>2];if(!a){break Gb}n=ob[v[v[a>>2]+104>>2]](a,n,e)|0;i=v[b>>2];if(!(!n|i)){ob[v[v[a>>2]+96>>2]](a,c,w[k|0]|256,0,e);break Gb}if(n|!i){break Gb}ob[v[v[a>>2]+96>>2]](a,c,w[k|0],x[(B(e,872)+d|0)+1075680>>1],e)}kb=h+16|0;pe(b,0,256);v[j+8>>2]=v[j+8>>2]<<6;Hb:{if(E){Db(j+16|0,o,31);if(Cb(v[v[j+16>>2]>>2],v[j+20>>2])){kt(d,g)}c=j+8|0;a=kb-16|0;kb=a;Ib:{if(!my(d,g,0)){break Ib}h=v[g+656>>2];k=d+1074312|0;Db(a+8|0,k,31);Jb:{if(Cb(v[v[a+8>>2]>>2],v[a+12>>2])){b=v[g+724>>2];if(b){break Jb}break Ib}b=v[g+724>>2]}Db(a+8|0,k,31);i=b-Cb(v[v[a+8>>2]>>2],v[a+12>>2])|0;b=aq(h+48|0,i,256,64);r=w[h+65|0];Kb:{if((r|0)==255){break Kb}n=u[g+728>>1];if((n|0)==-1){break Kb}r=Eb(v[h+48>>2],r);h=w[r+2|0];r=x[r>>1];Db(a+8|0,k,94);k=h<<2;b=(i|0)==(r|0)?k:b;if(Cb(v[v[a+8>>2]>>2],v[a+12>>2])){b=n+(b-k<<1)|0;break Kb}if(!h){b=0;break Kb}b=(B(b,n)|0)/(k|0)|0}Xa=c,Ya=(B(Yb(b,0,512),v[c>>2])|0)/256|0,v[Xa>>2]=Ya}kb=a+16|0;CN(g,c);a=kb-16|0;kb=a;Lb:{if(!my(d,g,1)){break Lb}c=v[g+656>>2];h=d+1074312|0;Db(a+8|0,h,31);Mb:{if(Cb(v[v[a+8>>2]>>2],v[a+12>>2])){b=v[g+732>>2];if(b){break Mb}break Lb}b=v[g+732>>2]}Db(a+8|0,h,31);c=aq(c+68|0,b-Cb(v[v[a+8>>2]>>2],v[a+12>>2])|0,64,64)-32|0;b=v[g+684>>2];Xa=g,Ya=Yb(((B(c,(b|0)>127?256-b|0:b)|0)/32|0)+b|0,0,256),v[Xa+684>>2]=Ya}kb=a+16|0;Db(j+16|0,o,115);if(Cb(v[v[j+16>>2]>>2],v[j+20>>2])){break Hb}b=w[m+1075789|0];if(!b){break Hb}a=v[J>>2];if(!a|!w[a+26|0]){break Hb}GN(m+1075676|0,b,w[a+26|0],w[a+27|0]);break Hb}if(!(w[p+1|0]&16)){break Hb}v[m+1075688>>2]=0;v[j+8>>2]=0}Nb:{if(w[m+1075843|0]&8){c=0;v[j+8>>2]=0;break Nb}c=v[j+8>>2];if(!c){c=0;break Nb}if(w[p+3|0]&8){v[G>>2]=0;break Nb}if(Qd(w[S|0])){a=B(v[j+32>>2],v[m+1075740>>2]);b=a;h=a>>31;a=c<<8;Xa=G,Ya=Ic(Pka(Oka(b,h,a,a>>31),nb,1048576,0),nb),v[Xa>>2]=Ya;break Nb}a=B(v[j+32>>2],v[m+1075740>>2]);b=a;h=a>>31;a=B(v[d+1074456>>2],c);Xa=G,Ya=Ic(Pka(Oka(b,h,a,a>>31),nb,1048576,0),nb),v[Xa>>2]=Ya}v[Q>>2]=c;Ob:{Pb:{c=v[l>>2];if(!(v[F>>2]==2|(c|0)>=v[d+480260>>2])){if(!oj(d)){break Pb}c=v[l>>2]}if((c|0)<v[d+480264>>2]){break Ob}Db(j+16|0,o,113);if(!Cb(v[v[j+16>>2]>>2],v[j+20>>2])){break Ob}if(oj(d)){break Ob}v[l>>2]=v[d+480264>>2];break Ob}v[l>>2]=v[d+480260>>2]}Db(j+16|0,o,73);a=v[l>>2];v[j+36>>2]=a;Qb:{if((v[p>>2]&1572864)!=1572864){break Qb}b=v[d+480208>>2];if(b&2097152){if(!wm(w[m+1075782|0],w[m+1075783|0])|b&4096){break Qb}}b=m+1075704|0;Rb:{if((a|0)==v[b>>2]){c=v[m+1075708>>2];break Rb}v[b>>2]=a;c=a;a=m+1075764|0;b=m+1075696|0;c=fh(d,ht(d,c,u[a>>1],v[b>>2]),u[a>>1],v[b>>2]);v[m+1075708>>2]=c}v[j+36>>2]=c}k=kb-16|0;kb=k;i=B(e,872)+d|0;r=i+1075648|0;a=v[r>>2];Sb:{if(!a){break Sb}b=w[a+34|0];if(v[(B(e,872)+d|0)+1075080>>2]&134218752|(!b|w[a+15|0]&2)){break Sb}if(!v[Md(d+906300|0,b-1|0)>>2]){break Sb}b=B(e,872)+d|0;h=b+1075780|0;a=w[b+1075793|0];Y=b+1075783|0;n=w[Y|0];Tb:{Ub:{if((n|0)==1){b=a;Vb:{Wb:{switch(((y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 0:b=a+(w[(B(e,872)+d|0)+1075798|0]>>>4|0)|0;break Vb;case 1:break Wb;default:break Vb}}b=a+(w[(B(e,872)+d|0)+1075798|0]&15)|0}c=B(e,872)+d|0;if(w[c+1075792|0]==(b&255)){break Tb}if(!(t[c+1075843|0]&1)){break Ub}if(!$c(w[h|0])){break Ub}if(wm(w[h+2|0],1)){break Ub}break Tb}if(w[h|0]){b=a;if(!wm(w[h+2|0],n)){break Tb}}b=a;if(!w[(B(e,872)+d|0)+1075792|0]){break Tb}}tm(d,e,b&255|512,x[(B(e,872)+d|0)+1075680>>1])}V=(B(e,872)+d|0)+1075792|0;c=w[V|0];Xb:{Yb:{if(c){if((n|0)!=1|(b&255)!=(c|0)){break Yb}break Xb}if(!(t[(B(e,872)+d|0)+1075843|0]&1)|(n|0)!=1){break Xb}if($c(w[h|0])){break Xb}c=a;if(!$c(a)){break Xb}}tm(d,e,c&255|256,0)}t[V|0]=w[Y|0]==1?b:0}Zb:{if(w[i+1075797|0]!=1){break Zb}if(wj(v[r>>2])){b=0;_b:{$b:{ac:{switch(y[d+1074392>>2]%3|0){case 1:b=w[(B(e,872)+d|0)+1075798|0]>>>4|0;break $b;case 0:break $b;case 2:break ac;default:break _b}}b=w[(B(e,872)+d|0)+1075798|0]&15}u[j+42>>1]=b}a=(B(e,872)+d|0)+1075843|0;t[a|0]=w[a|0]|96;break Zb}if(!(!(w[d+480209|0]&16)|v[d+480180>>2]!=1048576)){a=B(e,872)+d|0;b=fh(d,w[a+1075789|0],u[a+1075764>>1],v[a+1075696>>2]);v[j+36>>2]=b;v[a+1075692>>2]=b}b=d+1074312|0;Db(k+8|0,b,13);if(Cb(v[v[k+8>>2]>>2],v[k+12>>2])){b=w[(B(e,872)+d|0)+1075798|0];if(!b){break Zb}a=65536;bc:{switch(((y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:b=b<<4;case 0:a=v[((b&240)<<2)+37136>>2];break;default:break bc}}e=oj(d);b=v[j+36>>2];c=b;b=b>>31;if(e){a=Oka(c,b,a,a>>31)+32768|0;h=nb;a=Pka(a,a>>>0<32768?h+1|0:h,65536,0)}else{e=(a|0)/2|0;h=e>>31;n=b<<16|c>>>16;c=c<<16;b=c+e|0;n=h+n|0;a=Pka(b,b>>>0<c>>>0?n+1|0:n,a,a>>31)}b=nb;Xa=j,Ya=Ic(a,b),v[Xa+36>>2]=Ya;break Zb}Db(k+8|0,b,51);if(Cb(v[v[k+8>>2]>>2],v[k+12>>2])){if(w[d+480209|0]&16){break Zb}cc:{dc:{a=v[d+1074416>>2];b=a-(y[d+1074392>>2]%(a>>>0)|0)|0;if((b|0)>16){break dc}if((b|0)==16){break Zb}a=0;ec:{switch((b|0)%3|0){case 0:break Zb;case 2:break dc;case 1:break ec;default:break cc}}a=w[(B(e,872)+d|0)+1075798|0]>>>4|0;break cc}a=w[(B(e,872)+d|0)+1075798|0]&15}c=a;a=B(e,872)+d|0;b=a+1075764|0;a=a+1075696|0;c=c+ht(d,v[j+36>>2],u[b>>1],v[a>>2])|0;b=fh(d,c,u[b>>1],v[a>>2]);v[j+36>>2]=b;if(c>>>0<109){break Zb}v[k+8>>2]=b;Xa=k,Ya=fh(d,109,0,v[a>>2]),v[Xa+4>>2]=Ya;Xa=j,Ya=v[Zc(k+8|0,k+4|0)>>2],v[Xa+36>>2]=Ya;break Zb}h=v[d+1074392>>2];n=d+480180|0;c=v[n>>2];fc:{if((c|0)!=1){a=w[(B(e,872)+d|0)+1075789|0];break fc}a=B(e,872)+d|0;a=ht(d,v[j+36>>2],u[a+1075764>>1],v[a+1075696>>2]);c=v[n>>2]}gc:{hc:{switch((((c&67633152?h+2|0:h)>>>0)%3|0)-1|0){case 0:a=(w[(B(e,872)+d|0)+1075798|0]>>>4|0)+a|0;break gc;case 1:break hc;default:break gc}}a=(w[(B(e,872)+d|0)+1075798|0]&15)+a|0}if(!(c&67633408|w[(B(e,872)+d|0)+1075789|0]!=(a&255))){Db(k+8|0,b,82);if(!Cb(v[v[k+8>>2]>>2],v[k+12>>2])){break Zb}}if(w[d+480210|0]&32){c=a&255;if((c|0)==85){v[j+36>>2]=2147483647;break Zb}a=c>>>0>85?a-37|0:a}c=B(e,872)+d|0;h=fh(d,a&255,u[c+1075764>>1],v[c+1075696>>2]);v[j+36>>2]=h;if(v[d+480180>>2]&71860480){v[c+1075692>>2]=h;break Zb}Db(k+8|0,b,82);if(!Cb(v[v[k+8>>2]>>2],v[k+12>>2])){break Zb}t[(B(e,872)+d|0)+1075792|0]=a}kb=k+16|0;if(!(!(w[I|0]&33)|v[j+36>>2]==2147483647)){ic:{if(v[F>>2]==2){c=452;a=3424;break ic}a=B(x[m+1075764>>1]>>>4&15,24);b=x[a+32870>>1]>>>1|0;c=b>>>0>452?b:452;a=x[a+32848>>1]<<1}pe(j+36|0,c,a);pe(l,c,a)}LN(d,g);b=v[p>>2]}jc:{if(!(b&256)|w[K|0]&64){break jc}Db(j+16|0,o,37);if(!Cb(v[v[j+16>>2]>>2],v[j+20>>2])){break jc}v[m+1075676>>2]=128}l=q&65535;tM(d,l);kc:{if(!f){break kc}a=DN(d,g,j+36|0);if((a|0)<0|!(w[p+1|0]&2)){break kc}b=v[d+1298300>>2];if(!Fd(b)){break kc}$p(b,l,a>>>2&255,1)}lc:{if(w[m+1075782|0]!=8){break lc}mc:{nc:{a=w[m+1075783|0];switch(a-5|0){case 1:break lc;case 0:case 2:break mc;default:break nc}}if((a|0)!=26){break lc}}a=v[F>>2];if((a|0)==4){if(w[K|0]&16){break lc}a=m+1075811|0;t[a|0]=w[a|0]+w[m+1075815|0];break lc}if(!(a&16777248)){break lc}il(g,w[m+1075784|0]);sM(d,l,j+36|0,j+44|0)}sM(d,l,j+36|0,j+44|0);oc:{if(!f){break oc}v[j+32>>2]=0;b=j+36|0;n=kb-16|0;kb=n;e=v[g+104>>2];pc:{if(!e|!w[e+40|0]){break pc}i=wj(v[g+656>>2]);f=oj(d);Db(n+8|0,d+1074312|0,21);a=f?38160:37136;k=f?37136:38160;if(!(i|!Cb(v[v[n+8>>2]>>2],v[n+12>>2])|v[d+480180>>2]==1048576)){i=w[e+41|0];if(!i){break pc}c=w[g+818|0];v[n+4>>2]=v[g+756>>2]+w[e+39|0];bi(n+4|0,w[e+40|0]<<8);h=v[n+4>>2];t[g+818|0]=c+i;v[g+756>>2]=h;h=(h|0)/256|0;qc:{rc:{switch(w[e+38|0]-1|0){case 3:c=pM(Un(d))+-64|0;break qc;case 2:c=64-(c+1>>>1|0)|0;break qc;case 1:c=(c+1>>>1|0)+-64|0;break qc;case 0:c=(c>>>1^-1)&64;break qc;default:break rc}}c=t[c+33440|0]}bi(b,8388607);e=v[b>>2]<<8;v[b>>2]=e;h=B(c,h);i=(h|0)/64|0;c=i>>31;i=(c^i)-c|0;r=i>>>2|0;c=e;sc:{tc:{if((h|0)<=-64){h=e>>31;a=v[(r<<2)+a>>2];a=Ic(Pka(Oka(e,h,a,a>>31),nb,65536,0),nb)-e|0;k=i&3;if(!k){break sc}f=(k<<2)+(f?37072:37008)|0;break tc}h=e>>31;a=v[k+(r<<2)>>2];a=Ic(Pka(Oka(e,h,a,a>>31),nb,65536,0),nb)-e|0;k=i&3;if(!k){break sc}f=(k<<2)+(f?37008:37072)|0}k=a;a=v[f>>2];a=(k+Ic(Pka(Oka(a,a>>31,e,h),nb,65536,0),nb)|0)-e|0}v[b>>2]=(a+c|0)/256;v[j+32>>2]=a&255;break pc}h=v[d+480180>>2]&16777248;c=w[e+39|0];uc:{if(!(h|c)){v[g+756>>2]=w[e+40|0]<<8;break uc}vc:{wc:{if(h){r=c<<1;f=v[g+756>>2];c=g+756|0;break wc}if(w[g+89|0]&8){break vc}f=((w[e+40|0]<<8&65280)>>>0)/(c>>>0)|0;r=v[g+756>>2];c=g+756|0}v[c>>2]=f+r}bi(g+756|0,w[e+40|0]<<8)}c=w[g+818|0]+w[e+41|0]|0;t[g+818|0]=c;c=c<<24>>24;xc:{yc:{switch(w[e+38|0]-1|0){case 3:t[g+818|0]=c+1;h=t[(c&63)+33376|0];break xc;case 2:h=(64-(c>>>1|0)&127)+-64|0;break xc;case 1:h=((c>>>1|0)- -64&127)+-64|0;break xc;case 0:h=(c|0)>=0?-64:64;break xc;default:break yc}}h=0-t[(c&255)+33440|0]|0;if(v[d+480180>>2]!=1048576){break xc}h=(64-t[(c+-64&255)+33440|0]|0)/2<<16>>16}c=h;h=B(c,v[g+756>>2]);f=(h|0)/256|0;if(i){z[j+44>>2]=z[j+44>>2]+C(C(C(C(w[e+40|0])*C(.05000000074505806))*C(c|0))*C(.000244140625));t[g+851|0]=w[g+851|0]|64;break pc}if(v[d+480180>>2]!=4){zc:{if((h|0)<=-256){f=0-f|0;c=0-h>>>16|0;e=(c<<2)+a|0;break zc}a=k;c=(h|0)/65536|0;e=a+(c<<2)|0}h=v[b>>2];c=v[((c<<2)+a|0)+4>>2];a=v[e>>2];a=((B(c-a|0,(f|0)/4&63)|0)/64|0)+a|0;a=Ic(Pka(Oka(h,h>>31,a,a>>31),nb,256,0),nb);v[b>>2]=a;v[j+32>>2]=a&255;v[b>>2]=v[b>>2]/256;break pc}v[b>>2]=v[b>>2]+((h|0)/16384|0)}kb=n+16|0;f=v[j+36>>2];if((f|0)<=v[d+480260>>2]){Db(j+16|0,o,81);if(Cb(v[v[j+16>>2]>>2],v[j+20>>2])){v[m+1075068>>2]=0}f=v[d+480260>>2];v[j+36>>2]=f}Ac:{if(!wj(v[g+656>>2])){break Ac}a=m+1075843|0;b=w[a|0];if(!(v[d+1074392>>2]|!(b&32)?b&64:1)){break Ac}yP(g,z[j+44>>2],u[j+42>>1],d);b=a;a=w[a|0];t[b|0]=(a&64?-65:-33)&a}a=j+16|0;_y(a,d,g,f,v[j+32>>2]);b=Gb(a);a=Oka(v[j+16>>2],v[j+20>>2],v[d+480240>>2],0);f=nb;c=Pka(a,f,65536,0);e=nb;a=a+65535|0;f=a>>>0<65535?f+1|0:f;a=!f&a>>>0<131071;c=a?1:c;v[j+16>>2]=c;a=a?0:e;v[j+20>>2]=a;v[A>>2]=c;v[A+4>>2]=a;if((v[p>>2]&134219264)!=512){break oc}if(!Fd(v[d+1298300>>2])){break oc}Db(j+8|0,o,99);Bc:{Cc:{if(Xa=Cb(v[v[j+8>>2]>>2],v[j+12>>2]),Ya=1,_a=w[p+1|0]&16,_a?Xa:Ya){a=v[F>>2];break Cc}a=v[F>>2];if((a|0)!=2){break Bc}}c=v[p>>2];e=c&2048;Dc:{if(e?(a|0)==2:0){break Dc}a=Oka(v[b>>2],0,261625,0)+66904|0;f=nb;b=Ec(Rka(a,a>>>0<66904?f+1|0:f,133808,0),nb);a=1;Ec:{if(e){break Ec}a=0;if(!(c&4096)){break Ec}a=!v[m+1075688>>2]}Db(j+8|0,o,110);if(Xa=Cb(v[v[j+8>>2]>>2],v[j+12>>2]),Ya=0,_a=a,_a?Xa:Ya){break Dc}c=v[d+1298300>>2];Db(j+8|0,o,95);rz(c,l,b,a,Cb(v[v[j+8>>2]>>2],v[j+12>>2]))}b=v[d+1298300>>2];a=Oka(B(v[m+1075744>>2],B(v[m+1075740>>2],v[Q>>2])),0,63,0)+33554432|0;f=nb;f=a>>>0<33554432?f+1|0:f;$p(b,l,Ec((f&67108863)<<6|a>>>26,f>>>26|0)&255,0);a=m+1075676|0;h=a;b=v[a>>2];c=0;a=v[d+1298300>>2];e=pl(a,l);Fc:{if((e|0)==255){break Fc}f=v[a>>2];if(jk(f)){break Fc}c=Lb(Nd(a+318|0,e),10);n=v[a+4>>2];e=zt(e)|192;a=w[c|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;b=a&255;hh(f,n,l,e,b);c=(b>>>5&1)+(a<<27>>31)|0}v[h>>2]=(c<<7)+128}Gc:{a=v[J>>2];if(!a|(w[a+60|0]&7)!=1){break Gc}b=v[a+48>>2];a=v[a+52>>2];if(pc(b,a)){break Gc}b=v[rM(g,0)>>2];a=Bj(a);if(b>>>0<x[a>>1]|w[a+2|0]){break Gc}rj(v[d+1298300>>2],l,1);Db(j+8|0,o,109);a=v[p>>2];Xa=p,Ya=(Cb(v[v[j+8>>2]>>2],v[j+12>>2])?a:a&-4609)|4096,v[Xa>>2]=Ya;v[m+1075688>>2]=0;break oc}Db(j+8|0,o,99);if(!Cb(v[v[j+8>>2]>>2],v[j+12>>2])|!(w[p+1|0]&16)|v[m+1075688>>2]){break oc}rj(v[d+1298300>>2],l,1);v[p>>2]=v[p>>2]&-513}Hc:{if(!E){break Hc}Db(j+16|0,o,31);if(Cb(v[v[j+16>>2]>>2],v[j+20>>2])){break Hc}kt(d,g)}b=v[p>>2];a=b&-65537;n=m+1075012|0;k=v[G>>2];i=m+1075016|0;c=v[n>>2]|(k|v[i>>2])?(a|b<<7&65536)^65536:a;v[p>>2]=c;r=m+1075664|0;a=r;v[a>>2]=0;v[a+4>>2]=0;h=m+1075834|0;a=w[h|0];b=a-4|0;b=a>>>0<b>>>0?0:b;t[h|0]=b;l=m+1075835|0;a=w[l|0];e=a-4|0;a=a>>>0<e>>>0?0:e;t[l|0]=a;Ic:{Jc:{Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{e=v[m+1075096>>2];Rc:{if(!e){break Rc}f=v[e+20>>2];if(!_d(v[e>>2],f)|!v[m+1075068>>2]){break Rc}if(yi(v[g+8>>2],v[g+12>>2])){break Qc}}v[m+1075008>>2]=0;break Pc}v[m+1075008>>2]=f;if(f){break Oc}}if(!qj(v[g+656>>2])){break Nc}f=0;if(c&6144){break Nc}}G=v[m+1075676>>2];e=(B(k,256-G|0)|0)/16384|0;e=e>>>0<127?e:127;if(b<<24>>24<0){t[h|0]=e;V=e}else{V=b}b=e>>>1|0;if((V&255)>>>0<b>>>0){t[h|0]=b}b=(B(k,G)|0)/16384|0;b=b>>>0<127?b:127;if(a<<24>>24<0){t[l|0]=b;a=b}b=b>>>1|0;if(b>>>0>(a&255)>>>0){break Mc}break Lc}if((b&255)>>>0>=129){t[h|0]=0}f=0;b=0;if((a&255)>>>0<129){break Kc}}t[l|0]=b}if(!f){break Kc}f=128;h=v[d+24624>>2];if(h>>>0>=2){f=Yb(v[m+1075676>>2],0,256)}v[j+16>>2]=f;b=B(k,s)>>>(Qd(w[R|0])?7:8)|0;Sc:{Tc:{Uc:{switch(w[X|0]){case 0:if(!(w[d+24616|0]&16)){break Tc}case 1:if((f|0)<=127){a=b>>>1|0;b=(B(b,f)|0)/256|0;break Sc}a=(B(b,256-f|0)|0)/256|0;b=b>>>1|0;break Sc;case 3:break Uc;default:break Tc}}bi(j+16|0,255);e=v[j+16>>2];if((e|0)<=0){a=65536}else{a=x[(0-e<<1)+39696>>1]}a=B(a,b)>>>16|0;b=B(b,x[(e<<1)+39184>>1])>>>16|0;break Sc}a=(B(b,256-f|0)|0)/256|0;b=(B(b,f)|0)/256|0}e=v[J>>2];Vc:{if(e){f=w[e+14|0];if(Io(f)){break Vc}}f=w[d+480268|0];if(Io(f)){break Vc}e=w[d+24648|0];f=w[I|0]&128?v[d+24668>>2]?-1:e:e}k=m+1075668|0;l=m+1075786|0;t[l|0]=f;e=v[A>>2];n=v[A+4>>2];if(!(c&131072|((e|0)!=0|(n|0)!=1)|(v[m+1075748>>2]|(f&255)==255))){t[l|0]=0}f=a;a=1<<v[Z>>2];v[r>>2]=(f|0)/(a|0);a=(b|0)/(a|0)|0;v[k>>2]=(c&256)>>>8|0?(h|0)==2?0-a|0:a:a;if(c&128){v[A>>2]=0-e;v[A+4>>2]=0-(((e|0)!=0)+n|0)}f=0;k=kb-16|0;kb=k;v[g+28>>2]=0;v[g+32>>2]=0;bi(g+672|0,524287);bi(g+676|0,524287);Wc:{Xc:{e=v[g+88>>2];if(!(e&65536)){b=v[g+676>>2];a=v[g+672>>2];break Xc}a=v[g+20>>2];h=v[g+672>>2];Yc:{if((a|0)!=(h|0)){b=v[g+24>>2];c=v[g+676>>2];break Yc}b=v[g+24>>2];c=v[g+676>>2];if((b|0)==(c|0)){break Xc}}e=v[d+24620>>2];c=(a|0)<(h|0)|(b|0)<(c|0);Zc:{if(c){a=Bt(e,v[d+24636>>2]);break Zc}a=Bt(e,v[d+24640>>2])}Db(k,d+1074312|0,4);if(!(!Cb(v[v[k>>2]>>2],v[k+4>>2])|!(v[d+480180>>2]&4))){a=v[d+24620>>2];a=Oka(a,a>>31,5,0)+500|0;h=nb;a=Ic(Pka(a,a>>>0<500?h+1|0:h,1e3,0),nb)}e=v[g+656>>2];_c:{if(!e){b=a;break _c}b=a;if(!c){break _c}c=x[e+12>>1];if(c){b=(B(c,v[d+24620>>2])>>>0)/1e5|0}f=(c|0)!=0}l=b?b:1;e=v[g+672>>2];n=v[g+20>>2];i=e-n<<12;r=g;c=v[g+676>>2];b=v[g+24>>2];h=c-b<<12;if(!(w[g+90|0]&32|(!(c|e)|(!(b|n)|f)))){v[k+12>>2]=v[d+1074380>>2];pe(k+12|0,a,2048);l=v[k+12>>2]}h=(h|0)/(l|0)|0;v[r+32>>2]=h;f=(i|0)/(l|0)|0;v[g+28>>2]=f;b=c+((B(h,l)|0)/-4096|0)|0;v[g+24>>2]=b;a=e+((B(f,l)|0)/-4096|0)|0;v[g+20>>2]=a;if(f|h){v[g+100>>2]=l;c=v[g+88>>2];break Wc}v[g+24>>2]=c;v[g+20>>2]=e;b=c;a=e;c=v[g+88>>2]&-65537;break Wc}v[g+24>>2]=b;v[g+20>>2]=a;c=e&-65537}v[g+88>>2]=c&-2097153;v[g+40>>2]=b<<12;v[g+36>>2]=a<<12;kb=k+16|0;c=v[p>>2];if(!(c&512)){break Jc}break Ic}v[n>>2]=0;v[i>>2]=0;v[m+1075068>>2]=0;if(v[m+1075088>>2]){break Jc}if(!v[m+1075084>>2]){break Ic}}a=x[d+480212>>1];u[d+480212>>1]=a+1;u[((a<<1)+d|0)+1074478>>1]=q}v[m+1075660>>2]=c}q=q+1|0;continue}break}}kb=j+48|0;if(N^1){a=v[d+480208>>2];break h}if(Qd(w[Ha|0])){b=v[d+480208>>2]|512;break i}l=0;$c:{a=v[d+24620>>2]/10|0;c=Ic(a,a>>31);if(!c){break $c}b=c>>>0<1048576?c:1048576;v[d+1074380>>2]=b;g=x[d+480212>>1];e=d+1074376|0;while(1){if((g|0)==(l|0)){break $c}a=e+B(x[(e+(l<<1)|0)+102>>1],872)|0;h=a+1288|0;v[h>>2]=0;v[h+4>>2]=0;v[a+716>>2]=b;h=v[a+640>>2]<<12;v[a+656>>2]=h;f=v[a+636>>2]<<12;v[a+652>>2]=f;v[a+704>>2]=v[a+704>>2]|65536;v[a+644>>2]=(0-f|0)/(b|0);v[a+648>>2]=(0-h|0)/(b|0);l=l+1|0;continue}}a=v[d+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;v[d+480208>>2]=a}if(!(a&512)){break g}Xa=d+1074392|0,Ya=jl(Ga),v[Xa>>2]=Ya}kb=M+112|0;break f}v[M+96>>2]=512;a=v[d+1074380>>2];v[M+104>>2]=fa;v[M+100>>2]=a;k=JB(M+96|0);if(v[d+24632>>2]){a=0;b=kb-48|0;kb=b;c=k<<2;while(1){if((a|0)==4){ad:{a=0;while(1){if((a|0)==4){break ad}v[(b+32|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}}}else{v[b+32>>2]=0;e=((a<<11)+d|0)+16396|0;Zz(e,c+e|0,b+32|0);a=a+1|0;continue}break}a=v[d+24632>>2];v[b+24>>2]=k;v[b+20>>2]=a;v[b+16>>2]=b+32;a=v[v[ma>>2]+8>>2];v[b+8>>2]=k;c=v[b+20>>2];v[b>>2]=v[b+16>>2];v[b+4>>2]=c;ob[a|0](ma,b);kb=b+48|0}if(Qd(Fa)){a=0;while(1){if((a|0)==4){a=v[d+24632>>2];v[M+88>>2]=k;v[M+84>>2]=a;v[M+80>>2]=M+96;a=v[v[oa>>2]+8>>2];v[M+40>>2]=k;b=v[M+84>>2];v[M+32>>2]=v[M+80>>2];v[M+36>>2]=b;ob[a|0](oa,M+32|0)}else{v[(M+96|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}break}}$=0;ga=0;E=kb-48|0;kb=E;if(k){o=d+12|0;r=d+24592|0;A=d+24588|0;$m(o,k,r,A);if(y[d+24624>>2]>=3){$m(d+8204|0,k,d+24600|0,d+24596|0)}u[E+42>>1]=0;ta=d+1074312|0;Ja=d+24648|0;ua=d+906300|0;Ka=d+24596|0;La=d+24600|0;Ma=d+8204|0;F=d+397452|0;G=d+397448|0;p=d+393352|0;va=d+397456|0;ia=d+1074376|0;Na=d+480190|0;while(1){if(x[d+480212>>1]<=$>>>0){Xa=d,Ya=x[le(d+480214|0,E+42|0)>>1],u[Xa+480214>>1]=Ya}else{l=ia+($<<1)|0;h=x[l+102>>1];a=B(h,872);Q=a+ia|0;bd:{cd:{if(v[Q+632>>2]){break cd}b=a+d|0;if(v[b+1075088>>2]){break cd}if(!v[b+1075084>>2]){break bd}}j=a+d|0;a=w[j+1075786|0]+1&255;if(a>>>0<=5){f=v[(a<<2)+27776>>2]}else{f=0}I=j+1075080|0;g=v[I>>2];dd:{if(!(!(g&16777216)&w[d+24612|0]>>>5)){a=r;b=A;c=g;e=o;if(!(c&8388608)){break dd}}a=G;b=F;if(!w[va+12|0]){$m(p,k,a,b)}t[va+12|0]=1;h=x[l+102>>1];c=v[I>>2];e=p}n=b;b=c>>>8&y[d+24624>>2]>2;S=b?Ka:n;J=b?La:a;c=b?Ma:e;ja=Pl(d,ia,h,2,1)-1|0;wa=(ja&255)>>>0>249;ed:{if(wa){break ed}b=v[Md(ua,ja)>>2];if(!b){break ed}a=v[b+24>>2];if(!a){break ed}S=b+36|0;J=b+40|0;if(!(t[b+28|0]&1)){$m(a,k,J,S);v[b+28>>2]=v[b+28>>2]|1}c=a}l=Q+616|0;if(w[j+1075843|0]&8){jD(l,c,k);a=j+1075084|0;v[J>>2]=v[J>>2]+v[a>>2];v[S>>2]=v[S>>2]+v[j+1075088>>2];v[a>>2]=0;v[a+4>>2]=0;break bd}ba=0;e=kb-16|0;kb=e;a=E+16|0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;b=e+8|0;h=d+1074312|0;Db(b,h,33);Xa=a,Ya=Cb(v[v[e+8>>2]>>2],v[e+12>>2]),t[Xa+16|0]=Ya;Db(b,h,116);Xa=a,Ya=Cb(v[v[e+8>>2]>>2],v[e+12>>2])^1,t[Xa+17|0]=Ya;if(v[l+16>>2]){hD(a,l);s=v[l+8>>2];n=v[l+12>>2];b=n>>31;n=(b^n)-((b>>>0>(b^s)>>>0)+b|0)|0;b=n;v[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Oa=g>>>12&8|(g>>>5&2|(f|g&1));Pa=ga&65535;Qa=j+1075795|0;Ra=j+1075778|0;Sa=j+1075688|0;Ta=j+1075024|0;Ua=j+1075020|0;Va=j+1075668|0;Wa=j+1075664|0;R=j+1075088|0;X=j+1075084|0;xa=j+1075016|0;ya=j+1075012|0;ca=j+1075096|0;Z=j+1075076|0;N=j+1075068|0;K=j+1075e3|0;ha=j+1075072|0;Y=j+1075092|0;kb=e+16|0;q=a;a=k;while(1){fd:{b=v[Y>>2];ea=b?a>>>0>b>>>0?b:a:a;v[E+8>>2]=ea;gd:{hd:{if(!ea){break hd}j=v[K>>2];g=v[K+4>>2];if(!(j|g)){break hd}f=v[N>>2];if(!f){break hd}e=v[q>>2];if(!e){break hd}b=v[I>>2];n=v[ha>>2];v[Q+632>>2]=e;e=v[l>>2];id:{jd:{s=n&b<<30>>31;h=v[l+4>>2];m=h;if((s|0)>(h|0)){if((g|0)<0){e=Tg(0,s<<1,e,h);v[l>>2]=e;h=nb;v[l+4>>2]=h;if(!((h|0)>=(s|0)&h>>>0<f+s>>>1>>>0)){e=0;v[l>>2]=e;h=s;v[l+4>>2]=h}kd:{if(b&4){b=b&-129;v[I>>2]=b;g=0-(((j|0)!=0)+g|0)|0;j=0-j|0;v[K>>2]=j;v[K+4>>2]=g;break kd}v[l>>2]=e;h=f-1|0;v[l+4>>2]=h}if(!(b&2)){break hd}if(f>>>0>h>>>0){break id}break hd}if((h|0)>0|(h|0)>=0){break id}h=0;break jd}if(f>>>0>m>>>0){break id}if(!(b&2)){break hd}if(b&4){if(!!j&(g|0)>=0|(g|0)>0){g=0-(((j|0)!=0)+g|0)|0;j=0-j|0;v[K>>2]=j;v[K+4>>2]=g}b=b|128;v[I>>2]=b;if(w[E+33|0]){m=w[E+32|0];i=v[Z>>2]-(m+n|0)|0;e=Tg(e,h,0,f);h=nb;if(h>>>0<i>>>0){e=Tg(0,f-m|0,e,h);h=nb;break jd}h=n;e=0;break jd}h=1-((e|0)!=0)|0;e=0-e|0;i=(f<<1)-(h+m|0)|0;m=e;v[l>>2]=e;V=0;h=V|i;v[l+4>>2]=h;if(i>>>0>n>>>0&f>>>0>i>>>0){break id}v[E+44>>2]=w[E+32|0]+1;e=m;h=V|f-v[Kb(N,E+44|0)>>2];break jd}if((g|0)<0){g=0-(((j|0)!=0)+g|0)|0;j=0-j|0;v[K>>2]=j;v[K+4>>2]=g}Rb(l,0,s-f|0);b=v[I>>2]|8192;v[I>>2]=b;e=v[l>>2];h=v[l+4>>2];break id}v[l>>2]=e;v[l+4>>2]=h}V=h;ld:{if((h|0)<(s|0)){if((g|h)<0){break hd}v[E+44>>2]=ea;f=j;n=g;break ld}f=v[N>>2];if(f>>>0<V>>>0|(!!j&(g|0)>=0|(g|0)>0)&(f|0)==(V|0)){break hd}v[E+44>>2]=ea;f=g>>31;i=f^j;m=f;f=i-f|0;n=(g^m)-((i>>>0<m>>>0)+m|0)|0}m=f;i=n;xc(E+8|0,v[E+28>>2]);f=v[ha>>2];za=f+16|0;Aa=v[E+8>>2];Qf(e,h,lf(j,g,Aa-1|0),nb);n=nb;Ba=f>>>0>V>>>0;if(!(!Ba&V>>>0<za>>>0)){b=b&-8193;v[I>>2]=b}md:{nd:{ka=v[E+20>>2];od:{if(ka){f=v[E+24>>2];if(f>>>0<=V>>>0){pd:{if((g|0)<0){j=0;g=f;break pd}j=e;g=h;e=0;h=v[Z>>2]}Xa=E,Ya=Ro(Tg(Tg(e,h,j,g),nb,1,0),nb,m,i)+1|0,v[Xa+44>>2]=Ya;v[Q+632>>2]=ka;break md}if(!(!(b&8192)|Ba|V>>>0>=za>>>0)){Xa=E,Ya=Ro(Tg(Tg(0,s+16|0,e,h),nb,1,0),nb,m,i)+1|0,v[Xa+44>>2]=Ya;Xa=Q,Ya=B(v[Z>>2]-s|0,Fk(x[v[ca>>2]+34>>1]))+ka|0,v[Xa+632>>2]=Ya;break md}if(!j&(g|0)<=0|(g|0)<0){break od}if(ea>>>0<2|f>>>0>n>>>0){break nd}Xa=E,Ya=Ro(Tg(Tg(0,f,e,h),nb,1,0),nb,m,i)+1|0,v[Xa+44>>2]=Ya;break md}if((g|0)>0|(g|0)>=0){break nd}}if((n|0)>=(s|0)){break md}Xa=E,Ya=Ro(Tg(Tg(e,h,0,s),nb,1,0),nb,m,i)+1|0,v[Xa+44>>2]=Ya;break md}b=v[N>>2];if((b|0)>(n|0)){break md}Xa=E,Ya=Ro(Tg(Tg(0,b,e,h),nb,1,0),nb,m,i)+1|0,v[Xa+44>>2]=Ya}Qo(E+44|0,1,Aa);g=v[E+44>>2];if((g|0)>0){break gd}}v[Q+632>>2]=0;v[N>>2]=0;v[l>>2]=0;v[l+4>>2]=0;v[Y>>2]=0;jD(l,c,a);v[J>>2]=v[J>>2]+v[X>>2];v[S>>2]=v[S>>2]+v[R>>2];v[R>>2]=0;v[X>>2]=0;v[I>>2]=v[I>>2]&-129;break fd}qd:{rd:{if(y[d+24608>>2]>Pa>>>0){b=4;if(v[Y>>2]){break rd}b=0;if(v[xa>>2]|v[ya>>2]){break rd}}Rb(l,lf(v[K>>2],v[K+4>>2],g),nb);ba=0;v[R>>2]=0;v[X>>2]=0;c=(g<<3)+c|0;break qd}e=(g<<3)+c|0;h=e-8|0;v[X>>2]=0-v[h>>2];f=e-4|0;v[R>>2]=0-v[f>>2];ob[v[((b|Oa)<<2)+27392>>2]](l,Ja,c,g);v[X>>2]=v[X>>2]+v[h>>2];v[R>>2]=v[R>>2]+v[f>>2];ba=1;c=e}b=v[Y>>2];sd:{if(!b){break sd}if(b>>>0<=g>>>0){v[Y>>2]=0;v[ya>>2]=v[Wa>>2];v[xa>>2]=v[Va>>2];v[Ua>>2]=0;v[Ta>>2]=0;if(v[Sa>>2]|!(w[I+1|0]&16)){break sd}v[N>>2]=0;v[Q+632>>2]=0;break sd}v[Y>>2]=b-g}e=0;h=0;b=v[l+4>>2];h=b>>>0>=y[Z>>2]?(w[I|0]&2)>>>1|0:h;f=b;b=v[N>>2];e=f>>>0<b>>>0|(!b|w[I|0]&2)?e:!x[Ra>>1];a=a-g|0;Db(E+8|0,ta,85);td:{ud:{vd:{wd:{if(!Cb(v[v[E+8>>2]>>2],v[E+12>>2])){break wd}b=w[Qa|0];if(!b|b>>>0>x[Na>>1]){break wd}b=B(b,104)+d|0;g=b+484380|0;f=v[ca>>2];if((g|0)==(f|0)|(e|h)!=1){break vd}v[ca>>2]=g;v[Q+632>>2]=v[b+484400>>2];e=x[b+484414>>1];v[I>>2]=e|v[I>>2]&-768;h=e<<30>>31;e=v[b+484388>>2];v[N>>2]=h&e;b=v[b+484384>>2];v[ha>>2]=b;v[Z>>2]=e;v[l+4>>2]=b;hD(q,l);if(!v[Q+632>>2]){break fd}if((a|0)>0){continue}break fd}if(h){break ud}break td}if(!h|(f|0)!=(g|0)){break td}}Db(E+8|0,ta,83);if(!Cb(v[v[E+8>>2]>>2],v[E+12>>2])|v[ha>>2]){break td}v[l>>2]=v[l>>2];v[l+4>>2]=0;b=v[v[ca>>2]+8>>2];v[N>>2]=b;v[Z>>2]=b}if((a|0)>0){continue}}break}v[Q+632>>2]=v[q>>2];ga=ba+ga|0;u[E+42>>1]=ga;if(!ba|wa){break bd}a=v[Md(ua,ja)>>2];if(!a){break bd}ob[v[v[a>>2]+152>>2]](a)}$=$+1|0;continue}break}}kb=E+48|0;i=v[d+1298300>>2];if(Fd(i)){a=_;b=k;c=(B(v[d+480232>>2],v[d+480236>>2])>>>0)/48|0;l=kb-16|0;kb=l;xd:{if(!w[i+534|0]){break xd}e=Oka(c,0,6169,0);c=nb;f=c>>>16|0;p=Ec((c&65535)<<16|e>>>16,f);while(1){if(!b){break xd}f=v[i>>2];h=v[f>>2];c=v[f+4>>2];while(1){if((c|0)>=(h|0)){v[f+8>>2]=v[f+12>>2];h=0;j=0;q=0;c=kb-16|0;kb=c;while(1){if((q|0)==18){e=(h|0)<32767?h:32767;u[f+12>>1]=(e|0)>-32768?e:-32768;e=(j|0)<32767?j:32767;u[f+14>>1]=(e|0)>-32768?e:-32768;u[f+3832>>1]=x[f+3832>>1]+1;e=(x[f+3834>>1]+1>>>0)%13440|0;u[f+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;u[f+3836>>1]=(e&65280)>>>8;if(!w[f+3843|0]){u[f+3836>>1]=(e&64512)>>>10}e=x[f+3838>>1]+1|0;u[f+3838>>1]=e;if((e&65535)>>>0>=1024){u[f+3838>>1]=0;u[f+3840>>1]=x[f+3840>>1]+1&7}kb=c+16|0}else{g=f+B(q,44)|0;yd:{if(!w[g+56|0]){u[c+12>>1]=0;u[c+14>>1]=0;break yd}n=v[g+32>>2];e=x[n+3840>>1];if(e&3){n=(x[g+36>>1]>>>7&7)>>>(w[n+3844|0]^1)>>>(e&1)<<x[g+38>>1];e=e&4?0-n|0:n}else{e=0}n=v[g+52>>2];zd:{if(n){r=x[n+32>>1];o=x[g+48>>1];n=ig(v[g+16>>2],v[g+40>>2],e<<16>>16,0,u[g+46>>1]);s=v[g+40>>2];m=v[g+20>>2];if(!r){if(!o){e=e<<16>>16;n=ig(m,s,e,n,0);n=ig(v[g+24>>2],v[g+40>>2],e,n,0);e=ig(v[g+28>>2],v[g+40>>2],e,n,0);break zd}e=e<<16>>16;s=ig(m,s,e,0,0);s=ig(v[g+24>>2],v[g+40>>2],e,s,0);e=ig(v[g+28>>2],v[g+40>>2],e,s,0)+n|0;break zd}if(!o){e=e<<16>>16;n=ig(m,s,e,n,0);s=ig(v[g+24>>2],v[g+40>>2],e,0,0);e=ig(v[g+28>>2],v[g+40>>2],e,s,0)+n|0;break zd}e=e<<16>>16;s=ig(m,s,e,0,0);e=(ig(v[g+24>>2],v[g+40>>2],e,s,0)+n|0)+ig(v[g+28>>2],v[g+40>>2],e,0,0)|0;break zd}o=x[g+48>>1];e=e<<16>>16;n=ig(v[g+16>>2],v[g+40>>2],e,0,u[g+46>>1]);s=v[g+40>>2];m=v[g+20>>2];if(!o){e=ig(m,s,e,n,0);break zd}e=ig(m,s,e,0,0)+n|0}u[c+14>>1]=w[g+57|0]?e:0;u[c+12>>1]=w[g+58|0]?e:0}q=q+1|0;j=u[c+12>>1]+j|0;h=u[c+14>>1]+h|0;continue}break}h=v[f>>2];c=v[f+4>>2]-h|0;v[f+4>>2]=c;continue}break}e=h-c|0;u[l+14>>1]=(B(u[f+12>>1],c)+B(e,u[f+8>>1])|0)/(h|0);u[l+12>>1]=(B(u[f+14>>1],c)+B(e,u[f+10>>1])|0)/(h|0);v[f+4>>2]=c+49716;v[a>>2]=v[a>>2]+B(p,u[l+14>>1]);v[a+4>>2]=v[a+4>>2]+B(p,u[l+12>>1]);a=a+8|0;b=b-1|0;continue}}kb=l+16|0}a=w[H+12|0];if(v[H+16>>2]?1:a){if(!a){$m(aa,k,sa,ra)}a=v[H>>2];b=v[H+80>>2];c=B(a,b)>>>4|0;c=c>>>0<32767?c:32767;u[H+98>>1]=c;u[H+96>>1]=c;c=v[H+49948>>2];e=B(c,a)>>>4|0;e=e>>>0<65536?e:65536;g=e+127>>>3|0;u[H+49946>>1]=g;e=e+255>>>4|0;u[H+49944>>1]=e;u[H+49942>>1]=e;u[H+49940>>1]=g;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0>8?a:8)|0;a=16-(B((b|0)<32768?b:32768,a>>>0>16?0:a)>>15)|0;q=0;while(1){if((k|0)!=(q|0)){b=q<<3;c=b+_|0;v[c>>2]=v[c>>2]+B(a,v[b+aa>>2]>>4);b=b|4;c=b+_|0;v[c>>2]=v[c>>2]+B(a,v[b+aa>>2]>>4);q=q+1|0;continue}break}n=H+68|0;l=0;b=u[H+84>>1];c=v[H+40>>2];h=v[H+36>>2];while(1){if((k|0)==(l|0)){v[H+40>>2]=c;v[H+36>>2]=h;g=k}else{a=(l<<3)+aa|0;e=v[a>>2]>>12;h=(B(b,e-h|0)>>15)+e|0;v[a>>2]=h;e=a;a=v[a+4>>2]>>12;c=(B(b,a-c|0)>>15)+a|0;v[e+4>>2]=c;l=l+1|0;continue}break}if(g){b=aa;a=g;r=v[n>>2]-1|0;i=x[n+22>>1];e=u[n+26>>1];s=u[n+18>>1];c=x[n+20>>1];h=u[n+24>>1];m=u[n+16>>1];q=v[n+4>>2];f=n+32928|0;while(1){if(a){j=kd(v[b>>2]);l=kd(v[b+4>>2]);c=kd((c<<16>>16)-j|0);i=kd((i<<16>>16)-l|0);c=ed(kd((B(c,m)|0)/65536<<1)+j|0);i=ed(kd((B(i,s)|0)/65536<<1)+l|0);l=f+(q<<2)|0;p=u[l>>1];j=ed(((B(p,h)|0)/-65536|0)+c|0);q=q+1&127;o=f+(q<<2)|0;l=u[l+2>>1];A=ed(((B(l,e)|0)/-65536|0)+i|0);u[o+2>>1]=A;u[o>>1]=j;r=r+1&8191;o=n+(r<<2)|0;Xa=o,Ya=ed(p+((B(h,j)|0)/65536|0)|0),u[Xa+160>>1]=Ya;Xa=o,Ya=ed(l+((B(e,A)|0)/65536|0)|0),u[Xa+162>>1]=Ya;b=b+8|0;a=a-1|0;continue}break}u[n+22>>1]=i;u[n+20>>1]=c;v[n+4>>2]=q}j=H+49892|0;G=H+33508|0;b=g;a=aa;while(1){if(b){e=v[H+76>>2];h=e&4095;i=G+(h<<2)|0;c=a;h=4096-h|0;A=e-v[H+49892>>2]&4095;e=4096-A|0;e=e>>>0>h>>>0?h:e;e=b>>>0<e>>>0?b:e;h=e>>>0<64?e:64;q=h;e=0;s=kb-32|0;kb=s;f=v[n>>2];while(1){if((e|0)==7){Ad:{p=u[n+28>>1]/8<<16>>16;Bd:while(1){if(!q){break Ad}q=q-1|0;e=0;l=0;f=0;while(1)if((e|0)==4){e=4;r=0;o=ed((f|0)/32768|0);F=ed((l|0)/32768|0);l=0;while(1)if((e|0)==7){e=ed(o+((l|0)/32768|0)|0);u[i>>1]=e;v[c>>2]=B(e,p);e=ed(F+((r|0)/32768|0)|0);u[i+2>>1]=e;v[c+4>>2]=B(e,p);c=c+8|0;i=i+4|0;continue Bd}else{f=s+(e<<2)|0;m=v[f>>2]+1&8191;v[f>>2]=m;m=n+(m<<2)|0;E=u[m+160>>1];f=n+(e<<4)|0;m=u[m+162>>1];r=(B(E,u[f+44>>1])+r|0)+B(m,u[f+46>>1])|0;l=(B(E,u[f+40>>1])+l|0)+B(m,u[f+42>>1])|0;e=e+1|0;continue}}else{m=s+(e<<2)|0;o=v[m>>2]+1&8191;v[m>>2]=o;V=l;l=n+(o<<2)|0;o=u[l+160>>1];m=n+(e<<4)|0;r=u[l+162>>1];l=(V+B(o,u[m+44>>1])|0)+B(r,u[m+46>>1])|0;f=(B(o,u[m+40>>1])+f|0)+B(r,u[m+42>>1])|0;e=e+1|0;continue}}}}else{v[s+(e<<2)>>2]=f+(v[(n+(e<<4)|0)+32>>2]^-1);e=e+1|0;continue}break}kb=s+32|0;q=G+(A<<2)|0;e=a;c=h;f=v[j+4>>2];l=j+8256|0;s=j- -64|0;m=j+24640|0;i=j+16448|0;while(1){p=f&2047;if(c){E=u[l+((f+1206&2047)<<2)>>1];J=u[(l+((f+754&2047)<<2)|0)+2>>1];F=u[(s+((f+1602&2047)<<2)|0)+2>>1];I=u[s+((f+1750&2047)<<2)>>1];o=u[q>>1];r=u[q+2>>1];A=m+((f+502&2047)<<2)|0;K=u[A>>1];Q=kd(u[j+32>>1]-K|0);A=u[A+2>>1];N=kd(u[j+34>>1]-A|0);S=u[j+26>>1];R=m+((f+22&2047)<<2)|0;X=u[R>>1];Z=kd(u[j+36>>1]-X|0);Y=u[j+28>>1];R=u[R+2>>1];V=kd(u[j+38>>1]-R|0);$=u[j+30>>1];K=ed(kd((B(Q,u[j+24>>1])|0)/65536<<1)+K|0);u[j+32>>1]=K;Xa=j,Ya=ed(kd((B(N,S)|0)/65536<<1)+A|0),u[Xa+34>>1]=Ya;Xa=j,Ya=ed(kd((B(Z,Y)|0)/65536<<1)+X|0),u[Xa+36>>1]=Ya;A=ed(kd((B(V,$)|0)/65536<<1)+R|0);u[j+38>>1]=A;K=kd((B(K,u[j+16>>1])|0)/32768|0);A=kd((B(A,u[j+22>>1])|0)/32768|0);K=kd(K+((o|0)/4<<16>>16)|0);Q=kd(A+((r|0)/4<<16>>16)|0);o=u[j+8>>1];N=kd(K+((B(o,I)|0)/-65536|0)|0);r=p<<2;S=r+s|0;A=u[j+10>>1];R=kd(Q+((B(A,F)|0)/-65536|0)|0);u[S+2>>1]=R;u[S>>1]=N;I=kd(I+((B(o,N)|0)/65536|0)|0);N=i+r|0;F=kd(F+((B(A,R)|0)/65536|0)|0);u[N+2>>1]=F;u[N>>1]=I;I=kd(I+K|0);K=kd(F+Q|0);F=i+((f+682&2047)<<2)|0;Q=u[F+2>>1];N=u[F>>1];F=kd((B(Q,u[j+42>>1])+B(N,u[j+40>>1])|0)/32768|0);f=i+((f+426&2047)<<2)|0;S=u[f+2>>1];R=u[f>>1];f=kd((B(S,u[j+46>>1])+B(R,u[j+44>>1])|0)/32768|0);N=kd(kd(I+N|0)-F|0);Q=kd(kd(K+Q|0)-f|0);I=kd(kd(I+R|0)-F|0);K=kd(kd(K+S|0)-f|0);F=kd(F+((B(o,E)|0)/-65536|0)|0);S=l+r|0;R=kd(f+((B(A,J)|0)/-65536|0)|0);u[S+2>>1]=R;u[S>>1]=F;o=(B(o,F)|0)/65536|0;f=kd(o+E|0);r=m+r|0;A=(B(A,R)|0)/65536|0;F=kd(A+J|0);u[r+2>>1]=F;u[r>>1]=f;Xa=e,Ya=(v[e>>2]+B(kd(f+N|0),u[j+48>>1])|0)+B(kd(F+Q|0),u[j+50>>1])|0,v[Xa>>2]=Ya;Xa=e,Ya=(v[e+4>>2]+B(kd(kd(o)+I|0),u[j+52>>1])|0)+B(kd(kd(A)+K|0),u[j+54>>1])|0,v[Xa+4>>2]=Ya;e=e+8|0;f=p+1|0;q=q+4|0;c=c-1|0;continue}break}v[j+4>>2]=p;v[H+76>>2]=h+v[H+76>>2]&4095;v[H+68>>2]=h+v[H+68>>2]&8191;b=b-h|0;a=(h<<3)+a|0;continue}break}v[H+68>>2]=v[H+68>>2]&8191;l=aa;e=_;c=g;h=0;f=0;j=v[H+56>>2];b=v[H- -64>>2];q=v[H+52>>2];a=v[H+60>>2];while(1){if(c){h=v[l>>2];f=v[l+4>>2];b=b-f|0;b=(((b|0)/1024|0)-b|0)+j|0;v[e+4>>2]=b+v[e+4>>2];a=a-h|0;a=(((a|0)/1024|0)-a|0)+q|0;v[e>>2]=a+v[e>>2];j=b+((b|0)/-512|0)|0;q=a+((a|0)/-512|0)|0;e=e+8|0;l=l+8|0;c=c-1|0;a=h;b=f;continue}break}v[H+64>>2]=f;v[H+60>>2]=h;v[H+56>>2]=j;v[H+52>>2]=q;a=v[H+20>>2];Cd:{if(w[H+12|0]){break Cd}a=v[H+16>>2];if(a>>>0>g>>>0){a=a-g|0;break Cd}AK(H,sa,ra);a=0}t[H+12|0]=0;v[H+16>>2]=a}if(v[d+946300>>2]){Dd:{f=0;e=0;g=k<<2;q=d+906300|0;i=x[d+480214>>1]!=0;Ca=z[d+1074336>>2];W=z[d+1074332>>2];while(1)if((f|0)==250){h=d+12|0;n=d+12300|0;s=d+14348|0;uv(h,n,s,k,W);a=d+1074476|0;A=w[a|0];t[a|0]=0;a=s;c=n;while(1){Ed:{Fd:{Gd:{if((e|0)!=250){m=Md(q,e);l=v[m>>2];if(!l|!v[l+24>>2]){break Ed}if(!ai(l+44|0)){break Ed}j=l;Hd:{if(tv(w[m+24|0])){break Hd}b=ob[v[v[l>>2]+148>>2]](l)|0;j=v[m>>2];if(b){break Hd}f=0;if(w[j+28|0]&2){break Hd}while(1){if((e|0)==(f|0)){break Ed}b=Md(q,f);f=f+1|0;if((Zm(v[b+28>>2])|0)!=(e|0)){continue}break}}b=v[l+44>>2];p=Kc(b,0);r=Kc(b,1);o=(c|0)==(p|0);c=o?n:c;b=c;a=o?s:a;f=v[m+28>>2];g=a;Id:{if(!f){break Id}b=c;f=Zm(f);g=a;if(f>>>0<=e>>>0){break Id}g=a;if(f>>>0>249){break Id}f=v[Md(q,f)>>2];g=a;if(!f){break Id}if(!(w[j+28|0]&4)){ob[v[v[f>>2]+152>>2]](f)}g=a;if(!ai(f+44|0)){break Id}g=v[f+44>>2];b=Kc(g,0);g=Kc(g,1)}if(!tv(w[m+24|0])){break Fd}f=0;Jd:{if(o){break Jd}while(1){if((f|0)==(k|0)){break Jd}o=f<<2;F=o+p|0;G=c+o|0;z[F>>2]=z[G>>2]+z[F>>2];F=o+r|0;o=a+o|0;z[F>>2]=z[o>>2]+z[F>>2];v[G>>2]=0;v[o>>2]=0;f=f+1|0;continue}}a=g;c=b;if(!(i&1)){break Fd}a=v[m>>2];if(a){ob[v[v[a>>2]+152>>2]](a)}f=Zm(v[m+28>>2]);a=e;while(1){c=f;f=c&255;if(f>>>0>249|f>>>0<=(a&255)>>>0){break Gd}o=Md(q,f);f=Zm(v[o+28>>2]);a=c;c=v[o>>2];if(!c){continue}ob[v[v[c>>2]+152>>2]](c);continue}}b=0;while(1){if((b|0)!=(k|0)){W=C(z[c>>2]*Ca);Kd:{if(C(D(W))<C(2147483648)){e=~~W;break Kd}e=-2147483648}v[h>>2]=e;W=C(z[a>>2]*Ca);Ld:{if(C(D(W))<C(2147483648)){e=~~W;break Ld}e=-2147483648}v[h+4>>2]=e;b=b+1|0;h=h+8|0;a=a+4|0;c=c+4|0;continue}break}break Dd}a=g;c=b}f=0;Md:{Nd:{o=w[m+24|0];if(!((o&2)>>>1|0)){if(!eD(o)|!(w[j+28|0]&4)){break Nd}}while(1){if((f|0)==(k|0)){break Md}l=f<<2;m=l+b|0;z[m>>2]=z[l+p>>2]+z[m>>2];m=g+l|0;z[m>>2]=z[l+r>>2]+z[m>>2];f=f+1|0;continue}}if(A){ob[v[v[l>>2]+132>>2]](l)}ob[v[v[l>>2]+60>>2]](l,b,g,k);v[j+32>>2]=k+v[j+32>>2];if(!eD(w[m+24|0])){break Md}if((ob[v[v[l>>2]+160>>2]](l)|0)<=0|y[j+32>>2]<v[d+24620>>2]<<2>>>0){break Md}Od:{while(1){if((f|0)==(k|0)){break Od}l=f<<2;W=z[l+b>>2];Pd:{if(W>=C(1.1920928955078125e-7)|W<=C(-1.1920928955078125e-7)){break Pd}W=z[g+l>>2];if(W>=C(1.1920928955078125e-7)){break Pd}f=f+1|0;if(!(W<=C(-1.1920928955078125e-7))){continue}}break}v[j+32>>2]=0;break Md}v[j+28>>2]=v[j+28>>2]|4}v[j+28>>2]=v[j+28>>2]&-3}e=e+1|0;continue}}else{h=Md(q,f);a=v[h>>2];Qd:{if(!a|!v[a+24>>2]){break Qd}if(!ai(a+44|0)){break Qd}if(!(ob[v[v[a>>2]+116>>2]](a)|0)){ob[v[v[a>>2]+112>>2]](a,1);ob[v[v[a>>2]+124>>2]](a)}c=v[a+44>>2];b=Kc(c,0);c=Kc(c,1);Rd:{if(t[a+28|0]&1){uv(v[a+24>>2],b,c,k,W);break Rd}j=a+40|0;if(v[a+36>>2]?1:v[j>>2]){$m(v[a+24>>2],k,j,a+36|0);uv(v[a+24>>2],b,c,k,W);break Rd}Ub(b,0,g);Ub(c,0,g)}b=a;a=v[a+28>>2];v[b+28>>2]=a&-2;if(tv(w[h+24|0])){break Qd}i=!(a&4)|i}f=f+1|0;continue}}}if(v[d+24624>>2]==1){b=0;while(1){if((b|0)!=(k|0)){a=(b<<3)+_|0;v[(b<<2)+_>>2]=(v[a+4>>2]+v[a>>2]|0)/2;b=b+1|0;continue}break}}if(Qd(w[Ia|0])){c=0;g=kb-16|0;kb=g;Sd:{if(!v[d+1074376>>2]){l=d+1074460|0;a=l;v[a>>2]=0;v[a+4>>2]=0;a=v[d+1074456>>2];v[d+1074468>>2]=a;break Sd}a=v[d+1074456>>2];b=v[d+1074468>>2];Td:{if((a|0)==(b|0)){e=v[d+1074460>>2];break Td}v[d+1074468>>2]=a;e=v[d+24620>>2];h=d+1074460|0;Ud:{if((a|0)>(b|0)){e=Bt(e,v[d+24636>>2]);break Ud}e=Bt(e,v[d+24640>>2])}v[h>>2]=e;v[d+1074464>>2]=e;b=a}l=d+1074460|0;if((e|0)<=0){break Sd}b=(b<<12)-v[d+1074472>>2]|0;c=(b|0)/(e|0)|0;if(w[d+1074368|0]!=2){break Sd}v[g+12>>2]=50;h=v[d+1074464>>2];v[g+8>>2]=1e4/(h+1|0);f=v[Pe(g+12|0,g+8|0)>>2];while(1){j=c>>31;if((f|0)>=((j^c)-j|0)){break Sd}e=e+h|0;v[l>>2]=e;c=(b|0)/(e|0)|0;continue}}Vd:{Wd:{switch(v[d+24624>>2]-1|0){case 0:b=0;f=(k|0)>0?k:0;j=a<<12;e=d+12|0;n=a>>31;while(1){if((b|0)==(f|0)){break Vd}Xd:{if(v[l>>2]>0){h=v[d+1074472>>2]+c|0;v[d+1074472>>2]=h;s=v[e>>2];Xa=e,Ya=Ic(Pka(Oka(s,s>>31,h,h>>31),nb,1048576,0),nb),v[Xa>>2]=Ya;v[d+1074460>>2]=v[d+1074460>>2]-1;break Xd}h=v[e>>2];Xa=e,Ya=Ic(Pka(Oka(h,h>>31,a,n),nb,256,0),nb),v[Xa>>2]=Ya;v[d+1074472>>2]=j}b=b+1|0;e=e+4|0;continue};case 1:b=0;j=(k|0)>0?k:0;n=a<<12;e=d+12|0;h=a>>31;while(1){if((b|0)==(j|0)){break Vd}Yd:{if(v[l>>2]>0){f=v[d+1074472>>2]+c|0;v[d+1074472>>2]=f;s=v[e>>2];Xa=e,Ya=Ic(Pka(Oka(s,s>>31,f,f>>31),nb,1048576,0),nb),v[Xa>>2]=Ya;f=v[d+1074472>>2];m=f;s=f>>31;f=v[e+4>>2];Xa=e,Ya=Ic(Pka(Oka(m,s,f,f>>31),nb,1048576,0),nb),v[Xa+4>>2]=Ya;v[d+1074460>>2]=v[d+1074460>>2]-1;break Yd}f=v[e>>2];Xa=e,Ya=Ic(Pka(Oka(f,f>>31,a,h),nb,256,0),nb),v[Xa>>2]=Ya;f=v[e+4>>2];Xa=e,Ya=Ic(Pka(Oka(f,f>>31,a,h),nb,256,0),nb),v[Xa+4>>2]=Ya;v[d+1074472>>2]=n}b=b+1|0;e=e+8|0;continue};case 3:break Wd;default:break Vd}}f=0;n=(k|0)>0?k:0;s=a<<12;e=d+8204|0;b=d+12|0;h=a>>31;while(1){if((f|0)==(n|0)){break Vd}Zd:{if(v[l>>2]>0){j=v[d+1074472>>2]+c|0;v[d+1074472>>2]=j;m=v[b>>2];Xa=b,Ya=Ic(Pka(Oka(m,m>>31,j,j>>31),nb,1048576,0),nb),v[Xa>>2]=Ya;j=v[d+1074472>>2];m=j;i=j>>31;j=v[b+4>>2];Xa=b,Ya=Ic(Pka(Oka(m,i,j,j>>31),nb,1048576,0),nb),v[Xa+4>>2]=Ya;j=v[d+1074472>>2];m=j;i=j>>31;j=v[e>>2];Xa=e,Ya=Ic(Pka(Oka(m,i,j,j>>31),nb,1048576,0),nb),v[Xa>>2]=Ya;j=v[d+1074472>>2];m=j;i=j>>31;j=v[e+4>>2];Xa=e,Ya=Ic(Pka(Oka(m,i,j,j>>31),nb,1048576,0),nb),v[Xa+4>>2]=Ya;v[d+1074460>>2]=v[d+1074460>>2]-1;break Zd}j=v[b>>2];Xa=b,Ya=Ic(Pka(Oka(j,j>>31,a,h),nb,256,0),nb),v[Xa>>2]=Ya;j=v[b+4>>2];Xa=b,Ya=Ic(Pka(Oka(j,j>>31,a,h),nb,256,0),nb),v[Xa+4>>2]=Ya;j=v[e>>2];Xa=e,Ya=Ic(Pka(Oka(j,j>>31,a,h),nb,256,0),nb),v[Xa>>2]=Ya;j=v[e+4>>2];Xa=e,Ya=Ic(Pka(Oka(j,j>>31,a,h),nb,256,0),nb),v[Xa+4>>2]=Ya;v[d+1074472>>2]=s}f=f+1|0;e=e+8|0;b=b+8|0;continue}}kb=g+16|0}if(v[pa>>2]!=128){b=d+12|0;c=d+8204|0;a=v[d+24604>>2];e=v[d+24624>>2];_d:{if((a|0)==128|e>>>0<2){break _d}nM(b,k,a);if(e>>>0<4){break _d}nM(c,k,a)}}if(v[d+24624>>2]==4){a=k;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+_|0;c=a<<3;e=c|4;v[b+12>>2]=v[e+qa>>2];v[b+8>>2]=v[c+qa>>2];v[b+4>>2]=v[e+_>>2];v[b>>2]=v[c+_>>2];continue}break}}if(Qd(Ea)){a=v[d+24624>>2];v[M+72>>2]=k;v[M+68>>2]=a;v[M+64>>2]=_;a=v[v[na>>2]+8>>2];v[M+24>>2]=k;b=v[M+68>>2];v[M+16>>2]=v[M+64>>2];v[M+20>>2]=b;ob[a|0](na,M+16|0)}a=v[d+24624>>2];v[M+56>>2]=k;v[M+52>>2]=a;v[M+48>>2]=_;a=v[v[la>>2]+8>>2];v[M+8>>2]=k;b=v[M+52>>2];v[M>>2]=v[M+48>>2];v[M+4>>2]=b;ob[a|0](la,M);v[d+1074380>>2]=v[d+1074380>>2]-k;v[d+1074376>>2]=k+v[d+1074376>>2];fa=fa-k|0;Da=k+Da|0;continue}break}kb=da+32|0;return Da}function wg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,m=0,o=0,p=0,r=0,s=0,E=C(0),F=0,G=0,H=C(0),I=0,J=0,K=0,M=0,N=0;k=kb-2288|0;kb=k;a:{b:{c:{d:{e:{f:{if(wv(v[c>>2])){xc(b,268435456);J=v[c+8>>2];G=k+2264|0;e=G;v[e>>2]=0;v[e+4>>2]=0;Tb(e+8|0);v[k+2260>>2]=0;g:{h:{i:{j:{k:{l:{e=w[a+3|0];m:{n:{if((e-4&255)>>>0<=4){v[23588]=0;d=S(202,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}v[k+2260>>2]=d;break n}if(e>>>0>17){break m}o:{g=1<<e;if(!(g&63503)){if(!(g&198144)){break m}break o}if(w[a|0]){break o}break n}e=0;f=QA(a,v[b>>2]);v[23588]=0;U(203,k+96|0,c|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break k}d=k+96|0;f=v[d+4>>2];v[G>>2]=v[d>>2];v[G+4>>2]=f;Lm(G+8|0,d+8|0);Uc(d);f=Je(G);d=v[G>>2];v[k+2260>>2]=d;if(!f){break g}}e=w[a+3|0]}h=1;p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=!w[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}h=0}g=v[b>>2];if(!(g>>>0<262145|h)){e=e&255;v[k+96>>2]=((e|0)==10)<<4;h=d-v[Kb(k+96|0,k+2260|0)>>2]|0;if(e>>>0>15){break j}r:{if(!(1<<e&63503)){if((e|0)==10){break r}break j}if(!(w[a|0]&7)){break j}}e=(h|0)>=0?h<<1:-1;break i}e=e&255;if(e>>>0>8){break h}if(!(1<<e&432)){if((e|0)!=6){break h}e=0;if(d>>>0<10){break g}v[23588]=0;Q(188,c|0,4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}v[23588]=0;e=S(157,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[k+96>>2]=e;v[k+72>>2]=v[k+2260>>2];d=v[Kb(k+96|0,k+72|0)>>2];zg(c,8);e=((d>>>0>50529027?-1:B(d,85))>>>0)/(w[a|0]>>>3>>>0)|0;break i}a=P()|0;O()|0;break a}e=8/(oq(w[a+1|0])>>>0)|0;Oka(e,0,d,0);e=nb?-1:B(e,d);break i}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}g=0;d=oq(w[a+1|0]);s:{t:{switch(e|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:g=w[a|0];break s;case 9:g=16;break s;case 10:g=4;break s;case 16:case 17:break t;default:break s}}g=8}e=B(d,g&255)>>>3|0;d=(e+h|0)-1|0;e=((d>>>0<h>>>0?-1:d)>>>0)/(e>>>0)|0}xc(b,e);g=v[b>>2]}if(!g){e=0;break g}u[b+34>>1]=x[b+34>>1]&65470|w[a|0]>15|(w[a+1|0]!=1)<<6;if(!Og(b)){e=0;v[b>>2]=0;break g}u:{if(oe(a,_c(k+96|0,8,1,0,10))){v[23588]=0;d=Q(204,c|0,k+96|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){e=0;if(!d){break u}a=v[b>>2];d=0;v[23588]=0;v[k+72>>2]=a+1>>>1;e=S(202,c|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}xc(k+72|0,e);a=f+16|0;b=v[b+20>>2];h=v[k+72>>2];e=h;while(1)if(e){g=k+96|0;f=d+w[g|w[a|0]&15]|0;t[b|0]=f;d=w[g|w[a|0]>>>4]+(f&255)|0;t[b+1|0]=d;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=h+16|0;break u}}a=P()|0;O()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{g=w[a+3|0];switch(g-4|0){case 3:break D;case 4:break E;case 5:break F;case 2:break G;case 0:case 1:break H;default:break B}}v[23588]=0;b=fa(205,k+1168|0,c|0,b|0,(g|0)==5|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}Bb(b);e=v[c+8>>2]-J|0;break u}if(w[a+1|0]!=1){break C}v[23588]=0;Q(188,c|0,4)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}v[23588]=0;f=S(157,c|0)|0;a=v[23588];v[23588]=0;I:{J:{K:{if((a|0)!=1){v[23588]=0;v[k+72>>2]=f;h=S(206,c|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break K}v[23588]=0;U(207,k+96|0,c|0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break J}xc(k+72|0,v[k+96>>2]);g=v[k+72>>2];e=Je(k+96|0);d=x[b+34>>1];f=v[b+20>>2];b=v[b>>2];a=v[k+96>>2];v[23588]=0;da(208,e|0,a|0,f|0,Ij(b,d)|0,h<<24>>24);a=v[23588];v[23588]=0;if((a|0)==1){break I}e=g+9|0;Uc(k+96|0);break u}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Uc(k+96|0);break a}if(w[a+1|0]!=1|w[a|0]!=16){break C}e=v[k+2260>>2];d=Ak(k+1160|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];h=kb-16|0;kb=h;v[h+12>>2]=e>>>1;v[h+8>>2]=a;d=v[Kb(h+12|0,h+8|0)>>2];e=d;while(1){if(e){a=w[f|0]+g|0;g=a+w[f+1|0]|0;u[b>>1]=g<<8|a&255;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}kb=h+16|0;e=d<<1;break u}if(w[a+1|0]!=1|w[a|0]>16){break C}d=v[c+8>>2];f=v[c>>2];e=0;v[23588]=0;d=W(156,f|0,d|0,8)|0;f=v[23588];v[23588]=0;if((f|0)==1){break f}if(!d){break u}v[23588]=0;d=S(157,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break f}v[k+2260>>2]=d;if(d>>>0<4){break u}v[23588]=0;U(190,k+72|0,c|0,d|0);f=v[23588];v[23588]=0;if((f|0)==1){break c}f=k+72|0;s=rr(k+96|0,f);Bb(f);f=v[s>>2];v[23588]=0;d=S(209,f|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}e=d+4|0;p=w[a|0];m=(p|0)!=16;g=0;h=0;while(1){if(y[b>>2]<=h>>>0){break w}L:{if(m){break L}v[23588]=0;r=Q(164,s|0,8)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break L}a=V(30480)|0;break x}v[23588]=0;i=Q(164,s|0,1)|0;a=v[23588];v[23588]=0;if((a|0)==1){break y}v[23588]=0;f=Q(164,s|0,1)|0;a=v[23588];v[23588]=0;if((a|0)==1){break y}M:{N:{O:{if(!f){f=8;while(1){v[23588]=0;d=Q(164,s|0,1)|0;a=v[23588];v[23588]=0;if((a|0)==1){break M}if(d){break O}f=f+16|0;continue}}v[23588]=0;a=Q(164,s|0,3)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break N}break y}v[23588]=0;d=Q(164,s|0,4)|0;a=v[23588];v[23588]=0;if((a|0)==1){break y}a=f+d|0}g=(g&255)+(((i?-1:0)^a)&255)|0;P:{if((p|0)!=16){t[v[b+20>>2]+h|0]=g;break P}u[v[b+20>>2]+(h<<1)>>1]=r&255|g<<8}h=h+1|0;continue}break}a=V(30480)|0;break x}if(w[a+1|0]!=1){break B}break A}if((g|0)!=7){break B}if(w[a+1|0]==1){break A}}e=w[a|0];break z}e=w[a|0];if(e>>>0>16){break z}e=0;if(y[k+2260>>2]<5){break u}d=x[b+34>>1];f=v[b+20>>2];a=v[b>>2];v[23588]=0;e=W(210,c|0,f|0,Ij(a,d)|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break u}break f}Q:{if((g&254)!=16|(e&255)!=16){break Q}d=w[a+1|0];if((d-1&255)>>>0>1){break Q}K=k,M=B(v[b>>2],oq(d)),v[K+96>>2]=M;xc(k+96|0,v[k+2260>>2]);a=v[b+20>>2];e=v[k+96>>2];if((g|0)==16){b=e;while(1){if(!b){break u}K=a,M=x[dc(30512,w[f|0])>>1],u[K>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}b=e;while(1){if(!b){break u}K=a,M=x[dc(31024,w[f|0])>>1],u[K>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}d=(e&255)!=8;if(!(d|w[a+1|0]!=1)){R:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=kb-16|0;kb=d;v[d+12>>2]=v[k+2260>>2];v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0];b=b+1|0;f=f+1|0;e=e-1|0;continue}break};kb=d+16|0;e=a;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=kb-16|0;kb=d;v[d+12>>2]=v[k+2260>>2];v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0]^128;b=b+1|0;f=f+1|0;e=e-1|0;continue}break};kb=d+16|0;e=a;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break R}}e=v[k+2260>>2];d=Cr(k- -64|0);a=v[b>>2];b=v[b+20>>2];g=w[d|0];d=kb-16|0;kb=d;v[d+12>>2]=e;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=w[f|0]+g|0;t[b|0]=g;b=b+1|0;f=f+1|0;e=e-1|0;continue}break}kb=d+16|0;e=a;break u}if(!(w[a+1|0]!=3|d)){S:{switch(g|0){case 0:i=kb-16|0;kb=i;e=v[k+2260>>2];v[i+12>>2]=e;d=v[b>>2];v[i+8>>2]=d;a=i+8|0;g=v[Kb(a,i+12|0)>>2];v[i+8>>2]=d;v[i+4>>2]=e-g;e=v[Kb(a,i+4|0)>>2];h=v[b+20>>2];a=g;d=f;while(1){if(a){t[h|0]=w[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=v[b+20>>2]+1|0;d=v[b>>2]+f|0;a=e;while(1){if(a){t[h|0]=w[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};kb=i+16|0;e=e+g|0;break u;case 1:i=kb-16|0;kb=i;e=v[k+2260>>2];v[i+12>>2]=e;d=v[b>>2];v[i+8>>2]=d;a=i+8|0;g=v[Kb(a,i+12|0)>>2];v[i+8>>2]=d;v[i+4>>2]=e-g;e=v[Kb(a,i+4|0)>>2];h=v[b+20>>2];a=g;d=f;while(1){if(a){t[h|0]=w[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=v[b+20>>2]+1|0;d=v[b>>2]+f|0;a=e;while(1){if(a){t[h|0]=w[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};kb=i+16|0;e=e+g|0;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break S}}h=v[k+2260>>2];e=w[Cr(k+56|0)|0];p=kb-16|0;kb=p;v[p+12>>2]=h;g=v[b>>2];v[p+8>>2]=g;d=p+8|0;i=v[Kb(d,p+12|0)>>2];v[p+8>>2]=g;v[p+4>>2]=h-i;h=v[Kb(d,p+4|0)>>2];m=b;r=v[b+20>>2];d=e;b=i;g=f;while(1){if(b){d=w[g|0]+d|0;t[r|0]=d;r=r+2|0;g=g+1|0;b=b-1|0;continue}break}r=v[m+20>>2]+1|0;g=v[m>>2]+f|0;b=h;while(1){if(b){e=w[g|0]+e|0;t[r|0]=e;r=r+2|0;g=g+1|0;b=b-1|0;continue}break}kb=p+16|0;e=h+i|0;if(w[a+3|0]!=11){break u}a=v[m+20>>2];b=a+(v[m>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;continue}}d=e&255;if(!((d|0)!=8|w[a+1|0]!=2)){e=0;T:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=kb-16|0;kb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0];t[b+1|0]=w[f+1|0];b=b+2|0;f=f+2|0;e=e-1|0;continue}break};kb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=kb-16|0;kb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0]^128;t[b+1|0]=w[f+1|0]^128;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};kb=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=v[k+2260>>2];a=Cr(k+48|0);d=v[b>>2];g=v[b+20>>2];a=w[a|0];h=kb-16|0;kb=h;v[h+12>>2]=e>>>1;v[h+8>>2]=d;b=a;e=v[Kb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=w[f|0]+a|0;t[g|0]=a;b=w[f+1|0]+b|0;t[g+1|0]=b;g=g+2|0;f=f+2|0;d=d-1|0;continue}break}kb=h+16|0;e=e<<1;break u}if(!(w[a+2|0]|((d|0)!=16|w[a+1|0]!=1))){U:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=kb-16|0;kb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[f|0]|w[f+1|0]<<8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};kb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=kb-16|0;kb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[f|0]|w[f+1|0]<<8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};kb=d+16|0;e=a<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break U}}e=v[k+2260>>2];d=Ak(k+40|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];d=kb-16|0;kb=d;v[d+12>>2]=e>>>1;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(w[f|0]+g|0)+(w[f+1|0]<<8)|0;u[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}kb=d+16|0;e=a<<1;break u}d=e&255;if(!((d|0)!=16|w[a+1|0]!=1|w[a+2|0]!=1)){e=0;V:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];g=kb-16|0;kb=g;v[g+12>>2]=v[k+2260>>2]>>>1;v[g+8>>2]=a;d=v[Kb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=a<<8|a>>>8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};kb=g+16|0;e=d<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];g=kb-16|0;kb=g;v[g+12>>2]=v[k+2260>>2]>>>1;v[g+8>>2]=a;d=v[Kb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};kb=g+16|0;e=d<<1;break u;case 2:break V;default:break u}}e=v[k+2260>>2];d=Ak(k+32|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];d=kb-16|0;kb=d;v[d+12>>2]=e>>>1;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(w[f+1|0]+g|0)+(w[f|0]<<8)|0;u[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}kb=d+16|0;e=a<<1;break u}h=a;if(!(w[a+2|0]|((d|0)!=16|w[a+1|0]!=3))){W:{switch(g|0){case 0:m=kb-16|0;kb=m;d=v[k+2260>>2];v[m+12>>2]=d;i=v[b>>2]<<1;v[m+8>>2]=i;a=m+8|0;g=v[Kb(a,m+12|0)>>2];v[m+8>>2]=i;v[m+4>>2]=d-g;a=v[Kb(a,m+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){u[e>>1]=w[d|0]|w[d+1|0]<<8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+i|0;d=v[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){u[d>>1]=w[e|0]|w[e+1|0]<<8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};kb=m+16|0;e=a+h<<1;break u;case 1:m=kb-16|0;kb=m;d=v[k+2260>>2];v[m+12>>2]=d;i=v[b>>2]<<1;v[m+8>>2]=i;a=m+8|0;g=v[Kb(a,m+12|0)>>2];v[m+8>>2]=i;v[m+4>>2]=d-g;a=v[Kb(a,m+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){u[e>>1]=(w[d|0]|w[d+1|0]<<8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+i|0;d=v[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){u[d>>1]=(w[e|0]|w[e+1|0]<<8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};kb=m+16|0;e=a+h<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break W}}g=v[k+2260>>2];a=x[Ak(k+24|0)>>1];s=kb-16|0;kb=s;v[s+12>>2]=g;p=v[b>>2]<<1;v[s+8>>2]=p;d=s+8|0;e=v[Kb(d,s+12|0)>>2];v[s+8>>2]=p;v[s+4>>2]=g-e;m=v[Kb(d,s+4|0)>>2];g=b;d=v[g+20>>2];b=a;i=e>>>1|0;r=i;e=f;while(1){if(r){b=(w[e|0]+b|0)+(w[e+1|0]<<8)|0;u[d>>1]=b;d=d+4|0;e=e+2|0;r=r-1|0;continue}break}e=f+p|0;d=v[g+20>>2]+2|0;b=m>>>1|0;r=b;while(1){if(r){a=(w[e|0]+a|0)+(w[e+1|0]<<8)|0;u[d>>1]=a;d=d+4|0;e=e+2|0;r=r-1|0;continue}break}kb=s+16|0;e=b+i<<1;if(w[h+3|0]!=11){break u}a=v[g+20>>2];b=a+(v[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;continue}}a=e&255;if(!((a|0)!=16|w[h+1|0]!=3|w[h+2|0]!=1)){e=0;X:{switch(g|0){case 0:p=kb-16|0;kb=p;d=v[k+2260>>2];v[p+12>>2]=d;m=v[b>>2]<<1;v[p+8>>2]=m;a=p+8|0;g=v[Kb(a,p+12|0)>>2];v[p+8>>2]=m;v[p+4>>2]=d-g;i=v[Kb(a,p+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=a<<8|a>>>8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=v[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=a<<8|a>>>8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};kb=p+16|0;e=b+h<<1;break u;case 1:p=kb-16|0;kb=p;d=v[k+2260>>2];v[p+12>>2]=d;m=v[b>>2]<<1;v[p+8>>2]=m;a=p+8|0;g=v[Kb(a,p+12|0)>>2];v[p+8>>2]=m;v[p+4>>2]=d-g;i=v[Kb(a,p+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=(a<<8|a>>>8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=v[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};kb=p+16|0;e=b+h<<1;break u;case 2:break X;default:break u}}e=v[k+2260>>2];a=x[Ak(k+16|0)>>1];r=kb-16|0;kb=r;v[r+12>>2]=e;p=v[b>>2]<<1;v[r+8>>2]=p;d=r+8|0;g=v[Kb(d,r+12|0)>>2];v[r+8>>2]=p;v[r+4>>2]=e-g;m=v[Kb(d,r+4|0)>>2];e=b;h=v[b+20>>2];b=a;i=g>>>1|0;d=i;g=f;while(1){if(d){b=(w[g+1|0]+b|0)+(w[g|0]<<8)|0;u[h>>1]=b;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}g=f+p|0;h=v[e+20>>2]+2|0;b=m>>>1|0;d=b;while(1){if(d){a=(w[g+1|0]+a|0)+(w[g|0]<<8)|0;u[h>>1]=a;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}kb=r+16|0;e=b+i<<1;break u}if(!(w[h+2|0]|((a|0)!=16|w[h+1|0]!=2))){e=0;Y:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=kb-16|0;kb=d;v[d+12>>2]=v[k+2260>>2]>>>2;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[f|0]|w[f+1|0]<<8;u[b+2>>1]=w[f+2|0]|w[f+3|0]<<8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};kb=d+16|0;e=a<<2;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=kb-16|0;kb=d;v[d+12>>2]=v[k+2260>>2]>>>2;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[f|0]|w[f+1|0]<<8)^32768;u[b+2>>1]=(w[f+2|0]|w[f+3|0]<<8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};kb=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}e=v[k+2260>>2];a=Ak(k+8|0);d=v[b>>2];g=v[b+20>>2];a=x[a>>1];h=kb-16|0;kb=h;v[h+12>>2]=e>>>2;v[h+8>>2]=d;b=a;e=v[Kb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(w[f|0]+a|0)+(w[f+1|0]<<8)|0;u[g>>1]=a;b=(w[f+2|0]+b|0)+(w[f+3|0]<<8)|0;u[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}kb=h+16|0;e=e<<2;break u}a=e&255;if(!((a|0)!=16|w[h+1|0]!=2|w[h+2|0]!=1)){e=0;Z:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];g=kb-16|0;kb=g;v[g+12>>2]=v[k+2260>>2]>>>2;v[g+8>>2]=a;d=v[Kb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=a<<8|a>>>8;a=w[f+2|0]|w[f+3|0]<<8;u[b+2>>1]=a<<8|a>>>8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};kb=g+16|0;e=d<<2;break u;case 1:a=v[b>>2];b=v[b+20>>2];g=kb-16|0;kb=g;v[g+12>>2]=v[k+2260>>2]>>>2;v[g+8>>2]=a;d=v[Kb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;a=w[f+2|0]|w[f+3|0]<<8;u[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};kb=g+16|0;e=d<<2;break u;case 2:break Z;default:break u}}e=v[k+2260>>2];a=Ak(k);d=v[b>>2];g=v[b+20>>2];a=x[a>>1];h=kb-16|0;kb=h;v[h+12>>2]=e>>>2;v[h+8>>2]=d;b=a;e=v[Kb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(w[f+1|0]+a|0)+(w[f|0]<<8)|0;u[g>>1]=a;b=(w[f+3|0]+b|0)+(w[f+2|0]<<8)|0;u[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}kb=h+16|0;e=e<<2;break u}if(!(g|w[h+1|0]!=1|(a|0)!=24)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=kb-16|0;kb=g;v[g+12>>2]=(b>>>0)/3;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=ld(w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24,16),u[K>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}kb=g+16|0;e=B(b,3);break u}g=kb-16|0;kb=g;v[g+12>>2]=(b>>>0)/3;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=ld(w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24,16),u[K>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}kb=g+16|0;e=B(b,3);break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=24)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=kb-16|0;kb=g;v[g+12>>2]=(b>>>0)/6;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=ld(w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24,16),u[K>>1]=M;K=a,M=ld(w[f+4|0]<<16|w[f+3|0]<<8|w[f+5|0]<<24,16),u[K+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}kb=g+16|0;e=B(b,6);break u}g=kb-16|0;kb=g;v[g+12>>2]=(b>>>0)/6;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=ld(w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24,16),u[K>>1]=M;K=a,M=ld(w[f+4|0]<<16|w[f+5|0]<<8|w[f+3|0]<<24,16),u[K+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}kb=g+16|0;e=B(b,6);break u}if(!(g|w[h+1|0]!=1|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=kb-16|0;kb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=ld(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),16),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}kb=g+16|0;e=b<<2;break u}g=kb-16|0;kb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);K=a,M=ld(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}kb=g+16|0;e=b<<2;break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=kb-16|0;kb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=ld(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),16),u[K>>1]=M;K=a,M=ld(w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),16),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}kb=g+16|0;e=b<<3;break u}g=kb-16|0;kb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);K=a,M=ld(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);K=a,M=ld(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}kb=g+16|0;e=b<<3;break u}if(!(g|w[h+1|0]!=1|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=kb-16|0;kb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=Yc(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),48),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}kb=g+16|0;e=b<<3;break u}i=kb-16|0;kb=i;v[i+12>>2]=b>>>3;v[i+8>>2]=d;d=v[Kb(i+12|0,i+8|0)>>2];e=d;while(1){if(e){h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);b=h<<24|h<<8&16711680;m=h>>>8|0;g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=h>>>24|0;b=b|((m|g<<24)&65280|(h|g<<8)&255);K=a,M=Yc((m|(g&255)<<24)&-16777216|(h|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24),b,48),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}kb=i+16|0;e=d<<3;break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=kb-16|0;kb=g;v[g+12>>2]=b>>>4;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=Yc(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),48),u[K>>1]=M;K=a,M=Yc(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24),w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24),48),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}kb=g+16|0;e=b<<4;break u}i=kb-16|0;kb=i;v[i+12>>2]=b>>>4;v[i+8>>2]=d;d=v[Kb(i+12|0,i+8|0)>>2];e=d;while(1){if(e){h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);b=h<<24|h<<8&16711680;m=h>>>8|0;g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=h>>>24|0;b=b|((m|g<<24)&65280|(h|g<<8)&255);K=a,M=Yc((m|(g&255)<<24)&-16777216|(h|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24),b,48),u[K>>1]=M;h=w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24);g=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);b=h<<24|h<<8&16711680|((g<<24|h>>>8)&65280|(g<<8|h>>>24)&255);K=a,M=Yc(((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24),b,48),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}kb=i+16|0;e=d<<4;break u}if(!(w[h+1|0]!=1|(g|0)!=3|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=kb-16|0;kb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){j=Kf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Wh(C(Yd(og(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));_:{if(C(D(j))<C(2147483648)){d=~~j;break _}d=-2147483648}K=a,M=ed(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}kb=g+16|0;e=b<<2;break u}g=kb-16|0;kb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Kf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Wh(C(Yd(og(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));$:{if(C(D(j))<C(2147483648)){d=~~j;break $}d=-2147483648}K=a,M=ed(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}kb=g+16|0;e=b<<2;break u}a=e&255;if(!(w[h+1|0]!=2|(g|0)!=3|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=kb-16|0;kb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){j=Kf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Wh(C(Yd(og(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));aa:{if(C(D(j))<C(2147483648)){d=~~j;break aa}d=-2147483648}K=a,M=ed(d),u[K>>1]=M;j=Kf((l(2,w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24)),q()));j=Wh(C(Yd(og(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));ba:{if(C(D(j))<C(2147483648)){d=~~j;break ba}d=-2147483648}K=a,M=ed(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}kb=g+16|0;e=b<<3;break u}g=kb-16|0;kb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Kb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Kf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Wh(C(Yd(og(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));ca:{if(C(D(j))<C(2147483648)){d=~~j;break ca}d=-2147483648}K=a,M=ed(d),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);j=Kf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Wh(C(Yd(og(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));da:{if(C(D(j))<C(2147483648)){d=~~j;break da}d=-2147483648}K=a,M=ed(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}kb=g+16|0;e=b<<3;break u}if(!(w[h+1|0]!=1|(g|0)!=3|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=kb-32|0;kb=g;v[g+24>>2]=b>>>3;v[g+16>>2]=d;d=v[Kb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,b|0);o=ng(+n());K=g,N=nf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=xe(A[Hg(g+24|0,g+16|0,g+8|0)>>3]*32768);ea:{if(D(o)<2147483648){b=~~o;break ea}b=-2147483648}K=a,M=ed(b),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}kb=g+32|0;e=d<<3;break u}m=kb-32|0;kb=m;v[m+24>>2]=b>>>3;v[m+16>>2]=d;h=v[Kb(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;i=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);d=r|i<<24;b=b>>>24|0;l(0,(r|(i&255)<<24)&-16777216|(b|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,g|(d&65280|(b|i<<8)&255));o=ng(+n());K=m,N=nf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=xe(A[Hg(m+24|0,m+16|0,m+8|0)>>3]*32768);fa:{if(D(o)<2147483648){b=~~o;break fa}b=-2147483648}K=a,M=ed(b),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}kb=m+32|0;e=h<<3;break u}a=e&255;if(!(w[h+1|0]!=2|(g|0)!=3|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=kb-32|0;kb=g;v[g+24>>2]=b>>>4;v[g+16>>2]=d;d=v[Kb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,b|0);o=ng(+n());K=g,N=nf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=xe(A[Hg(g+24|0,g+16|0,g+8|0)>>3]*32768);ga:{if(D(o)<2147483648){b=~~o;break ga}b=-2147483648}K=a,M=ed(b),u[K>>1]=M;b=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);l(0,w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24));l(1,b|0);o=ng(+n());K=g,N=nf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=xe(A[Hg(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(D(o)<2147483648){b=~~o;break ha}b=-2147483648}K=a,M=ed(b),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}kb=g+32|0;e=d<<4;break u}m=kb-32|0;kb=m;v[m+24>>2]=b>>>4;v[m+16>>2]=d;h=v[Kb(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);d=b<<24|b<<8&16711680;i=b>>>8|0;g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);b=b>>>24|0;d=d|((i|g<<24)&65280|(b|g<<8)&255);l(0,(i|(g&255)<<24)&-16777216|(b|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24));l(1,d|0);o=ng(+n());K=m,N=nf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=xe(A[Hg(m+24|0,m+16|0,m+8|0)>>3]*32768);ia:{if(D(o)<2147483648){b=~~o;break ia}b=-2147483648}K=a,M=ed(b),u[K>>1]=M;b=w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;i=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);d=r|i<<24;b=b>>>24|0;l(0,(r|(i&255)<<24)&-16777216|(b|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,g|(d&65280|(b|i<<8)&255));o=ng(+n());K=m,N=nf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=xe(A[Hg(m+24|0,m+16|0,m+8|0)>>3]*32768);ja:{if(D(o)<2147483648){b=~~o;break ja}b=-2147483648}K=a,M=ed(b),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}kb=m+32|0;e=h<<4;break u}if(!((g|0)!=15|(w[h+1|0]-1&255)>>>0>1|(a|0)!=24)){v[k+96>>2]=-2147483648;a=v[k+2260>>2];ka:{if(!w[h+2|0]){r=k+96|0;e=0;s=kb-16|0;kb=s;K=s,M=B(v[b>>2],Ld(x[b+34>>1])),v[K+12>>2]=M;xc(s+12|0,(a>>>0)/3|0);a=f;g=v[s+12>>2];h=g;while(1){if(h){i=w[a+1|0]<<16|w[a|0]<<8|w[a+2|0]<<24;la:{ma:{na:{if((i|0)>=0){d=i;break na}d=-2147483648;if((i|0)==-2147483648){break ma}d=0-i|0}if(d>>>0<=e>>>0){break la}}e=d}h=h-1|0;a=a+3|0;continue}else{oa:{if(!e){break oa}p=e-1|0;m=e>>>1|0;h=v[b+20>>2];a=g;while(1){if(!a){break oa}d=w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24;i=d>>31<<31|d>>>1;d=m|d<<31;pa:{if((i|0)>0|(i|0)>=0){d=Rka(d,i,e,0);i=nb;break pa}i=Rka(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,e,0);d=0-i|0;i=0-(nb+((i|0)!=0)|0)|0}K=h,M=ld(Ic(d,i),16),u[K>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=e}kb=s+16|0;e=B(g,3);break ka}r=k+96|0;e=0;s=kb-16|0;kb=s;K=s,M=B(v[b>>2],Ld(x[b+34>>1])),v[K+12>>2]=M;xc(s+12|0,(a>>>0)/3|0);a=f;g=v[s+12>>2];h=g;while(1){if(h){i=w[a+1|0]<<16|w[a+2|0]<<8|w[a|0]<<24;qa:{ra:{sa:{if((i|0)>=0){d=i;break sa}d=-2147483648;if((i|0)==-2147483648){break ra}d=0-i|0}if(d>>>0<=e>>>0){break qa}}e=d}h=h-1|0;a=a+3|0;continue}else{ta:{if(!e){break ta}p=e-1|0;m=e>>>1|0;h=v[b+20>>2];a=g;while(1){if(!a){break ta}d=w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24;i=d>>31<<31|d>>>1;d=m|d<<31;ua:{if((i|0)>0|(i|0)>=0){d=Rka(d,i,e,0);i=nb;break ua}i=Rka(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,e,0);d=0-i|0;i=0-(nb+((i|0)!=0)|0)|0}K=h,M=ld(Ic(d,i),16),u[K>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=e}kb=s+16|0;e=B(g,3)}if(!e){break u}a=v[k+96>>2];if((a|0)==-2147483648){break u}f=Oka(x[b+32>>1],0,a,0)+1073741824|0;a=nb;a=f>>>0<1073741824?a+1|0:a;K=b,M=Dd(Ec((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}va:{a=e&255;if((a|0)!=32){break va}if(!((g|0)!=15|(w[h+1|0]-1&255)>>>0>1)){v[k+96>>2]=-2147483648;d=v[k+2260>>2];wa:{if(!w[h+2|0]){r=k+96|0;a=0;s=kb-16|0;kb=s;K=s,M=B(v[b>>2],Ld(x[b+34>>1])),v[K+12>>2]=M;xc(s+12|0,d>>>2|0);e=f;h=f;g=v[s+12>>2];f=g;while(1){if(f){i=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);xa:{ya:{za:{if((i|0)>=0){d=i;break za}d=-2147483648;if((i|0)==-2147483648){break ya}d=0-i|0}if(d>>>0<=a>>>0){break xa}}a=d}f=f-1|0;h=h+4|0;continue}else{Aa:{if(!a){break Aa}p=a-1|0;m=a>>>1|0;h=v[b+20>>2];f=g;while(1){if(!f){break Aa}d=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);i=d>>31<<31|d>>>1;d=m|d<<31;Ba:{if((i|0)>0|(i|0)>=0){d=Rka(d,i,a,0);i=nb;break Ba}i=Rka(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(nb+((i|0)!=0)|0)|0}K=h,M=ld(Ic(d,i),16),u[K>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=a}kb=s+16|0;e=g<<2;break wa}r=k+96|0;a=0;s=kb-16|0;kb=s;K=s,M=B(v[b>>2],Ld(x[b+34>>1])),v[K+12>>2]=M;xc(s+12|0,d>>>2|0);e=f;h=f;g=v[s+12>>2];f=g;while(1){if(f){d=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);i=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);Ca:{Da:{Ea:{if((i|0)>=0){d=i;break Ea}d=-2147483648;if((i|0)==-2147483648){break Da}d=0-i|0}if(a>>>0>=d>>>0){break Ca}}a=d}f=f-1|0;h=h+4|0;continue}else{Fa:{if(!a){break Fa}p=a-1|0;m=a>>>1|0;h=v[b+20>>2];f=g;while(1){if(!f){break Fa}d=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);i=d>>31<<31|d>>>1;d=m|d<<31;Ga:{if((i|0)>0|(i|0)>=0){d=Rka(d,i,a,0);i=nb;break Ga}i=Rka(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(nb+((i|0)!=0)|0)|0}K=h,M=ld(Ic(d,i),16),u[K>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=a}kb=s+16|0;e=g<<2}if(!e){break u}a=v[k+96>>2];if((a|0)==-2147483648){break u}f=Oka(x[b+32>>1],0,a,0)+1073741824|0;a=nb;a=f>>>0<1073741824?a+1|0:a;K=b,M=Dd(Ec((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}if((g|0)!=14|(w[h+1|0]-1&255)>>>0>1){break va}v[k+96>>2]=1065353216;a=v[k+2260>>2];Ha:{if(!w[h+2|0]){e=k+96|0;h=kb-16|0;kb=h;K=h,M=B(v[b>>2],Ld(x[b+34>>1])),v[K+12>>2]=M;xc(h+12|0,a>>>2|0);g=f;d=v[h+12>>2];a=d;while(1){if(a){j=Kf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));j=C(D(og(j)?j>=C(0)?C(1):C(-1):j));E=j>E?j:E;a=a-1|0;g=g+4|0;continue}else{Ia:{a=E==C(0);if(a){break Ia}H=a?C(1):C(C(1)/E);g=v[b+20>>2];a=d;while(1){if(!a){break Ia}j=Kf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Wh(C(Yd(C(H*(og(j)?j>=C(0)?C(1):C(-1):j)),C(-1))*C(32768)));Ja:{if(C(D(j))<C(2147483648)){i=~~j;break Ja}i=-2147483648}K=g,M=ed(i),u[K>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){z[e>>2]=E}kb=h+16|0;e=d<<2}break}break Ha}e=k+96|0;i=kb-16|0;kb=i;K=i,M=B(v[b>>2],Ld(x[b+34>>1])),v[K+12>>2]=M;xc(i+12|0,a>>>2|0);g=f;d=v[i+12>>2];a=d;while(1){if(a){h=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);j=Kf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),q()));j=C(D(og(j)?j>=C(0)?C(1):C(-1):j));E=j>E?j:E;a=a-1|0;g=g+4|0;continue}else{Ka:{a=E==C(0);if(a){break Ka}H=a?C(1):C(C(1)/E);g=v[b+20>>2];a=d;while(1){if(!a){break Ka}h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Kf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),q()));j=Wh(C(Yd(C(H*(og(j)?j>=C(0)?C(1):C(-1):j)),C(-1))*C(32768)));La:{if(C(D(j))<C(2147483648)){h=~~j;break La}h=-2147483648}K=g,M=ed(h),u[K>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){z[e>>2]=E}kb=i+16|0;e=d<<2}break}}if(!e){break u}j=z[k+96>>2];if(j==C(1)){break u}j=Wh(az(C(j*C(x[b+32>>1])),C(1),C(64)));a=65535;Ma:{if(j>=C(65535)){break Ma}a=0;if(j<=C(0)){break Ma}a=~~j>>>0;if(j<C(4294967296)&j>=C(0)){break Ma}a=0}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break u}if(!((g|0)!=14|(w[h+1|0]-1&255)>>>0>1|(a|0)!=64)){v[k+96>>2]=0;v[k+100>>2]=1072693248;a=v[k+2260>>2];Na:{if(!w[h+2|0]){h=k+96|0;i=kb-32|0;kb=i;K=i,M=B(v[b>>2],Ld(x[b+34>>1])),v[K+4>>2]=M;xc(i+4|0,a>>>3|0);d=f;e=v[i+4>>2];a=e;while(1){if(a){g=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);l(0,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));l(1,g|0);o=ng(+n());o=D(nf(o)?o>=0?1:-1:o);F=o>F?o:F;a=a-1|0;d=d+8|0;continue}else{Oa:{a=F==0;if(a){break Oa}I=a?1:1/F;d=v[b+20>>2];a=e;while(1){if(!a){break Oa}g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,g|0);o=ng(+n());K=i,N=I*(nf(o)?o>=0?1:-1:o),A[K+24>>3]=N;v[i+16>>2]=0;v[i+20>>2]=-1074790400;v[i+8>>2]=0;v[i+12>>2]=1072693248;o=xe(A[Hg(i+24|0,i+16|0,i+8|0)>>3]*32768);Pa:{if(D(o)<2147483648){g=~~o;break Pa}g=-2147483648}K=d,M=ed(g),u[K>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(h){A[h>>3]=F}kb=i+32|0;e=e<<3}break}break Na}i=k+96|0;p=kb-32|0;kb=p;K=p,M=B(v[b>>2],Ld(x[b+34>>1])),v[K+4>>2]=M;xc(p+4|0,a>>>3|0);d=f;g=v[p+4>>2];a=g;while(1){if(a){e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=e<<24|e<<8&16711680;r=e>>>8|0;m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);e=e>>>24|0;h=h|((r|m<<24)&65280|(e|m<<8)&255);l(0,(r|(m&255)<<24)&-16777216|(e|(m&16777215)<<8)&16711680|(m>>>8&65280|m>>>24));l(1,h|0);o=ng(+n());o=D(nf(o)?o>=0?1:-1:o);F=o>F?o:F;a=a-1|0;d=d+8|0;continue}else{Qa:{a=F==0;if(a){break Qa}I=a?1:1/F;d=v[b+20>>2];a=g;while(1){if(!a){break Qa}m=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);e=m<<24|m<<8&16711680;r=m>>>8|0;h=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);m=m>>>24|0;e=e|((r|h<<24)&65280|(m|h<<8)&255);l(0,(r|(h&255)<<24)&-16777216|(m|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,e|0);o=ng(+n());K=p,N=I*(nf(o)?o>=0?1:-1:o),A[K+24>>3]=N;v[p+16>>2]=0;v[p+20>>2]=-1074790400;v[p+8>>2]=0;v[p+12>>2]=1072693248;o=xe(A[Hg(p+24|0,p+16|0,p+8|0)>>3]*32768);Ra:{if(D(o)<2147483648){e=~~o;break Ra}e=-2147483648}K=d,M=ed(e),u[K>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(i){A[i>>3]=F}kb=p+32|0;e=g<<3}break}}if(!e){break u}o=A[k+96>>3];if(o==1){break u}K=b,M=bU(tu(o*+x[b+32>>1],1,64)),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}Sa:{Ta:{Ua:{Va:{a=(e&255)!=32;Wa:{if(!(a|(w[h+1|0]!=1|(g|0)!=12))){E=C(30517578125e-15);e=v[k+2260>>2];if(!w[h+2|0]){break Wa}break Sa}if(!(w[h+1|0]!=2|(g|0)!=12|a)){E=C(30517578125e-15);e=v[k+2260>>2];if(!w[h+2|0]){break Ua}break Ta}a=(e&255)!=32;if(a|(w[h+1|0]!=1|(g|0)!=13)){break Va}E=C(1.1920928955078125e-7);e=v[k+2260>>2];if(w[h+2|0]){break Sa}}a=v[b>>2];b=v[b+20>>2];d=kb-16|0;kb=d;v[d+12>>2]=e>>>2;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){j=Kf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Wh(C(Yd(C((og(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));Xa:{if(C(D(j))<C(2147483648)){g=~~j;break Xa}g=-2147483648}K=b,M=ed(g),u[K>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}kb=d+16|0;e=a<<2;break u}e=0;if(w[h+1|0]!=2|(g|0)!=13|a){break u}E=C(1.1920928955078125e-7);e=v[k+2260>>2];if(w[h+2|0]){break Ta}}a=v[b>>2];b=v[b+20>>2];d=kb-16|0;kb=d;v[d+12>>2]=e>>>3;v[d+8>>2]=a;a=v[Kb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){j=Kf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Wh(C(Yd(C((og(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));Ya:{if(C(D(j))<C(2147483648)){g=~~j;break Ya}g=-2147483648}K=b,M=ed(g),u[K>>1]=M;j=Kf((l(2,w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24)),q()));j=Wh(C(Yd(C((og(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));Za:{if(C(D(j))<C(2147483648)){g=~~j;break Za}g=-2147483648}K=b,M=ed(g),u[K+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}kb=d+16|0;e=a<<3;break u}a=v[b>>2];b=v[b+20>>2];g=kb-16|0;kb=g;v[g+12>>2]=e>>>3;v[g+8>>2]=a;a=v[Kb(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Kf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Wh(C(Yd(C((og(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));_a:{if(C(D(j))<C(2147483648)){d=~~j;break _a}d=-2147483648}K=b,M=ed(d),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);j=Kf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Wh(C(Yd(C((og(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));$a:{if(C(D(j))<C(2147483648)){d=~~j;break $a}d=-2147483648}K=b,M=ed(d),u[K+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}kb=g+16|0;e=a<<3;break u}a=v[b>>2];b=v[b+20>>2];g=kb-16|0;kb=g;v[g+12>>2]=e>>>2;v[g+8>>2]=a;a=v[Kb(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Kf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Wh(C(Yd(C((og(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));ab:{if(C(D(j))<C(2147483648)){d=~~j;break ab}d=-2147483648}K=b,M=ed(d),u[K>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}kb=g+16|0;e=a<<2;break u}a=V(30480)|0}if((O()|0)!=(ea(30480)|0)){break d}_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break v}}Bb(s);break u}a=P()|0;O()|0;break d}v[23588]=0;Q(155,c|0,e+J|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}}Uc(G)}kb=k+2288|0;return e|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Bb(s);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Uc(G);T(a|0);L()}function Mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=kb-640|0;kb=d;zc(b);f=kb-16|0;kb=f;h=d+448|0;Mq(f+8|0,h);j=v[f+12>>2];g=b;nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(j|0)){_b(g,v[f+12>>2])}kb=f+16|0;b=(b|0)==(j|0);if(!b){zT(h)}a:{b:{c:{if(!b){break c}if(!BT(d+448|0)){break c}if(!Qb(v[g>>2],v[g+8>>2],Ec(AT(d+448|0),nb))){break c}if(!c){e=1;break c}Bd(a,32);t[d+447|0]=0;j=Mb(d+432|0);d:{e:{f:{g:{h:{i:{j:{k:{if(!Sb(d+448|0,16245,4)){v[23588]=0;R(406,a|0,16777216);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=v[g>>2];v[23588]=0;b=S(160,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;Q(155,g|0,b-4|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;A=S(157,g|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break k}break b}l:{m:{n:{o:{p:{q:{if((x[d+488>>1]-2185&65535)>>>0>1910){break q}b=v[g>>2];v[23588]=0;b=S(160,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;Q(155,g|0,b-4|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;A=S(157,g|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}if(A>>>0<256){break q}b=v[g>>2];v[23588]=0;b=S(160,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}if(b>>>0<=A>>>0){break q}v[23588]=0;b=Q(155,g|0,A|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}if(!b){break q}v[23588]=0;b=S(407,g|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}if(!b){break q}v[23588]=0;R(406,a|0,16777216);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=x[d+488>>1];if(b>>>0>=4096){v[23588]=0;c=Q(1,d+168|0,16460)|0;b=v[23588];v[23588]=0;if((b|0)==1){break j}a=v[a+1298464>>2];v[23588]=0;U(376,a|0,1,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(c);e=0;break d}b=P()|0;O()|0;Ab(c);break a}if(b>>>0<2194){break q}v[23588]=0;e=Q(1,d+416|0,15984)|0;b=v[23588];v[23588]=0;if((b|0)==1){break p}b=v[a+1298464>>2];v[23588]=0;U(376,b|0,4,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break o}Ab(e)}if(v[a+480180>>2]!=32){break k}b=x[d+488>>1];if((b&61440)!=20480){break l}b=b&4095;e=b<<16;if(Sb(d+508|0,13568,4)){break n}t[d+447|0]=1;break m}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ab(e);break a}if(b>>>0<297){break m}e=x[d+508>>1]|e}v[a+1074308>>2]=e;break k}e=x[d+490>>1];if(!((e|0)!=2184&(b|0)!=2184)){t[d+447|0]=1;v[a+1074308>>2]=18284544;break k}r:{switch(b-532|0){default:if(v[d+508>>2]|((b|0)!=768|(e|0)!=768)|(x[d+480>>1]!=256|w[d+500|0]!=128)){break k}if(w[d+501|0]){break k}v[a+1074308>>2]=18285088;t[d+447|0]=1;break k;case 3:if(v[d+508>>2]|(e|0)!=512){break k}s:{if(VA(d+512|0,255,64)){v[a+1074308>>2]=18219008;v[23588]=0;b=Q(1,d+400|0,14786)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break s}b=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[23588]=0;b=Q(1,d+400|0,16834)|0;e=v[23588];v[23588]=0;if((e|0)==1){break i}}Jb(j,b);Ab(b);t[d+447|0]=1;break k;case 1:case 2:break k;case 0:break r}}if(v[d+508>>2]|(e|0)!=514){break k}v[a+1074308>>2]=17367040;v[23588]=0;b=Q(1,d+400|0,14671)|0;e=v[23588];v[23588]=0;if((e|0)==1){break f}Jb(j,b);Ab(b);t[d+447|0]=1}b=x[d+492>>1];e=b>>>2|0;v[a+480208>>2]=b<<3&32768|(e&8|(e&4|(v[a+480208>>2]&-32797|b<<1&16)));b=d+280|0;cr(b,d+448|4);v[23588]=0;R(222,d+168|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break h}b=d+168|0;Bc(a+1298308|0,b);zb(b);if(!(!(w[d+494|0]&4)|v[a+1074308>>2]-18285314>>>0>4276681982)){v[a+480216>>2]=w[d+478|0];v[a+480220>>2]=w[d+479|0]}b=w[d+496|0];v[a+480200>>2]=b>>>0>128?256:b<<1;b=w[d+498|0];if(b){v[a+480196>>2]=b}t[d+168|0]=31;t[d+280|0]=w[d+499|0];b=d+168|0;e=d+280|0;I=a,J=B(w[kf(b,e)|0],1e4),v[I+480204>>2]=J;t[d+168|0]=w[d+497|0];t[d+280|0]=128;I=a,J=w[Xb(b,e)|0],v[I+480228>>2]=J;e=0;while(1){if((e|0)==64){t:{v[23588]=0;Q(155,g|0,192)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}if(v[a+480180>>2]==16777216&(x[d+488>>1]-2187&65535)>>>0<=2){break t}b=w[a+484376|0];e=v[a+484360>>2];v[23588]=0;da(340,Wb(e,b)|0,g|0,x[d+480>>1],255,254);b=v[23588];v[23588]=0;if((b|0)==1){break b}break e}}else{h=(d+448|0)+e|0;i=h- -64|0;u:{if(w[i|0]==255){break u}f=(e<<5)+a|0;b=f+480280|0;ef(b);I=f+480286|0,J=Dd(w[h+128|0],0,64),u[I>>1]=J;h=t[i|0];if((h|0)<0){v[b>>2]=v[b>>2]|1024}h=h&127;if(h>>>0<=64){u[f+480284>>1]=h<<2;break u}if((h|0)!=100){break u}v[b>>2]=v[b>>2]|256}e=e+1|0;continue}break}e=0;v[23588]=0;b=S(194,g|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break g}if(b){break d}v[23588]=0;b=S(157,g|0)|0;f=v[23588];v[23588]=0;v:{if((f|0)==1){break v}if(b>>>0>4e3){break d}f=w[a+484376|0];h=v[a+484360>>2];v[23588]=0;b=W(408,Wb(h,f)|0,g|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break v}if(!b){break d}break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}s=Tb(d+384|0);p=Tb(d+368|0);e=0;n=Tb(d+352|0);v[23588]=0;b=W(409,g|0,s|0,x[d+482>>1])|0;f=v[23588];v[23588]=0;w:{x:{y:{if((f|0)==1){break y}if(!b){break w}v[23588]=0;b=W(409,g|0,p|0,x[d+484>>1])|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}if(!b){break w}v[23588]=0;b=W(409,g|0,n|0,x[d+486>>1])|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}if(!b){break w}v[d+348>>2]=-1;I=d,J=Fb(v[s>>2]),v[I+168>>2]=J;e=Fb(v[s+4>>2]);while(1){b=v[d+168>>2];if(Pb(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Le(d+168|0);continue}else{I=d,J=Fb(v[p>>2]),v[I+168>>2]=J;e=Fb(v[p+4>>2]);while(1){b=v[d+168>>2];if(Pb(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Le(d+168|0);continue}else{I=d,J=Fb(v[n>>2]),v[I+168>>2]=J;e=Fb(v[n+4>>2]);z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{while(1){b=v[d+168>>2];if(Pb(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Le(d+168|0);continue}else{if(t[d+494|0]&1){v[d+168>>2]=v[d+504>>2];I=d,J=v[Kb(d+348|0,d+168|0)>>2],v[I+348>>2]=J}e=0;if(x[d+490>>1]!=532){break H}b=x[d+488>>1];if(w[d+479|0]|(b?(b|0)!=532:0)|(w[d+478|0]|w[d+501|0])){break H}if(v[d+508>>2]|w[d+492|0]&192){break H}if(x[d+482>>1]){break I}f=x[d+484>>1];if(!f){break I}if((v[g+8>>2]+(vc(v[p>>2],v[p+4>>2])<<2)|0)+2>>>0>y[d+348>>2]){break I}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){v[23588]=0;b=S(157,g|0)|0;f=v[23588];v[23588]=0;J:{if((f|0)!=1){if(!b){break J}zg(g,((e&65535)<<2)+4|0);break I}b=P()|0;O()|0;break x}e=e+1|0;f=x[d+484>>1];continue}break}v[23588]=0;b=Q(1,d+336|0,14936)|0;e=v[23588];v[23588]=0;if((e|0)==1){break G}Jb(j,b);Ab(b)}e=1;if(x[d+488>>1]){break H}v[23588]=0;b=Q(1,d+320|0,15393)|0;f=v[23588];v[23588]=0;if((f|0)==1){break F}Jb(j,b);Ab(b)}b=x[d+494>>1];K:{if(b&2){v[23588]=0;f=S(194,g|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break A}b=v[g+8>>2];h=v[g>>2];v[23588]=0;i=b;b=f<<3;h=W(156,h|0,i|0,b|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break A}if(!(!h|y[d+348>>2]<b+v[g+8>>2]>>>0)){v[23588]=0;b=a+1298408|0;R(410,b|0,f|0);h=v[23588];v[23588]=0;if((h|0)==1){break A}I=d,J=Fb(v[b>>2]),v[I+280>>2]=J;h=Fb(v[a+1298412>>2]);L:{M:{while(1){b=v[d+280>>2];if(!Pb(b,h)){if(!(!f&e)){break K}if(!(w[d+494|0]&4)){break L}v[23588]=0;b=Q(1,d+304|0,15426)|0;e=v[23588];v[23588]=0;if((e|0)==1){break M}Jb(j,b);Ab(b);break K}v[23588]=0;R(411,g|0,d+168|0);i=v[23588];v[23588]=0;if((i|0)!=1){v[b>>2]=0;v[b+4>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;i=w[d+168|0]|w[d+169|0]<<8;if(i|(w[d+170|0]|w[d+171|0]<<8)){v[b>>2]=((i&65024)>>>9|0)+1980;I=b,J=Yb((w[d+168|0]|w[d+169|0]<<8)>>>5&15,1,12),v[I+4>>2]=J;I=b,J=Yb((w[d+168|0]|w[d+169|0]<<8)&31,1,31),v[I+8>>2]=J;I=b,J=Yb((w[d+170|0]|w[d+171|0]<<8)>>>11|0,0,23),v[I+12>>2]=J;I=b,J=Yb((w[d+170|0]|w[d+171|0]<<8)>>>5&63,0,59),v[I+16>>2]=J;i=Yb((w[d+170|0]|w[d+171|0]<<8)<<1&62,0,59);v[b+24>>2]=i;v[b+28>>2]=i>>31}v[b+32>>2]=w[d+172|0]|w[d+173|0]<<8|(w[d+174|0]<<16|w[d+175|0]<<24);v[d+280>>2]=v[d+280>>2]+40;continue}break}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}v[23588]=0;b=Q(1,d+304|0,14976)|0;e=v[23588];v[23588]=0;if((e|0)!=1){Jb(j,b);Ab(b);break K}b=P()|0;O()|0;break x}zg(g,2);break K}if(!(b>>>0<2&e)){break K}v[23588]=0;b=S(194,g|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break z}if(!b){v[23588]=0;b=Q(1,d+304|0,14936)|0;e=v[23588];v[23588]=0;if((e|0)!=1){Jb(j,b);Ab(b);break K}b=P()|0;O()|0;break x}zg(g,2)}N:{if(!(w[d+494|0]&8?1:w[d+492|0]&128)){break N}v[23588]=0;b=a+901404|0;e=Q(412,g|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break E}if(!e){break N}UA(b)}if(x[d+488>>1]<=531){qq(a+901404|0)}v[23588]=0;C=S(174,d+280|0)|0;b=v[23588];v[23588]=0;O:{P:{Q:{if((b|0)!=1){v[23588]=0;b=Q(402,g|0,13805)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Q}if(b){v[23588]=0;b=S(157,g|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break P}v[23588]=0;U(190,d+256|0,g|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break P}b=d+256|0;e=kc(d+168|0,b);hd(C,e);Bb(e);Bb(b)}u[a+480188>>1]=1;v[23588]=0;b=Q(402,g|0,13810)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Q}if(!b){break C}v[23588]=0;b=S(157,g|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;U(190,d+256|0,g|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break O}}b=P()|0;O()|0;break B}b=P()|0;O()|0;break x}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=d+256|0;f=kc(d+168|0,b);Bb(b);b=v[f>>2];v[23588]=0;b=S(160,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break D}u[d+256>>1]=(b>>>0)/20;b=x[Wc(26644,d+256|0)>>1];u[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){Bb(f);break C}v[23588]=0;U(413,f|0,((e<<5)+a|0)+480289|0,20);h=v[23588];v[23588]=0;if((h|0)!=1){e=e+1|0;continue}break}break D}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;Bb(f);break B}R:{b=v[d+348>>2];e=v[g+8>>2];S:{if(b>>>0>=e>>>0){e=b-e|0;break S}v[23588]=0;e=S(202,g|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break R}}v[23588]=0;U(190,d+168|0,g|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break R}b=d+168|0;D=kc(d+256|0,b);Bb(b);v[23588]=0;E=Q(414,a|0,D|0)|0;b=v[23588];v[23588]=0;T:{U:{V:{if((b|0)==1){break V}if(!(t[d+494|0]&1)|!x[d+502>>1]){break U}v[23588]=0;b=Q(155,g|0,v[d+504>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break V}if(!b){break U}v[23588]=0;X(331,a+1298332|0,g|0,x[d+502>>1],4);b=v[23588];v[23588]=0;if((b|0)!=1){break U}}b=P()|0;O()|0;break T}h=a+480192|0;u[h>>1]=0;f=0;if(w[d+492|0]&4){u[d+168>>1]=x[d+482>>1];u[d+96>>1]=255;f=x[Wc(d+168|0,d+96|0)>>1];u[h>>1]=f}e=0;W:{while(1){if((f&65535)>>>0<=e>>>0){v[d+252>>2]=0;e=x[d+484>>1];if(e){b=Eb(v[p>>2],e-1|0);v[d+252>>2]=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+80}u[d+168>>1]=e;u[d+96>>1]=3999;q=a+480190|0;f=x[Wc(d+168|0,d+96|0)>>1];u[q>>1]=f;m=c&2;o=d+188|0;z=a+1298464|0;e=0;b=0;while(1){X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((f&65535)>>>0>e>>>0){f=Eb(v[p>>2],e);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if(!f){break Y}v[23588]=0;f=Q(155,g|0,f|0)|0;h=v[23588];v[23588]=0;da:{ea:{fa:{ga:{ha:{if((h|0)==1){break ha}if(!f){break Y}v[23588]=0;f=Q(415,g|0,d+168|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break ha}if(!f){break Y}v[23588]=0;i=e+1|0;f=B(i,104)+a|0;h=f+484380|0;k=Q(416,d+168|0,h|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break ga}l=d+152|0;cr(l,o);v[23588]=0;R(222,d+96|0,l|0);l=v[23588];v[23588]=0;if((l|0)==1){break fa}l=d+96|0;Dc(((i<<5)+a|0)+946304|0,l);zb(l);v[23588]=0;k=Q(155,g|0,k|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break ga}if(!k){break Y}f=x[f+484414>>1];if(!(f&512)){break ea}v[23588]=0;f=Q(417,g|0,d+96|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break ca}if(!f){break da}v[d+8>>2]=v[d+104>>2];f=v[d+100>>2];v[d>>2]=v[d+96>>2];v[d+4>>2]=f;Gl(h,1,d);break da}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if(!(f&16384)){r=x[d+488>>1];k=w[d+186|0];l=k&2;f=w[d+214|0];i=_c(d+96|0,l?16:8,1,0,(f^-1)&1);if(!(!(k&4)|r>>>0<532)){Ko(i,3)}ia:{ja:{if(k&8){k=f&4?5:4;break ja}if(!l){k=10;if((f|0)==255){break ja}}if(f&2){t[i+2|0]=1}if(f&4){dg(i,2)}if(!(f&8)){break ia}k=9;if(!l){break ia}}dg(i,k)}if(m){f=0;v[23588]=0;W(219,d+96|0,h|0,g|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){break _}break X}f=1;i=w[d+99|0];if(i>>>0>17){break Z}i=1<<i;if(!(i&63503)){if(!(i&198144)){break Z}break $}if(w[d+96|0]){break $}break _}v[23588]=0;R(418,g|0,d+80|0);f=v[23588];v[23588]=0;if((f|0)==1){break aa}h=v[d+80>>2];if(!(!m|!h)){f=Mb(d+96|0);v[23588]=0;U(268,g|0,f|0,h|0);h=v[23588];v[23588]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((h|0)!=1){v[23588]=0;R(374,d+136|0,16382);h=v[23588];v[23588]=0;if((h|0)==1){break qa}v[d+64>>2]=i;v[23588]=0;U(11,d+120|0,0,f|0);h=v[23588];v[23588]=0;if((h|0)==1){break pa}v[23588]=0;X(419,d+152|0,d+136|0,d- -64|0,d+120|0);h=v[23588];v[23588]=0;if((h|0)==1){break oa}h=v[z>>2];v[23588]=0;U(376,h|0,2,d+152|0);h=v[23588];v[23588]=0;if((h|0)==1){break na}Ab(d+152|0);Ab(d+120|0);bc(d+136|0);zb(f);break da}b=P()|0;O()|0;break ka}b=P()|0;O()|0;break ka}b=P()|0;O()|0;break la}b=P()|0;O()|0;break ma}b=P()|0;O()|0;Ab(d+152|0)}Ab(d+120|0)}bc(d+136|0)}zb(f);break T}v[23588]=0;Q(188,g|0,h|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break aa}}f=0;break Z}u[d+168>>1]=1;u[d+96>>1]=f;I=a+480190|0,J=x[le(d+168|0,d+96|0)>>1],u[I>>1]=J;if(!(x[d+488>>1]==516&b)|x[d+490>>1]!=512|(x[d+494>>1]|v[d+508>>2])){break ba}if((x[d+492>>1]&65527)!=21|w[d+496|0]!=128|(w[d+497|0]!=48|w[d+500|0]!=128)){break ba}if(w[d+501|0]|x[d+502>>1]){break ba}f=d+576|0;b=d+512|0;e=1;while(1)if((b|0)==(f|0)){b=d+640|0;while(1)if((b|0)==(f|0)){f=20;while(1){if((f|0)==26){ra:{if(!(e&1)){break ba}v[23588]=0;b=Q(1,d+152|0,9829)|0;e=v[23588];v[23588]=0;if((e|0)==1){break ra}Jb(j,b);Ab(b);break ba}}else{e=!w[(d+f|0)+452|0]&e;f=f+1|0;continue}break}b=P()|0;O()|0;break T}else{e=w[f|0]==64&e;f=f+1|0;continue}}else{e=(w[b|0]&127)==32&e;b=b+1|0;continue}}b=P()|0;O()|0;break T}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;b=vc(v[n>>2],v[n+4>>2]);u[d+168>>1]=b;q=x[Wc(d+168|0,v[a+8>>2]+10|0)>>1];u[d+118>>1]=q;sa:{ta:{ua:{va:{if((b|0)!=(q|0)){v[23588]=0;Y(420,d+96|0);b=v[23588];v[23588]=0;if((b|0)==1){break sa}b=v[n+4>>2];e=v[n>>2];v[23588]=0;I=d,J=vc(e,b),v[I+136>>2]=J;X(421,d+168|0,d+96|0,d+136|0,d+118|0);b=v[23588];v[23588]=0;if((b|0)==1){break ua}b=v[a+1298464>>2];v[23588]=0;U(376,b|0,2,d+168|0);b=v[23588];v[23588]=0;if((b|0)==1){break va}Ab(d+168|0);bc(d+96|0)}if(!(c&1)){u[d+118>>1]=0;q=0}m=a+480188|0;h=0;wa:{xa:{ya:{za:{Aa:{Ba:{while(1){Ca:{if((h|0)==(q|0)){Da:{Ea:{b=v[d+252>>2];if(!b){break Ea}v[23588]=0;Q(155,g|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Da}if(!(r&1)){break Ea}while(1){Fa:{b=v[g+8>>2];c=v[g>>2];v[23588]=0;b=W(156,c|0,b|0,4)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Fa}if(!b){break Ea}v[23588]=0;b=Q(402,g|0,13779)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Fa}Ga:{if(!b){v[23588]=0;b=Q(402,g|0,13784)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Fa}if(!b){break Ga}}v[23588]=0;b=S(157,g|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){zg(g,8);if(!(b&1616928864)|b&-2139062144){break Ga}break Ea}b=P()|0;O()|0;break T}v[23588]=0;b=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Fa}v[23588]=0;Q(188,g|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}b=P()|0;O()|0;break T}v[23588]=0;b=Q(422,a|0,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Da}b=b|w[d+447|0];t[d+447|0]=b;if(!(!b|E)){nu(a+1074312|0);t[a+1074368|0]=0}v[23588]=0;X(423,a|0,g|0,0,d+447|0);b=v[23588];v[23588]=0;if((b|0)==1){break Da}v[23588]=0;o=a+484344|0;R(225,o|0,q|0);b=v[23588];v[23588]=0;if((b|0)==1){break Da}z=a+480188|0;H=a+480183|0;h=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{while(1){Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((h|0)!=(q|0)){b=Eb(v[n>>2],h);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b){v[23588]=0;b=Q(155,g|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break ab}if(b){break $a}}v[23588]=0;b=W(226,o|0,h&65535,64)|0;c=v[23588];v[23588]=0;if((c|0)==1){break ab}if(b){break bb}u[d+48>>1]=h;v[23588]=0;Y(424,d+96|0);b=v[23588];v[23588]=0;if((b|0)==1){break fb}v[23588]=0;U(425,d+168|0,d+96|0,d+48|0);b=v[23588];v[23588]=0;if((b|0)==1){break eb}b=v[a+1298464>>2];v[23588]=0;U(376,b|0,2,d+168|0);b=v[23588];v[23588]=0;if((b|0)==1){break db}Ab(d+168|0);bc(d+96|0)}if(!v[a+1074308>>2]){e=x[d+488>>1];if((e|0)!=2184){break Za}v[a+1074308>>2]=18284544}if(!sh(v[j+4>>2],w[j+11|0])){break _a}v[23588]=0;c=Q(1,d+96|0,17579)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Ra}b=v[a+1074308>>2];v[23588]=0;R(140,d- -64|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break Ta}v[23588]=0;U(2,d+168|0,c|0,d- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break Ua}e=d+168|0;b=Jb(j,e);Ab(e);Ab(d- -64|0);Ab(c);if(!Sb(d+508|0,13568,4)|(x[d+488>>1]&61440)!=20480){break Ya}v[23588]=0;c=Q(1,d+168|0,16846)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Va}v[23588]=0;Q(98,b|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Wa}Ab(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break cb}b=P()|0;O()|0;Ab(d+168|0)}bc(d+96|0);break T}b=v[o>>2];v[23588]=0;R(426,Zb(b,h)|0,C|0);b=v[23588];v[23588]=0;if((b|0)!=1){break Pa}}b=P()|0;O()|0;break T}v[23588]=0;b=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ha}v[23588]=0;F=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ia}v[23588]=0;c=Q(188,g|0,4)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Ia}if(!c){break Pa}v[23588]=0;c=W(226,o|0,h&65535,F|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Ia}if(!c){break Pa}v[23588]=0;U(190,d+96|0,g|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break Ja}b=d+96|0;m=kc(d+168|0,b);Bb(b);b=v[o>>2];v[23588]=0;R(426,Zb(b,h)|0,C|0);b=v[23588];v[23588]=0;if((b|0)==1){break La}b=x[z>>1];v[23588]=0;l=Q(427,d+120|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Ma}b=x[z>>1];c=d+96|0;Fj(c);v[23588]=0;k=W(428,d+80|0,b|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Oa}I=d,J=Fb(v[Zb(v[o>>2],h)>>2]),v[I+64>>2]=J;r=0;while(1){gb:{hb:{ib:{jb:{if(r>>>0>=F>>>0){break jb}b=v[m>>2];v[23588]=0;b=W(156,b|0,v[d+176>>2],1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Qa}if(!b){break jb}v[23588]=0;b=S(206,m|0)|0;c=v[23588];v[23588]=0;kb:{if((c|0)!=1){b=b<<24>>24;if(b){break kb}lU(d- -64|0,x[z>>1]);r=r+1|0;continue}break Qa}lb:{c=b&127;i=c?c-1&65535:0;if(fd(v[l>>2],v[d+124>>2])>>>0>i>>>0){break lb}v[23588]=0;t[d+96|0]=0;c=i+1|0;U(429,l|0,c|0,d+96|0);e=v[23588];v[23588]=0;if((e|0)==1){break Qa}e=d+96|0;Fj(e);v[23588]=0;U(430,k|0,c|0,e|0);c=v[23588];v[23588]=0;if((c|0)!=1){break lb}break Qa}if((b|0)<0){v[23588]=0;b=S(206,m|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Qa}I=Lb(v[l>>2],i),J=b,t[I|0]=J}f=d+96|0;Fj(f);if(i>>>0<x[z>>1]){f=Id(v[d+64>>2],i)}b=Lb(v[l>>2],i);e=w[b|0];if(e&16){I=f,J=w[Id(v[k>>2],i)|0],t[I|0]=J;e=w[b|0]}if(e&32){I=f,J=w[Id(v[k>>2],i)+1|0],t[I+1|0]=J;e=w[b|0]}if(e&64){c=Id(v[k>>2],i);t[f+2|0]=w[c+2|0];t[f+4|0]=w[c+4|0];e=w[b|0]}if(e<<24>>24<0){c=Id(v[k>>2],i);t[f+3|0]=w[c+3|0];t[f+5|0]=w[c+5|0];e=w[b|0]}if(e&1){v[23588]=0;b=S(206,m|0)|0;c=v[23588];v[23588]=0;mb:{nb:{if((c|0)!=1){b=b<<24>>24;b=(((b^-1)&128)>>>7|0)+b|0;if(!(t[H|0]&1)){break nb}c=b;break mb}break Qa}c=253;if((b-121&255)>>>0<132){break mb}c=(b&255)==253?0:b}t[f|0]=c;I=Id(v[k>>2],i),J=c,t[I|0]=J;b=Lb(v[l>>2],i)}if(w[b|0]&2){v[23588]=0;b=S(206,m|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Qa}t[f+1|0]=b;I=Id(v[k>>2],i),J=b,t[I+1|0]=J;b=Lb(v[l>>2],i)}if(!(w[b|0]&4)){break gb}v[23588]=0;b=S(206,m|0)|0;c=v[23588];v[23588]=0;ob:{pb:{if((c|0)!=1){if(b>>>0>64){break pb}t[f+4|0]=b;e=1;break ob}break Qa}if(b<<24>>24<=-64){e=2;t[f+2|0]=2;b=b^-128;t[f+4|0]=b;break hb}if(b>>>0<=74){e=5;t[f+2|0]=5;b=b-65|0;t[f+4|0]=b;break hb}if(b>>>0<=84){e=6;t[f+2|0]=6;b=b-75|0;t[f+4|0]=b;break hb}if(b>>>0<=94){e=3;t[f+2|0]=3;b=b-85|0;t[f+4|0]=b;break hb}if(b>>>0<=104){e=4;t[f+2|0]=4;b=b-95|0;t[f+4|0]=b;break hb}if(b>>>0<=114){e=13;t[f+2|0]=13;b=b-105|0;t[f+4|0]=b;break hb}if(b>>>0<=124){e=12;t[f+2|0]=12;b=b-115|0;t[f+4|0]=b;break hb}c=b+63|0;if((c&255)>>>0<=9){t[f+4|0]=c;e=11;t[f+2|0]=11;b=c;break hb}c=b+53|0;G=c&255;if(G>>>0<=9){t[f+4|0]=c;e=8;t[f+2|0]=8;if(!G){b=0;break hb}if(v[a+1074308>>2]-1>>>0>18285139){break ib}e=7;t[f+2|0]=7;break ib}b=b+33|0;if((b&255)>>>0>=10){b=w[f+4|0];e=w[f+2|0];break hb}t[f+4|0]=b;e=15}t[f+2|0]=e;break hb}vk(k);ic(l);Bb(m);break Pa}b=c}c=Id(v[k>>2],i);t[c+4|0]=b;t[c+2|0]=e;b=Lb(v[l>>2],i)}if(!(w[b|0]&8)){continue}v[23588]=0;R(260,d+32|0,m|0);b=v[23588];v[23588]=0;if((b|0)!=1){RA(f,w[d+32|0],w[Oc(d+32|0)|0],1);b=Id(v[k>>2],i);t[b+3|0]=w[f+3|0];t[b+5|0]=w[f+5|0];continue}break}break Qa}e=x[d+488>>1]}qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{b=e&65535;switch(b>>>12|0){case 13:break rb;case 7:break sb;case 6:break tb;case 4:break ub;case 1:break wb;case 0:break xb;default:break Xa}}if(E){v[23588]=0;b=Q(1,d+168|0,8300)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Jb(j,b);Ab(b);break Xa}b=P()|0;O()|0;break T}yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((e&65535)==532){f=x[d+490>>1];if((f|0)!=532){if((f|0)!=512){e=532;break Kb}Mb:{if(x[d+494>>1]|x[d+492>>1]!=9|(w[d+479|0]|w[d+478|0])){break Mb}if(x[d+482>>1]|x[d+480>>1]!=(x[d+486>>1]+1|0)|(w[d+496|0]!=128|w[d+497|0]!=100)){break Mb}if(w[d+498|0]!=1|w[d+500|0]!=128|(w[d+501|0]|x[d+502>>1])){break Mb}if(v[d+504>>2]|v[d+508>>2]){break Mb}v[23588]=0;b=Q(1,d+168|0,9810)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Jb(j,b);Ab(b);break Xa}b=P()|0;O()|0;break T}e=532;if(v[d+508>>2]|(w[d+479|0]|w[d+478|0])){break Jb}v[a+1074308>>2]=16777381;v[23588]=0;b=Q(1,d+168|0,14867)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Jb(j,b);Ab(b);t[d+447|0]=1;break Xa}b=P()|0;O()|0;break T}if(!Sb(d+508|0,14048,4)){v[23588]=0;b=Q(1,d+168|0,8338)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Jb(j,b);Ab(b);e=a+1074312|0;f=38;break vb}b=P()|0;O()|0;break T}e=532;if(w[d+501|0]|x[d+494>>1]>1|(v[d+508>>2]|(x[d+492>>1]&4294)!=4)){break Lb}if(!x[a+480190>>1]){break Lb}v[23588]=0;e=Q(55,d+96|0,13388)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Hb}b=kb-16|0;kb=b;c=kb-16|0;kb=c;pv(c+8|0,a+484527|0);lT(b+8|0,v[c+8>>2],v[c+12>>2]);kb=c+16|0;Ge(b,e);c=Qc(v[b+8>>2],v[b+12>>2],v[b>>2],v[b+4>>2]);kb=b+16|0;zb(e);if(c){break Ib}e=x[d+488>>1]}if(e&65535){break Lb}if(sh(v[j+4>>2],w[j+11|0])){break Fb}}f=x[d+490>>1]}if((f&65535)>>>0>767){break Xa}}if(!sh(v[j+4>>2],w[j+11|0])){break Xa}if((f&65535)>>>0<533){break Db}v[23588]=0;b=Q(1,d- -64|0,14900)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Eb}Jb(j,b);Ab(b);break Cb}v[23588]=0;b=Q(1,d+168|0,8364)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Gb}Jb(j,b);Ab(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}v[23588]=0;b=Q(1,d+168|0,9700)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Jb(j,b);Ab(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if((e&65535)>>>0>=533){v[23588]=0;R(431,d- -64|0,4018);b=v[23588];v[23588]=0;Nb:{if((b|0)!=1){v[23588]=0;v[d+48>>2]=x[d+488>>1]-532;U(432,d+168|0,d- -64|0,d+48|0);b=v[23588];v[23588]=0;if((b|0)==1){break Nb}b=d+168|0;Jb(j,b);Ab(b);bc(d- -64|0);break Cb}b=P()|0;O()|0;break T}b=P()|0;O()|0;bc(d- -64|0);break T}v[23588]=0;R(266,d- -64|0,4317);b=v[23588];v[23588]=0;if((b|0)==1){break Bb}b=x[d+488>>1];v[d+32>>2]=b>>>8&15;v[23588]=0;v[d+16>>2]=b&255;R(433,d+48|0,d+16|0);b=v[23588];v[23588]=0;if((b|0)==1){break Ab}v[23588]=0;X(419,d+168|0,d- -64|0,d+32|0,d+48|0);b=v[23588];v[23588]=0;if((b|0)==1){break zb}b=d+168|0;Jb(j,b);Ab(b);Ab(d+48|0);bc(d- -64|0)}b=a+1298408|0;if(!pc(v[b>>2],v[a+1298412>>2])){break Xa}c=v[d+508>>2];if(!c){break Xa}c=WC(x[d+488>>1],c);e=yo(d+168|0);v[e+32>>2]=c;v[23588]=0;R(434,b|0,e|0);b=v[23588];v[23588]=0;if((b|0)!=1){break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break yb}b=P()|0;O()|0;Ab(d+48|0)}bc(d- -64|0);break T}c=v[d+508>>2];v[23588]=0;U(435,d+168|0,b|0,v[d+508>>2]);e=v[23588];v[23588]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if((e|0)!=1){e=d+168|0;Jb(j,e);Ab(e);b=(b|0)==8191?c:b-4176|0;if((b|0)>1915){break Vb}f=v[a+480208>>2];if(!(f&16)){break Ub}v[23588]=0;Q(265,a+1074312|0,7)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break Tb}break qb}b=P()|0;O()|0;break T}if(b>>>0>4200){break Rb}f=v[a+480208>>2]}if(!(f&16)){v[23588]=0;Q(265,a+1074312|0,7)|0;c=v[23588];v[23588]=0;if((c|0)==1){break qb}}if((b|0)>2385){break Sb}}v[23588]=0;Q(265,a+1074312|0,38)|0;b=v[23588];v[23588]=0;if((b|0)==1){break qb}}v[23588]=0;b=Q(265,a+1074312|0,102)|0;c=v[23588];v[23588]=0;if((c|0)==1){break qb}v[23588]=0;Q(265,b|0,48)|0;b=v[23588];v[23588]=0;if((b|0)==1){break qb}break Qb}if(b>>>0>4383){break Pb}}v[23588]=0;b=W(264,a+1074312|0,116,1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break qb}v[23588]=0;Q(265,b|0,115)|0;b=v[23588];v[23588]=0;if((b|0)==1){break qb}break Ob}if(b>>>0>4563){break Xa}}v[23588]=0;b=Q(265,a+1074312|0,43)|0;c=v[23588];v[23588]=0;if((c|0)==1){break qb}v[23588]=0;e=Q(265,b|0,42)|0;b=v[23588];v[23588]=0;f=87;if((b|0)==1){break qb}}v[23588]=0;Q(265,e|0,f|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break qb}break Xa}v[23588]=0;Y(436,d+96|0);b=v[23588];v[23588]=0;Wb:{Xb:{Yb:{if((b|0)!=1){b=x[d+488>>1];v[d+48>>2]=b>>>8&15;v[23588]=0;v[d+32>>2]=b&255;R(433,d- -64|0,d+32|0);b=v[23588];v[23588]=0;if((b|0)==1){break Yb}v[23588]=0;X(419,d+168|0,d+96|0,d+48|0,d- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break Xb}b=d+168|0;Jb(j,b);Ab(b);Ab(d- -64|0);bc(d+96|0);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break Wb}b=P()|0;O()|0;Ab(d- -64|0)}bc(d+96|0);break T}v[23588]=0;b=Q(1,d+168|0,8300)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Jb(j,b);Ab(b);break Xa}b=P()|0;O()|0;break T}if(!((b|0)!=32767|x[d+490>>1]!=533)){v[23588]=0;b=Q(1,d+168|0,5045)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Jb(j,b);Ab(b);break Xa}b=P()|0;O()|0;break T}v[23588]=0;R(137,d+96|0,4153);b=v[23588];v[23588]=0;Zb:{if((b|0)!=1){b=x[d+488>>1];v[d+64>>2]=b>>>8&15;v[d+48>>2]=b>>>4&15;v[23588]=0;v[d+32>>2]=b&15;da(138,d+168|0,d+96|0,d- -64|0,d+48|0,d+32|0);b=v[23588];v[23588]=0;if((b|0)==1){break Zb}b=d+168|0;Jb(j,b);Ab(b);bc(d+96|0);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;bc(d+96|0);break T}v[23588]=0;b=Q(1,d+168|0,6126)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Jb(j,b);Ab(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if(!cE(v[a+1074308>>2])){break Xa}v[23588]=0;c=Q(1,d+168|0,17082)|0;e=v[23588];v[23588]=0;_b:{if((e|0)!=1){v[23588]=0;Q(98,b|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break _b}Ab(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;Ab(c);break T}$b:{ac:{bc:{cc:{dc:{ec:{e=v[a+480180>>2];if(!((e|0)!=16777216|x[d+488>>1]<2186)){v[23588]=0;b=Q(155,g|0,A|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Da}if(b){v[23588]=0;U(437,a|0,g|0,x[d+488>>1]);b=v[23588];v[23588]=0;if((b|0)==1){break Da}}e=v[a+480180>>2]}fc:{if((e|0)==16777216){v[23588]=0;b=Q(1,d+48|0,13752)|0;c=v[23588];v[23588]=0;if((c|0)==1){break ec}Jb(a+1298344|0,b);Ab(b);break fc}v[23588]=0;R(266,d+32|0,4317);b=v[23588];v[23588]=0;if((b|0)==1){break dc}b=x[d+490>>1];v[d+28>>2]=b>>>8;v[23588]=0;v[d+12>>2]=b&255;R(433,d+16|0,d+12|0);b=v[23588];v[23588]=0;if((b|0)==1){break cc}v[23588]=0;X(419,d+48|0,d+32|0,d+28|0,d+16|0);b=v[23588];v[23588]=0;if((b|0)==1){break bc}b=d+48|0;Jb(a+1298344|0,b);Ab(b);Ab(d+16|0);bc(d+32|0)}b=v[a+480180>>2];v[23588]=0;b=Q(1,d+48|0,((b|0)==16777216?10074:6130)|0)|0;c=v[23588];v[23588]=0;e=1;if((c|0)==1){break $b}Jb(a+1298356|0,b);Ab(b);Jb(a+1298368|0,j);v[a+1298404>>2]=v[a+1074308>>2]?8:5;Bb(D);Bb(C);break w}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break ac}b=P()|0;O()|0;Ab(d+16|0)}bc(d+32|0);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;Ab(c);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;Ab(d- -64|0);break Sa}b=P()|0;O()|0}Ab(c);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;u[d+48>>1]=h;vk(k);break Na}h=h+1|0;continue}break}b=P()|0;O()|0;u[d+48>>1]=h}ic(l);break Ka}b=P()|0;O()|0;u[d+48>>1]=h;break Ka}b=P()|0;O()|0;u[d+48>>1]=h}Bb(m);break T}b=P()|0;O()|0;u[d+48>>1]=h;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}gc:{b=Eb(v[n>>2],h);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);hc:{if(!b){break hc}v[23588]=0;b=Q(155,g|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ba}if(!b){break hc}v[23588]=0;b=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break wa}v[23588]=0;l=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break xa}if((l-1025&65535)>>>0<64512){break hc}v[23588]=0;c=Q(188,g|0,4)|0;e=v[23588];v[23588]=0;if((e|0)==1){break xa}if(!c){break hc}v[23588]=0;U(190,d+96|0,g|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break ya}b=d+96|0;f=kc(d+168|0,b);Bb(b);c=x[m>>1];b=0;v[23588]=0;i=Q(427,d+136|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Aa}ic:{while(1){if(b>>>0>=l>>>0){break ic}c=v[f>>2];v[23588]=0;c=W(156,c|0,v[d+176>>2],1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break gc}if(!c){break ic}v[23588]=0;c=S(206,f|0)|0;e=v[23588];v[23588]=0;jc:{if((e|0)!=1){c=c<<24>>24;if(c){break jc}b=b+1|0;continue}break Ca}kc:{e=c&127;o=e?e-1|0:0;k=o&65535;if(fd(v[i>>2],v[d+140>>2])>>>0>k>>>0){break kc}v[23588]=0;t[d+96|0]=0;U(429,i|0,k+1|0,d+96|0);e=v[23588];v[23588]=0;if((e|0)!=1){break kc}break Ca}lc:{if((c|0)<0){v[23588]=0;c=S(206,f|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break lc}I=Lb(v[i>>2],k),J=c,t[I|0]=J}e=Lb(v[i>>2],k);c=w[e|0];if(!(!(c&15)|k>>>0<x[m>>1])){u[m>>1]=o+1;c=w[e|0]}if(c&1){v[23588]=0;Q(188,f|0,1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break lc}e=Lb(v[i>>2],k)}if(w[e|0]&2){v[23588]=0;Q(188,f|0,1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break lc}e=Lb(v[i>>2],k)}if(w[e|0]&4){v[23588]=0;Q(188,f|0,1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break lc}e=Lb(v[i>>2],k)}if(!(w[e|0]&8)){continue}v[23588]=0;Q(188,f|0,2)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}break}break Ca}v[d+96>>2]=v[g+8>>2];I=d,J=v[Zc(d+252|0,d+96|0)>>2],v[I+252>>2]=J;ic(i);Bb(f)}h=h+1|0;continue}}break}b=P()|0;O()|0;ic(i);break za}b=P()|0;O()|0;break T}b=P()|0;O()|0}Bb(f);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;Ab(d+168|0);break ta}b=P()|0;O()|0}bc(d+96|0);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}f=0;i=QA(d+96|0,v[h>>2]);v[23588]=0;Q(188,g|0,i|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break X}}if(w[d+99|0]!=1){break Z}b=v[h>>2]!=0|b}v[d+96>>2]=v[g+8>>2];I=d,J=v[Zc(d+252|0,d+96|0)>>2],v[I+252>>2]=J;r=(f|0)!=0}e=e+1|0;f=x[q>>1];continue}break}b=P()|0;O()|0;break T}mc:{b=Eb(v[s>>2],e);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);nc:{if(!b){break nc}v[23588]=0;b=Q(155,g|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break mc}if(!b){break nc}b=v[g+8>>2];f=v[g>>2];v[23588]=0;b=W(156,f|0,b|0,554)|0;f=v[23588];v[23588]=0;if((f|0)==1){break mc}if(!b){break nc}v[23588]=0;b=W(251,a|0,e+1&65535,0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break W}if(!b){break nc}v[23588]=0;X(438,a|0,g|0,b|0,x[d+490>>1]);f=v[23588];v[23588]=0;if((f|0)==1){break W}t[b+33|0]=w[d+501|0]}e=e+1|0;f=x[h>>1];continue}break}b=P()|0;O()|0;break T}b=P()|0;O()|0}Bb(D);break B}b=P()|0;O()|0}Bb(C);break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}}}}}b=P()|0;O()|0}wc(n);wc(p);wc(s);break a}wc(n);wc(p);wc(s)}Ab(j)}kb=d+640|0;return e|0}b=P()|0;O()|0}Ab(j);T(b|0);L()}function iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0;e=kb-1744|0;kb=e;zc(b);a:{if(!di(b,e+1736|0)){break a}if(!zS(e+1736|0)){break a}if(!c){g=1;break a}p=w[e+1739|0];t[e+1735|0]=p;v[e+1728>>2]=-1;v[e+1724>>2]=1048576;if(p>>>0>=5){d=Cg(b);v[e+1728>>2]=d;if(!Qb(v[b>>2],v[b+8>>2],d)){break a}v[e+304>>2]=134217727;N=e,V=v[Kb(e+304|0,e+1728|0)>>2]<<5,v[N+1724>>2]=V}C=Tb(e+1712|0);v[e+304>>2]=v[e+1740>>2];d=v[Kb(e+1724|0,e+304|0)>>2];v[23588]=0;R(538,C|0,d|0);d=v[23588];v[23588]=0;b:{c:{d:{e:{f:{if((d|0)!=1){v[23588]=0;d=W(539,b|0,C|0,v[e+1740>>2])|0;f=v[23588];v[23588]=0;g:{if((f|0)==1){break g}if(!d){break b}if(p>>>0>=5){v[23588]=0;Q(155,b|0,v[e+1728>>2]+12|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}}v[23588]=0;R(246,a|0,0);d=v[23588];v[23588]=0;if((d|0)==1){break g}ag(a);se(e+1680|0,v[C>>2],v[C+4>>2]);d=fe(e+1672|0);f=v[d+4>>2];d=v[d>>2];v[23588]=0;m=Fg(540,e+1688|0,v[e+1680>>2],v[e+1684>>2],d,f);d=v[23588];v[23588]=0;h:{i:{j:{if((d|0)!=1){v[23588]=0;U(350,m|0,a+1298308|0,-1);d=v[23588];v[23588]=0;if((d|0)==1){break j}v[23588]=0;U(350,m|0,a+1298332|0,-1);d=v[23588];v[23588]=0;if((d|0)==1){break j}v[23588]=0;d=Q(541,m|0,e+1248|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break f}if(!d){break c}d=t[e+1248|0];if((d|0)<=0|(w[e+1257|0]|w[e+1258|0]<<8)>>>0>255|(w[e+1259|0]|w[e+1260|0]<<8)>>>0>3999){break c}D=a+480188|0;u[D>>1]=d&255;Ve(Wb(v[a+484360>>2],w[a+484376|0]),w[e+1251|0]|w[e+1252|0]<<8);u[a+480192>>1]=w[e+1257|0]|w[e+1258|0]<<8;u[a+480190>>1]=w[e+1259|0]|w[e+1260|0]<<8;d=w[e+1261|0];v[a+480196>>2]=d?d:6;d=w[e+1262|0];v[a+480204>>2]=B(d?d:125,1e4);f=w[e+1263|0]|w[e+1264|0]<<8|(w[e+1265|0]<<16|w[e+1266|0]<<24);d=32;k:{if(f&256){break k}d=2;if(f&2){break k}d=1;if(f&128){break k}d=f&8?16:4}v[23588]=0;R(406,a|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break f}h=v[a+480208>>2];f=h|16777216;v[a+480208>>2]=f;d=w[e+1263|0]|w[e+1264|0]<<8|(w[e+1265|0]<<16|w[e+1266|0]<<24);if(d&1){f=h|16777232;v[a+480208>>2]=f}h=v[a+480180>>2];i=(h|0)==32;g=i&!(d&1024);j=(h|0)==2;n=j&d>>>2;j=j&d>>>4;i=i&!(d&2048);r=d&2097152;if(r?1:n|j|(i|g)){f=j?f|65536:f;f=n?f|2:f;f=i?f|4:f;v[a+480208>>2]=r>>>6|(g?f|8:f)}if(d&524288){v[23588]=0;W(264,a+1074312|0,5,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}h=v[a+480180>>2]}if((h|0)==2){break i}if((h|0)!=32){break h}t[e+304|0]=w[e+1267|0];t[e+224|0]=128;N=a,V=w[Xb(e+304|0,e+224|0)|0]<<1,v[N+480200>>2]=V;break h}d=P()|0;O()|0;break d}d=P()|0;O()|0;break e}t[e+304|0]=w[e+1267|0];t[e+224|0]=64;N=a,V=w[Xb(e+304|0,e+224|0)|0]<<2,v[N+480200>>2]=V}d=t[e+1269|0];l:{if((d|0)<0){d=d+52|0;break l}F=Fs(+(d|0)*3.1/20);m:{if(F<4294967296&F>=0){d=~~F>>>0;break m}d=0}d=d+51|0}v[a+480228>>2]=d;u[e+304>>1]=64;i=x[Wc(D,e+304|0)>>1];f=0;j=(h|0)!=32;n=(h|0)==4;g=0;while(1)if((g|0)==(i|0)){g=0;i=0;while(1){if((f|0)!=16){i=w[(e+f|0)+1398|0]!=0|i;f=f+1|0;continue}break}while(1){if((g|0)!=128){i=w[((g<<1)+e|0)+1415|0]!=0|i;g=g+1|0;continue}break}n:{if(!(i&1)){break n}d=a+901692|0;g=0;while(1){if((g|0)==16){d=a+902204|0;g=0;while(1){if((g|0)!=128){f=(e+1248|0)+(g<<1)|0;o:{if(w[f+167|0]){v[23588]=0;Y(542,e+224|0);h=v[23588];v[23588]=0;p:{q:{r:{s:{t:{if((h|0)!=1){h=w[f+167|0];v[23588]=0;v[e+248>>2]=h-1;R(543,e+1192|0,e+248|0);h=v[23588];v[23588]=0;if((h|0)==1){break t}f=w[f+166|0];v[23588]=0;t[e+192|0]=f;R(544,e+1168|0,e+192|0);f=v[23588];v[23588]=0;if((f|0)==1){break s}v[23588]=0;X(545,e+304|0,e+224|0,e+1192|0,e+1168|0);f=v[23588];v[23588]=0;if((f|0)==1){break r}f=e+304|0;Ge(e+1224|0,f);hf(ze(d,g),v[e+1224>>2],v[e+1228>>2]);zb(f);zb(e+1168|0);zb(e+1192|0);$b(e+224|0);break o}d=P()|0;O()|0;break e}d=P()|0;O()|0;break p}d=P()|0;O()|0;break q}d=P()|0;O()|0;zb(e+1168|0)}zb(e+1192|0)}$b(e+224|0);break e}f=rc(e+1216|0,21619);hf(ze(d,g),v[f>>2],v[e+1220>>2])}g=g+1|0;continue}break}h=v[a+480180>>2];break n}f=(e+g|0)+1398|0;u:{if(w[f|0]){v[23588]=0;Y(546,e+224|0);h=v[23588];v[23588]=0;v:{w:{x:{if((h|0)!=1){f=w[f|0];v[23588]=0;v[e+1168>>2]=f-1;R(543,e+1192|0,e+1168|0);f=v[23588];v[23588]=0;if((f|0)==1){break x}v[23588]=0;U(288,e+304|0,e+224|0,e+1192|0);f=v[23588];v[23588]=0;if((f|0)==1){break w}f=e+304|0;Ge(e+1240|0,f);hf(ze(d,g),v[e+1240>>2],v[e+1244>>2]);zb(f);zb(e+1192|0);$b(e+224|0);break u}d=P()|0;O()|0;break e}d=P()|0;O()|0;break v}d=P()|0;O()|0;zb(e+1192|0)}$b(e+224|0);break e}f=rc(e+1232|0,21619);hf(ze(d,g),v[f>>2],v[e+1236>>2])}g=g+1|0;continue}}d=w[a+484376|0];f=v[a+484360>>2];v[23588]=0;f=Wb(f,d);d=h&5;da(340,f|0,m|0,w[e+1249|0]|w[e+1250|0]<<8,(d?65535:255)|0,(d?65535:254)|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;U(190,e+304|0,m|0,B(w[e+1248|0],w[e+1253|0]|w[e+1254|0]<<8)<<1);d=v[23588];v[23588]=0;if((d|0)!=1){d=e+304|0;G=kc(e+1192|0,d);Bb(d);v[23588]=0;U(190,d|0,m|0,(w[e+1253|0]|w[e+1254|0]<<8)<<1);d=v[23588];v[23588]=0;y:{if((d|0)!=1){d=e+304|0;H=kc(e+1168|0,d);Bb(d);v[23588]=0;r=Q(218,e+1152|0,w[e+1255|0]|w[e+1256|0]<<8)|0;d=v[23588];v[23588]=0;z:{if((d|0)!=1){N=e,V=Fb(v[r>>2]),v[N+248>>2]=V;d=Fb(v[r+4>>2]);A:{B:{C:{while(1){f=v[e+248>>2];if(!Pb(f,d)){j=a+480180|0;d=v[j>>2];A=c&1;if(!A){break B}v[23588]=0;R(225,a+484344|0,w[e+1253|0]|w[e+1254|0]<<8);f=v[23588];v[23588]=0;if((f|0)!=1){break B}d=P()|0;O()|0;break A}v[23588]=0;h=S(157,m|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){v[23588]=0;U(190,e+224|0,m|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break C}g=f;f=e+224|0;h=kc(e+304|0,f);hd(g,h);Bb(h);Bb(f);Nf(e+248|0);continue}break}d=P()|0;O()|0;break A}d=P()|0;O()|0;break A}s=(d|0)==16?14:(d|0)==32?1:13;I=a+484344|0;n=1;while(1){D:{E:{F:{G:{H:{I:{if((w[e+1253|0]|w[e+1254|0]<<8)>>>0<=q>>>0){switch(v[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}v[23588]=0;d=S(194,H|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break H}v[e+224>>2]=d;if(!A){break D}v[23588]=0;d=W(226,I|0,q&65535,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break H}l=0;if(!d){break D}while(1){h=l&65535;if(h>>>0>=w[e+1248|0]){break D}v[23588]=0;d=S(194,G|0)|0;f=v[23588];v[23588]=0;J:{if((f|0)!=1){f=v[r>>2];if(Cf(f,v[r+4>>2])>>>0<=d>>>0){break J}k=Pg(f,d);zc(k);f=0;d=Zb(v[I>>2],q);g=jd(v[d>>2],v[v[d+48>>2]+12>>2],0,h);K:while(1){if(y[e+224>>2]<=f>>>0){break J}v[23588]=0;d=S(206,k|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){if(!d){break J}z=d>>>4|0;J=d&15;i=0;h=ug(e+304|0);while(1){L:{M:{N:{if(J>>>0>(i&255)>>>0){v[23588]=0;R(260,e+248|0,k|0);d=v[23588];v[23588]=0;if((d|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{d=w[Lb(e+248|0,0)|0];switch(d-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(d-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}d=w[Lb(e+248|0,1)|0];fa:{if(d>>>0<=119){d=d+s|0;break fa}ga:{switch(d-254|0){case 1:d=255;break fa;case 0:d=254;break fa;default:break ga}}d=253}t[h|0]=d;n=gB(d)&n;break L}N=e,V=w[Lb(e+248|0,1)|0]+1|0,t[N+305|0]=V;break L}ha:{if(w[e+306|0]){break ha}d=v[j>>2];if((d|0)!=32){if((d|0)!=4){break ha}d=w[Lb(e+248|0,1)|0];if(d&15){break ha}t[e+306|0]=11;t[e+308|0]=d>>>4;break L}o=w[Lb(e+248|0,1)|0];d=0;while(1){if((d|0)==10){break ha}if((o|0)==w[d+43744|0]){t[e+308|0]=d;t[e+306|0]=11;break L}else{d=d+1|0;continue}}}N=e,V=w[Lb(e+248|0,1)|0],t[N+309|0]=V;t[e+307|0]=4;break L}d=Lb(e+248|0,1);ia:{if(w[e+306|0]){break ia}o=w[d|0];if(v[j>>2]!=32|o>>>0>9){break ia}t[e+308|0]=o;t[e+306|0]=8;break L}t[e+309|0]=w[d|0];t[e+307|0]=5;break L}ja:{if(w[e+306|0]){break ja}ka:{d=v[j>>2];if((d|0)!=4){if((d|0)!=32){break ja}d=Lb(e+248|0,1);o=w[d|0];if((o|0)!=255){break ka}t[e+308|0]=64;t[e+306|0]=2;break L}d=Lb(e+248|0,1);if(w[d|0]&15){break ja}break M}if(!(o&3)){break M}}N=e,V=w[Lb(e+248|0,1)|0],t[N+309|0]=V;t[e+307|0]=9;break L}o=w[e+306|0];d=Lb(e+248|0,1);la:{if(o|v[j>>2]==1){break la}o=w[d|0];if(o>>>0>64){break la}t[e+308|0]=o;t[e+306|0]=1;break L}t[e+309|0]=w[d|0];t[e+307|0]=13;break L}d=w[Lb(e+248|0,1)|0];t[e+309|0]=d;t[e+307|0]=14;if(v[j>>2]==32){break L}t[e+309|0]=B((d&240)>>>4|0,10)+(d&15);break L}d=w[Lb(e+248|0,1)|0];t[e+309|0]=d;t[e+307|0]=d>>>0<32?16:17;break L}o=w[Lb(e+248|0,1)|0];if(o>>>0>=16){t[e+308|0]=o>>>4;t[e+306|0]=(d|0)==20?3:5;break L}t[e+308|0]=o&15;t[e+306|0]=(d|0)==20?4:6;break L}d=w[Lb(e+248|0,1)|0];if(d>>>0>=16){t[e+306|0]=10;t[e+308|0]=d>>>4;break L}t[e+306|0]=9;t[e+308|0]=d&15;break L}d=w[Lb(e+248|0,1)|0];t[e+307|0]=28;t[e+309|0]=d|16;break L}d=w[Lb(e+248|0,1)|0];t[e+307|0]=28;t[e+309|0]=d|32;break L}N=e,V=w[Lb(e+248|0,1)|0],t[N+308|0]=V;t[e+306|0]=(d|0)==31?7:8;break L}d=w[e+307|0];t[e+307|0]=(d|0)==4?6:(d|0)==5?7:11;N=e,V=w[Lb(e+248|0,1)|0],t[N+309|0]=V;break L}d=Lb(e+248|0,1);t[e+308|0]=w[d|0]%10;d=w[d|0];if(d>>>0<=9){t[e+306|0]=5;break L}if(d>>>0<=19){t[e+306|0]=6;break L}if(d>>>0<=29){t[e+306|0]=3;break L}if(d>>>0>39){break L}t[e+306|0]=4;break L}N=e,V=w[Lb(e+248|0,1)|0],t[N+308|0]=V;t[e+306|0]=(d|0)==49?13:12;break L}d=w[Lb(e+248|0,1)|0]+33|0;if((d&255)>>>0>9){break L}t[e+306|0]=15;t[e+308|0]=d;break L}if(d>>>0>57){break L}N=e,V=w[Lb(e+248|0,1)|0],t[N+309|0]=V;t[e+307|0]=w[d+26816|0];break L}v[e+248>>2]=f+z;d=v[Kb(e+248|0,e+224|0)>>2];d=d>>>0<f>>>0?f:d;while(1){if((d|0)!=(f|0)){i=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[g|0]=i;t[g+1|0]=i>>>8;t[g+2|0]=i>>>16;t[g+3|0]=i>>>24;i=w[h+4|0]|w[h+5|0]<<8;t[g+4|0]=i;t[g+5|0]=i>>>8;f=f+1|0;g=B(w[e+1248|0],6)+g|0;continue}break}f=d;continue K}d=P()|0;O()|0;break A}d=w[d|0];t[e+306|0]=2;t[e+308|0]=d>>>2}i=i+1|0;continue}}break}d=P()|0;O()|0;break A}d=P()|0;O()|0;break A}l=l+1|0;continue}}g=x[a+480192>>1];d=0;break E}d=P()|0;O()|0;break A}if((n^1)&1|x[D>>1]!=4){break F}v[a+480208>>2]=v[a+480208>>2]|8454144}g=0;d=!((w[e+1263|0]|w[e+1264|0]<<8|(w[e+1265|0]<<16|w[e+1266|0]<<24))&512)}v[23588]=0;o=Q(547,e+1136|0,g|0)|0;f=v[23588];v[23588]=0;ma:{na:{oa:{pa:{qa:{if((f|0)!=1){q=a+480192|0;j=p>>>0<5;n=a+480180|0;i=1;ra:{while(1){g=i&65535;if(g>>>0>x[q>>1]){break ra}sa:{ta:{ua:{va:{if(!d){v[23588]=0;h=W(251,a|0,g|0,0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break va}if(h){break ua}}while(1){v[23588]=0;f=S(206,m|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break na}if(f){continue}break}if(!j){while(1){v[23588]=0;f=S(206,m|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){d=P()|0;O()|0;break ma}if(f){continue}break}}v[23588]=0;Q(188,m|0,826)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break ta}}d=P()|0;O()|0;break ma}f=Mb(e+224|0);v[23588]=0;U(350,m|0,f|0,-1);l=v[23588];v[23588]=0;if((l|0)==1){break sa}Dc(h+492|0,f);if(!j){v[23588]=0;U(350,m|0,f|0,-1);l=v[23588];v[23588]=0;if((l|0)==1){break sa}Dc(h+524|0,f)}v[23588]=0;l=Q(548,m|0,e+304|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break oa}if(!l){break qa}l=v[n>>2];v[23588]=0;U(549,e+304|0,h|0,l|0);h=v[23588];v[23588]=0;if((h|0)==1){break oa}if(v[n>>2]==4){h=Eb(v[o>>2],g-1|0);g=x[e+1106>>1]|x[e+1108>>1]<<16;t[h|0]=g;t[h+1|0]=g>>>8;t[h+2|0]=g>>>16;t[h+3|0]=g>>>24}zb(f)}i=i+1|0;continue}break}break oa}if(!d){break pa}u[a+480192>>1]=0;break pa}d=P()|0;O()|0;break A}zb(f)}d=x[a+480190>>1];v[23588]=0;q=Q(550,e+288|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){J=!(t[e+1263|0]&1)|p>>>0>4;A=c&2;M=a+480180|0;i=1;d=0;while(1){c=d;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{n=i&65535;if(n>>>0<=x[a+480190>>1]){g=Mb(e+272|0);v[23588]=0;U(350,m|0,g|0,-1);d=v[23588];v[23588]=0;if((d|0)==1){break Ra}j=B(n,104)+a|0;Dc(((n<<5)+a|0)+946304|0,g);d=p>>>0<5;if(!d){v[23588]=0;U(350,m|0,g|0,-1);f=v[23588];v[23588]=0;if((f|0)==1){break Ra}Ce(j+484423|0,g)}v[23588]=0;f=Q(551,m|0,e+304|0)|0;h=v[23588];v[23588]=0;Sa:{Ta:{if((h|0)==1){break Ta}if(!f){break Sa}h=v[M>>2];v[23588]=0;f=j+484380|0;X(552,e+304|0,f|0,h|0,J|0);h=v[23588];v[23588]=0;if((h|0)==1){break Ta}s=0;Ua:{if((x[e+324>>1]&61440)!=28672|d){break Ua}v[23588]=0;s=S(553,m|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break Ua}d=P()|0;O()|0;break za}if(!A){break xa}h=w[e+339|0]|w[e+340|0]<<8|(w[e+341|0]<<16|w[e+342|0]<<24);d=x[e+324>>1];l=d&61440;if(!(h|l)){d=_c(e+224|0,d&1?16:8,d&1024?3:1,0,0);v[23588]=0;W(219,d|0,f|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break xa}d=P()|0;O()|0;break za}if((h|0)<0){d=h+n|0;if((d|0)<=0){break xa}yS(f,(B(d,104)+a|0)+484380|0);break xa}if((h|0)<=0){break xa}if(d&1){k=j+484414|0;u[k>>1]=x[k>>1]|1}if(d&1024){k=j+484414|0;u[k>>1]=x[k>>1]|64}v[23588]=0;U(190,e+224|0,b|0,h|0);h=v[23588];v[23588]=0;Va:{Wa:{Xa:{Ya:{Za:{_a:{if((h|0)!=1){k=e+224|0;h=kc(e+248|0,k);Bb(k);k=Ld(x[f+34>>1]);K=(l|0)==16384;if(!K&(l|0)!=8192){break Ya}z=v[h>>2];v[23588]=0;z=S(160,z|0)|0;E=v[23588];v[23588]=0;if((E|0)==1){break Va}E=4/(k>>>0)|0;Oka(E,0,z,0);xc(f,nb?-1:B(E,z));if((l|0)==8192){break _a}if(!K){break Ya}if(!Og(f)){break Xa}d=v[j+484400>>2];f=v[f>>2];if(!(t[e+324|0]&1)){break Za}v[23588]=0;X(554,h|0,d|0,f|0,k|0);f=v[23588];v[23588]=0;d=c;if((f|0)==1){break Ba}break Wa}d=P()|0;O()|0;break za}if(!Og(f)){break Xa}d=v[j+484400>>2];f=v[f>>2];if(t[e+324|0]&1){v[23588]=0;X(555,h|0,d|0,f|0,k|0);f=v[23588];v[23588]=0;d=c;if((f|0)!=1){break Wa}break Ba}v[23588]=0;X(556,h|0,d|0,f|0,k|0);f=v[23588];v[23588]=0;d=c;if((f|0)==1){break Ba}break Wa}v[23588]=0;X(557,h|0,d|0,f|0,k|0);f=v[23588];v[23588]=0;d=c;if((f|0)==1){break Ba}break Wa}if((d&45056)==12288){d=xS(e+224|0,h,w[e+343|0]|w[e+344|0]<<8,s);N=hd(mf(v[q>>2],n-1|0),d),V=v[d+20>>2],v[N+20>>2]=V;Bb(d);break Xa}if((l|0)!=32768){d=1;if((l|0)!=4096){break Wa}l=ke(e+224|0,h);v[23588]=0;d=Q(558,e+216|0,h|0)|0;k=v[23588];v[23588]=0;if((k|0)!=1){$a:{ab:{if(!w[e+221|0]){break ab}s=w[e+343|0]|w[e+344|0]<<8;k=x[e+218>>1]<<1;if(s>>>0<(k&65535)>>>0){break ab}k=s-k|0;t[e+343|0]=k;t[e+344|0]=k>>>8;d=x[d>>1];v[23588]=0;Q(155,h|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break $a}v[23588]=0;d=S(202,h|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break $a}v[23588]=0;U(190,e+168|0,h|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break $a}d=e+168|0;k=kc(e+192|0,d);hd(l,k);Bb(k);Bb(d)}v[23588]=0;n=W(559,a|0,n|0,l|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break $a}d=1;if(n){d=w[e+343|0]|w[e+344|0]<<8;bb:{if(!d){break bb}n=x[f+34>>1];k=Ij(v[f>>2],n);if(k>>>0<=d>>>0){break bb}n=Fk(n);j=v[j+484400>>2];hj(j,d+j|0,k-d|0);v[f>>2]=v[f>>2]-((d>>>0)/(n>>>0)|0)}xc(f,v[e+312>>2]);d=c}Bb(l);break Wa}}d=P()|0;O()|0;Bb(l);break Aa}v[23588]=0;d=Q(417,h|0,e+224|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break Qa}if(!d){break Xa}v[e+80>>2]=v[e+232>>2];d=v[e+228>>2];v[e+72>>2]=v[e+224>>2];v[e+76>>2]=d;Gl(f,1,e+72|0)}d=c}Bb(h);break wa}d=P()|0;O()|0;break Aa}d=P()|0;O()|0;break za}zb(g)}cb:{if(!A){break cb}n=1;while(1){g=n&65535;if(g>>>0>x[a+480190>>1]){break cb}b=mf(v[q>>2],g-1|0);d=v[b>>2];v[23588]=0;d=S(178,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Pa}db:{eb:{if(!d){break eb}f=x[b+22>>1];d=f+n&65535;i=x[b+20>>1];j=(f|0)!=0&(d|0)!=0&d>>>0<=x[a+480190>>1]&(i|0)!=0;fb:{if(j){f=mf(v[q>>2],d-1|0);break fb}d=v[b>>2];v[23588]=0;i=S(160,d|0)|0;d=v[23588];v[23588]=0;f=b;if((d|0)==1){break Oa}}zc(f);gb:{if(j){d=v[f+8>>2];h=v[f>>2];p=x[b+20>>1];v[23588]=0;d=W(156,h|0,d|0,p|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break Oa}if(!d){break eb}v[e+224>>2]=0;v[e+248>>2]=0;v[23588]=0;U(203,e+304|0,f|0,i|0);d=v[23588];v[23588]=0;hb:{if((d|0)!=1){h=qA(Je(e+304|0),Fi(v[e+304>>2]),e+224|0,e+248|0);v[23588]=0;Q(188,f|0,v[e+224>>2])|0;d=v[23588];v[23588]=0;if((d|0)==1){break hb}Uc(e+304|0);break gb}d=P()|0;O()|0;break ya}d=P()|0;O()|0;Uc(e+304|0);break ya}h=0;v[e+224>>2]=0;v[e+248>>2]=0}v[23588]=0;R(560,e+304|0,b|0);d=v[23588];v[23588]=0;ib:{jb:{if((d|0)!=1){d=Je(e+304|0);i=v[e+304>>2];if(!j){h=qA(d,Fi(i),e+224|0,e+248|0);v[23588]=0;f=v[e+224>>2];Q(188,b|0,f|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break db}i=i-f|0;d=d+f|0}if(h){break jb}c=1;break ib}d=P()|0;O()|0;break ya}f=B(g,104)+a|0;p=f+484380|0;Og(p);s=f+484400|0;f=0;g=v[e+248>>2];while(1){kb:{if(!i|(g|0)!=1?g:0){break kb}g=v[p>>2];if(g>>>0<=f>>>0){break kb}if(!_d(g,v[p+20>>2])){break kb}v[e+192>>2]=0;v[e+168>>2]=0;l=wS(h,d,Fi(i),e+192|0,e+272|0,e+168|0);v[23588]=0;v[e+224>>2]=l;Q(188,b|0,l|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ca}bi(e+168|0,Fi(v[p>>2]-f|0));j=v[e+168>>2];lb:{if((j|0)<=0){break lb}g=v[e+192>>2];z=x[p+34>>1];if((Ld(z)|0)!=(g|0)){break lb}k=B(f,g);A=v[s>>2];if(z&1){v[e+160>>2]=j;v[e+144>>2]=j;v[e- -64>>2]=j;v[e+48>>2]=j;v[e+140>>2]=g;v[e+136>>2]=v[e+272>>2];v[e+156>>2]=g;v[e+152>>2]=A+(k<<1);v[23588]=0;g=v[e+140>>2];v[e+40>>2]=v[e+136>>2];v[e+44>>2]=g;g=v[e+156>>2];v[e+56>>2]=v[e+152>>2];v[e+60>>2]=g;R(561,e+56|0,e+40|0);g=v[23588];v[23588]=0;if((g|0)!=1){break lb}break Ca}v[e+128>>2]=j;v[e+112>>2]=j;v[e+32>>2]=j;v[e+16>>2]=j;v[e+108>>2]=g;v[e+104>>2]=v[e+272>>2];v[e+124>>2]=g;v[e+120>>2]=k+A;v[23588]=0;g=v[e+108>>2];v[e+8>>2]=v[e+104>>2];v[e+12>>2]=g;g=v[e+124>>2];v[e+24>>2]=v[e+120>>2];v[e+28>>2]=g;R(562,e+24|0,e+8|0);g=v[23588];v[23588]=0;if((g|0)==1){break Ca}}i=i-l|0;d=d+l|0;g=vS(h);v[e+248>>2]=g;f=f+j|0;continue}break}uS(h)}Uc(e+304|0)}n=n+1|0;continue}break}break Ca}mb:{if(v[a+480180>>2]!=4){break mb}g=0;d=a+480192|0;while(1){if(x[d>>1]<=g>>>0){break mb}b=Eb(v[o>>2],g);f=w[b+3|0];h=w[b+2|0];i=w[b+1|0];b=w[b|0];v[23588]=0;g=g+1|0;ma(391,a|0,g&65535,b|0,i|0,h|0,f|0);b=v[23588];v[23588]=0;if((b|0)!=1){continue}break}d=P()|0;O()|0;break ya}if(!(w[e+1265|0]&16)){break Ka}b=v[m+8>>2];d=v[m>>2];v[23588]=0;b=W(156,d|0,b|0,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ma}if(!b){break Ka}g=0;v[23588]=0;b=S(206,m|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Na}if(!(b&1)){break La}while(1){if(x[D>>1]<=g>>>0){break La}v[23588]=0;b=S(157,m|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){t[((g<<5)+a|0)+480288|0]=b;g=g+1|0;continue}break}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break za}d=P()|0;O()|0;break Aa}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=a+906300|0;while(1){b=v[m+8>>2];f=v[m>>2];v[23588]=0;b=W(156,f|0,b|0,1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Da}if(!b){break Ka}v[23588]=0;b=S(206,m|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Ia}if(!b){break Ka}v[23588]=0;f=S(157,m|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break Ja}v[23588]=0;U(190,e+224|0,m|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break Ja}h=e+224|0;f=kc(e+304|0,h);Bb(h);nb:{if(b>>>0<=250){v[23588]=0;R(439,f|0,Md(d,b-1|0)|0);b=v[23588];v[23588]=0;if((b|0)==1){break nb}}Bb(f);continue}break}d=P()|0;O()|0;Bb(f);break ya}j=a+901404|0;i=Mb(e+192|0);n=a+480180|0;p=a+484348|0;d=0;h=0;while(1){b=v[m+8>>2];f=v[m>>2];v[23588]=0;b=W(156,f|0,b|0,8)|0;f=v[23588];v[23588]=0;ob:{pb:{qb:{rb:{sb:{if((f|0)!=1){if(b){v[23588]=0;f=S(157,m|0)|0;b=v[23588];v[23588]=0;tb:{ub:{vb:{wb:{xb:{yb:{zb:{Ab:{if((b|0)!=1){v[23588]=0;b=S(157,m|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ab}v[23588]=0;U(190,e+304|0,m|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break zb}g=e+304|0;b=kc(e+224|0,g);Bb(g);if((f|0)==1229211981){break wb}if((f|0)==1229476432){break xb}if((f|0)==1397900630){break yb}if((f|0)!=1414548815){break ob}v[23588]=0;f=Q(402,b|0,13805)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ha}if(!f){break pb}v[23588]=0;f=S(157,b|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){v[23588]=0;U(190,e+304|0,b|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){break vb}}d=P()|0;O()|0;break Ga}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}Bb:{Cb:{Db:{f=v[n>>2];switch(f-2|0){case 1:break ob;case 0:break ub;case 2:break Cb;default:break Db}}if((f|0)==16){break Bb}if((f|0)!=32){break ob}v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Ha}v[23588]=0;h=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break ob}break Ha}v[e+304>>2]=32;f=v[b>>2];v[23588]=0;f=S(160,f|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){v[e+248>>2]=f;f=v[Kb(e+304|0,e+248|0)>>2];v[23588]=0;U(563,b|0,i|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){break ob}}d=P()|0;O()|0;break Ga}v[23588]=0;f=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break tb}v[23588]=0;R(564,e+248|0,4214);g=v[23588];v[23588]=0;Eb:{if((g|0)!=1){v[e+272>>2]=f>>>4;v[23588]=0;v[e+88>>2]=f&15;X(302,e+304|0,e+248|0,e+272|0,e+88|0);f=v[23588];v[23588]=0;if((f|0)==1){break Eb}f=e+304|0;Jb(i,f);Ab(f);bc(e+248|0);break ob}d=P()|0;O()|0;break Ga}d=P()|0;O()|0;bc(e+248|0);break Ga}v[23588]=0;f=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ha}v[a+480216>>2]=f;v[23588]=0;f=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ha}v[a+480220>>2]=f;break ob}v[23588]=0;Q(412,b|0,j|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Ha}UA(j);break ob}g=e+304|0;f=kc(e+248|0,g);Bb(g);g=v[f>>2];v[23588]=0;g=S(160,g|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break qb}u[e+304>>1]=g>>>5;N=e,V=Bf(v[a+484344>>2],v[p>>2]),u[N+272>>1]=V;l=x[Wc(e+304|0,e+272|0)>>1];g=0;while(1){if((g|0)==(l|0)){Bb(f);break pb}v[23588]=0;R(565,f|0,e+304|0);k=v[23588];v[23588]=0;Fb:{if((k|0)==1){break Fb}k=v[I>>2];v[23588]=0;R(566,Zb(k,g)|0,e+304|0);k=v[23588];v[23588]=0;if((k|0)==1){break Fb}g=g+1|0;continue}break}break qb}v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Ha}break ob}d=P()|0;O()|0;break Ga}b=v[a+480180>>2];Gb:{Hb:{Ib:{if((b|0)!=32){break Ib}f=d&65535;if(f>>>0<256){break Ib}if(f>>>0<532){break Hb}}b=(b|0)!=2;Jb:{if(b){break Jb}f=d&65535;if(f>>>0<12544){break Jb}if(f>>>0<12820){break Hb}}if(b){break Gb}b=d&65535;if(b>>>0<4864|b>>>0>4895){break Gb}}qq(j)}g=1;Kb:{if(!(t[e+1265|0]&1)){break Kb}f=v[a+1074308>>2];if(!f){d=a+480192|0;f=a+480180|0;while(1){b=g&65535;if(b>>>0<=x[d>>1]){b=v[((b<<2)+a|0)+900380>>2];if(b){j=v[f>>2];v[23588]=0;R(567,Hh(b,2)|0,j|0);j=v[23588];v[23588]=0;if((j|0)==1){break sb}t[b+19|0]=w[b+19|0]+3>>>2}g=g+1|0;continue}break}f=v[a+1074308>>2]}if(f>>>0<=18350079){v[23588]=0;b=Q(265,a+1074312|0,27)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Fa}v[23588]=0;Q(265,b|0,57)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Fa}f=v[a+1074308>>2]}if(f>>>0<=19070975){v[23588]=0;Q(265,a+1074312|0,73)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Fa}f=v[a+1074308>>2]}if(f>>>0>19267583){break Kb}v[23588]=0;Q(265,a+1074312|0,50)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Fa}}Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{if(sh(v[i+4>>2],w[i+11|0])){v[23588]=0;Y(568,e+224|0);b=v[23588];v[23588]=0;Zb:{if((b|0)!=1){v[23588]=0;U(536,e+304|0,e+224|0,e+1735|0);b=v[23588];v[23588]=0;if((b|0)==1){break Zb}break Yb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;bc(e+224|0);break Ea}v[23588]=0;Y(569,e+224|0);b=v[23588];v[23588]=0;if((b|0)==1){break Xb}v[23588]=0;X(570,e+304|0,e+224|0,e+1735|0,i|0);b=v[23588];v[23588]=0;if((b|0)==1){break Wb}}b=e+304|0;Jb(i,b);Ab(b);b=e+224|0;bc(b);v[23588]=0;R(535,b|0,3980);b=v[23588];v[23588]=0;if((b|0)==1){break Ub}v[23588]=0;U(536,e+304|0,e+224|0,e+1735|0);b=v[23588];v[23588]=0;if((b|0)==1){break Tb}b=e+304|0;Jb(a+1298344|0,b);Ab(b);bc(e+224|0);v[23588]=0;b=Q(1,b|0,14954)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Sb}Jb(a+1298356|0,b);Ab(b);b=v[a+480180>>2];switch(b-1|0){case 2:break rb;case 1:break Ob;case 3:break Pb;case 0:break Qb;default:break Vb}}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;bc(e+224|0);break Ea}if((b|0)==16){break Rb}if((b|0)==32){break Nb}if((b|0)!=16777216){break rb}v[23588]=0;b=Q(1,e+224|0,10074)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Mb}Jb(a+1298392|0,b);Ab(b);v[23588]=0;b=Q(1,e+248|0,13752)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Lb}Jb(a+1298380|0,b);Ab(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;bc(e+224|0);break Ea}d=P()|0;O()|0;break Ea}v[23588]=0;b=Q(1,e+224|0,10079)|0;d=v[23588];v[23588]=0;_b:{if((d|0)!=1){Jb(a+1298392|0,b);Ab(b);v[23588]=0;b=Q(1,e+248|0,8325)|0;d=v[23588];v[23588]=0;if((d|0)==1){break _b}Jb(a+1298380|0,b);Ab(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23588]=0;b=Q(1,e+224|0,12238)|0;d=v[23588];v[23588]=0;$b:{if((d|0)!=1){Jb(a+1298392|0,b);Ab(b);v[23588]=0;b=Q(1,e+248|0,14219)|0;d=v[23588];v[23588]=0;if((d|0)==1){break $b}Jb(a+1298380|0,b);Ab(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23588]=0;b=Q(1,e+224|0,10052)|0;d=v[23588];v[23588]=0;ac:{if((d|0)!=1){Jb(a+1298392|0,b);Ab(b);v[23588]=0;b=Q(1,e+248|0,15257)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ac}Jb(a+1298380|0,b);Ab(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23588]=0;b=Q(1,e+224|0,10424)|0;d=v[23588];v[23588]=0;bc:{if((d|0)!=1){Jb(a+1298392|0,b);Ab(b);v[23588]=0;b=Q(1,e+248|0,15007)|0;d=v[23588];v[23588]=0;if((d|0)==1){break bc}Jb(a+1298380|0,b);Ab(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23588]=0;b=Q(1,e+224|0,6130)|0;d=v[23588];v[23588]=0;cc:{dc:{ec:{fc:{gc:{if((d|0)!=1){Jb(a+1298392|0,b);Ab(b);if(!(h&65535)){break cc}v[23588]=0;R(266,e+272|0,4317);b=v[23588];v[23588]=0;if((b|0)==1){break gc}v[e+100>>2]=(h&65280)>>>8;v[23588]=0;v[e+84>>2]=h&255;R(433,e+88|0,e+84|0);b=v[23588];v[23588]=0;if((b|0)==1){break fc}v[23588]=0;X(419,e+248|0,e+272|0,e+100|0,e+88|0);b=v[23588];v[23588]=0;if((b|0)==1){break ec}b=e+248|0;Jb(a+1298380|0,b);Ab(b);Ab(e+88|0);bc(e+272|0);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break dc}d=P()|0;O()|0;Ab(e+88|0)}bc(e+272|0);break Ea}v[23588]=0;b=Q(1,e+248|0,8517)|0;d=v[23588];v[23588]=0;if((d|0)!=1){Jb(a+1298380|0,b);Ab(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}Jb(a+1298368|0,i);hc:{if(v[a+1074308>>2]){v[a+1298404>>2]=8;break hc}if(v[a+480180>>2]==1){v[a+1298404>>2]=14;break hc}v[a+1298404>>2]=5}g=1;ic:{jc:{if(c&1){v[23588]=0;b=Q(1,e+272|0,16594)|0;c=v[23588];v[23588]=0;if((c|0)==1){break jc}a=v[a+1298464>>2];v[23588]=0;U(376,a|0,2,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break ic}Ab(b)}Ab(i);tS(q);wc(o);Vc(r);Bb(H);Bb(G);break c}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;Ab(b);break Ea}d=P()|0;O()|0;Bb(f);break Ga}v[23588]=0;f=Q(402,b|0,13810)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ha}kc:{if(!f){break kc}v[23588]=0;f=S(157,b|0)|0;g=v[23588];v[23588]=0;lc:{if((g|0)!=1){v[23588]=0;U(190,e+248|0,b|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){break lc}}d=P()|0;O()|0;break Ga}g=e+248|0;f=kc(e+304|0,g);Bb(g);g=v[f>>2];v[23588]=0;g=S(160,g|0)|0;l=v[23588];v[23588]=0;if((l|0)!=1){u[e+248>>1]=(g>>>0)/20;u[e+272>>1]=x[D>>1];l=x[Wc(e+248|0,e+272|0)>>1];g=0;while(1){if((g|0)==(l|0)){Bb(f);break kc}v[23588]=0;U(413,f|0,((g<<5)+a|0)+480289|0,20);k=v[23588];v[23588]=0;if((k|0)!=1){g=g+1|0;continue}break}}d=P()|0;O()|0;Bb(f);break Ga}v[23588]=0;Q(422,a|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Ha}v[23588]=0;X(423,a|0,b|0,1,0);f=v[23588];v[23588]=0;if((f|0)==1){break Ha}if((d-2186&65535)>>>0<=117){v[n>>2]=16777216;v[23588]=0;U(437,a|0,b|0,d&65535);f=v[23588];v[23588]=0;if((f|0)==1){break Ha}}if(!v[a+1074308>>2]){break ob}v[23588]=0;f=Q(1,e+168|0,17579)|0;g=v[23588];v[23588]=0;mc:{nc:{oc:{if((g|0)!=1){g=v[a+1074308>>2];v[23588]=0;R(140,e+248|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break oc}v[23588]=0;U(2,e+304|0,f|0,e+248|0);g=v[23588];v[23588]=0;if((g|0)==1){break nc}g=e+304|0;Jb(i,g);Ab(g);Ab(e+248|0);Ab(f);break ob}d=P()|0;O()|0;break Ga}d=P()|0;O()|0;break mc}d=P()|0;O()|0;Ab(e+248|0)}Ab(f);break Ga}Bb(b);continue}}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0}Bb(b);break Ea}d=P()|0;O()|0}Ab(i);break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0;Uc(e+304|0);break ya}d=P()|0;O()|0}Bb(h)}zb(g)}tS(q);break ma}d=c}zb(g);i=i+1|0;continue}}d=P()|0;O()|0;break ma}d=P()|0;O()|0;zb(f);break ma}d=P()|0;O()|0}wc(o);break A}q=q+1|0;continue}}Vc(r);break z}d=P()|0;O()|0}Bb(H);break y}d=P()|0;O()|0}Bb(G);break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}else{pc:{qc:{if(!j){t[e+304|0]=w[(e+g|0)+1270|0];t[e+224|0]=64;N=((g<<5)+a|0)+480286|0,V=w[Xb(e+304|0,e+224|0)|0],u[N>>1]=V;break qc}if(n){break pc}}rc:{d=w[(e+g|0)+1334|0];if((d|0)!=255){if((d|0)!=127){break rc}v[((g<<5)+a|0)+480280>>2]=256;break pc}u[((g<<5)+a|0)+480284>>1]=256;break pc}u[((g<<5)+a|0)+480284>>1]=d}g=g+1|0;continue}}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0}Bb(m)}ic(C);T(d|0);L()}Bb(m)}ic(C)}kb=e+1744|0;return g|0}function vha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;e=kb-976|0;kb=e;zc(b);a:{if(!HS(b,e+920|0)){break a}if(!LS(e+920|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(KS(e+920|0),nb))){break a}if(!c){d=1;break a}Bd(a,8);ag(a);aa=w[e+923|0];K=aa-48|0;t[e+919|0]=K;dd(b,cc(v[e+928>>2]));f=e+608|0;ae(f,b,504);_=kc(e+896|0,f);Bb(f);v[23588]=0;R(509,b|0,f|0);f=v[23588];v[23588]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(w[e+891|0]>63){break b}if(Ib(x[e+608>>1])<<16>>16<0){break b}Ub(e+528|0,0,80);h:{d=cc(v[e+952>>2]);if(!d){break h}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){if(!f){break h}v[23588]=0;R(510,b|0,e+528|0);d=v[23588];v[23588]=0;if((d|0)!=1){break h}}i=P()|0;O()|0;break e}v[23588]=0;U(511,e+520|0,b|0,K&255);d=v[23588];v[23588]=0;if((d|0)!=1){ba=Te(e+520|0);d=0;f=x[e+520>>1];if((f-128&65535)>>>0<65409){break b}u[a+480188>>1]=f;M=Tb(e+504|0);d=cc(v[e+944>>2]);i:{if(d){v[23588]=0;Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;U(512,b|0,M|0,w[e+891|0]);d=v[23588];v[23588]=0;if((d|0)==1){break g}j=w[e+891|0];break i}j=w[e+891|0];d=0;if(j){break c}}j=j&255;u[a+480192>>1]=j;u[a+480190>>1]=j;ca=(K&255)>>>0<2|t[e+872|0]>=0;r=!ca;p=c&2;s=1;C=1;while(1){j:{k:{l:{m:{n:{o:{g=C&65535;if(g>>>0<=(j&65535)>>>0){v[23588]=0;y=s&65535;f=W(251,a|0,g|0,y|0)|0;d=v[23588];v[23588]=0;p:{if((d|0)!=1){if(f){break p}break d}i=P()|0;O()|0;break f}z=v[((g<<2)+a|0)+900380>>2];u[e+84>>1]=0;v[e+80>>2]=0;v[23588]=0;D=S(174,e+480|0)|0;d=v[23588];v[23588]=0;q:{if((d|0)!=1){d=Eb(v[M>>2],g-1|0);d=cc(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));r:{if(!d){break r}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break k}if(!f){break r}v[23588]=0;R(513,b|0,e+80|0);d=v[23588];v[23588]=0;if((d|0)==1){break k}f=v[e+80>>2];d=u[e+84>>1];v[23588]=0;f=cc(f);d=qe(d);U(190,e+120|0,b|0,f<<(d>>>5&1&(d|0)>0));d=v[23588];v[23588]=0;if((d|0)==1){break k}f=e+120|0;d=kc(e+192|0,f);hd(D,d);Bb(d);Bb(f)}q=qe(u[e+84>>1]);d=q&15;if((q|0)>=0){break q}eu(z,0);ea=1;break o}i=P()|0;O()|0;break f}if(d>>>0>6){break o}A=w[d+26694|0];if(!d){break m}u[a+480190>>1]=(x[a+480190>>1]+A|0)-1;l=z+108|0;m=z+236|0;n=A-2|0;j=4;s:while(1){g=1;if((j|0)==10){break n}k=B(j,12);d=(n<<3)+j|0;h=w[d+26700|0]+s|0;g=w[d+26748|0];d=0;while(1)if((d|0)==12){j=j+1|0;continue s}else{f=d+k|0;fa=dc(m,f),ga=h,u[fa>>1]=ga;f=Lb(l,f);t[f|0]=g+w[f|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=cc(v[e+532>>2]);if(!d){break D}if(!Ib(x[e+536>>1])){break D}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break C}if(!f){break D}fa=e,ga=Ib(x[e+536>>1]),u[fa+192>>1]=ga;u[e+120>>1]=w[e+891|0];f=e+120|0;p=x[Wc(e+192|0,f)>>1];d=e+128|0;l=f|4;y=Ib(x[e+538>>1]);m=y>>>0<19;n=y>>>0<21;k=y>>>0<15;h=y>>>0<6;j=0;while(1){if((j|0)==(p|0)){break D}v[23588]=0;U(514,b|0,e+192|0,y|0);f=v[23588];v[23588]=0;E:{F:{G:{if((f|0)!=1){j=j+1|0;q=v[((j<<2)+a|0)+900380>>2];r=w[e+192|0];if(r){g=Al(e+120|0,0,64);Al(l,r-1&65535,64);f=w[e+193|0];if(f){f=64/(f>>>0)|0}else{f=0}Al(d,f+r|0,0);v[23588]=0;r=q+48|0;U(515,r|0,g|0,3);f=v[23588];v[23588]=0;if((f|0)==1){break G}if(w[e+192|0]==1){g=v[fc(e+472|0,Fb(v[r>>2]))>>2];f=Fb(v[r>>2]);f=v[r>>2]+(cu(g,f)<<2)|0;Od(r,Qi(f+4|0,v[r+4>>2],f));Fb(f)}f=w[e+193|0];v[q>>2]=f?f<<9:32767;t[q+60|0]=w[q+60|0]|1;F=1}H:{if(m){break H}v[q+4>>2]=w[e+210|0]+1>>>1;if(n){break H}u[q+28>>1]=x[e+212>>1]}g=B(x[dc(q+236|0,61)>>1],104)+a|0;t[g+484417|0]=w[e+195|0]<<4;if(k){break F}f=cc(x[e+202>>1]|x[e+204>>1]<<16);v[g+484384>>2]=f;fa=g+484388|0,ga=cc(x[e+206>>1]|x[e+208>>1]<<16)+f|0,v[fa>>2]=ga;break E}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}if(h){continue}}f=g+484414|0;i=f;o=x[f>>1]&65529;f=w[e+197|0];u[i>>1]=o|f<<1&2|f>>>1&4;if(!(f&4)){continue}u[g+484412>>1]=0;continue}}I:{d=cc(v[e+548>>2]);if(!d){break I}if(!Ib(x[e+552>>1])){break I}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break C}if(!f){break I}fa=e,ga=Ib(x[e+552>>1]),u[fa+192>>1]=ga;u[e+120>>1]=w[e+891|0];n=x[Wc(e+192|0,e+120|0)>>1];k=Ib(x[e+554>>1]);d=0;J:while(1){if((d|0)==(n|0)){break I}v[23588]=0;U(516,b|0,e+192|0,k|0);f=v[23588];v[23588]=0;if((f|0)==1){break t}f=e+80|0;sU(f,e+192|0);v[23588]=0;R(222,e+120|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break u}d=d+1|0;m=((d<<2)+a|0)+900380|0;g=e+120|0;Dc(v[m>>2]+492|0,g);zb(g);f=v[m>>2];v[23588]=0;R(380,g|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break v}fa=e,ga=Gi(v[e+120>>2]),v[fa+80>>2]=ga;h=xf(e+120|0);while(1){f=v[e+80>>2];if(Pb(f,h)){l=(x[ro(f)>>1]<<5)+a|0;g=l+946328|0;p=v[m>>2];f=v[p+520>>2];v[g>>2]=v[p+516>>2];v[g+4>>2]=f;f=v[p+512>>2];g=l+946320|0;v[g>>2]=v[p+508>>2];v[g+4>>2]=f;f=v[p+504>>2];g=l+946312|0;v[g>>2]=v[p+500>>2];v[g+4>>2]=f;f=v[p+496>>2];g=l+946304|0;v[g>>2]=v[p+492>>2];v[g+4>>2]=f;Lg(e+80|0);continue}else{ru(e+120|0);continue J}}}}qq(a+901404|0);d=rc(e+464|0,4943);hf(ze(a+901692|0,0),v[d>>2],v[d+4>>2]);zc(b);D=c&1;G=a+484344|0;H=a+1298332|0;da=a+1298308|0;$=a+484360|0;c=0;while(1){K:{f=c&255;if(f>>>0<w[ba|0]){v[23588]=0;X(517,b|0,e+920|0,e+528|0,e+608|0);d=v[23588];v[23588]=0;L:{M:{N:{O:{P:{if((d|0)==1){break P}Q:{if(!f){d=0;break Q}v[23588]=0;f=S(272,$|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break P}d=c;if((f|0)==255){break d}}o=yj(v[$>>2],d&255);E=Yf(e+448|0);Lc(o);I=K&255;if(I>>>0>1){break N}i=0;f=Ib(x[e+610>>1]);if(f>>>0>256|x[a+480188>>1]>16){break L}d=e+192|0;FS(d,e+608|0);v[23588]=0;U(518,o|0,d|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break O}fa=e,ga=Fb(v[o>>2]),v[fa+192>>2]=ga;d=Fb(v[o+4>>2]);while(1){f=v[e+192>>2];if(Pb(f,d)){u[f>>1]=x[f>>1]+J;Se(e+192|0);continue}else{oh(a,1);f=x[a+480188>>1];d=0;while(1)if((d|0)==(f|0)){d=32;break M}else{t[e+192|0]=w[(d+e|0)+874|0];t[e+120|0]=64;fa=((d<<5)+a|0)+480286|0,ga=w[Xb(e+192|0,e+120|0)|0],u[fa>>1]=ga;d=d+1|0;continue}}}}i=P()|0;O()|0;break f}i=P()|0;O()|0;break w}FS(e+192|0,e+608|0);R:{S:{T:{U:{d=Ib(x[e+204>>1]);if(!(!d|d>>>0>64|x[a+480188>>1]>64)){l=cc(v[e+212>>2]);d=Ib(x[e+216>>1]);if(d){u[e+120>>1]=d;u[e+80>>1]=800;f=Ec(((x[Wc(e+120|0,e+80|0)>>1]<<5)+50>>>0)/100|0,0)}else{f=32}d=v[e+200>>2];v[23588]=0;g=Q(155,b|0,cc(d)|0)|0;d=v[23588];v[23588]=0;V:{if((d|0)==1){break V}d=0;W:{if(!g){break W}while(1){if(x[a+480188>>1]<=d>>>0){break W}v[23588]=0;h=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){t[e+120|0]=h;t[e+80|0]=64;fa=((d<<5)+a|0)+480286|0,ga=w[Xb(e+120|0,e+80|0)|0],u[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;O()|0;break w}X:{Y:{d=cc(v[e+208>>2]);if(!d){break Y}v[23588]=0;g=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break V}d=0;if(!g){break Y}while(1){if(x[a+480188>>1]<=d>>>0){break X}v[23588]=0;h=S(519,b|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){fa=((d<<5)+a|0)+480284|0,ga=(Yb(h,-16,16)<<3)+128|0,u[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;O()|0;break w}oh(a,1)}p=Tb(e+176|0);d=v[e+196>>2];v[23588]=0;g=Q(155,b|0,cc(d)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break U}i=1;d=0;if(!g){break R}k=x[e+610>>1];h=v[b+8>>2];g=v[b>>2];v[23588]=0;h=W(156,g|0,h|0,Ib(k)<<1)|0;g=v[23588];v[23588]=0;if((g|0)==1){break U}if(!h){break R}g=x[e+610>>1];v[23588]=0;h=W(520,b|0,p|0,Ib(g)|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break U}if(!h){break R}fa=e,ga=Fb(v[p>>2]),v[fa+168>>2]=ga;m=Fb(v[e+180>>2]);while(1){d=v[e+168>>2];if(!Pb(d,m)){i=0;d=1;break R}g=Ib(w[d|0]|w[d+1|0]<<8);Z:{if(Ib(x[e+206>>1])>>>0<g>>>0){break Z}d=v[e+192>>2];v[23588]=0;Q(155,b|0,cc(d)+(g<<2)|0)|0;d=v[23588];v[23588]=0;_:{$:{aa:{ba:{ca:{if((d|0)==1){break ca}v[23588]=0;g=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ca}v[23588]=0;g=Q(155,b|0,g|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ca}if(!g){break Z}g=v[b+8>>2];d=v[b>>2];v[23588]=0;g=W(156,d|0,g|0,42)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ca}if(!g){break Z}v[23588]=0;R(521,b|0,e+120|0);d=v[23588];v[23588]=0;da:{if((d|0)!=1){if(pc(v[o>>2],v[o+4>>2])){break da}v[23588]=0;R(522,o|0,65534);d=v[23588];v[23588]=0;if((d|0)!=1){break da}}i=P()|0;O()|0;break S}h=Ib(x[e+160>>1]);v[e+116>>2]=h;g=v[b+8>>2];d=v[b>>2];v[23588]=0;g=W(156,d|0,g|0,h|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ba}if(!g){v[23588]=0;g=S(202,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ba}xc(e+116|0,g)}xc(e+116|0,65534);h=v[o+4>>2];g=v[o>>2];d=0;v[23588]=0;n=v[e+116>>2];k=Rc(g,h);R(523,o|0,n+k|0);g=v[23588];v[23588]=0;if((g|0)==1){break $}while(1){ea:{if((d|0)==(n|0)){if(w[e+120|0]){break ea}break aa}v[23588]=0;h=S(271,b|0)|0;g=v[23588];v[23588]=0;fa:{if((g|0)!=1){g=h<<16>>16;if((g|0)<0){break fa}v[23588]=0;R(522,o|0,g+J&65535);g=v[23588];v[23588]=0;if((g|0)!=1){break fa}}i=P()|0;O()|0;break S}d=d+1|0;continue}break}Vm(e+104|0,e+120|0);v[23588]=0;U(524,e+56|0,v[e+104>>2],v[e+108>>2]);d=v[23588];v[23588]=0;ga:{ha:{ia:{if((d|0)!=1){v[23588]=0;U(11,e+80|0,14,e+56|0);d=v[23588];v[23588]=0;if((d|0)==1){break ia}v[23588]=0;R(273,o|0,e+80|0);d=v[23588];v[23588]=0;if((d|0)==1){break ha}Ab(e+80|0);zb(e+56|0);break aa}i=P()|0;O()|0;break S}i=P()|0;O()|0;break ga}i=P()|0;O()|0;Ab(e+80|0)}zb(e+56|0);break S}i=P()|0;O()|0;break S}i=P()|0;O()|0;break S}d=cc(v[e+152>>2]);if(!d){break Z}v[23588]=0;g=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break _}}i=P()|0;O()|0;break S}if(!g){break Z}while(1){ja:{v[23588]=0;g=Q(525,b|0,e+104|0)|0;d=v[23588];v[23588]=0;ka:{la:{ma:{if((d|0)!=1){if(!g){break Z}v[23588]=0;U(190,e+56|0,b|0,w[e+107|0]);d=v[23588];v[23588]=0;if((d|0)==1){break ma}d=e+56|0;n=kc(e+80|0,d);Bb(d);d=Ib(x[e+104>>1]);g=Dl(d+k|0);u[e+56>>1]=g;if((d|0)==65535){break ja}d=v[o>>2];if(Rc(d,v[o+4>>2])>>>0<=g>>>0){break ja}na:{switch(w[e+106|0]-1|0){case 1:break ka;case 0:break la;default:break na}}Bb(n);continue}i=P()|0;O()|0;break S}i=P()|0;O()|0;break S}fa=dc(d,g),ga=65535,u[fa>>1]=ga;Bb(n);continue}v[23588]=0;h=S(271,n|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break T}v[23588]=0;g=Q(526,E|0,e+56|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break T}u[g>>1]=h;fa=dc(v[o>>2],x[e+56>>1]),ga=65534,u[fa>>1]=ga;Bb(n);continue}break}Bb(n)}Se(e+168|0);continue}}i=P()|0;O()|0;break w}i=0;break L}i=P()|0;O()|0;break S}i=P()|0;O()|0;Bb(n)}od(p);break w}od(p);if(d){d=f>>>(l>>>1&1)|0;break M}bu(E);if(!i){break d}break K}g=Ib(x[e+868>>1]);h=w[e+871|0];q=h&64;f=w[e+872|0];z=f&32;N=(f&31)+1|0;fa=a,ga=CS(g,q>>>6|0,z>>>5|0,N),v[fa+480204>>2]=ga;fa=a,ga=Dd(w[e+873|0],1,32),v[fa+480196>>2]=ga;if(z){v[a+480216>>2]=N;v[a+480220>>2]=N<<2}f=w[e+890|0];if(f){t[e+192|0]=f;t[e+120|0]=64;fa=a,ga=w[Xb(e+192|0,e+120|0)|0]<<2,v[fa+480200>>2]=ga}v[a+480228>>2]=d;v[a+480232>>2]=d;v[a+480208>>2]=v[a+480208>>2]&-3|(h>>>4^-1)&2;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{d=cc(v[e+572>>2]);if(!d){break ya}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}if(!f){break ya}d=v[e+576>>2];v[23588]=0;U(268,b|0,da|0,cc(d)|0);d=v[23588];v[23588]=0;if((d|0)==1){break xa}if(w[ba|0]<2){break ya}v[23588]=0;U(11,e+192|0,14,da|0);d=v[23588];v[23588]=0;za:{if((d|0)!=1){v[23588]=0;R(273,o|0,e+192|0);d=v[23588];v[23588]=0;if((d|0)==1){break za}Ab(e+192|0);break ya}i=P()|0;O()|0;break w}i=P()|0;O()|0;Ab(e+192|0);break w}Aa:{if(cc(v[e+544>>2])>>>0<2){break Aa}d=v[e+540>>2];v[23588]=0;f=Q(155,b|0,cc(d)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}if(!f){break Aa}d=v[e+544>>2];v[23588]=0;X(331,H|0,b|0,cc(d)-1|0,4);d=v[23588];v[23588]=0;if((d|0)==1){break xa}}d=cc(v[e+584>>2]);if(!d){break oa}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}if(!f){break oa}f=v[b+8>>2];d=v[b>>2];v[23588]=0;f=W(156,d|0,f|0,12)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}if(!f){break oa}v[23588]=0;Q(188,b|0,6)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}v[23588]=0;f=S(271,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break xa}if((f|0)!=1){break oa}v[23588]=0;g=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break va}if(!g){break oa}f=v[b+8>>2];d=v[b>>2];v[23588]=0;f=W(156,d|0,f|0,g|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break va}if(f){break wa}break oa}i=P()|0;O()|0;break w}k=eE(e+192|0,H);v[23588]=0;X(331,H|0,b|0,g|0,4);d=v[23588];v[23588]=0;if((d|0)==1){break qa}if(!Re(k)){v[23588]=0;f=W(527,e+24|0,2,13)|0;d=v[23588];v[23588]=0;if((d|0)==1){break ua}v[23588]=0;U(528,e+120|0,k|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break ta}v[23588]=0;U(529,e+40|0,e+120|0,H|0);d=v[23588];v[23588]=0;if((d|0)==1){break sa}d=e+40|0;Bc(H,d);zb(d);zb(e+120|0);zb(f)}zb(k);break oa}i=P()|0;O()|0;break w}i=P()|0;O()|0;break pa}i=P()|0;O()|0;break ra}i=P()|0;O()|0;zb(e+120|0)}zb(f);break pa}i=P()|0;O()|0}zb(k);break w}Ba:{if(I>>>0<2){break Ba}i=0;if(!cc(v[e+596>>2])){break Ba}while(1){if(x[a+480188>>1]<=i>>>0){break Ba}d=v[e+596>>2];v[23588]=0;f=Q(155,b|0,cc(d)+(i<<2)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}Ca:{if(!f){break Ca}v[23588]=0;f=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}v[23588]=0;f=Q(155,b|0,f|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}m=0;d=0;if(!f){break Ca}while(1){Da:{g=v[b+8>>2];f=v[b>>2];v[23588]=0;g=W(156,f|0,g|0,8)|0;f=v[23588];v[23588]=0;Ea:{Fa:{Ga:{if((f|0)!=1){if(!g){break Da}v[23588]=0;R(530,b|0,e+192|0);f=v[23588];v[23588]=0;if((f|0)==1){break Ga}f=cc(v[e+192>>2]);if(!f){break Da}switch((f&536870911)-1|0){case 1:break Ea;case 0:break Fa;default:continue}}i=P()|0;O()|0;break w}i=P()|0;O()|0;break w}m=cc(v[e+196>>2]);continue}d=cc(v[e+196>>2]);continue}break}if(!m|!d){break Ca}v[23588]=0;g=Q(155,b|0,m|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}if(!g){break Ca}v[23588]=0;U(413,b|0,((i<<5)+a|0)+480289|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break y}}i=i+1|0;continue}}d=x[e+608>>1];v[23588]=0;s=Ib(d);R(225,G|0,J+s&65535);d=v[23588];v[23588]=0;if((d|0)==1){break z}y=h&16;r=J&65535;g=0;Ha:{Ia:{while(1){if((g|0)==(s|0)){fa=e,ga=Gi(v[E>>2]),v[fa+120>>2]=ga;g=xf(E);while(1){d=v[e+120>>2];if(!Ig(d,g)){i=1;d=cc(v[e+528>>2]);if(!d){break L}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break z}if(!f){break L}J=s+J|0;bu(E);break K}k=ro(d);h=Te(k);Ja:{Ka:{La:{Ma:{d=x[k>>1];if(!d){j=0;break Ma}v[23588]=0;f=Q(311,o|0,d-1&65535)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ja}j=x[k>>1];if(!f){break Ma}v[23588]=0;j=Q(360,o|0,j-1&65535)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ja}break La}if(x[h>>1]==((j&65535)+1|0)){break Ka}v[23588]=0;j=Q(359,G|0,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ja}if((j|0)==65535){break Ka}fa=dc(v[o>>2],x[k>>1]),ga=j,u[fa>>1]=ga}d=Zb(v[G>>2],j);Ae(d,Mm(Ue(Oe(e+192|0,12,Bu(x[h>>1])),v[d+12>>2]-1|0)));s=(s&65535)>>>0>j>>>0?s:j+1|0}Lg(e+120|0);continue}break}i=P()|0;O()|0;break w}Na:{Oa:{if(!D){break Oa}d=v[e+936>>2];v[23588]=0;f=Q(155,b|0,cc(d)+(g<<2)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ia}if(!f){break Oa}v[23588]=0;f=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ia}v[23588]=0;f=Q(155,b|0,f|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ia}if(!f){break Oa}V=Mb(e+56|0);v[23588]=0;Y=S(174,e|0)|0;d=v[23588];v[23588]=0;Pa:{Qa:{if((d|0)!=1){if(I){break Qa}v[23588]=0;R(531,b|0,e+192|0);d=v[23588];v[23588]=0;if((d|0)==1){break Na}u[e+104>>1]=w[e+192|0];Z=w[e+193|0]+1|0;f=48;break Pa}i=P()|0;O()|0;break A}v[23588]=0;n=t[e+870|0];R(532,b|0,e+176|0);d=v[23588];v[23588]=0;Ra:{Sa:{if((d|0)!=1){k=Ib(x[e+176>>1]);u[e+104>>1]=k;Z=Ib(x[e+178>>1])+1|0;d=cc(v[e+180>>2]);if(!d){break Ra}h=v[b+8>>2];v[23588]=0;Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}v[23588]=0;R(533,b|0,e+192|0);d=v[23588];v[23588]=0;if((d|0)==1){break B}d=v[e+196>>2];v[23588]=0;f=Q(155,b|0,cc(d)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}if(!f){break Sa}d=v[e+200>>2];v[23588]=0;U(268,b|0,V|0,cc(d)|0);d=v[23588];v[23588]=0;if((d|0)!=1){break Sa}break B}break B}d=cc(v[e+208>>2]);Ta:{if(!d){break Ta}v[23588]=0;f=Q(155,b|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}if(!f){break Ta}v[23588]=0;f=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}v[23588]=0;f=Q(155,b|0,f|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}if(!f){break Ta}v[23588]=0;U(190,e+80|0,b|0,B(k,Z)|0);d=v[23588];v[23588]=0;if((d|0)==1){break B}f=e+80|0;d=kc(e+120|0,f);hd(Y,d);Bb(d);Bb(f)}v[23588]=0;Q(155,b|0,h|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}}f=n+(I>>>0<3?48:24)|0}v[23588]=0;k=g+r|0;h=W(226,G|0,k&65535,Z|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}Ua:{if(!h){break Ua}d=v[G>>2];v[23588]=0;A=Zb(d,k);R(281,A|0,V|0);d=v[23588];v[23588]=0;if((d|0)==1){break Ha}Ff(e+104|0,x[a+480188>>1]);C=0;p=x[e+104>>1];Va:while(1){if((C|0)==(Z|0)){break Ua}i=0;d=jd(v[A>>2],v[v[A+48>>2]+12>>2],C,0);while(1){if((i&65535)>>>0>=p>>>0){C=C+1|0;continue Va}Wa:{if(!I){v[23588]=0;R(534,e+192|0,b|0);h=v[23588];v[23588]=0;if((h|0)!=1){m=w[e+192|0];n=e+192|0;h=Oc(n);t[d+1|0]=m>>>3&16|w[h|0]>>>4|m>>>1&32;k=w[h|0];fa=d,ga=w[Te(n)|0],t[fa+5|0]=ga;h=m&63;j=h?h+f|0:0;m=k&15;break Wa}break B}v[23588]=0;R(349,e+192|0,b|0);h=v[23588];v[23588]=0;Xa:{Ya:{if((h|0)!=1){h=e+192|0;l=Oc(h);m=Te(h);n=Mi(h);v[23588]=0;k=S(206,Y|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break B}t[d+4|0]=k;k=w[e+192|0];h=k&127;if(!h){break Ya}j=f+h|0;break Xa}break B}j=0;if((k|0)!=128){break Xa}t[d|0]=254}t[d+1|0]=w[l|0]&63;m=w[m|0];t[d+5|0]=w[n|0]}if(j-1>>>0<=119){t[d|0]=j}F=(j|0)>84&ca|F;n=(q|0)!=0;k=(z|0)!=0;h=(y|0)!=0;l=kb-16|0;kb=l;t[d+3|0]=0;Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{m=m&255;switch(m-4|0){case 4:case 10:break Za;case 42:break $a;case 37:break ab;case 28:break bb;case 27:break cb;case 26:break db;case 25:break eb;case 24:break fb;case 23:break gb;case 22:break hb;case 21:break ib;case 20:break jb;case 18:break kb;case 17:break lb;case 16:break mb;case 14:break nb;case 13:break ob;case 12:break pb;case 11:break qb;case 9:break rb;case 8:break sb;case 5:break tb;case 0:break ub;default:break _a}}t[d+3|0]=5;k=w[d+5|0];t[l+15|0]=k>>>3;t[l+14|0]=15;h=w[Xb(l+15|0,l+14|0)|0];t[l+13|0]=k<<1&30;t[l+12|0]=15;fa=d,ga=w[Xb(l+13|0,l+12|0)|0]|h<<4,t[fa+5|0]=ga;break Za}if((w[d+5|0]-1&255)>>>0>19){break Za}t[d+3|0]=16;break Za}t[d+3|0]=13;k=w[d+5|0];vb:{if(!h){if(k>>>0>152){break vb}t[d+5|0]=B((k&240)>>>4|0,10)+(k&15);break Za}t[d+5|0]=(k&127)+1>>>1;break Za}t[d+3|0]=0;break Za}t[d+3|0]=11;break Za}h=w[d+5|0];if(!h){t[d+3|0]=14;break Za}if(h>>>0>240){break Za}t[d+3|0]=17;if(h>>>0<=2){t[d+5|0]=112;break Za}fa=d,ga=tk(+(CS(h,n,k,N)>>>0)/1e4),t[fa+5|0]=ga;break Za}t[d+3|0]=31;t[d+5|0]=w[d+5|0]|128;break Za}t[d+3|0]=19;t[l+11|0]=15;fa=d,ga=w[Xb(d+5|0,l+11|0)|0]|16,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+10|0]=15;fa=d,ga=w[Xb(d+5|0,l+10|0)|0]|32,t[fa+5|0]=ga;break Za}t[d+3|0]=5;h=w[d+5|0];t[l+9|0]=(h>>>4|0)+1;t[l+8|0]=15;fa=d,ga=h&15|w[Xb(l+9|0,l+8|0)|0]<<4,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[d+5|0]=w[d+5|0]&15|80;break Za}t[d+3|0]=19;t[l+7|0]=15;fa=d,ga=w[Xb(d+5|0,l+7|0)|0]|96,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+6|0]=15;fa=d,ga=w[Xb(d+5|0,l+6|0)|0]|192,t[fa+5|0]=ga;break Za}t[d+3|0]=10;break Za}t[d+3|0]=19;t[l+5|0]=15;fa=d,ga=w[Xb(d+5|0,l+5|0)|0]|160,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+4|0]=15;fa=d,ga=w[Xb(d+5|0,l+4|0)|0]|176,t[fa+5|0]=ga;break Za}h=(w[d+5|0]<<24)-16777216>>24;if((h|0)<0){break Za}t[d+5|0]=h;t[d+3|0]=31;break Za}t[d+3|0]=14;break Za}t[d+3|0]=19;t[l+3|0]=15;fa=d,ga=w[Xb(d+5|0,l+3|0)|0]|224,t[fa+5|0]=ga;break Za}h=w[d+5|0];if(h&240){t[d+3|0]=19;t[d+5|0]=h>>>4|208;break Za}if(!(h&15)){break Za}t[d+3|0]=19;t[d+5|0]=h|144;break Za}if(w[d+5|0]|w[d+4|0]){break Za}if(!$c(w[d|0])){break Za}t[d+5|0]=159;t[d+3|0]=20;break Za}h=w[d+4|0];if(!h){break Za}t[d+3|0]=44;fa=d,ga=Ml(Ec(((w[d+5|0]<<8&65280)>>>0)/(h>>>0)|0,0)),t[fa+5|0]=ga;break Za}h=w[d+5|0];if((h+16&255)>>>0>32){break Za}t[d+3|0]=9;fa=d,ga=tg(((h^128)<<3)-896|0),t[fa+5|0]=ga;break Za}if(m>>>0>15){break Za}Pf(d,m,w[d+5|0])}kb=l+16|0;d=d+6|0;i=i+1|0;continue}}}Bb(Y);zb(V)}g=g+1|0;continue}break}break B}i=P()|0;O()|0;break w}break B}bu(E);d=0;if(!i){break c}}Gj($,0);d=1;wb:{if(F&1){break wb}while(1){b=d&65535;if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=0;break wb}c=((b<<2)+a|0)+900380|0;b=v[c>>2];if(b){Nb(du(b))}v[c>>2]=0;d=d+1|0;continue}}xb:{if(!ea){break xb}v[23588]=0;c=Q(1,e+192|0,16335)|0;b=v[23588];v[23588]=0;yb:{if((b|0)!=1){b=v[a+1298464>>2];v[23588]=0;U(376,b|0,2,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break yb}Ab(c);break xb}i=P()|0;O()|0;break f}i=P()|0;O()|0;Ab(c);break f}j=21619;zb:{Ab:{switch(aa-48|0){case 0:j=x[a+480188>>1]>4?17230:17216;break zb;case 1:j=17198;break zb;case 2:j=17180;break zb;case 3:break Ab;default:break zb}}j=17153}v[23588]=0;R(535,e+80|0,16768);b=v[23588];v[23588]=0;Bb:{Cb:{Db:{if((b|0)!=1){v[23588]=0;U(536,e+120|0,e+80|0,e+919|0);b=v[23588];v[23588]=0;if((b|0)==1){break Db}b=e+120|0;Jb(a+1298344|0,b);Ab(b);bc(e+80|0);v[23588]=0;c=Q(1,b|0,12558)|0;b=v[23588];v[23588]=0;if((b|0)==1){break Cb}Jb(a+1298356|0,c);Ab(c);v[23588]=0;R(136,a+1298368|0,j|0);b=v[23588];v[23588]=0;if((b|0)==1){break Bb}v[a+1298404>>2]=14;d=1;break c}i=P()|0;O()|0;break f}i=P()|0;O()|0;bc(e+80|0);break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}c=c+1|0;continue}}i=P()|0;O()|0;break f}i=P()|0;O()|0;Bb(Y)}zb(V);break w}i=P()|0;O()|0;break w}i=P()|0;O()|0;break w}i=P()|0;O()|0}bu(E);break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}A=1;if((d|0)!=7){break m}d=z+108|0;f=dA(d);while(1){if((d|0)!=(f|0)){fa=d,ga=Cl(w[d|0]-24|0),t[fa|0]=ga;d=d+1|0;continue}break}g=0}F=1;break l}g=0;Eb:{if(r|(q|0)<0){break Eb}n=z+108|0;j=7;Fb:while(1){if((j|0)==10){break Eb}k=B(j,12);h=B(j,-12)+72|0;d=0;while(1)if((d|0)==12){j=j+1|0;continue Fb}else{f=Lb(n,d+k|0);t[f|0]=h+w[f|0];d=d+1|0;continue}}}}v[23588]=0;R(537,_|0,e+192|0);d=v[23588];v[23588]=0;if((d|0)!=1){Gb:{d=w[e+196|0];if((d-1&255)>>>0<=15){t[z+31|0]=d;F=1}d=w[e+197|0];if((d<<24)-16777216>>24>=0){t[z+30|0]=d}d=0;Hb:{while(1){if((d|0)==(A|0)){if(!p){break j}if((q|0)>=0){break Hb}break j}v[23588]=0;h=B(d+y|0,104)+a|0;R(277,h+484380|0,8);f=v[23588];v[23588]=0;if((f|0)!=1){t[e+120|0]=w[e+198|0];t[e+56|0]=64;fa=h+484410|0,ga=w[Xb(e+120|0,e+56|0)|0]<<2,u[fa>>1]=ga;t[h+484416|0]=w[e+199|0];d=d+1|0;continue}break}break k}k=_c(e+120|0,8,1,1,0);h=Ib(x[e+194>>1]);i=Ib(x[e+192>>1]);d=v[D>>2];v[23588]=0;j=S(160,d|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){d=qe(u[e+84>>1]);if(d&16){xd(k,16);j=j>>>1|0}if(d&32){Ko(k,3);j=j>>>1|0}if(d&64){dg(k,2)}j=g?(j>>>0)/((-1<<A^-1)>>>0)|0:j;m=h+i|0;d=0;while(1){if((d|0)==(A|0)){break j}g=B(d+y|0,104)+a|0;f=g+484380|0;v[f>>2]=j;v[23588]=0;W(219,k|0,f|0,D|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Gb}i=i<<1;m=m<<1;if(h>>>0>=2){v[g+484388>>2]=m;v[g+484384>>2]=i;f=g+484414|0;u[f>>1]=x[f>>1]|2}d=d+1|0;j=j<<1;continue}}}}}i=P()|0;O()|0;Bb(D);break f}Bb(D);C=C+1|0;s=s+A|0;j=x[a+480192>>1];continue}}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}i=P()|0;O()|0}wc(M)}Bb(_);T(i|0);L()}d=0}wc(M)}Bb(_)}kb=e+976|0;return d|0}function efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=C(0),ga=0,ha=0,ia=0,ka=0,la=0,ma=0;e=kb-672|0;kb=e;zc(b);a:{b:{c:{if(!di(b,e+664|0)){break c}if(!BQ(e+664|0)){break c}if((Co(b)|0)>=0){break c}if(!c){d=1;break c}Bd(a,16777216);d=a+480208|0;v[d>>2]=v[d>>2]|1681e4;wq(e+272|0,32);h=v[e+284>>2];d=a+1074320|0;v[d>>2]=v[e+280>>2];v[d+4>>2]=h;d=v[e+276>>2];v[a+1074312>>2]=v[e+272>>2];v[a+1074316>>2]=d;_f(a+1074312|0,38);p=Tb(e+648|0);q=Tb(e+632|0);A=Tb(e+616|0);l=Tb(e+600|0);zg(b,4);i=a+480190|0;J=c&1;I=a+1298332|0;r=2500;H=!(c&2);F=a+1298464|0;d:{e:{f:{while(1){c=v[b+8>>2];d=v[b>>2];v[23588]=0;c=W(156,d|0,c|0,4)|0;d=v[23588];v[23588]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){v[23588]=0;c=S(682,b|0)|0;d=v[23588];v[23588]=0;o:{if((d|0)==1){break o}n=4;d=0;p:{q:{r:{switch(c+21|0){case 20:v[23588]=0;c=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){d=c&65535;if(x[a+480188>>1]|d-1>>>0>126){continue}u[a+480188>>1]=c;la=a,ma=Yb(512/(d>>>0)|0,16,128),v[la+480228>>2]=ma;continue}c=P()|0;O()|0;break a;case 19:v[23588]=0;M=S(279,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break o}if(M>>>0<=1024){continue}break m;case 16:v[23588]=0;c=S(279,b|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){if((c&65535)==4){continue}break m}c=P()|0;O()|0;break a;case 15:v[23588]=0;c=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[e+272>>2]=c;v[e+168>>2]=800;la=a,ma=Qe(+y[Kb(e+272|0,e+168|0)>>2]*1.24*1e4),v[la+480204>>2]=ma;continue}c=P()|0;O()|0;break a;case 31:v[23588]=0;c=S(279,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break o}_=1;r=Dd(c,0,1e4);continue;case 32:case 33:v[23588]=0;c=S(279,b|0)|0;d=v[23588];v[23588]=0;s:{t:{if((d|0)!=1){_=1;if(!c){continue}v[23588]=0;d=Q(1,e+584|0,12467)|0;c=v[23588];v[23588]=0;if((c|0)==1){break t}c=v[F>>2];v[23588]=0;U(376,c|0,2,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break s}Ab(d);continue}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;Ab(d);break a;case 14:v[23588]=0;Q(188,b|0,4)|0;c=v[23588];v[23588]=0;if((c|0)==1){break o}g=!x[i>>1]|g;continue;case 11:if(!J){break q}if(!pc(v[p>>2],v[p+4>>2])){break q}v[23588]=0;R(683,e+272|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){if(v[p>>2]){Lc(p);c=v[p>>2];lo(p);Nb(c);la=Gb(p),ma=0,v[la>>2]=ma;v[p>>2]=0;v[p+4>>2]=0}c=e+272|0;v[p>>2]=v[c>>2];v[p+4>>2]=v[c+4>>2];d=Gb(c);la=Gb(p),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Ei(c);continue}c=P()|0;O()|0;break a;case 3:case 4:case 10:h=Ah(v[l>>2],v[l+4>>2]);d=x[i>>1];if(h>>>0<=d>>>0){continue}if((g|H)&1){break q}if(!Yh(d)){break q}d=d+1|0;u[i>>1]=d;s=Tb(e+568|0);v[23588]=0;n=S(174,e+544|0)|0;g=v[23588];v[23588]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}v[23588]=0;c=S(279,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break u}v[23588]=0;U(190,e+168|0,b|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break u}c=e+168|0;g=kc(e+272|0,c);hd(n,g);Bb(g);break g}c=P()|0;O()|0;break d}v[23588]=0;R(684,e+272|0,b|0);c=v[23588];v[23588]=0;x:{if((c|0)!=1){c=e+272|0;g=Lm(s,c);ic(c);se(e+512|0,v[g>>2],v[e+572>>2]);c=v[fe(e+504|0)>>2];v[23588]=0;c=Fg(328,e+520|0,v[e+512>>2],v[e+516>>2],c,v[e+508>>2]);g=v[23588];v[23588]=0;if((g|0)==1){break x}hd(n,c);break g}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}v[23588]=0;R(685,e+272|0,b|0);c=v[23588];v[23588]=0;y:{if((c|0)!=1){c=e+272|0;g=Lm(s,c);ic(c);se(e+472|0,v[g>>2],v[e+572>>2]);c=v[fe(e+464|0)>>2];v[23588]=0;c=Fg(328,e+480|0,v[e+472>>2],v[e+476>>2],c,v[e+468>>2]);g=v[23588];v[23588]=0;if((g|0)==1){break y}hd(n,c);break g}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e;case 9:c=x[i>>1];if(!Yh(c)){continue}u[i>>1]=c+1;continue;case 8:if(!J){break q}if(!pc(v[A>>2],v[A+4>>2])){break q}v[23588]=0;R(686,e+272|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){c=e+272|0;AQ(A,c);wc(c);continue}c=P()|0;O()|0;break a;case 7:if(!pc(v[l>>2],v[l+4>>2])){break q}v[23588]=0;R(687,e+272|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){if(v[l>>2]){Lc(l);c=v[l>>2];Sz(l);Nb(c);la=Gb(l),ma=0,v[la>>2]=ma;v[l>>2]=0;v[l+4>>2]=0}c=e+272|0;v[l>>2]=v[c>>2];v[l+4>>2]=v[c+4>>2];d=Gb(c);la=Gb(l),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Pt(c);continue}c=P()|0;O()|0;break a;case 6:if(!J){break q}if(!pc(v[q>>2],v[q+4>>2])){break q}v[23588]=0;R(688,e+272|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){if(v[q>>2]){Lc(q);c=v[q>>2];Nt(q);Nb(c);la=Gb(q),ma=0,v[la>>2]=ma;v[q>>2]=0;v[q+4>>2]=0}c=e+272|0;v[q>>2]=v[c>>2];v[q+4>>2]=v[c+4>>2];d=Gb(c);la=Gb(q),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Cm(c);continue}c=P()|0;O()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}v[23588]=0;R(689,e+272|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break n}z:{c=v[e+272>>2];d=v[e+276>>2];if(pc(c,d)){break z}v[23588]=0;X(337,I|0,c|0,fd(c,d)|0,1);c=v[23588];v[23588]=0;if((c|0)!=1){break z}c=P()|0;O()|0;ic(e+272|0);break a}ic(e+272|0);continue}v[23588]=0;n=S(279,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break o}}v[23588]=0;Q(188,b|0,n|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}c=P()|0;O()|0;break a}d=0;if(!x[a+480188>>1]|!M){break m}b=v[l>>2];c=v[l+4>>2];if(pc(b,c)){break m}if(J){if(pc(v[p>>2],v[p+4>>2])){break m}if(pc(v[A>>2],v[A+4>>2])){break m}if(pc(v[q>>2],v[q+4>>2])){break m}}b=Ah(b,c);if(b>>>0>=256){v[23588]=0;R(690,l|0,255);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=Ah(v[l>>2],v[l+4>>2])}u[a+480192>>1]=b;m=a+480190|0;n=a+480192|0;la=m,ma=x[le(i,n)>>1],u[la>>1]=ma;if(g&1){v[23588]=0;b=Q(1,e+568|0,16424)|0;c=v[23588];v[23588]=0;if((c|0)==1){break h}c=v[a+1298464>>2];v[23588]=0;U(376,c|0,2,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break i}Ab(b)}g=0;A:while(1){if((g|0)!=2){d=1;while(1){f=d&65535;if(f>>>0>x[n>>1]){g=g+1|0;continue A}B:{h=Am(v[l>>2],f-1|0);if(!w[h|0]|t[h+128|0]<0){break B}if((Lt(h)|0)==((g|0)!=1|0)){break B}C:{D:{E:{c=0;F:{if(!Lt(h)){break F}if(Ib(w[h+6|0]|w[h+7|0]<<8)){break F}if(Ib(w[h+14|0]|w[h+15|0]<<8)>>>0>20){break F}c=(Ib(w[h+18|0]|w[h+19|0]<<8)|0)==4}G:{H:{if(c){c=w[h+23|0];b=w[h+140|0];v[23588]=0;b=ja(691,h|0,a|0,(b&2)>>>1|0,(B(f,104)+a|0)+484380|0,r&65535)|0;k=v[23588];v[23588]=0;I:{J:{if((k|0)!=1){if(!b){break I}v[23588]=0;b=Q(55,e+400|0,10676)|0;k=v[23588];v[23588]=0;if((k|0)==1){break J}Dc(((f<<5)+a|0)+946304|0,b);zb(b);k=v[l>>2];b=d;if(Ah(k,v[l+4>>2])>>>0<=c>>>0){break G}la=h,ma=w[h+143|0]+w[Am(k,c)+143|0]|0,t[la+143|0]=ma;break H}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}b=c+1|0;break G}c=0;K:{if(!Lt(h)){break K}if((Ib(w[h+6|0]|w[h+7|0]<<8)|0)!=1){break K}if((Ib(w[h+14|0]|w[h+15|0]<<8)|0)!=2){break K}c=(Ib(w[h+18|0]|w[h+19|0]<<8)|0)==10}b=d;if(!c){break G}sQ(e+272|0,h);b=Ib(x[e+292>>1]);if(b>>>0>=x[i>>1]){break H}v[23588]=0;c=S(681,e+168|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break E}k=x[e+308>>1];o=x[m>>1];v[23588]=0;s=B(b,104);b=a+484380|0;k=Ib(k);b=fa(692,e+272|0,(s+b|0)+104|0,(k>>>0<o>>>0?(b+B(k,104)|0)+104|0:c)|0,b+B(f,104)|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break D}if(!b){break H}v[23588]=0;b=Q(55,e+152|0,11173)|0;c=v[23588];v[23588]=0;if((c|0)==1){break C}Dc(((f<<5)+a|0)+946304|0,b);zb(b);t[h+139|0]=w[h+139|0]+12}b=d}v[23588]=0;b=b&65535;c=W(251,a|0,f|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){if(!c|b>>>0>x[i>>1]){break B}v[23588]=0;X(693,h|0,c|0,(B(b,104)+a|0)+484380|0,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){break B}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}d=d+1|0;continue}}break}I=Yf(e+136|0);s=Yf(e+120|0);b=vc(v[A>>2],v[A+4>>2]);$=B(x[a+480188>>1],M);aa=Dl((b>>>0)/($>>>0)|0);v[23588]=0;V=a+484344|0;R(225,V|0,aa|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}ba=a+484376|0;Lc(Wb(v[a+484360>>2],w[ba|0]));b=x[a+480188>>1];v[23588]=0;F=Q(694,e+104|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break l}la=e,ma=Fb(v[q>>2]),v[la+48>>2]=ma;ga=a+902204|0;ha=Fb(v[q+4>>2]);ia=a+480208|0;while(1){L:{M:{N:{k=v[e+48>>2];if(!Pb(k,ha)){break N}b=qe((w[k+6|0]|w[k+7|0]<<8)<<16>>16);if((b|0)==1){break L}if((b&65535)==65535){break N}g=Ib(w[k|0]|w[k+1|0]<<8);b=v[p>>2];h=v[p+4>>2];c=rg(b,h);if(g>>>0>=c>>>0){break L}d=Ib(w[k+2|0]|w[k+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(rg(b,h)<<5)|0;v[e+272>>2]=b;v[e+276>>2]=c-b>>5;b=v[e+272>>2];hc(e+80|0,b+(Ib(w[k|0]|w[k+1|0]<<8)<<5)|0,Ib(w[k+2|0]|w[k+3|0]<<8));O:{H=Wb(v[a+484360>>2],w[ba|0]);if(pc(v[H>>2],v[H+4>>2])){break O}v[23588]=0;R(522,H|0,65534);b=v[23588];v[23588]=0;if((b|0)!=1){break O}break M}b=v[e+80>>2];ka=ze(b,v[e+84>>2]);while(1){if((b|0)==(ka|0)){break L}c=qe(qe((w[k+8|0]|w[k+9|0]<<8)<<16>>16)+qe((w[b+16|0]|w[b+17|0]<<8)<<16>>16)<<16>>16);t[b+16|0]=c;t[b+17|0]=c>>>8;h=b;b=Td(I);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!Ht(h,d)){c=1;if(!Ht(d,h)){break P}b=b+4|0}b=v[b>>2];continue}break}Q:{R:{S:{if(c){v[23588]=0;b=Q(695,I|0,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}E=x[b>>1];break S}E=0;if(!J){break S}b=w[h+12|0]|w[h+13|0]<<8;v[23588]=0;E=Q(359,V|0,Ib(b)|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break M}if((E|0)==65535){break L}v[23588]=0;b=Q(695,I|0,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}u[b>>1]=E;if(Ib(w[h+8|0]|w[h+9|0]<<8)>>>0>=aa>>>0){break R}if(Ib(w[h+10|0]|w[h+11|0]<<8)>>>0>=M>>>0){break R}m=Ib(w[h+14|0]|w[h+15|0]<<8);c=zm(Fb(v[A>>2]),B(Ib(w[h+8|0]|w[h+9|0]<<8),$));b=x[a+480188>>1];la=e,ma=zm(c,B(b,Ib(w[h+10|0]|w[h+11|0]<<8))),v[la+32>>2]=ma;N=0;v[e+16>>2]=0;o=ug(e- -64|0);T:while(1){U:{d=Ib(w[h+12|0]|w[h+13|0]<<8);c=Zb(v[V>>2],E);if(d>>>0<=N>>>0){break U}n=0;Z=jd(v[c>>2],v[v[c+48>>2]+12>>2],N,0);c=0;while(1){if((b&65535)>>>0<=n>>>0){N=N+1|0;continue T}b=Fb(v[A+4>>2]);d=v[e+32>>2];i=Pb(d,b)?d:e+16|0;b=Fb(v[A+4>>2]);if(Pb(v[e+32>>2],b)){yQ(e+32|0)}d=B(n,6)+Z|0;g=w[i+1|0];b=(g>>>0<85?g+25|0:-1)<<24>>24;r=0;f=v[l>>2];K=Ah(f,v[l+4>>2]);G=w[i+3|0];V:{if(K>>>0<=G>>>0){break V}r=G+1|0;if(t[Am(f,G)+142|0]&1|(b|0)<0){break V}b=Cl(qe((w[h+16|0]|w[h+17|0]<<8)<<16>>16)+b<<24>>24)}W:{if(!w[d|0]|!(w[i+2|0]?1:G|(w[i|0]|(g|0)!=255))){break W}g=w[d+1|0];if(!g|g>>>0>K>>>0){break W}if(w[Am(f,g-1|0)+132|0]!=2){break W}jo(d)}f=Ot(v[F>>2],n);X:{Y:{if(!(c&1)){g=w[i|0];break Y}c=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);t[d|0]=c;t[d+1|0]=c>>>8;t[d+2|0]=c>>>16;t[d+3|0]=c>>>24;c=w[o+4|0]|w[o+5|0]<<8;t[d+4|0]=c;t[d+5|0]=c>>>8;Z:{if(w[d+3|0]){break Z}g=w[f+21|0];c=w[Ot(v[F>>2],n-1|0)+21|0];if((g|0)==(c|0)){break Z}t[d+3|0]=21;t[f+21|0]=c;t[d+5|0]=c}c=0;g=w[i|0];if(!(g-24>>>0<2|(g|0)==9|!g&(w[i+2|0]+7&255)>>>0<2)){break X}}_:{$:{aa:{ba:{ca:{da:{switch(g|0){case 5:c=w[f+17|0];break ca;case 0:ea:{c=w[i+2|0];if(c>>>0>=201){g=0;fa:{switch(c-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[f+16|0]=0;break $;case 9:if(!w[d|0]){t[d|0]=w[f+17|0]}t[d+4|0]=1;t[d+2|0]=15;break $;case 8:if((m&255)>>>0<2){break $}m=m-1|0;break aa;case 7:if((m&255)==255){m=255;break $}m=m+1|0;break aa;case 6:t[f+17|0]=b;if(w[f+18|0]!=(r&255)){break $}t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;u[f+32>>1]=0;v[f+8>>2]=0;break $;case 5:t[d+5|0]=242;t[d+3|0]=2;break $;case 4:t[d+5|0]=242;t[d+3|0]=3;break $;case 3:t[d+5|0]=244;t[d+3|0]=2;break $;case 2:t[d+5|0]=244;t[d+3|0]=3;break $;case 1:t[d+5|0]=248;t[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}t[d+5|0]=248;t[d+3|0]=3;break $}g=0;K=t[i+1|0];if((K|0)<0&c>>>0>99){break $}if((K|0)>=0){t[f+17|0]=b;t[d|0]=b;t[f+18|0]=r;t[d+1|0]=r;u[f+32>>1]=0;v[f+8>>2]=0;c=w[i+2|0]}b=c&255;if(!b){break $}la=f,ma=tk(+(b>>>0)*.64),t[la+19|0]=ma;j=z[f>>2];v[f>>2]=0;g=j!=C(0);break $}t[d+4|0]=0;t[d+2|0]=14;t[f+16|0]=1;break $;case 1:v[f+4>>2]=0;z[f>>2]=C(w[i+2|0])*C(.0333000011742115);break _;case 2:v[f+4>>2]=0;z[f>>2]=C(w[i+2|0])*C(-.0333000011742115);break _;case 12:t[e+272|0]=15;t[e+100|0]=w[i+3|0]>>>3;b=w[Xb(e+272|0,e+100|0)|0];t[e+272|0]=15;t[e+100|0]=w[i+2|0]>>>3;la=f,ma=w[Xb(e+272|0,e+100|0)|0]|b<<4,t[la+24|0]=ma;break _;case 3:v[f+12>>2]=0;b=w[i+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(.0333000011742115);break _;case 4:v[f+12>>2]=0;b=w[i+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(-.0333000011742115);break _;case 15:if(!w[i+2|0]|(b|0)<0){break _}g=b-w[f+17|0]<<5;c=g>>31;c=(c^g)-c|0;v[e+272>>2]=c;t[f+17|0]=b;v[f+8>>2]=0;t[d|0]=b;t[d+3|0]=4;b=tg((c>>>0)/(w[i+2|0]<<1>>>0)|0);t[d+5|0]=b;t[f+27|0]=b;v[e+100>>2]=B(b,(m&255)-1|0);la=f,ma=c-v[td(e+272|0,e+100|0)>>2]|0,u[la+32>>1]=ma;break _;case 13:t[e+272|0]=15;t[e+100|0]=w[i+3|0]>>>3;b=w[Xb(e+272|0,e+100|0)|0];t[e+272|0]=15;t[e+100|0]=w[i+2|0];la=f,ma=w[Xb(e+272|0,e+100|0)|0]|b<<4,t[la+23|0]=ma;break _;case 18:b=w[i+2|0]+w[f+17|0]&255;b=b?b>>>0<120?b:120:1;t[f+17|0]=b;t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;break ba;case 23:case 24:case 25:b=Td(s);while(1){ga:{c=0;if(!b){break ga}g=b+13|0;if(!Jt(i,g)){c=1;if(!Jt(g,i)){break ga}b=b+4|0}b=v[b>>2];continue}break};if(c){t[d+3|0]=31;v[23588]=0;b=Q(696,s|0,i|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}t[d+5|0]=w[b|0];break _}b=v[Gb(s)>>2];if(b>>>0>127){break _}v[e+96>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);c=v[ia>>2];v[23588]=0;v[e+12>>2]=v[e+96>>2];c=W(697,e+12|0,ze(ga,b&255)|0,c|0)|0;g=v[23588];v[23588]=0;ha:{if((g|0)==1){break ha}if(!c){break _}t[d+3|0]=31;v[23588]=0;c=Q(696,s|0,i|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break ha}b=b|-128;t[c|0]=b;t[d+5|0]=b;ca=(w[i|0]&254)==24|ca;break _}break M;case 16:if(!w[i+2|0]){break _}t[d+3|0]=15;v[e+272>>2]=15;v[e+100>>2]=w[i+3|0]+1;la=d,ma=v[td(e+272|0,e+100|0)>>2],t[la+5|0]=ma;u[f+30>>1]=B(w[i+2|0],w[i+3|0]+1|0);break _;case 9:t[d+3|0]=16;b=w[i+2|0];m=b?b:4;t[d+5|0]=m;break _;case 19:ia:{b=w[i+1|0];switch(b|0){case 0:case 4:break ia;default:break _}}g=128;g=(b|0)==4?w[i+3|0]:g;t[e+95|0]=g;t[e+272|0]=w[i+2|0];t[e+100|0]=100;b=e+272|0;r=e+100|0;c=w[Xb(b,r)|0];v[e+272>>2]=128;v[e+100>>2]=256-(g&255);g=v[td(b,r)>>2];t[e+272|0]=128;b=w[Xb(b,e+95|0)|0];g=(B(c,g)|0)/128|0;r=g&255;if((r|0)!=w[f+20|0]){t[f+20|0]=g;t[d+3|0]=21;g=Ec(((B(r,w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=g;t[d+5|0]=g}if(w[i+1|0]!=4|(x[a+480188>>1]-1|0)<=(n|0)){break _}g=n+1|0;i=Ot(v[F>>2],g);b=B(b,c)>>>7|0;if(w[i+20|0]==(b&255)){break _}t[i+20|0]=b;b=B(g,6)+Z|0;t[b+3|0]=21;c=Ec(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=c;t[b+5|0]=c;break _;case 10:case 11:case 17:case 20:t[d+3|0]=0;break _;case 7:b=w[i+2|0];t[f+25|0]=0;t[f+26|0]=0;t[f+22|0]=b;break _;case 8:t[f+22|0]=w[f+22|0]+w[i+2|0];break _;case 14:t[f+25|0]=w[i+3|0];t[f+26|0]=w[i+2|0];break _;case 6:break da;default:break _}}t[f+18|0]=r;t[f+17|0]=b;t[d+1|0]=r;c=b}t[d|0]=c;if((b|0)>=0){t[f+18|0]=r;t[d+1|0]=r}if(w[i|0]==5){t[d+4|0]=1;t[d+2|0]=11}c=w[f+22|0];b=w[f+26|0];if(!(b?1:c|w[i+2|0])){break ba}if(b){da=(Di(+x[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{da=0}t[d+3|0]=44;la=d,ma=tk(da+ +(c+w[i+2|0]|0)),t[la+5|0]=ma}u[f+32>>1]=0;break _}t[d+5|0]=m;t[d+3|0]=16}b=Ec(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!g&w[f+21|0]==(b&255))){t[f+21|0]=b;t[d+5|0]=b;t[d+3|0]=21}if(n&1|t[i+1|0]<=0|(x[a+480188>>1]-1|0)<=(n|0)){break _}b=v[l>>2];if(Ah(b,v[l+4>>2])>>>0<=G>>>0){break _}if(w[Am(b,G)+132|0]!=1){break _}g=n+1|0;b=B(g,6)+Z|0;c=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[d+4|0]|w[d+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;t[b+1|0]=w[b+1|0]+1;b=Ot(v[F>>2],g);t[b+19|0]=w[f+19|0];z[b>>2]=z[f>>2];z[b+4>>2]=z[f+4>>2];z[b+8>>2]=z[f+8>>2];z[b+12>>2]=z[f+12>>2];u[b+30>>1]=x[f+30>>1]}ja:{if(w[d|0]){t[f+16|0]=0;break ja}c=0;if(w[f+16|0]){break X}}ka:{if(!x[f+30>>1]){break ka}b=m&255;u[e+272>>1]=b;c=f+30|0;la=c,ma=x[le(c,e+272|0)>>1]-b|0,u[la>>1]=ma;if(w[d+3|0]){break ka}t[d+3|0]=15;t[d+5|0]=0}j=z[f>>2];la:{if(j==C(0)){break la}b=m&255;j=C(C(j*C(b>>>0))+z[f+4>>2]);z[f+4>>2]=j;if(w[d+3|0]){break la}ma:{na:{oa:{pa:{if(b>>>0>=2){g=b-1|0;D=C(g|0);if(!(D<=j)){break pa}t[e+272|0]=15;la=e,ma=kh(C(j/D)),t[la+100|0]=ma;b=w[Xb(e+272|0,e+100|0)|0];z[f+4>>2]=j-C(B(b,g)|0);t[d+3|0]=22;c=b<<4;break ma}if(!(j>=C(1))){break oa}break na}if(j>=C(1)){break na}if(!(j<=C(1-b|0))){break oa}t[e+272|0]=15;la=e,ma=kh(C(C(-j)/D)),t[la+100|0]=ma;c=w[Xb(e+272|0,e+100|0)|0];z[f+4>>2]=j+C(B(g,c)|0);t[d+3|0]=22;break ma}if(!(j<=C(-1))){break la}t[e+272|0]=14;la=e,ma=kh(C(-j)),t[la+100|0]=ma;b=w[Xb(e+272|0,e+100|0)|0];z[f+4>>2]=j+C(b>>>0);t[d+3|0]=22;c=b|-16;break ma}t[e+272|0]=15;la=e,ma=kh(j),t[la+100|0]=ma;b=w[Xb(e+272|0,e+100|0)|0];z[f+4>>2]=j-C(b>>>0);t[d+3|0]=22;c=b<<4|15}t[d+5|0]=c}j=z[f+8>>2];qa:{if(j==C(0)){break qa}b=m&255;j=C(C(j*C(b>>>0))+z[f+12>>2]);z[f+12>>2]=j;ra:{if(!w[d+3|0]){sa:{ta:{if(b>>>0>=2){c=b-1|0;D=C(c|0);if(!(D<=j)){break ta}t[e+272|0]=223;la=e,ma=kh(C(j/D)),t[la+100|0]=ma;b=w[Xb(e+272|0,e+100|0)|0];z[f+12>>2]=j-C(B(b,c)|0);t[d+3|0]=2;t[d+5|0]=b;break qa}if(!(j>=C(1))){break sa}break ra}if(j>=C(1)){break ra}if(!(j<=C(1-b|0))){break sa}t[e+272|0]=223;la=e,ma=kh(C(C(-j)/D)),t[la+100|0]=ma;b=w[Xb(e+272|0,e+100|0)|0];z[f+12>>2]=j+C(B(b,c)|0);t[d+3|0]=3;t[d+5|0]=b;break qa}if(!(j<=C(-1))){break qa}t[e+272|0]=14;la=e,ma=kh(C(-j)),t[la+100|0]=ma;b=w[Xb(e+272|0,e+100|0)|0];z[f+12>>2]=j+C(b>>>0);t[d+3|0]=3;t[d+5|0]=b|240;break qa}if(w[d+2|0]|b>>>0<2){break qa}ea=C(j*C(.25));c=b-1|0;D=C(c|0);if(ea>=D){t[e+272|0]=9;la=e,ma=kh(C(j/D))>>>2|0,t[la+100|0]=ma;b=w[Xb(e+272|0,e+100|0)|0];z[f+12>>2]=j-C(B(b,c)<<2);t[d+2|0]=12;t[d+4|0]=b;break qa}if(!(C(1-b|0)>=ea)){break qa}t[e+272|0]=9;la=e,ma=kh(C(C(-j)/D))>>>2|0,t[la+100|0]=ma;b=w[Xb(e+272|0,e+100|0)|0];z[f+12>>2]=j+C(B(b,c)<<2);t[d+2|0]=13;t[d+4|0]=b;break qa}t[e+272|0]=15;la=e,ma=kh(j),t[la+100|0]=ma;b=w[Xb(e+272|0,e+100|0)|0];z[f+12>>2]=j-C(b>>>0);t[d+3|0]=2;t[d+5|0]=b|240}ua:{va:{wa:{xa:{ya:{za:{Aa:{b=w[d+3|0];switch(b|0){case 4:break ua;case 0:break Aa;default:break za}}Ba:{b=w[f+23|0];if(!b){b=w[f+24|0];if(b){break Ba}if(!x[f+32>>1]){break ua}c=f+32|0;break ya}t[d+3|0]=5;t[d+5|0]=b;if(!x[f+32>>1]){break ua}break xa}t[d+3|0]=8;t[d+5|0]=b;if(x[f+32>>1]){break xa}break ua}if(!x[f+32>>1]){break ua}c=f+32|0;if(b){break wa}}t[d+3|0]=4;break va}c=f+32|0}t[d+2|0]=11}u[e+272>>1]=B(w[f+27|0],(m&255)-1|0);la=f,ma=x[f+32>>1]-x[Wc(c,e+272|0)>>1]|0,u[la+32>>1]=ma}u[f+28>>1]=x[f+28>>1]+B(w[f+25|0],m&255)&1023;c=0;if(n&1){break X}b=w[f+18|0];if(!b){break X}g=v[l>>2];if(Ah(g,v[l+4>>2])>>>0<b>>>0){break X}g=Am(g,b-1|0);if(!(w[g+142|0]&4)){break X}b=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[o|0]=b;t[o+1|0]=b>>>8;t[o+2|0]=b>>>16;t[o+3|0]=b>>>24;b=w[d+4|0]|w[d+5|0]<<8;t[o+4|0]=b;t[o+5|0]=b>>>8;c=1;b=w[e+65|0];if(!b|w[g+132|0]!=1){break X}t[e+65|0]=b+1}n=n+1|0;b=x[a+480188>>1];continue}}break}Ae(c,Fh(Ue(Oe(e+272|0,16,Ib(w[h+14|0]|w[h+15|0]<<8)&255),0)))}b=El(v[H>>2],v[H+4>>2]);la=e,ma=Ib(w[h+4|0]|w[h+5|0]<<8),u[la+272>>1]=ma;u[e+64>>1]=1;c=x[le(e+272|0,e- -64|0)>>1];v[23588]=0;X(698,H|0,b|0,c|0,E&65535);b=v[23588];v[23588]=0;if((b|0)==1){break Q}b=qe((w[k+8|0]|w[k+9|0]<<8)<<16>>16);b=qe(qe((w[h+16|0]|w[h+17|0]<<8)<<16>>16)-b<<16>>16);t[h+16|0]=b;t[h+17|0]=b>>>8}b=h+32|0;continue}break}break M}d=ca&1;if(d){v[23588]=0;g=a+906300|0;b=Md(g,0);Y(284,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break M}v[b+16>>2]=1299020115;v[b+20>>2]=1869112133;v[b+24>>2]=655376;v[b+28>>2]=0;v[e+272>>2]=0;h=b+48|0;c=e+272|0;xV(b+32|0,h,c);v[23588]=0;c=Q(55,c|0,9516)|0;f=v[23588];v[23588]=0;if((f|0)==1){break M}KB(h,c);zb(c);v[23588]=0;c=Q(55,e+80|0,9509)|0;h=v[23588];v[23588]=0;if((h|0)==1){break M}Lu(b+80|0,c);zb(c);v[23588]=0;b=Q(55,e- -64|0,9501)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}KB(Md(g,1)+48|0,b);zb(b)}b=0;while(1){if(x[a+480188>>1]>b>>>0){tB(a,b&65535);c=(b<<5)+a|0;t[c+480288|0]=d;u[c+480284>>1]=b<<8&256;b=b+1|0;continue}break}v[23588]=0;b=Q(1,e+48|0,12017)|0;c=v[23588];v[23588]=0;Ca:{Da:{Ea:{if((c|0)!=1){Jb(a+1298344|0,b);Ab(b);v[23588]=0;b=Q(1,e+32|0,12235)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}Jb(a+1298356|0,b);Ab(b);if(_){break Ea}v[23588]=0;b=Q(1,e+16|0,12017)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}break Da}break M}if(Ah(v[l>>2],v[l+4>>2])>>>0<=128){v[23588]=0;b=Q(1,e+16|0,9258)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break Da}break M}v[23588]=0;b=Q(1,e+16|0,14758)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ca}}Jb(a+1298368|0,b);Ab(b);v[a+1298404>>2]=14;xQ(F);oQ(s);nQ(I);d=1;break m}}c=P()|0;O()|0;xQ(F);break j}fq(e+48|0);continue}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}Pt(l);wc(A);Cm(q);Ei(p);break c}c=P()|0;O()|0;break j}c=P()|0;O()|0}oQ(s);nQ(I);break a}c=P()|0;O()|0;Ab(b);break a}c=P()|0;O()|0;break a}Bb(c);v[23588]=0;c=d&65535;d=W(699,a|0,c|0,n|0)|0;g=v[23588];v[23588]=0;Fa:{Ga:{Ha:{Ia:{if((g|0)==1){break Ia}if(d){break Fa}v[23588]=0;d=W(700,a|0,c|0,n|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ia}if(d){break Fa}v[23588]=0;d=W(701,a|0,c|0,n|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ia}if(d){break Fa}v[23588]=0;d=Q(702,(B(c,104)+a|0)+484380|0,n|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ia}if(d){break Fa}v[23588]=0;d=Q(1,e+448|0,16130)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Ha}g=v[F>>2];v[23588]=0;U(376,g|0,2,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break Ga}Ab(d);break Fa}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;Ab(d);break e}Ja:{Ka:{La:{E=B(c,104)+a|0;if(w[E+484414|0]&64){d=x[i>>1];if(Yh(d)){break La}}d=v[l>>2];if(Ah(d,v[l+4>>2])>>>0<=c>>>0){break Ka}if(w[Am(d,c)+132|0]!=2){break Ka}c=x[i>>1];if(!Yh(c)){break Ka}u[i>>1]=c+1;break Ka}c=d+1|0;u[i>>1]=c;G=B(c&65535,104)+a|0;o=G+484380|0;f=E+484380|0;d=v[f>>2];g=v[f+20>>2];Ma:{if(!_d(d,g)){break Ma}h=x[f+34>>1];if((f|0)==(o|0)|(Ld(h)|0)!=2){break Ma}c=(f|0)==(o|0);if(!(_d(v[o>>2],v[o+20>>2])?c:1)){break Ma}_d(v[f>>2],v[f+20>>2]);if(!c){g=Kt(d,_m(h))}h=v[f+20>>2];if(!(h?g:0)){if(!c){Cz(g)}break Ma}Na:{Oa:{switch(_m(x[f+34>>1])-1|0){case 1:d=g;c=h;m=v[f+20>>2];k=v[f>>2];while(1){if(k){u[d>>1]=x[m>>1];u[c>>1]=x[m+2>>1];m=m+4|0;c=c+2|0;d=d+2|0;k=k-1|0;continue}break};break Na;case 0:break Oa;default:break Na}}d=g;c=h;m=v[f+20>>2];k=v[f>>2];while(1){if(k){t[d|0]=w[m|0];t[c|0]=w[m+1|0];m=m+2|0;c=c+1|0;d=d+1|0;k=k-1|0;continue}break}}d=ko(o,f);u[d+34>>1]=x[d+34>>1]&65471;v[o+20>>2]=g;g=ko(f,f);u[g+34>>1]=x[g+34>>1]&65471;v[f+20>>2]=h;h=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(h|0)){f=v[c+104>>2];if(!((f|0)!=(d|0)&(f|0)!=(g|0))){v[c+88>>2]=v[c+88>>2]&-65}c=c+872|0;continue}break}uj(d,a);uj(g,a)}v[23588]=0;c=Q(55,e+432|0,6323)|0;d=v[23588];v[23588]=0;if((d|0)==1){break Ja}Ce(G+484423|0,c);zb(c);v[23588]=0;c=Q(55,e+416|0,6226)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}Ce(E+484423|0,c);zb(c)}Bb(n);ic(s);g=0;continue}break}c=P()|0;O()|0;break e}c=P()|0;O()|0}Bb(n)}ic(s);break a}kb=e+672|0;return d|0}c=P()|0;O()|0}Pt(l);wc(A);Cm(q);Ei(p);T(c|0);L()}function _t(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,S=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ha=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ca=0,Da=0,Ea=C(0),Fa=0,Ga=0,Ha=0,Ia=C(0);i=kb-192|0;kb=i;$=Tb(a);q=i+160|0;t[q+26|0]=0;u[q+24>>1]=0;v[q+16>>2]=0;v[q+20>>2]=-1;v[q+8>>2]=-1;v[q+12>>2]=-1;v[q>>2]=0;v[q+4>>2]=0;M=v[d+16>>2];a=w[d+6|0];na=b+484360|0;e=v[na>>2];oa=(Fa=a,Ga=w[b+484376|0],Ha=sj(e,v[b+484364>>2])>>>0>a>>>0,Ha?Fa:Ga);a=oa&255;I=yj(e,a);v[23588]=0;r=Q(580,i+128|0,b|0)|0;e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){l=v[r+4>>2];v[23588]=0;J=W(581,i+88|0,b|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break i}ca=c&7;h=v[d>>2];a=x[d+4>>1];while(1){e=a&65535;if(Rc(v[I>>2],v[I+4>>2])>>>0<=e>>>0){break g}v[23588]=0;e=Q(311,I|0,e|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break h}if(e){break g}a=a+1|0;h=0;continue}}k=P()|0;O()|0;break d}k=P()|0;O()|0;break e}k=P()|0;O()|0;v[d>>2]=h;u[d+4>>1]=a;break f}v[d>>2]=h;u[d+4>>1]=a;v[l+52>>2]=h;K=l+48|0;v[K>>2]=h;v[q+16>>2]=h;u[l+74>>1]=a;u[l+72>>1]=a;u[q+24>>1]=a;pa=fe(i+80|0);j:{if((ca|0)!=7){break j}a=kb-16|0;kb=a;e=a+8|0;Db(e,pa,1);po(e);kb=a+16|0;if((M|0)!=2){break j}a=v[I>>2];n=Rc(a,v[I+4>>2]);e=x[d+12>>1];if(n>>>0<=e>>>0){break j}n=v[b+484344>>2];f=v[b+484348>>2];a=x[dc(a,e)>>1];if(!ye(n,f,a)){break j}e=Zb(n,a);n=v[d+8>>2];if(y[e+12>>2]<=n>>>0){break j}a=0;k=jd(v[e>>2],v[v[e+48>>2]+12>>2],n,0);e=x[b+480188>>1];n=v[r+8>>2];f=x[b+480192>>1];while(1){if((a|0)==(e|0)){break j}k:{l:{m:{n:{g=w[k|0];switch(g-253|0){case 1:case 2:break l;case 0:break n;default:break m}}if(f){break l}}if(!$c(g)){break k}if(wm(w[k+2|0],w[k+3|0])){break k}}Fa=bf(n,a),Ga=-1,v[Fa>>2]=Ga}k=k+6|0;a=a+1|0;continue}}aa=c&1;if(aa){dO(l+223860|0)}V=l+74|0;wa=l+223872|0;xa=(M|0)!=3;N=l+80|0;ya=b+901692|0;za=b+902204|0;ga=l+44|0;ha=l+223860|0;ba=l+20|0;H=b+1074312|0;qa=l+616|0;ea=32768;ra=A[d+8>>3];o(+ra);a=j(1)|0;Aa=j(0)|0;ka=a;_=b+480188|0;G=b+480180|0;la=b+484348|0;sa=(M|0)!=2;Ca=l+223884|0;ta=b+480192|0;Da=(ca|0)!=7;d=0;o:{p:{q:{r:{s:{t:while(1){n=ka;while(1){cO(i+16|0,v[G>>2],x[_>>1],l,p&1);if(!(!(A[r+24>>3]>=ra)|xa)){break p}g=w[i+16|0];a=65535;f=v[I>>2];h=Rc(f,v[I+4>>2]);e=x[l+72>>1];if(h>>>0>e>>>0){a=x[dc(f,e)>>1]}u[l+70>>1]=a;f=v[b+484344>>2];h=v[la>>2];k=a&65535;if(!(ye(f,h,k)|(k|0)==65535|sa)&(e|0)==(n&65535)){break p}u:{v:{while(1){a=a&65535;if(Bf(f,h)>>>0>a>>>0){break u}k=x[l+72>>1];w:{x:{if((a|0)!=65535){e=v[I>>2];m=Rc(e,v[I+4>>2]);if(k>>>0<m>>>0){break x}}a=x[I+28>>1];if((k|0)==(a|0)){break u}e=v[I>>2];m=Rc(e,v[I+4>>2]);break w}a=k+1|0}u[l+72>>1]=a;k=65535;s=m;m=a&65535;if(s>>>0>m>>>0){k=x[dc(e,m)>>1]}u[l+74>>1]=a;u[l+70>>1]=k;y:{if(!ye(f,h,k&65535)){e=Vp(i+16|0,qa);v[23588]=0;a=ja(582,J|0,a&65535,0,e|0,(g|0)!=0|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}if(a){break v}h=v[la>>2];f=v[b+484344>>2]}a=x[l+70>>1];continue}break}k=P()|0;O()|0;break f}if(M>>>0<=1){a=x[l+72>>1];v[q+8>>2]=0;u[q+20>>1]=a;if(!M){break u}}v[23588]=0;a=W(583,J|0,V|0,K|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break q}if(!a){break u}A[q>>3]=A[r+24>>3];v[23588]=0;R(584,$|0,q|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[q+16>>2]=v[K>>2];u[q+24>>1]=x[V>>1];v[23588]=0;Y(585,r|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}a=x[l+74>>1];u[l+72>>1]=a;Fa=l,Ga=x[dc(v[I>>2],a)>>1],u[Fa+70>>1]=Ga;v[l+52>>2]=v[l+48>>2]}if(x[V>>1]==65535){break o}a=v[b+484344>>2];e=x[l+70>>1];if(!ye(a,v[la>>2],e)){a=x[l+72>>1];if((a|0)==x[I+28>>1]){if(!M){break o}v[23588]=0;a=W(583,J|0,V|0,K|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break q}if(!a){break o}A[q>>3]=A[r+24>>3];v[23588]=0;R(584,$|0,q|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[q+16>>2]=v[K>>2];u[q+24>>1]=x[V>>1];v[23588]=0;Y(585,r|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[l+52>>2]=v[l+48>>2];continue}u[V>>1]=a+1;continue}f=v[K>>2];if(f>>>0>=y[Zb(a,e)+12>>2]){v[K>>2]=0;f=0}if(!(x[l+72>>1]!=(n&65535)|sa)&(f|0)==(Aa|0)){break p}a=0;if(!((M|0)==3|y[J+28>>2]<ea>>>0)){v[r+24>>2]=0;v[r+28>>2]=2146435072;v[J+28>>2]=0;ea=ea>>>(ea>>>0>256)|0;f=v[K>>2];a=1}e=x[l+72>>1];h=Vp(i+16|0,qa);v[23588]=0;e=ja(582,J|0,e|0,f|0,h|0,(g|0)!=0|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break s}if((a|e)==1){if(M>>>0<=1){u[q+20>>1]=x[l+72>>1];v[q+8>>2]=v[l+48>>2];if(!M){break o}}v[23588]=0;a=W(583,J|0,V|0,K|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break r}if(!a){break o}A[q>>3]=A[r+24>>3];v[23588]=0;R(584,$|0,q|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}v[q+16>>2]=v[K>>2];u[q+24>>1]=x[V>>1];v[23588]=0;Y(585,r|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}v[l+52>>2]=v[l+48>>2];continue}u[q+22>>1]=x[l+72>>1];v[q+12>>2]=v[l+48>>2];bO(b,l,0);k=v[l+48>>2];e=Zb(v[b+484344>>2],x[l+70>>1]);if(k>>>0>=y[e+12>>2]){v[K>>2]=0;k=0}if(g){continue}break}a=0;k=jd(v[e>>2],v[v[e+48>>2]+12>>2],k,0);Db(i+16|0,H,77);g=Cb(v[v[i+16>>2]>>2],v[i+20>>2]);z:{while(1){if(x[_>>1]>a>>>0){A:{if(!(!$y(k)&(!g|!(w[((a<<5)+b|0)+480281|0]&4)))){jo((l+B(a,872)|0)+1404|0);break A}if(gh(w[k|0])){B:{if(!Qd(w[Ca|0])){break B}e=w[k+1|0];if(e-251>>>0<5|!e){break B}f=w[k+5|0];p=w[k+3|0];h=hk(w[k+2|0],w[k+4|0]);n=i+16|0;t[n|0]=e-1;v[n+4>>2]=h&65535;v[23588]=0;e=Q(586,wa|0,n|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break z}Fa=e,Ia=C(C(hk(p,f)>>>0)/C(999)),z[Fa>>2]=Ia}jo((l+B(a,872)|0)+1404|0);break A}e=l+B(a,872)|0;n=e+1408|0;f=w[k+4|0]|w[k+5|0]<<8;t[n|0]=f;t[n+1|0]=f>>>8;n=e+1404|0;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);t[n|0]=f;t[n+1|0]=f>>>8;t[n+2|0]=f>>>16;t[n+3|0]=f>>>24;C:{D:{E:{F:{switch(w[k+3|0]-16|0){case 0:h=w[k+5|0];break E;case 3:break C;case 4:break D;case 1:break F;default:break A}}Db(i+16|0,H,5);if(!Cb(v[v[i+16>>2]>>2],v[i+20>>2])){break A}h=w[k+5|0];if(!h){break A}}$N(b,l,h&255);break A}n=e+1409|0;f=w[n|0];G:{if(!(f|!(v[G>>2]&16777250))){t[n|0]=w[e+1449|0];break G}t[e+1449|0]=f}e=w[k+5|0];n=e&240;if((n|0)!=224){if((n|0)!=96){break A}v[l+24>>2]=v[l+24>>2]+(e&15);break A}if(v[ba>>2]){break A}e=e&15;if(e?0:w[G|0]&2){break A}v[ba>>2]=e+1;break A}e=w[k+5|0];if((e&240)!=224){break A}v[ba>>2]=(e&15)+1}k=k+6|0;a=a+1|0;continue}break}n=jl(l);v[i+16>>2]=1;a=v[Zc(ba,i+16|0)>>2];u[l+68>>1]=65535;v[l+60>>2]=-1;v[l+64>>2]=-1;D=n-1|0;a=n-a|0;F=B(a,1e4);k=0;while(1){if(x[_>>1]<=k>>>0){if(v[G>>2]==4&v[l+40>>2]==65535){break o}v[l+32>>2]=v[b+480216>>2];a=Zb(v[b+484344>>2],x[l+70>>1]);e=v[a+16>>2];if(_N(e,v[a+20>>2])){v[l+32>>2]=e}f=ZN(b,l);a=B(f,n);A[r+24>>3]=A[r+24>>3]+ +(a>>>0)/+y[b+24620>>2];v[l>>2]=a+v[l>>2];H:{I:{J:{if(Da){break J}k=0;fa=(d|0)!=0&(d|0)!=(f|0);while(1){if(x[_>>1]<=k>>>0){break J}F=bf(v[r+8>>2],k);K:{if(v[F>>2]==-1){break K}m=l+B(k,872)|0;s=m+1404|0;S=v[m+1316>>2];if(!S){if($y(s)){break K}}a=m+1409|0;e=1;L:{M:{E=m+1407|0;switch(w[E|0]-4|0){case 0:case 2:break L;default:break M}}e=w[m+1406|0]==11}D=w[a|0];if(w[m+1405|0]){v[m+1276>>2]=0}g=m+616|0;h=D&15;p=0;N:{if(!$c(w[s|0])){break N}if(!(!e|!w[F+4|0])){_y(i+16|0,b,g,S,0);p=v[i+20>>2];v[m+624>>2]=v[i+16>>2];v[m+628>>2]=p}t[m+1418|0]=w[m+1415|0];S=m+1308|0;Z=v[S>>2];p=w[m+1419|0];if(p){Up(b,g,p,e,1,1)}p=w[s|0];v[23588]=0;ia(587,b|0,g|0,p|0,e|0,1,0,65535);p=v[23588];v[23588]=0;if((p|0)==1){break I}D=D>>>4|0;YN(v[G>>2],x[_>>1],l,k&65535);ua=bf(v[r+8>>2],k);t[ua+4|0]=1;F=w[E|0];O:{if(!((w[a|0]&240)!=208|(F-19&255)>>>0>1)){p=h;if(h>>>0<n>>>0){break O}}p=(F|0)==33?n>>>0>D>>>0?D:0:0}va=v[ba>>2];if(!(!(v[G>>2]&16777250)|(!p|va>>>0<2))){p=B(va-1|0,v[l+24>>2]+v[l+40>>2]|0)+p|0}if(!e){v[ua>>2]=0}P:{if((F|0)==9){break P}Q:{if((F|0)!=19){if((F|0)!=20|(D|0)!=8){break Q}break P}if((D|0)==8){break P}}if(w[m+1406|0]!=2){break N}}v[S>>2]=Z}R:{if(!$c(w[s|0])){Db(i+16|0,H,114);if(!Cb(v[v[i+16>>2]>>2],v[i+20>>2])){break R}}S:{T:{U:{V:{e=w[E|0];switch(e-42|0){case 1:break S;case 0:break T;case 2:break U;default:break V}}if((e|0)!=10){break S}e=x[l+70>>1];D=v[l+48>>2];v[23588]=0;da(588,b|0,g|0,k&65535,D|0,e|0);e=v[23588];v[23588]=0;if((e|0)!=1){break R}break H}F=Oka(w[a|0],0,v[m+692>>2],0);D=nb;e=D>>>8|0;_n(b,g,Ec((D&255)<<24|F>>>8,e));break R}if(!v[m+720>>2]){break S}v[23588]=0;X(589,r|0,k&65535,d|0,-1);e=v[23588];v[23588]=0;if((e|0)==1){break H}WN(g,w[a|0]);p=v[l+40>>2]-1|0;break R}if(w[m+1406|0]!=15){break R}D=v[m+720>>2];if(!D){break R}e=w[m+1408|0];if(e>>>0>9){break R}W:{if(!e){e=v[m+1280>>2];break W}e=v[Eb(D+68|0,e-1|0)>>2];v[m+1280>>2]=e}_n(b,g,e)}X:{Y:{Z:{switch(w[s|0]-253|0){case 0:if(x[ta>>1]){break Y}break;case 1:case 2:break Y;default:break Z}}e=w[E|0];if(!((w[a|0]&240)!=192|(e-19&255)>>>0>1)&h>>>0<n>>>0){break Y}D=0;F=e&255;if((F|0)==33&(h|0)!=0&n>>>0>h+p>>>0){break Y}if((F|0)!=25){break X}}e=w[E|0];D=1}S=m+1304|0;F=e&255;_:{if((F|0)!=13){if(w[m+1406|0]!=1){break _}h=m+1408|0}else{h=a}v[S>>2]=w[h|0]<<2}$:{aa:{ba:{if(!v[m+720>>2]|D|F>>>0>45){break ba}Db(i+16|0,pa,F);if(Cb(v[v[i+16>>2]>>2],v[i+20>>2])){break aa}e=w[E|0];if((e|0)!=19){break ba}h=w[a|0]&240;if((h|0)==16){break aa}e=19;if((h|0)==32){break aa}}if(!D){break $}}AP(g);Fa=bf(v[r+8>>2],k),Ga=0,v[Fa>>2]=Ga;break K}if(fa){v[23588]=0;X(589,r|0,k&65535,d|0,-1);e=v[23588];v[23588]=0;if((e|0)==1){break H}e=w[E|0]}ca:{da:{ea:{fa:{ga:{e=e&255;if(e-6>>>0>=2){ha:{switch(e-19|0){case 1:break fa;case 0:break ga;default:break ha}}if(e-35>>>0<2){break da}if((e|0)==45){break ea}if((e|0)!=11){break ca}}if(!w[a|0]&v[G>>2]==1){break ca}e=m+1467|0;h=0;while(1){if((h|0)==(n|0)){break ca}t[e|0]=!h|w[e|0]&254;Zn(b,g,w[a|0]);h=h+1|0;continue}}e=w[a|0];a=e&15;if(!(v[G>>2]&1048580?1:a)){break ca}h=m+1467|0;t[h|0]=w[h|0]|1;e=e&240;if((e|0)!=176){if((e|0)!=160){break ca}Yn(b,g,a,0);break ca}Xn(b,g,a,0);break ca}ia:{ja:{ka:{a=w[a|0];switch(a-158|0){case 1:break ja;case 0:break ka;default:break ia}}v[23588]=0;X(589,r|0,k&65535,d|0,-1);a=v[23588];v[23588]=0;if((a|0)==1){break H}v[m+704>>2]=v[m+704>>2]&-129;break ca}v[23588]=0;X(589,r|0,k&65535,d|0,-1);a=v[23588];v[23588]=0;if((a|0)==1){break H}a=v[m+704>>2];v[m+704>>2]=a|128;if(v[g+4>>2]){break ca}e=v[m+692>>2];if(!e){break ca}if(!(Fa=$c(w[s|0]),Ga=1,Ha=a&2,Ha?Fa:Ga)){break ca}v[g>>2]=-1;v[g+4>>2]=e-1;break ca}if((a&240)!=112|a>>>0<115){break ca}xP(g,a,v[G>>2]);break ca}VN(g,w[a|0]);break ca}v[23588]=0;a=k&65535;X(589,r|0,a|0,d|0,-1);e=v[23588];v[23588]=0;if((e|0)==1){break H}UN(b,a,l,0)}h=m+1467|0;a=w[h|0]|1;t[h|0]=a;la:{ma:{na:{oa:{pa:{E=m+1406|0;switch(w[E|0]-3|0){case 11:break ma;case 0:case 1:break na;case 3:break oa;case 2:break pa;default:break la}}a=w[m+1408|0];Db(i+16|0,H,41);Yn(b,g,a,Cb(v[v[i+16>>2]>>2],v[i+20>>2]));break la}a=w[m+1408|0];Db(i+16|0,H,41);Xn(b,g,a,Cb(v[v[i+16>>2]>>2],v[i+20>>2]));break la}e=w[m+1408|0];qa:{if(e){break qa}Db(i+16|0,H,41);e=0;if(!Cb(v[v[i+16>>2]>>2],v[i+20>>2])){break qa}e=w[m+1450|0];if(!e){break la}}e=w[E|0]==3?e<<4:e;a=0;while(1){if((a|0)==(n|0)){break la}t[h|0]=!a|w[h|0]&254;Zn(b,g,e&255);a=a+1|0;continue}}e=w[m+1408|0];if(e>>>0>1){break la}t[h|0]=a&247|!e<<3}if(w[h|0]&8){break K}a=1;ra:{sa:{ta:{e=w[s+3|0];if(e>>>0>28){break ta}g=1<<e;if(g&92){break ra}if(!(g&268959744)){break ta}if((w[s+5|0]-16&255)>>>0<32){break ra}break sa}if(e-38>>>0<4){break ra}}a=(w[s+2|0]-11&255)>>>0<3}if(a){e=bf(v[r+8>>2],k);a=v[e>>2];v[e>>2]=a+n;v[23588]=0;X(589,r|0,k&65535,f|0,a+p|0);a=v[23588];v[23588]=0;if((a|0)!=1){break K}k=P()|0;O()|0;break f}a=bf(v[r+8>>2],k);v[a>>2]=v[a>>2]+(n-p|0)}k=k+1|0;continue}}p=TN(b,l,I,0);d=f;continue t}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}g=l+B(k,872)|0;h=g+1404|0;ua:{if($y(h)){break ua}p=g+616|0;fa=g+1409|0;f=w[fa|0];S=g+1407|0;m=w[S|0];va:{wa:{if(!aa){break wa}s=w[h|0];e=s;E=g+1405|0;Z=w[E|0];if(Z){t[g+1415|0]=0;t[g+1419|0]=Z;Fa=bf(v[r+8>>2],k),Ga=255,t[Fa+5|0]=Ga;e=w[h|0]}if($c(e)){t[g+1415|0]=s;zP(p);e=w[h|0]}xa:{if(!(Fa=1,Ga=$c(e),Ha=w[E|0],Ha?Fa:Ga)){break xa}Z=g+1419|0;e=w[Z|0];ya:{if(!e){e=0;break ya}if(x[ta>>1]<e>>>0){break ya}E=v[((e<<2)+b|0)+900380>>2];if(!E|!(t[E+15|0]&1)){break ya}bq(p,v[E+8>>2],b);e=w[Z|0]}e=vq(b,s,e&255);if(!e){break xa}e=B(e,104)+b|0;if(!(w[e+484414|0]&32)){break xa}bq(p,x[e+484408>>1],b)}za:{Aa:{Ba:{e=w[g+1406|0];switch(e-1|0){case 1:break wa;case 2:case 3:break Aa;case 0:break Ba;default:break za}}Fa=bf(v[r+8>>2],k),Ga=w[g+1408|0],t[Fa+5|0]=Ga;break wa}e=w[g+1408|0];if(!e){break wa}t[g+1450|0]=e;break wa}if((e|0)!=11){break wa}e=w[g+1408|0];if(!e){break wa}s=i+16|0;Zy(s,b,w[h+3|0],e,0);u[g+1384>>1]=x[i+16>>1];if(w[Te(s)|0]){break va}}Ca:{Da:{Ea:{Fa:{Ga:{switch(m-12|0){case 0:SN(b,l,k&65535);break Ca;case 2:e=RN(b,l,k&65535,f);if((e|0)==-1){break Ca}v[l+60>>2]=e;break Ca;case 5:Db(i+16|0,H,5);if(Cb(v[v[i+16>>2]>>2],v[i+20>>2])){break Ca}h=B(Wn(b,x[l+70>>1],v[l+48>>2],k&65535,0),1e4);Ha:{if(!aa|!(v[G>>2]&16777250)){break Ha}if(h>>>0>=1e4){t[g+1451|0]=(h>>>0)/1e4;break Ha}h=B(w[g+1451|0],1e4)}Ia:{if(h>>>0>319999){break Ia}s=(h>>>0)/1e4|0;h=B(F,s&15);e=v[ga>>2];if((s&240)==16){h=e+h|0;break Ia}h=e-h|0;h=e>>>0<h>>>0?0:h}v[ga>>2]=h;e=v[b+8>>2];h=v[e+20>>2];e=v[e+24>>2];Db(i+16|0,H,8);Qo(ga,B(h,1e4),Cb(v[v[i+16>>2]>>2],v[i+20>>2])?255e4:B(e,1e4));break Ca;case 8:Ja:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break Ca}v[g+704>>2]=v[g+704>>2]&-257|((f|0)==145)<<8;break Ca;case 1:t[g+1452|0]=f&15;break Ca;case 2:break Fa;case 6:break Ja;default:break Ca}}t[g+1460|0]=f&15;break Ca;case 1:case 3:case 4:case 6:break Ca;case 7:break Ga;default:break Da}}e=f&240;if((e|0)==240){break Ea}if((e|0)!=96){break Ca}}Yy(b,l,p,f&15);break Ca}t[g+1460|0]=f&15;break Ca}if((m|0)!=28|(f&240)!=160){break Ca}Db(i+16|0,H,58);if(Cb(v[v[i+16>>2]>>2],v[i+20>>2])){break Ca}t[g+1452|0]=f&15}if(!aa){break ua}Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{switch(m-2|0){case 0:if(!f){break Ka}Db(i+16|0,H,90);if(!Cb(v[v[i+16>>2]>>2],v[i+20>>2])){t[g+1428|0]=f}t[g+1427|0]=f;break va;case 1:if(!f){break Ka}Db(i+16|0,H,90);if(!Cb(v[v[i+16>>2]>>2],v[i+20>>2])){t[g+1427|0]=f}t[g+1428|0]=f;break va;case 2:if(!f){break Ka}u[g+1384>>1]=f;break va;case 8:if(!f){break Ka}v[g+1280>>2]=f<<8;break va;case 4:case 9:if(!f){break Ka}t[g+1425|0]=f;break va;case 11:Fa=bf(v[r+8>>2],k),Ga=f,t[Fa+5|0]=Ga;break va;case 21:e=v[G>>2];f=f<<(!(e&59593760)&f<<24>>24>=0);h=f&255;if(h>>>0<=128){v[N>>2]=h<<1;break va}if(e&16777250){break va}v[N>>2]=256;break va;case 22:Db(i+16|0,H,9);Ta:{if(Cb(v[v[i+16>>2]>>2],v[i+20>>2])){e=g+1433|0;if(f){t[e|0]=f;break Ta}f=w[e|0];break Ta}if(f){t[l+1433|0]=f;break Ta}f=w[l+1433|0]}e=f&240;h=f&15;Ua:{if(!(!e|(h|0)!=15)){f=e>>>4<<!(v[G>>2]&59593760);e=v[N>>2]+(f<<1)|0;break Ua}if(!(!h|(e|0)!=240)){f=h<<(v[G>>2]&59593760?1:2);e=v[N>>2]-f|0;break Ua}if(e){f=(f>>>3&30)<<!(v[G>>2]&59593760);e=v[N>>2]+B(a,f)|0;break Ua}f=h<<(v[G>>2]&59593760?1:2);e=v[N>>2]-B(a,f)|0}v[N>>2]=e;pe(N,0,256);break va;case 19:if(f>>>0>64){break va}v[g+1364>>2]=f;break va;case 20:e=g+1432|0;Va:{if(f){t[e|0]=f;break Va}f=w[e|0]}m=f&255;s=g+1364|0;e=v[s>>2];E=f&240;h=f&15;Wa:{if(!(!E|(h|0)!=15)){v[i+16>>2]=e+(m>>>4|0);break Wa}if(!(!h|(E|0)!=240)){v[i+16>>2]=e-h;break Wa}if(h){v[i+16>>2]=e-B(a,h);break Wa}v[i+16>>2]=e+B(a,m>>>4|0)}pe(i+16|0,0,64);v[s>>2]=v[i+16>>2];break va;case 7:vm(b,p,f,8);break va;case 29:case 30:break La;case 25:break Ma;case 6:break Na;case 24:break Oa;case 3:break Pa;case 5:break Qa;case 18:break Ra;case 17:break Sa;default:break va}}if(f>>>0>15){break Ra}e=(f&1)<<14;m=x[_>>1];h=0;while(1){if((h|0)==(m|0)){break Ra}s=l+B(h,872)|0;v[s+704>>2]=(e|v[s+704>>2]&-16385)^16384;h=h+1|0;continue}}if((f&240)!=128){break va}vm(b,p,f&15,4);break va}if(f){t[g+1425|0]=f}f=0}il(p,f);break va}QN(b,p,f);break va}PN(p,f);break va}NN(p,f);break va}Xa:{if(f<<24>>24>=0){e=ze(ya,w[g+1460|0]);break Xa}e=ze(za,f&127)}h=w[fa|0];v[23588]=0;ma(590,b|0,l|0,k&65535,0,e|0,h|0);e=v[23588];v[23588]=0;if((e|0)!=1){break va}k=P()|0;O()|0;break f}f=0}Ya:{Za:{switch(w[g+1406|0]-2|0){case 0:vm(b,p,w[g+1408|0],6);break Ya;case 5:Db(i+16|0,H,53);e=w[g+1408|0];if(Cb(v[v[i+16>>2]>>2],v[i+20>>2])){t[g+1439|0]=e&15;break Ya}il(p,e<<4);break Ya;case 6:break Za;default:break Ya}}il(p,w[g+1408|0])}_a:{$a:{ab:{bb:{cb:{e=w[S|0];switch(e-5|0){case 1:break _a;case 3:break ab;case 0:case 2:break bb;default:break cb}}switch(e-26|0){case 1:break $a;case 0:break bb;default:break _a}}db:{if(v[G>>2]&16777248){e=n;if(!(w[b+480208|0]&4)){break db}}e=a}h=w[g+1439|0];Db(i+16|0,H,21);g=g+1435|0;m=w[g|0];e=B(e,h);Fa=g,Ga=(Cb(v[v[i+16>>2]>>2],v[i+20>>2])?e<<2:e)+m|0,t[Fa|0]=Ga;break _a}eb:{if(v[G>>2]&16777248){e=n;if(!(w[b+480208|0]&4)){break eb}}e=a}h=w[g+1442|0];Db(i+16|0,H,21);g=g+1436|0;m=w[g|0];e=B(e,h);Fa=g,Ga=(Cb(v[v[i+16>>2]>>2],v[i+20>>2])?e<<2:e)+m|0,t[Fa|0]=Ga;break _a}e=g+1437|0;t[e|0]=w[e|0]+B(D,w[g+1445|0]);LN(b,p)}Db(i+16|0,H,78);if(!Cb(v[v[i+16>>2]>>2],v[i+20>>2])){break ua}e=f&255;if(!e){break ua}KN(p,e)}k=k+1|0;continue}}break}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}t[q+26|0]=1}fb:{if((ca|0)!=7){break fb}a=0;e=b+480188|0;while(1){if(x[e>>1]<=a>>>0){break fb}gb:{if(v[bf(v[r+8>>2],a)>>2]==-1){break gb}v[23588]=0;X(589,r|0,a&65535,d|0,-1);n=v[23588];v[23588]=0;if((n|0)!=1){break gb}k=P()|0;O()|0;break f}a=a+1|0;continue}}if(w[q+26|0]){u[q+20>>1]=x[l+72>>1];v[q+8>>2]=v[l+48>>2]}A[q>>3]=A[r+24>>3];v[23588]=0;R(584,$|0,q|0);a=v[23588];v[23588]=0;if((a|0)!=1){if(!aa){break a}if(!(M?w[q+26|0]:1)){break c}n=Ly(i+48|0);if(Qd(w[ha+24|0])){wN(n,ha)}Xy(ha);a=uc(b+1074376|0,l,614);f=0;while(1){if((f|0)==256){Lm(a+223848|0,l+223848|0);d=a+223860|0;f=w[d+24|0];e=l+223860|0;hb:{if((Qd(w[e+24|0])|0)==(f|0)){if(!f){break hb}f=jc(d);jt(d,v[f>>2]);v[d>>2]=v[e>>2];v[d+4>>2]=v[e+4>>2];v[d+8>>2]=v[e+8>>2];ib:{if(!v[Gb(d)>>2]){v[d>>2]=f;break ib}v[v[f>>2]+8>>2]=f;f=jc(e);v[e>>2]=f;v[f>>2]=0;Fa=Gb(e),Ga=0,v[Fa>>2]=Ga}d=d+12|0;f=jc(d);it(d,v[f>>2]);e=e+12|0;v[d>>2]=v[e>>2];v[d+4>>2]=v[e+4>>2];v[d+8>>2]=v[e+8>>2];jb:{if(!v[Gb(d)>>2]){v[d>>2]=f;break jb}v[v[f>>2]+8>>2]=f;d=jc(e);v[e>>2]=d;v[d>>2]=0;Fa=Gb(e),Ga=0,v[Fa>>2]=Ga}break hb}if(f){Xy(d);break hb}wN(d,e)}}else{d=B(f,872);Sp((d+a|0)+616|0,(d+l|0)+616|0);f=f+1|0;continue}break}Wy(a);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];kb:{lb:{d=v[b+1298300>>2];if(!Fd(d)){break lb}v[23588]=0;Y(591,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){break lb}break kb}while(1){if(x[b+480188>>1]<=a>>>0){a=$z(i+16|0);Fa=i,Ga=Gi(v[n+12>>2]),v[Fa+8>>2]=Ga;e=b+906300|0;p=xf(n+12|0);while(1){d=v[i+8>>2];if(!Ig(d,p)){mb:{p=250;d=a;nb:{while(1){if(p>>>0>=32){if(v[a>>2]){a=1;break nb}else{p=p-32|0;a=a+4|0;continue}}break}a=(v[d+28>>2]&67108863)!=0}if(!a){break mb}a=0;while(1){if((a|0)==250){break mb}Db(i,d,a);ob:{if(!Cb(v[v[i>>2]>>2],v[i+4>>2])){break ob}f=v[Md(e,a)>>2];g=v[v[f>>2]+180>>2];v[23588]=0;Y(g|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){break ob}break kb}a=a+1|0;continue}}Fa=i,Ga=Gi(v[n>>2]),v[Fa>>2]=Ga;a=xf(n);while(1){d=v[i>>2];if(Ig(d,a)){d=wd(d);f=jc(d);Fa=Md(e,w[d|0]),Ia=z[f>>2],z[Fa+144>>2]=Ia;Lg(i);continue}else{Tp(n);break b}}}f=wd(d);N=Gb(f);pb:{g=w[f|0];d=v[Md(e,g)>>2];if(d){Db(i,a,g);if(!Cb(v[v[i>>2]>>2],v[i+4>>2])){v[23588]=0;Q(592,a|0,g|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break pb}g=v[v[d>>2]+176>>2];v[23588]=0;R(g|0,d|0,-1);g=v[23588];v[23588]=0;if((g|0)==1){break pb}}Ea=z[N>>2];f=v[f+4>>2];g=v[v[d>>2]+44>>2];v[23588]=0;Ba(g|0,d|0,f|0,C(Ea));d=v[23588];v[23588]=0;if((d|0)==1){break pb}}Lg(i+8|0);continue}break}break kb}d=B(a,872)+b|0;e=w[d+1075791|0];if(e){t[d+1075794|0]=e}d=bf(v[r+8>>2],a);if(!((ca|0)==7|w[d+5|0]==255)){t[i+16|0]=64;Fa=(B(a,872)+b|0)+1075680|0,Ga=w[Xb(d+5|0,i+16|0)|0]<<2,v[Fa>>2]=Ga}qb:{e=B(a,872)+b|0;d=v[e+1075096>>2];rb:{if(!d|!(w[d+35|0]&2)){break rb}f=v[b+1298300>>2];if(!Fd(f)){break rb}v[23588]=0;ka=f;f=a&65535;U(593,ka|0,f|0,d+68|0);d=v[23588];v[23588]=0;if((d|0)==1){break qb}d=v[b+1298300>>2];v[23588]=0;U(594,d|0,f|0,1);d=v[23588];v[23588]=0;if((d|0)==1){break qb}}v[e+1075008>>2]=0;a=a+1|0;continue}break}}k=P()|0;O()|0;Tp(n);break f}k=P()|0;O()|0}nt(J)}JN(r)}Ei($);T(k|0);L()}if((c|0)==3){break b}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2]}a=oa&255;if((a|0)==w[b+484376|0]){break a}Gj(na,a)}if(c&9){a=b+1298264|0;if(v[a>>2]){AO(a);b=v[a>>2];Wj(a);Nb(b);Fa=Gb(a),Ga=0,v[Fa>>2]=Ga;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[J>>2];v[a+4>>2]=v[J+4>>2];b=Gb(J);Fa=Gb(a),Ga=v[b>>2],v[Fa>>2]=Ga;v[b>>2]=0;v[J>>2]=0;v[J+4>>2]=0;a=a+12|0;c=jc(a);Xp(a,v[c>>2]);b=J+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];sb:{if(!v[Gb(a)>>2]){v[a>>2]=c;break sb}v[v[c>>2]+8>>2]=c;a=jc(b);v[b>>2]=a;v[a>>2]=0;Fa=Gb(b),Ga=0,v[Fa>>2]=Ga}}nt(J);JN(r);kb=i+192|0}function wS(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,A=C(0),D=C(0),E=0,F=0,G=0,H=0,I=C(0),J=C(0),K=0,M=C(0),N=C(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=C(0),_=C(0),$=0,ba=C(0),ca=C(0),da=0,ea=0,fa=C(0),ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;U=kb-16|0;kb=U;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;Q=v[a+1420>>2];d=(Q|0)>0?Q:0;while(1){if((d|0)!=(E|0)){v[(B(E,20)+a|0)+1436>>2]=0;E=E+1|0;continue}break}b:{c:{d:{if((Q|0)>3){break d}E=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{h=b+d|0;if(w[h|0]!=79){break f}if(Sb(h,93872,4)){break f}g=d+26|0;if((g|0)>=(c|0)){break e}j=d+27|0;i=b+g|0;f=w[i|0];if((j+f|0)>=(c|0)){break e}k=f+27|0;E=0;e=0;while(1)if((e|0)==(f|0)){e=0;while(1){f=22;if((E|0)!=22){e=jx(e,w[(d+E|0)+b|0]);E=E+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;e=jx(e,0);continue}break}v[a+1420>>2]=Q+1;f=B(Q,20)+a|0;v[f+1432>>2]=e;v[f+1428>>2]=k-26;v[f+1424>>2]=w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24);e=w[(g+w[i|0]|0)+b|0]==255?-1:w[h+6|0]|w[h+7|0]<<8|(w[h+8|0]<<16|w[h+9|0]<<24);v[f+1436>>2]=g;v[f+1440>>2]=e;Q=v[a+1420>>2];if((Q|0)!=4){break f}Q=4;break d}else{k=w[(e+j|0)+b|0]+k|0;e=e+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(Q|0)?d:Q;while(1){if((d|0)==(i|0)){break b}E=0;f=B(d,20)+a|0;n=f+1428|0;h=v[n>>2];k=v[f+1436>>2];j=c-k|0;g=(h|0)<(j|0)?h:j;l=(g|0)>0?g:0;da=f+1432|0;e=v[da>>2];while(1){if((l|0)!=(E|0)){e=jx(e,w[(k+E|0)+b|0]);E=E+1|0;continue}break}v[n>>2]=h-g;v[da>>2]=e;if((h|0)<=(j|0)){h=e;e=f+1424|0;if((h|0)==v[e>>2]){v[a+1380>>2]=-1;v[a+992>>2]=0;v[a+1420>>2]=-1;b=v[(B(d,20)+a|0)+1440>>2];v[a+1060>>2]=b;v[a+1064>>2]=(b|0)!=-1;E=g+k|0;break c}f=Q-1|0;v[a+1420>>2]=f;f=B(f,20)+a|0;v[e+16>>2]=v[f+1440>>2];h=f+1432|0;g=v[h+4>>2];v[e+8>>2]=v[h>>2];v[e+12>>2]=g;f=f+1424|0;h=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=h;Q=v[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=E}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!mI(a)){v[f>>2]=0;c=0;break a}qa=U+12|0;da=kb-16|0;kb=da;v[a+1504>>2]=0;v[a+1508>>2]=0;h:{if(v[a+96>>2]){break h}i:{j:{k:{if(v[a+1380>>2]!=-1){break k}c=$e(a);if(v[a+96>>2]){break i}if((c|0)!=79){break j}if(($e(a)|0)!=103){break j}if(($e(a)|0)!=103){break j}if(($e(a)|0)!=83){break j}if(!lI(a)){break i}if(!(t[a+1375|0]&1)){break k}t[a+1376|0]=0;v[a+1384>>2]=0;ec(a,32);break i}k=gx(a);break i}ec(a,30)}if(!k){break h}if(oc(a,1)){ec(a,35);break h}s=da;l:{m:{if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){c=oc(a,jm(v[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=v[a+408>>2]){break h}v[da+12>>2]=c;k=B(c,6)+a|0;if(!w[k+412|0]){h=v[a+112>>2];g=h>>1;break m}h=v[a+116>>2];g=h>>1;c=oc(a,1);j=oc(a,1);if(c|!w[k+412|0]){break m}v[U+4>>2]=h-v[a+112>>2]>>2;c=v[a+112>>2]+h>>2;break l}aa(6328,13110,3152,10684);L()}v[U+4>>2]=0;c=g}v[s+8>>2]=c;n:{if(!(!w[k+412|0]|j)){c=B(h,3);v[U+8>>2]=c-v[a+112>>2]>>2;h=c+v[a+112>>2]>>2;break n}v[U+8>>2]=g}v[da+4>>2]=h;h=1}if(h){E=v[U+4>>2];la=v[U+8>>2];ka=v[da+4>>2];O=kb-2368|0;kb=O;F=v[a+404>>2];oa=B(v[da+12>>2],6)+a|0;G=w[oa+413|0];R=F+B(G,40)|0;V=v[((w[oa+412|0]<<2)+a|0)+104>>2];ha=V>>1;sa=0-ha|0;o:{while(1){c=v[a+4>>2];if((c|0)>(n|0)){c=w[(v[R+4>>2]+B(n,3)|0)+2|0];P=(O+1344|0)+(n<<2)|0;v[P>>2]=0;h=w[(c+R|0)+9|0];if(!x[((h<<1)+a|0)+132>>1]){ec(a,21);c=0;break o}g=v[a+260>>2];p:{q:{if(!oc(a,1)){break q}c=2;k=v[((n<<2)+a|0)+996>>2];g=g+B(h,1596)|0;r=v[(w[g+1588|0]<<2)+72700>>2];h=jm(r)-1|0;ta=k,ua=oc(a,h),u[ta>>1]=ua;ta=k,ua=oc(a,h),u[ta+2>>1]=ua;H=g+82|0;W=g+65|0;T=g+49|0;S=g+33|0;K=g+1|0;o=0;while(1){if(w[g|0]>o>>>0){p=w[o+K|0];q=w[p+T|0];l=-1<<q;X=w[p+S|0];r:{if(!q){i=0;break r}h=v[a+124>>2]+B(w[p+W|0],2096)|0;if(v[a+1396>>2]<=9){al(a)}j=v[a+1392>>2];i=u[(h+((j&1023)<<1)|0)+36>>1];s:{if((i|0)>=0){s=j;i=i&65535;j=w[i+v[h+8>>2]|0];v[a+1392>>2]=s>>>j;j=v[a+1396>>2]-j|0;v[a+1396>>2]=(j|0)>0?j:0;i=(j|0)>=0?i:-1;break s}i=im(a,h)}if(!w[h+23|0]){break r}i=v[v[h+2088>>2]+(i<<2)>>2]}ea=l^-1;h=c+X|0;while(1){if((c|0)!=(h|0)){l=0;j=u[(H+(p<<4)|0)+((i&ea)<<1)>>1];t:{if((j|0)<0){break t}j=v[a+124>>2]+B(j&65535,2096)|0;if(v[a+1396>>2]<=9){al(a)}l=v[a+1392>>2];X=u[(j+((l&1023)<<1)|0)+36>>1];u:{if((X|0)>=0){s=l;X=X&65535;l=w[X+v[j+8>>2]|0];v[a+1392>>2]=s>>>l;l=v[a+1396>>2]-l|0;v[a+1396>>2]=(l|0)>0?l:0;l=(l|0)>=0?X:-1;break u}l=im(a,j)}if(!w[j+23|0]){break t}l=v[v[j+2088>>2]+(l<<2)>>2]}i=i>>q;u[k+(c<<1)>>1]=l;c=c+1|0;continue}break}o=o+1|0;c=h;continue}break}if(v[a+1396>>2]==-1){break q}u[O+320>>1]=257;h=g+338|0;o=g+1088|0;c=2;while(1){l=v[g+1592>>2];if((l|0)<=(c|0)){c=0;while(1){if((c|0)>=(l|0)){break p}if(!w[(O+320|0)+c|0]){u[k+(c<<1)>>1]=65535;l=v[g+1592>>2]}c=c+1|0;continue}}else{j=c<<1;l=j+o|0;q=w[l|0];p=q<<1;i=x[p+h>>1];P=w[l+1|0];H=P<<1;W=u[k+p>>1];l=u[H+k>>1]-W|0;p=l>>31;i=(B((l^p)-p|0,x[h+j>>1]-i|0)|0)/(x[h+H>>1]-i|0)|0;l=W+((l|0)<0?0-i|0:i)|0;H=k+j|0;i=x[H>>1];v:{w:{if(i){j=O+320|0;t[j+P|0]=1;t[j+q|0]=1;t[c+j|0]=1;j=i<<16>>16;p=r-l|0;if((j|0)>=((l|0)>(p|0)?p:l)<<1){if((l|0)<(p|0)){break v}l=r+(i^-1)|0;break w}if(j&1){l=l-(j+1>>>1|0)|0;break w}l=(j>>1)+l|0;break w}t[(O+320|0)+c|0]=0}u[H>>1]=l}c=c+1|0;continue}}}v[P>>2]=1}n=n+1|0;continue}break}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){uc(O+320|0,O+1344|0,c<<2);g=x[R>>1];c=0;while(1){if((c|0)==(g|0)){c=F+B(G,40)|0}else{k=v[R+4>>2]+B(c,3)|0;h=w[k+1|0];l=O+1344|0;k=l+(w[k|0]<<2)|0;if(!(v[(h<<2)+l>>2]?v[k>>2]:0)){v[(O+1344|0)+(h<<2)>>2]=0;v[k>>2]=0}c=c+1|0;continue}break}X=c;i=0;while(1){x:{if(w[X+8|0]>i>>>0){l=0;c=v[a+4>>2];k=(c|0)>0?c:0;c=0;while(1){if((c|0)==(k|0)){break x}if(w[(v[R+4>>2]+B(c,3)|0)+2|0]==(i|0)){h=l+O|0;g=c<<2;y:{if(v[g+(O+1344|0)>>2]){g=0;n=1;break y}g=v[(a+g|0)+800>>2];n=0}t[h|0]=n;v[(O+256|0)+(l<<2)>>2]=g;l=l+1|0}c=c+1|0;continue}}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){k=(ha|0)>0?ha:0;h=x[R>>1];g=a+800|0;z:while(1){if((h|0)<=0){P=ha<<2;l=0;c=0;while(1){i=v[a+4>>2];if((i|0)<=(c|0)){while(1){if((i|0)>(l|0)){P=w[oa+412|0];R=V>>1;h=R<<2;X=v[a+92>>2];p=V>>3;W=V>>2;k=v[((l<<2)+a|0)+800>>2];c=R<<2;G=k+c|0;A:{if(v[a+80>>2]){j=Gn(a,h);break A}j=Pd(h)}h=(j+c|0)-8|0;g=v[((P<<2)+a|0)+1068>>2];i=g;c=k;while(1){if((c|0)!=(G|0)){z[h+4>>2]=C(z[c>>2]*z[i>>2])-C(z[i+4>>2]*z[c+8>>2]);z[h>>2]=C(z[c>>2]*z[i+4>>2])+C(z[c+8>>2]*z[i>>2]);c=c+16|0;i=i+8|0;h=h-8|0;continue}break}c=((R<<2)+k|0)-12|0;while(1){if(h>>>0>=j>>>0){z[h+4>>2]=C(z[c>>2]*z[i+4>>2])-C(z[c+8>>2]*z[i>>2]);z[h>>2]=C(C(-z[c+8>>2])*z[i+4>>2])-C(z[i>>2]*z[c>>2]);c=c-16|0;i=i+8|0;h=h-8|0;continue}break}c=W<<2;o=c+k|0;h=c+j|0;i=(g+(R<<2)|0)-32|0;c=j;n=k;while(1){if(g>>>0<=i>>>0){m=z[c>>2];A=z[h>>2];D=z[h+4>>2];I=z[c+4>>2];z[o+4>>2]=D+I;z[o>>2]=z[h>>2]+z[c>>2];D=C(D-I);m=C(A-m);z[n+4>>2]=C(D*z[i+16>>2])-C(z[i+20>>2]*m);z[n>>2]=C(m*z[i+16>>2])+C(D*z[i+20>>2]);m=z[c+8>>2];A=z[h+8>>2];D=z[h+12>>2];I=z[c+12>>2];z[o+12>>2]=D+I;z[o+8>>2]=z[h+8>>2]+z[c+8>>2];D=C(D-I);m=C(A-m);z[n+12>>2]=C(D*z[i>>2])-C(z[i+4>>2]*m);z[n+8>>2]=C(m*z[i>>2])+C(D*z[i+4>>2]);c=c+16|0;h=h+16|0;n=n+16|0;o=o+16|0;i=i-32|0;continue}break}h=jm(V);c=V>>4;n=R-1|0;i=0-p|0;iI(c,k,n,i,g);iI(c,k,n-W|0,i,g);H=V>>5;c=0-c|0;sp(H,k,n,c,g,16);sp(H,k,n-p|0,c,g,16);sp(H,k,n-(p<<1)|0,c,g,16);sp(H,k,n+B(p,-3)|0,c,g,16);c=h-4>>1;o=(c|0)>2?c:2;c=2;while(1){B:{C:{D:{if((c|0)==(o|0)){ea=h-7|0;break D}i=0;p=2<<c;p=(p|0)>0?p:0;r=8<<c;q=V>>c+4;F=V>>c+2;T=0-(F>>1)|0;while(1){if((i|0)==(p|0)){break C}sp(q,k,n-B(i,F)|0,T,g,r);i=i+1|0;continue}}while(1){E:{if((o|0)<(ea|0)){ma=32<<o;r=2<<o;T=8<<o;i=V>>o+6;Y=V>>o+2;$=0-(Y>>1)|0;h=n;c=g;while(1){if((i|0)<=0){break E}p=r;F=(h<<2)+k|0;q=F+($<<2)|0;S=B(T,12)+c|0;m=z[S>>2];K=(T<<3)+c|0;A=z[K>>2];s=(T<<2)+c|0;D=z[s>>2];I=z[S+4>>2];M=z[K+4>>2];Z=z[s+4>>2];_=z[c+4>>2];fa=z[c>>2];S=0-Y<<2;while(1){if((p|0)>0){K=q-4|0;N=z[K>>2];ba=z[F>>2];ca=z[q>>2];z[F>>2]=ba+ca;s=F-4|0;J=z[s>>2];z[s>>2]=J+z[K>>2];J=C(J-N);N=C(ba-ca);z[K>>2]=C(J*fa)+C(_*N);z[q>>2]=C(N*fa)-C(_*J);K=q-12|0;ba=z[K>>2];s=F-8|0;J=z[s>>2];ia=s;s=q-8|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-12|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*D)+C(Z*J);z[s>>2]=C(J*D)-C(Z*N);K=q-20|0;ba=z[K>>2];s=F-16|0;J=z[s>>2];ia=s;s=q-16|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-20|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*A)+C(M*J);z[s>>2]=C(J*A)-C(M*N);K=q-28|0;ba=z[K>>2];s=F-24|0;J=z[s>>2];ia=s;s=q-24|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-28|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*m)+C(I*J);z[s>>2]=C(J*m)-C(I*N);p=p-1|0;q=q+S|0;F=F+S|0;continue}break}i=i-1|0;h=h-8|0;c=(ma<<2)+c|0;continue}}c=(n<<2)+k|0;i=c-(H<<6)|0;m=z[g+(V>>3<<2)>>2];fa=C(-m);while(1){if(c>>>0>i>>>0){M=z[c>>2];h=c-32|0;Z=z[h>>2];z[c>>2]=M+Z;g=c-4|0;A=z[g>>2];n=g;g=c-36|0;_=z[g>>2];z[n>>2]=A+_;n=c-8|0;D=z[n>>2];s=n;n=c-40|0;J=z[n>>2];z[s>>2]=D+J;p=c-12|0;I=z[p>>2];s=p;p=c-44|0;N=z[p>>2];z[s>>2]=I+N;z[h>>2]=M-Z;z[g>>2]=A-_;g=c-16|0;A=z[g>>2];s=g;g=c-48|0;ba=z[g>>2];z[s>>2]=A+ba;D=C(D-J);I=C(I-N);z[n>>2]=m*C(D+I);z[p>>2]=m*C(I-D);n=c-28|0;D=z[n>>2];p=c-60|0;I=z[p>>2];r=c-24|0;M=z[r>>2];o=c-56|0;Z=z[o>>2];q=c-20|0;_=z[q>>2];s=q;q=c-52|0;J=z[q>>2];z[s>>2]=_+J;z[r>>2]=M+Z;z[n>>2]=D+I;z[g>>2]=_-J;z[q>>2]=-C(A-ba);A=C(D-I);D=C(M-Z);z[o>>2]=m*C(A-D);z[p>>2]=C(D+A)*fa;hI(c);hI(h);c=c+-64|0;continue}break}p=R-4|0;h=j+(p<<2)|0;i=(j+(W<<2)|0)-16|0;c=v[((P<<2)+a|0)+1100>>2];while(1){if(i>>>0>=j>>>0){g=(x[c>>1]<<2)+k|0;z[h+12>>2]=z[g>>2];z[h+8>>2]=z[g+4>>2];z[i+12>>2]=z[g+8>>2];z[i+8>>2]=z[g+12>>2];g=(x[c+2>>1]<<2)+k|0;z[h+4>>2]=z[g>>2];z[h>>2]=z[g+4>>2];z[i+4>>2]=z[g+8>>2];z[i>>2]=z[g+12>>2];c=c+4|0;h=h-16|0;i=i-16|0;continue}break}c=v[((P<<2)+a|0)+1084>>2];i=j;h=i+(R<<2)|0;g=h;while(1){n=g-16|0;if(n>>>0>i>>>0){m=z[i+4>>2];r=g-4|0;A=z[r>>2];D=C(m-A);I=z[c+4>>2];m=C(m+A);A=z[i>>2];o=g-8|0;M=z[o>>2];Z=C(A-M);_=z[c>>2];fa=C(C(I*m)-C(Z*_));z[i+4>>2]=D+fa;A=C(A+M);m=C(C(I*Z)+C(m*_));z[i>>2]=A+m;z[r>>2]=fa-D;z[o>>2]=A-m;m=z[i+8>>2];A=z[n>>2];D=C(m+A);I=z[c+12>>2];m=C(m-A);A=z[i+12>>2];g=g-12|0;M=z[g>>2];Z=C(A+M);_=z[c+8>>2];fa=C(C(I*m)+C(Z*_));z[i+8>>2]=D+fa;A=C(A-M);m=C(C(I*Z)-C(m*_));z[i+12>>2]=A+m;z[n>>2]=D-fa;z[g>>2]=m-A;i=i+16|0;c=c+16|0;g=n;continue}break}i=v[((P<<2)+a|0)+1076>>2]+(R<<2)|0;c=(p<<2)+k|0;g=((V<<2)+k|0)-16|0;while(1){n=h-32|0;if(n>>>0>=j>>>0){m=z[h-8>>2];A=z[i-4>>2];D=z[i-8>>2];I=z[h-4>>2];M=C(C(m*A)-C(D*I));z[k>>2]=M;z[c+12>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G>>2]=m;z[g+12>>2]=m;m=z[h-16>>2];A=z[i-12>>2];D=z[i-16>>2];I=z[h-12>>2];M=C(C(m*A)-C(D*I));z[k+4>>2]=M;z[c+8>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+4>>2]=m;z[g+8>>2]=m;m=z[h-24>>2];A=z[i-20>>2];D=z[i-24>>2];I=z[h-20>>2];M=C(C(m*A)-C(D*I));z[k+8>>2]=M;z[c+4>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+8>>2]=m;z[g+4>>2]=m;m=z[n>>2];A=z[i-28>>2];i=i-32|0;D=z[i>>2];I=z[h-28>>2];M=C(C(m*A)-C(D*I));z[k+12>>2]=M;z[c>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+12>>2]=m;z[g>>2]=m;g=g-16|0;c=c-16|0;G=G+16|0;k=k+16|0;h=n;continue}break}if(!v[a+80>>2]){Nb(j)}v[a+92>>2]=X;break B}o=o+1|0;continue}}c=c+1|0;continue}break}l=l+1|0;i=v[a+4>>2];continue}break}}else{h=c<<2;g=h+a|0;i=v[g+800>>2];F:{if(v[h+(O+320|0)>>2]){Ub(i,0,P);break F}F=v[g+996>>2];G:{h=w[(R+w[(v[R+4>>2]+B(c,3)|0)+2|0]|0)+9|0];if(!x[((h<<1)+a|0)+132>>1]){ec(a,21);break G}n=V>>1;p=v[a+260>>2]+B(h,1596)|0;H=p+338|0;W=p+838|0;k=B(w[p+1588|0],u[F>>1]);o=1;h=0;while(1){if(v[p+1592>>2]>(o|0)){g=w[o+W|0]<<1;j=u[g+F>>1];if((j|0)>=0){j=B(w[p+1588|0],j&65535);g=x[g+H>>1];if((g|0)!=(h|0)){q=j-k|0;r=g-h|0;G=(q|0)/(r|0)|0;H:{T=(g|0)<(n|0)?g:n;if((T|0)<=(h|0)){break H}s=q;q=q>>31;S=G>>31;S=((s^q)-q|0)-B(r,(S^G)-S|0)|0;K=q|1;q=i+(h<<2)|0;z[q>>2]=z[((k&255)<<2)+72720>>2]*z[q>>2];T=T-1|0;q=0;while(1){if((h|0)==(T|0)){break H}h=h+1|0;X=i+(h<<2)|0;q=q+S|0;ea=(q|0)<(r|0);k=(k+G|0)+(ea?0:K)|0;z[X>>2]=z[((k&255)<<2)+72720>>2]*z[X>>2];q=q-(ea?0:r)|0;continue}}h=g}k=j}o=o+1|0;continue}break}if((h|0)>=(n|0)){break G}g=(k<<2)+72720|0;while(1){if((h|0)==(n|0)){break G}k=i+(h<<2)|0;z[k>>2]=z[g>>2]*z[k>>2];h=h+1|0;continue}}}c=c+1|0;continue}break}kI(a);I:{if(w[a+1377|0]){v[a+1060>>2]=sa;t[a+1377|0]=0;v[a+1064>>2]=1;v[a+1412>>2]=V-ka;break I}c=v[a+1412>>2];if(!c){break I}h=la-E|0;if((h|0)<=(c|0)){v[a+1412>>2]=c-h;v[U+4>>2]=la;E=la;break I}E=c+E|0;v[U+4>>2]=E;v[a+1412>>2]=0}c=v[a+1064>>2];J:{K:{L:{M:{if(v[a+1388>>2]==v[a+1404>>2]){N:{if(!c|!(w[a+1375|0]&4)){break N}c=v[a+1408>>2];h=v[a+1060>>2];if(c>>>0>=h+(ka-E|0)>>>0){break N}h=c-h|0;c=(c>>>0<h>>>0?0:h)+E|0;c=(c|0)<(ka|0)?c:ka;v[qa>>2]=c;v[a+1060>>2]=c+v[a+1060>>2];break K}v[a+1064>>2]=1;c=v[a+1408>>2]+(E-ha|0)|0;break M}if(!c){break L}c=v[a+1060>>2]}v[a+1060>>2]=c+(la-E|0)}if(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0){break J}v[qa>>2]=ka}c=1;break o}aa(6328,13110,3451,5637);L()}h=h-1|0;c=v[R+4>>2]+B(h,3)|0;j=v[g+(w[c+1|0]<<2)>>2];i=v[g+(w[c|0]<<2)>>2];c=0;while(1){if((c|0)==(k|0)){continue z}n=c<<2;l=n+j|0;D=z[l>>2];n=i+n|0;m=z[n>>2];O:{if(m>C(0)){if(D>C(0)){A=C(m-D);break O}A=m;m=C(m+D);break O}if(D>C(0)){A=C(m+D);break O}A=m;m=C(m-D)}z[n>>2]=m;z[l>>2]=A;c=c+1|0;continue}}}aa(6328,13110,3335,5637);L()}W=O+256|0;n=0;q=kb-16|0;kb=q;G=v[a+4>>2];F=v[a+396>>2];o=w[(i+X|0)+24|0];p=F+B(o,24)|0;h=v[p+4>>2];ea=x[((o<<1)+a|0)+268>>1];c=ha<<((ea|0)==2);g=c>>>0>h>>>0?h:c;h=v[p>>2];P=(g-(c>>>0>h>>>0?h:c)>>>0)/y[p+8>>2]|0;k=P<<2;c=B(G,k+4|0);K=v[v[a+124>>2]+B(w[p+13|0],2096)>>2];ga=v[a+92>>2];P:{if(v[a+80>>2]){h=Gn(a,c);G=v[a+4>>2];break P}h=Pd(c)}j=(l|0)>0?l:0;H=ha<<2;g=0;c=(G|0)>0?G:0;r=(G<<2)+h|0;while(1){if((c|0)!=(g|0)){v[(g<<2)+h>>2]=r;g=g+1|0;r=k+r|0;continue}break}k=h;c=0;while(1){if((c|0)!=(j|0)){if(!w[c+O|0]){Ub(v[W+(c<<2)>>2],0,H)}c=c+1|0;continue}break}Q:{if(!((l|0)==1|(ea|0)!=2)){c=0;while(1){R:{if((c|0)!=(j|0)){if(w[c+O|0]){break R}}else{c=j}if((c|0)==(l|0)){break Q}r=F+B(o,24)|0;G=(l|0)!=2;F=(l|0)<3;while(1){if((n|0)==8){break Q}S:{if(!G){h=0;o=0;while(1){if((o|0)>=(P|0)){break S}c=v[p>>2]+B(v[p+8>>2],o)|0;v[q+12>>2]=c&1;v[q+8>>2]=c>>1;c=0;if(!n){j=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){al(a)}g=v[a+1392>>2];H=u[(j+((g&1023)<<1)|0)+36>>1];T:{if((H|0)>=0){s=g;H=H&65535;g=w[H+v[j+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?H:-1;break T}g=im(a,j)}g=w[j+23|0]?v[v[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k>>2]+(h<<2)>>2]=v[v[r+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(o|0)>=(P|0))){g=v[p+8>>2];j=u[(v[r+20>>2]+(w[v[v[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(n<<1)>>1];U:{if((j|0)>=0){if(jI(a,v[a+124>>2]+B(j&65535,2096)|0,W,2,q+12|0,q+8|0,ha,g)){break U}break Q}g=v[p>>2]+(g+B(g,o)|0)|0;v[q+8>>2]=g>>1;v[q+12>>2]=g&1}o=o+1|0;c=c+1|0;continue}break}h=h+1|0;continue}}if(F){break S}h=0;o=0;while(1){if((o|0)>=(P|0)){break S}g=v[p>>2]+B(v[p+8>>2],o)|0;c=(g|0)/(l|0)|0;v[q+12>>2]=g-B(c,l);v[q+8>>2]=c;c=0;if(!n){j=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){al(a)}g=v[a+1392>>2];H=u[(j+((g&1023)<<1)|0)+36>>1];V:{if((H|0)>=0){s=g;H=H&65535;g=w[H+v[j+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?H:-1;break V}g=im(a,j)}g=w[j+23|0]?v[v[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k>>2]+(h<<2)>>2]=v[v[r+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(o|0)>=(P|0))){g=v[p+8>>2];j=u[(v[r+20>>2]+(w[v[v[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(n<<1)>>1];W:{if((j|0)>=0){if(!jI(a,v[a+124>>2]+B(j&65535,2096)|0,W,l,q+12|0,q+8|0,ha,g)){break Q}break W}g=v[p>>2]+(g+B(g,o)|0)|0;j=(g|0)/(l|0)|0;v[q+8>>2]=j;v[q+12>>2]=g-B(j,l)}o=o+1|0;c=c+1|0;continue}break}h=h+1|0;continue}}n=n+1|0;continue}}c=c+1|0;continue}}ma=F+B(o,24)|0;l=0;while(1){if((l|0)==8){break Q}n=0;T=0;X:while(1){if((n|0)<(P|0)){h=0;c=0;Y:{if(l){break Y}while(1){if((c|0)==(j|0)){break Y}if(!w[c+O|0]){r=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){al(a)}g=v[a+1392>>2];o=u[(r+((g&1023)<<1)|0)+36>>1];Z:{if((o|0)>=0){s=g;o=o&65535;g=w[o+v[r+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?o:-1;break Z}g=im(a,r)}g=w[r+23|0]?v[v[r+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k+(c<<2)>>2]+(T<<2)>>2]=v[v[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((h|0)>=(K|0)){break $}c=0;if((n|0)>=(P|0)){break $}while(1){if((c|0)==(j|0)){break _}aa:{if(w[c+O|0]){break aa}g=c<<2;r=u[(v[ma+20>>2]+(w[v[v[g+k>>2]+(T<<2)>>2]+h|0]<<4)|0)+(l<<1)>>1];if((r|0)<0){break aa}G=v[a+124>>2]+B(r&65535,2096)|0;Y=v[g+W>>2];S=v[p+8>>2];H=v[p>>2]+B(S,n)|0;ba:{ca:{if(ea){F=0;while(1){g=1;if((F|0)>=(S|0)){break ba}$=Y+(H<<2)|0;g=S-F|0;o=0;m=C(0);da:{s=gI(a,G);if((s|0)<0){break da}r=v[G>>2];g=(g|0)>(r|0)?r:g;s=B(r,s);if(w[G+22|0]){r=0;g=(g|0)>0?g:0;o=1;while(1){if((g|0)==(r|0)){break da}ja=$+(r<<2)|0;m=C(m+z[v[G+28>>2]+(r+s<<2)>>2]);z[ja>>2]=z[ja>>2]+m;r=r+1|0;m=C(m+z[G+12>>2]);continue}}r=0;g=(g|0)>0?g:0;o=1;while(1){if((g|0)==(r|0)){break da}ja=$+(r<<2)|0;z[ja>>2]=z[ja>>2]+C(z[v[G+28>>2]+(r+s<<2)>>2]+C(0));r=r+1|0;continue}}if(!o){break ca}g=v[G>>2];H=g+H|0;F=g+F|0;continue}}F=0;r=(S|0)/v[G>>2]|0;s=(r|0)>0?r:0;ja=Y+(H<<2)|0;g=1;while(1){if((F|0)==(s|0)){break ba}o=F+H|0;Y=F<<2;F=F+1|0;ia=Y+ja|0;Y=S-o|0;$=0;m=C(0);ea:{na=gI(a,G);if((na|0)<0){break ea}o=0;$=v[G>>2];Y=(Y|0)>($|0)?$:Y;Y=(Y|0)>0?Y:0;na=B($,na);$=1;while(1){if((o|0)==(Y|0)){break ea}ra=(B(o,r)<<2)+ia|0;A=C(m+z[v[G+28>>2]+(o+na<<2)>>2]);z[ra>>2]=z[ra>>2]+A;m=w[G+22|0]?A:m;o=o+1|0;continue}}if($){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}}T=T+1|0;continue X}n=n+1|0;h=h+1|0;continue}}break}l=l+1|0;continue}}if(!v[a+80>>2]){Nb(k)}v[a+92>>2]=ga;kb=q+16|0;i=i+1|0;continue}}aa(6328,13110,3302,5637);L()}kb=O+2368|0}else{c=0}kb=da+16|0;if(!c){fa:{ga:{ha:{c=v[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}v[a+100>>2]=0;while(1){if(ta=0,ua=(wh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break fa}v[a+100>>2]=0;while(1){if(ta=0,ua=(wh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;c=1;break a}g=v[U+12>>2];j=v[U+4>>2];h=v[U+8>>2];ia:{ja:{k=v[a+992>>2];if(k){i=k<<1;ka:{if((i|0)==v[a+112>>2]){c=a+1092|0}else{c=0;if((i|0)!=v[a+116>>2]){break ka}c=a+1096|0}c=v[c>>2]}if(!c){break ja}n=(k|0)>0?k:0;while(1){if(v[a+4>>2]>(Q|0)){i=(Q<<2)+a|0;E=0;while(1){if((n|0)!=(E|0)){l=v[i+800>>2]+(j+E<<2)|0;s=l;A=z[l>>2];l=E<<2;z[s>>2]=C(A*z[l+c>>2])+C(z[l+v[i+928>>2]>>2]*z[c+(k+(E^-1)<<2)>>2]);E=E+1|0;continue}break}Q=Q+1|0;continue}break}Q=v[a+992>>2]}v[a+992>>2]=g-h;k=(g|0)<(h|0);i=(k?h:g)-h|0;while(1){if(v[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;E=0;while(1){if((i|0)!=(E|0)){z[v[c+928>>2]+(E<<2)>>2]=z[v[c+800>>2]+(h+E<<2)>>2];E=E+1|0;continue}break}pa=pa+1|0;continue}break}if(!Q){break ja}c=(k?g:h)-j|0;v[a+1416>>2]=c+v[a+1416>>2];break ia}c=0}h=c;v[U+12>>2]=c;c=0;g=v[a+4>>2];k=(g|0)>0?g:0;while(1){if((c|0)!=(k|0)){i=(c<<2)+a|0;v[i+864>>2]=v[i+800>>2]+(j<<2);c=c+1|0;continue}break}if(d){v[d>>2]=g}v[f>>2]=h;v[e>>2]=a+864;c=v[a+32>>2]-b|0}kb=U+16|0;return c}function wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=kb-1760|0;kb=d;zc(b);f=kb-16|0;kb=f;h=d+1632|0;SR(f+8|0,h);g=v[f+12>>2];k=b;nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(g|0)){_b(k,v[f+12>>2])}kb=f+16|0;b=(b|0)==(g|0);if(!b){RR(h)}a:{if(!b){break a}if(!TR(d+1632|0)){break a}if(!Qb(v[k>>2],v[k+8>>2],Ec(256,0))){break a}b:{if(!c){break b}Bd(a,1048576);ag(a);b=kb-16|0;kb=b;e=yc(b,4233);ad(d+1376|0,e);Ab(e);kb=b+16|0;b=x[d+1640>>1];v[d+160>>2]=b>>>8;v[23588]=0;v[d+16>>2]=b&255;R(433,d+88|0,d+16|0);b=v[23588];v[23588]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){v[23588]=0;X(419,d+272|0,d+1376|0,d+160|0,d+88|0);b=v[23588];v[23588]=0;if((b|0)==1){break m}b=d+272|0;Jb(a+1298344|0,b);Ab(b);e=d+88|0;Ab(e);f=d+1376|0;bc(f);g=yc(b,15096);Jb(a+1298356|0,g);Ab(g);Ne(e,2,d+1642|0);Fc(f,e);v[23588]=0;U(11,b|0,8,f|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}b=d+272|0;Jb(a+1298368|0,b);Ab(b);e=d+1376|0;zb(e);v[a+1298404>>2]=8;aA(e,2,d+1674|0);Fc(b,e);Bc(a+1298308|0,b);zb(b);u[a+480188>>1]=x[d+1744>>1];f=w[d+1748|0];v[a+480204>>2]=125e4;v[a+480208>>2]=32792;G=a,H=Dd(f,1,31),v[G+480196>>2]=H;u[a+480192>>1]=x[d+1754>>1];u[a+480190>>1]=x[d+1756>>1];f=Dd(w[d+1749|0],1,32);v[a+480216>>2]=f;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=f<<2;fv(k,e);f=a+484360|0;g=a+484376|0;Wq(Wb(v[f>>2],w[g|0]),e,x[d+1738>>1],65535,65535);Ve(Wb(v[f>>2],w[g|0]),x[d+1740>>1]);p=Sg(k);ae(b,k,p?274:0);A=kc(d+1352|0,b);Bb(b);v[23588]=0;b=S(157,k|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break k}v[23588]=0;U(190,d+272|0,k|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}b=d+272|0;s=kc(d+1328|0,b);Bb(b);b=a+480188|0;o=x[b>>1];if(p){u[b>>1]=o+8}z=c&1;if(!z){break j}v[23588]=0;R(225,a+484344|0,x[d+1742>>1]);b=v[23588];v[23588]=0;if((b|0)!=1){break j}g=P()|0;O()|0;break e}g=P()|0;O()|0;break l}g=P()|0;O()|0;Ab(d+88|0)}bc(d+1376|0);break c}g=P()|0;O()|0;break d}q=a+484344|0;C=a+480188|0;g=0;while(1){n:{o:{p:{q:{r:{s:{if(x[d+1742>>1]<=r>>>0){b=x[d+1746>>1];if((b-2&65535)>>>0>=4998){break q}if(!(g&1)){break s}i=0;b=Ic(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}v[23588]=0;b=S(194,k|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break f}v[d+160>>2]=b;v[23588]=0;b=S(157,k|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}v[23588]=0;U(190,d+88|0,k|0,b+1&-2);b=v[23588];v[23588]=0;if((b|0)==1){break g}b=d+88|0;m=kc(d+272|0,b);Bb(b);xc(d+160|0,1024);if(!z){break o}l=v[d+160>>2];if(!l){break o}v[23588]=0;b=W(226,q|0,r&65535,l|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if(!b){break o}h=0;e=0;if(t[d+1750|0]&1){break p}t:while(1){if((h|0)==(l|0)){break o}e=0;b=Zb(v[q>>2],r);b=Df(v[b>>2],v[v[b+48>>2]+12>>2],h);while(1){if((e|0)==(o|0)){h=h+1|0;continue t}v[23588]=0;R(601,m|0,d+88|0);f=v[23588];v[23588]=0;if((f|0)!=1){g=QR(b+B(e,6)|0,d+88|0)|g;e=e+1|0;continue}break}break}break h}break h}i=2;b=Qe(2646e3/+(B(b,B(v[a+480216>>2],v[a+480196>>2]))>>>0)*1e4)}t[a+480224|0]=i;v[a+480204>>2]=b}h=a+480188|0;b=x[h>>1];v[23588]=0;t[d+272|0]=0;r=W(602,d+1312|0,b|0,d+272|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){i=a+1298320|0;l=a+1298332|0;n=a+484348|0;m=0;u:{v:{w:{x:{y:{z:{while(1){b=v[s+8>>2];e=v[s>>2];v[23588]=0;b=W(156,e|0,b|0,8)|0;e=v[23588];v[23588]=0;A:{if((e|0)!=1){if(b){break A}f=a+906300|0;g=v[r>>2];h=0;i=a+480188|0;while(1){e=x[i>>1];if(e>>>0<=h>>>0){v[d+264>>2]=0;v[d+268>>2]=0;v[d+256>>2]=0;v[d+260>>2]=0;v[d+248>>2]=0;v[d+252>>2]=0;v[d+240>>2]=0;v[d+244>>2]=0;B:{C:{if(!p){break C}e=0;v[23588]=0;R(603,A|0,d+272|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}while(1){if((e|0)==8){e=0;v[23588]=0;h=Q(218,d+224|0,x[d+272>>1])|0;b=v[23588];v[23588]=0;if((b|0)!=1){D:{E:{F:{G:{while(1){if(x[d+272>>1]<=e>>>0){v[23588]=0;l=W(604,d+208|0,x[d+1742>>1],26924)|0;b=v[23588];v[23588]=0;if((b|0)==1){break E}j=a+484376|0;z=a+484348|0;C=a+480188|0;f=0;break F}v[23588]=0;b=S(194,k|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;U(190,d+160|0,k|0,b<<5);b=v[23588];v[23588]=0;if((b|0)==1){break G}f=d+160|0;b=kc(d+88|0,f);hd(Pg(v[h>>2],e),b);Bb(b);e=e+1|0;Bb(f);continue}break}g=P()|0;O()|0;break D}g=P()|0;O()|0;break D}while(1){if(x[d+1738>>1]<=f>>>0){od(l);Vc(h);break C}H:{g=d+f|0;e=w[g+290|0];if(e>>>0>=x[d+272>>1]){break H}b=x[dc(v[Wb(v[a+484360>>2],w[j|0])>>2],f)>>1];if(b>>>0>=x[d+1742>>1]){break H}I:{i=dc(v[l>>2],b);n=x[i>>1];J:{if((n|0)==65535){u[i>>1]=e;break J}if((e|0)==(n|0)){break J}v[23588]=0;e=Q(605,q|0,b|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break I}if((e|0)==65535){break J}G=dc(v[Wb(v[a+484360>>2],w[j|0])>>2],f),H=e,u[G>>1]=H;b=e}if(!ye(v[a+484344>>2],v[z>>2],b)){break H}p=Pg(v[h>>2],w[g+290|0]);zc(p);e=v[p>>2];v[23588]=0;e=S(160,e|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break I}D=e>>>5|0;i=0;K:while(1){e=Zb(v[q>>2],b);if(y[e+12>>2]<=i>>>0){break H}g=0;e=jd(v[e>>2],v[v[e+48>>2]+12>>2],i,x[C>>1]-8&65535);while(1){if((g|0)==8){i=i+1|0;continue K}Fj(d+88|0);n=x[d+92>>1];t[e+4|0]=n;t[e+5|0]=n>>>8;n=v[d+88>>2];t[e|0]=n;t[e+1|0]=n>>>8;t[e+2|0]=n>>>16;t[e+3|0]=n>>>24;L:{if(i>>>0>=D>>>0){break L}v[23588]=0;Q(606,p|0,d+88|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break I}if(t[d+88|0]>=0){break L}t[e|0]=61;t[e+1|0]=w[(d+256|0)+(g<<1)|0];n=w[d+88|0]&31;t[d+160|0]=n;if(n){wf(d+160|0,15);t[e+3|0]=20;t[e+5|0]=w[d+160|0]|208}t[e+2|0]=1;t[e+4|0]=w[d+89|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=P()|0;O()|0;od(l);break D}f=f+1|0;continue}}g=P()|0;O()|0}Vc(h);break u}g=P()|0;O()|0;break u}f=e<<1;g=f+(d+256|0)|0;b=x[a+480192>>1]+1&65535;h=x[v[a+8>>2]+58>>1];while(1){M:{N:{i=b&65535;if(i>>>0<=h>>>0){if(v[((i<<2)+a|0)+900380>>2]){break N}}else{b=65535}b=b&65535;break M}b=b+1|0;continue}break}u[g>>1]=b;h=f+(d+240|0)|0;f=x[(d+f|0)+274>>1];u[h>>1]=f;O:{if((b|0)!=65535){v[23588]=0;b=W(251,a|0,b|0,f+1&65535)|0;f=v[23588];v[23588]=0;P:{Q:{if((f|0)!=1){if(!b){break O}v[23588]=0;R(286,d+160|0,4478);f=v[23588];v[23588]=0;if((f|0)==1){break Q}v[23588]=0;v[d+16>>2]=e+1;U(607,d+88|0,d+160|0,d+16|0);f=v[23588];v[23588]=0;if((f|0)==1){break P}f=b+492|0;b=d+88|0;Dc(f,b);zb(b);$b(d+160|0);break O}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}g=P()|0;O()|0;$b(d+160|0);break u}u[g>>1]=0}e=e+1|0;continue}}R:{S:{b=x[d+1750>>1]|x[d+1752>>1]<<16;if(!(b&2)){break S}b=(((b&8?x[a+480188>>1]:o)&65535)+(x[d+1640>>1]>591?m:0)|0)+(b>>>4&1)|0;f=0;T:while(1){e=0;if(x[d+1742>>1]<=f>>>0){break S}while(1){U:{if((b|0)!=(e|0)){g=v[k+8>>2];h=v[k>>2];v[23588]=0;g=W(156,h|0,g|0,4)|0;h=v[23588];v[23588]=0;if((h|0)==1){break R}if(g){break U}}f=f+1|0;continue T}v[23588]=0;R(608,x[d+1640>>1],k|0);g=v[23588];v[23588]=0;if((g|0)==1){break R}e=e+1|0;continue}}}v[23588]=0;q=Q(218,d+192|0,255)|0;b=v[23588];v[23588]=0;if((b|0)!=1){n=a+480208|0;f=0;while(1){V:{b=f;W:{if((b|0)==255){m=$z(d+88|0);l=$z(d+160|0);g=0;while(1){X:{Y:{Z:{if((g|0)==256){h=0;break Z}v[23588]=0;R(609,k|0,d+272|0);b=v[23588];v[23588]=0;if((b|0)==1){break Y}v[23588]=0;b=S(157,k|0)|0;e=v[23588];v[23588]=0;_:{$:{aa:{if((e|0)!=1){v[23588]=0;U(190,d+16|0,k|0,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break aa}e=d+16|0;h=kc(d- -64|0,e);Bb(e);if(x[d+1756>>1]>g>>>0){e=d+48|0;Ne(e,2,d+272|0);v[23588]=0;R(222,d+16|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break _}e=d+16|0;Dc(((g<<5)+a|0)+946336|0,e);zb(e)}if(!b){break X}if(x[d+1756>>1]>g>>>0){break $}break X}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}v[23588]=0;b=B(g+1|0,104)+a|0;e=b+484380|0;R(277,e|0,32);f=v[23588];v[23588]=0;ba:{ca:{da:{if((f|0)!=1){Lo(e);v[23588]=0;R(610,h|0,d+16|0);f=v[23588];v[23588]=0;if((f|0)==1){break _}f=v[d+16>>2];v[e>>2]=f;v[b+484404>>2]=v[d+20>>2];if(w[d+24|0]>=2){i=b+484414|0;u[i>>1]=x[i>>1]|1;f=f>>>1|0;v[e>>2]=f}if(w[d+25|0]>=2){i=b+484414|0;u[i>>1]=x[i>>1]|64;v[e>>2]=f>>>1}i=2;switch(w[d+27|0]-1|0){case 0:break ca;case 1:break da;default:break ba}}break _}i=6}e=b+484414|0;u[e>>1]=x[e>>1]|i}v[b+484384>>2]=v[d+28>>2];v[b+484388>>2]=v[d+32>>2];u[b+484410>>1]=x[d+36>>1]>>>7;e=w[d+38|0];ea:{if((e|0)==128){e=b+484414|0;f=x[e>>1]|256;u[e>>1]=f;break ea}u[b+484408>>1]=(e<<24>>24)+128;f=x[b+484414>>1]}i=b+484414|0;u[i>>1]=f|32;t[b+484416|0]=w[d+39|0];e=w[d+26|0];if(e&2){b=d+48|0;Db(b,l,g);po(b);e=w[d+26|0]}if(e&5){u[i>>1]=x[i>>1]|16384}if(!(e&8)){break X}b=d+48|0;Db(b,m,g);po(b);e=0;while(1){if((e|0)==8){break X}b=e<<1;fa:{if(x[b+(d+240|0)>>1]!=(g|0)){break fa}b=v[((x[b+(d+256|0)>>1]<<2)+a|0)+900380>>2];if(!b){break fa}t[b+14|0]=0}e=e+1|0;continue}}g=P()|0;O()|0;Bb(h);break W}while(1){ga:{ha:{if(x[d+1754>>1]<=h>>>0){if(!(c&2)){break ha}e=a+1298404|0;f=a+1298464|0;g=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{while(1){if(x[a+480190>>1]<=g>>>0){break ha}g=g+1|0;c=B(g,104)+a|0;h=c+484380|0;b=c+484416|0;Bl(h,(+(t[b|0]-49|0)+ +t[c+484417|0]*-.0078125)/-12);u[b>>1]=0;b=x[c+484414>>1];if(!(b&16384)){b=_c(d+272|0,b&1?16:8,b&64?3:1,0,11);v[23588]=0;W(219,b|0,h|0,k|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}g=P()|0;O()|0;break W}v[23588]=0;h=S(157,k|0)|0;b=v[23588];v[23588]=0;qa:{if((b|0)==1){break qa}v[23588]=0;Q(188,k|0,12)|0;b=v[23588];v[23588]=0;if((b|0)==1){break qa}b=Mb(d+272|0);v[23588]=0;U(268,k|0,b|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break pa}Ce(c+484423|0,b);v[23588]=0;R(374,d- -64|0,16382);c=v[23588];v[23588]=0;if((c|0)==1){break oa}v[d+12>>2]=g;c=v[e>>2];v[23588]=0;U(11,d+48|0,c|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break na}v[23588]=0;X(419,d+16|0,d- -64|0,d+12|0,d+48|0);c=v[23588];v[23588]=0;if((c|0)==1){break ma}c=v[f>>2];v[23588]=0;U(376,c|0,2,d+16|0);c=v[23588];v[23588]=0;if((c|0)==1){break la}Ab(d+16|0);Ab(d+48|0);bc(d- -64|0);zb(b);continue}break}g=P()|0;O()|0;break W}g=P()|0;O()|0;break ia}g=P()|0;O()|0;break ia}g=P()|0;O()|0;break ja}g=P()|0;O()|0;break ka}g=P()|0;O()|0;Ab(d+16|0)}Ab(d+48|0)}bc(d- -64|0)}zb(b);break W}b=v[Pg(v[q>>2],h)>>2];v[23588]=0;b=S(160,b|0)|0;e=v[23588];v[23588]=0;ra:{sa:{if((e|0)!=1){if(!b){h=h+1|0;continue}b=Pg(v[q>>2],h);zc(b);v[23588]=0;R(611,b|0,d+272|0);b=v[23588];v[23588]=0;if((b|0)==1){break sa}i=Tb(d+16|0);v[23588]=0;U(612,k|0,i|0,x[d+272>>1]);b=v[23588];v[23588]=0;if((b|0)==1){break ra}h=h+1|0;b=v[((h<<2)+a|0)+900380>>2];if(!b|w[b+34|0]){break ga}v[b+4>>2]=32;e=0;eu(b,0);n=b+108|0;j=b+236|0;while(1){if((e|0)==96){break ga}f=w[(d+e|0)+274|0];ta:{if(f>>>0>=x[d+272>>1]){break ta}g=bf(v[i>>2],f);p=e+12|0;z=dc(j,p);f=w[g|0];o=f+1|0;u[z>>1]=o;if(f>>>0>=x[a+480190>>1]){break ta}f=B(o,104)+a|0;t[f+484418|0]=w[d+370|0]&3;t[f+484419|0]=w[d+371|0];t[f+484420|0]=w[d+372|0];t[f+484421|0]=w[d+373|0];u[f+484412>>1]=w[g+1|0]<<1;t[f+484417|0]=w[g+2|0];f=o-1|0;Db(d- -64|0,m,f);if(Cb(v[v[d+64>>2]>>2],v[d+68>>2])){t[b+14|0]=0}Db(d- -64|0,l,f);if(!Cb(v[v[d+64>>2]>>2],v[d+68>>2])){break ta}G=Lb(n,p),H=61,t[G|0]=H}e=e+1|0;continue}}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;re(i);break W}Vc(q);ic(r);Bb(s);Bb(A);break b}re(i);continue}}g=P()|0;O()|0;break W}Bb(h);g=g+1|0;continue}}v[23588]=0;R(609,k|0,d+160|0);e=v[23588];v[23588]=0;ua:{va:{wa:{xa:{if((e|0)!=1){v[23588]=0;e=S(157,k|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break xa}v[23588]=0;e=(e|0)==32?428:e;h=e?x[d+1640>>1]>513?e+4|0:e:e;U(190,d+88|0,k|0,h|0);e=v[23588];v[23588]=0;if((e|0)==1){break wa}g=d+88|0;e=kc(d+272|0,g);i=ke(d+16|0,hd(Pg(v[q>>2],b),e));Bb(e);f=b+1|0;Bb(g);if(b>>>0>=x[d+1754>>1]){break V}v[23588]=0;b=f&65535;g=W(251,a|0,b|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break va}break ua}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}if(!g){break V}b=d+88|0;Ne(b,2,d+160|0);v[23588]=0;R(222,d+272|0,b|0);b=v[23588];v[23588]=0;ya:{if((b|0)!=1){b=d+272|0;Dc(g+492|0,b);zb(b);if(!h){break V}v[23588]=0;R(611,i|0,d+272|0);b=v[23588];v[23588]=0;if((b|0)!=1){m=3;h=0;if(x[d+1640>>1]<513){l=0;break ya}v[23588]=0;l=S(194,i|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ua}if(x[d+1640>>1]<514){break ya}v[23588]=0;m=S(157,i|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break ya}break ua}break ua}break ua}v[g>>2]=x[d+374>>1];t[g+16|0]=w[(x[d+376>>1]&3)+26926|0];t[g+17|0]=w[(w[d+377|0]&3)+26926|0];t[g+18|0]=w[(x[d+376>>1]>>>12&3)+26930|0];while(1){za:{Aa:{if((h|0)==4){if(!(t[g+60|0]&1|w[g+16|0]==3)){v[g>>2]=32767}Mj(g,127,1);Lj(g,0,1);if(!l){break V}v[23588]=0;R(613,i|0,d+88|0);b=v[23588];v[23588]=0;if((b|0)==1){break ua}if(l&2){Mj(g,aB(v[n>>2],+x[d+90>>1]),1);Lj(g,w[d+92|0],1)}t[g+25|0]=w[d+89|0]==1;if(!(l&4)){break V}t[g+31|0]=w[d+95|0]+1;b=t[d+96|0];t[g+34|0]=b+1;if((b|0)<0){t[g+30|0]=w[d+103|0]+1}if(!w[d+100|0]){break Aa}h=g+108|0;e=0;while(1){if((e|0)==128){break Aa}b=e+1|0;v[d+64>>2]=b+t[d+100|0];MR(d- -64|0);G=Lb(h,e),H=v[d+64>>2],t[G|0]=H;e=b;continue}}if(!(m&1)){break za}v[23588]=0;R(614,i|0,d+88|0);b=v[23588];v[23588]=0;Ba:{if((b|0)!=1){b=Hh(g,w[h+26934|0]);Ca:{if((h|0)!=3){e=w[d+88|0];o=w[b+12|0]&-17;break Ca}e=w[d+88|0];o=e<<4&16|w[b+12|0]&-17}t[b+12|0]=e>>>1&2|(e<<1&4|(o&248|e&1));t[d+64|0]=w[d+89|0];t[d+48|0]=16;e=w[Xb(d- -64|0,d+48|0)|0];v[23588]=0;R(291,b|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break Ba}e=w[d+90|0];t[b+15|0]=e;t[b+16|0]=e;t[b+13|0]=w[d+91|0];t[b+14|0]=w[d+92|0];e=0;o=v[b>>2];j=$d(o,v[b+4>>2]);while(1){if((e|0)==(j|0)){break za}p=Eb(o,e);b=(d+88|0)+(e<<2)|0;u[p>>1]=w[b+8|0]|w[b+9|0]<<8;G=p,H=Dd(w[b+10|0]|w[b+11|0]<<8,0,64),t[G+2|0]=H;e=e+1|0;continue}}break ua}break ua}eu(g,0);break V}h=h+1|0;m=m>>>1|0;continue}}g=P()|0;O()|0;Bb(i)}Vc(q);break u}Bb(i);continue}}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}else{b=t[Lb(g,h)|0];Da:{if((b|0)<=(h|0)|(b|0)>=(e|0)){break Da}b=w[((b<<5)+a|0)+480288|0];if(!b){break Da}e=((h<<5)+a|0)+480288|0;l=w[e|0];if(!l){t[e|0]=b;break Da}e=l-1|0;while(1){l=Md(f,e&255);e=Zm(v[l+28>>2]);if((e|0)!=255){continue}break}b=b-1&255;v[l+28>>2]=b>>>0<250?b+128|0:0}h=h+1|0;continue}}}g=P()|0;O()|0;break u}v[23588]=0;f=S(157,s|0)|0;b=v[23588];v[23588]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((b|0)!=1){v[23588]=0;b=S(157,s|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Ma}v[23588]=0;U(190,d+272|0,s|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break Ma}e=d+272|0;b=kc(d+88|0,e);Bb(e);if((f|0)==4674381){break Ia}if((f|0)==5068115){break Ha}if((f|0)==726487106){break La}if((f|0)==844387158){break Ga}e=0;if((f|0)==1280004692){break Ka}if((f|0)==1314144592){break Ja}if((f|0)!=1397445204){break Fa}v[23588]=0;e=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break w}e=e>>>0<256?48:e>>>8|0;v[a+480228>>2]=e;v[a+480232>>2]=e>>>1;e=0;while(1){if(x[h>>1]<=e>>>0){break Fa}v[23588]=0;f=Q(615,b|0,d+272|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break z}if(f){u[((e<<5)+a|0)+480286>>1]=x[d+272>>1]>>>10;G=Lb(v[r>>2],e),H=w[d+275|0],t[G|0]=H}e=e+1|0;continue}}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}if(g&1){break Fa}t[a+480224|0]=2;v[23588]=0;E=+la(616,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break Ea}if(!(E>1e-8)){break Fa}G=a,H=Qe(2646e3/(E*+(B(v[a+480216>>2],v[a+480196>>2])>>>0))*1e4),v[G+480204>>2]=H;break Fa}while(1){Na:{if(x[h>>1]<=e>>>0){break Fa}f=v[b>>2];v[23588]=0;f=W(156,f|0,v[d+96>>2],1)|0;j=v[23588];v[23588]=0;if((j|0)==1){break y}if(!f){break Fa}f=Mb(d+272|0);v[23588]=0;U(350,b|0,f|0,-1);j=v[23588];v[23588]=0;if((j|0)!=1){j=d+16|0;cg(j,3,Mc(f),Hb(f));v[23588]=0;R(222,d+160|0,j|0);j=v[23588];v[23588]=0;if((j|0)==1){break Na}j=d+160|0;Hl(((e<<5)+a|0)+480289|0,j);zb(j);zb(f);e=e+1|0;continue}}break}g=P()|0;O()|0;zb(f);break v}while(1){if(x[d+1742>>1]<=e>>>0){break Fa}f=v[b>>2];v[23588]=0;f=W(156,f|0,v[d+96>>2],1)|0;j=v[23588];v[23588]=0;if((j|0)==1){break x}if(!f){break Fa}if(!Rm(v[a+484344>>2],v[n>>2],e&65535)){break Fa}f=Mb(d+272|0);v[23588]=0;U(350,b|0,f|0,-1);j=v[23588];v[23588]=0;Oa:{if((j|0)==1){break Oa}j=v[q>>2];v[23588]=0;R(281,Zb(j,e)|0,f|0);j=v[23588];v[23588]=0;if((j|0)==1){break Oa}zb(f);e=e+1|0;continue}break}g=P()|0;O()|0;zb(f);break v}v[23588]=0;Q(188,b|0,1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break w}v[23588]=0;e=S(202,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break w}v[23588]=0;X(331,l|0,b|0,e|0,2);e=v[23588];v[23588]=0;if((e|0)!=1){break Fa}break w}v[23588]=0;Q(617,b|0,d+16|0)|0;e=v[23588];v[23588]=0;Pa:{if((e|0)!=1){e=Mb(d+272|0);v[23588]=0;U(350,b|0,e|0,-1);f=v[23588];v[23588]=0;if((f|0)==1){break Pa}if(yq(e,12534)){v[23588]=0;U(11,d+160|0,8,e|0);f=v[23588];v[23588]=0;if((f|0)==1){break Pa}f=d+160|0;Jb(i,f);Ab(f)}zb(e);break Fa}g=P()|0;O()|0;break v}g=P()|0;O()|0;zb(e);break v}v[23588]=0;m=S(157,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break w}}Bb(b);continue}break}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0}Bb(b)}ic(r);break e}g=P()|0;O()|0;break e}while(1){b=v[m>>2];v[23588]=0;b=W(156,b|0,v[d+280>>2],1)|0;f=v[23588];v[23588]=0;Qa:{if((f|0)!=1){if(!b){break o}v[23588]=0;i=S(206,m|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break h}n=0;if((i|0)!=255){break Qa}v[23588]=0;n=S(206,m|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;i=S(206,m|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break Qa}}break h}break h}if(i&127){b=Zb(v[q>>2],r);f=jd(v[b>>2],v[v[b+48>>2]+12>>2],e,h&65535);Su(d+88|0);if(i&1){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+88|0]=b}if(i&2){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+89|0]=b}if(i&4){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+90|0]=b}if(i&8){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+91|0]=b}if(i&16){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+92|0]=b}if(i&32){v[23588]=0;b=S(206,m|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break n}t[d+93|0]=b}if(i&64){v[23588]=0;b=S(206,m|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break n}t[d+94|0]=b}D=QR(f,d+88|0);v[d+16>>2]=n;v[d+64>>2]=l+(e^-1);F=v[Kb(d+16|0,d- -64|0)>>2];i=0;b=f;while(1){if((i|0)!=(F|0)){b=B(x[C>>1],6)+b|0;j=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=j;t[b+1|0]=j>>>8;t[b+2|0]=j>>>16;t[b+3|0]=j>>>24;j=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=j;t[b+5|0]=j>>>8;i=i+1|0;continue}break}g=g|D}e=(e+n|0)+1|0;while(1){if(e>>>0>=l>>>0){h=h+1|0;e=e-l|0;continue}break}if(o>>>0>(h&65535)>>>0){continue}break}}Bb(m);r=r+1|0;continue}break}break h}g=P()|0;O()|0;zb(d+1376|0);break c}g=P()|0;O()|0;Bb(m);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0}Bb(s)}Bb(A)}T(g|0);L()}e=1}kb=d+1760|0;return e|0}function pja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=kb-1184|0;kb=d;zc(b);e=kb-16|0;kb=e;g=d+944|0;_T(e+8|0,g);m=v[e+12>>2];nc(e,v[b>>2],v[b+8>>2],v[e+8>>2],v[e+12>>2]);j=v[e+4>>2];if((j|0)==(m|0)){_b(b,v[e+12>>2])}kb=e+16|0;e=(j|0)==(m|0);if(!e){ZT(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!aU(d+944|0)){break o}if(!Qb(v[b>>2],v[b+8>>2],Ec($T(v[d+948>>2]),nb))){break o}if(!c){f=1;break o}Bd(a,16777216);ag(a);e=a+480208|0;v[e>>2]=v[e>>2]|16809984;f=d+480|0;wq(f,32);m=v[d+492>>2];e=a+1074320|0;v[e>>2]=v[d+488>>2];v[e+4>>2]=m;e=v[d+484>>2];v[a+1074312>>2]=v[d+480>>2];v[a+1074316>>2]=e;Ob(Ob(a+1074312|0,57,w[d+947|0]>5),114,1);e=yo(d+904|0);H=e,I=Dd(w[d+1144|0],1,31),v[H+8>>2]=I;H=e,I=Dd(w[d+1145|0],1,12),v[H+4>>2]=I;H=e,I=Ib(x[d+1146>>1]),v[H>>2]=I;DB(a+1298408|0,e);u[a+480188>>1]=32;e=d+376|0;YT(e,3,d+1148|0);m=d+56|0;Fc(m,e);v[23588]=0;U(11,f|0,1,m|0);e=v[23588];v[23588]=0;p:{q:{if((e|0)!=1){e=d+480|0;Jb(a+1298368|0,e);Ab(e);zb(d+56|0);r:{if(w[d+947|0]<=5){Sf(d+56|0,3927);break r}e=kb-16|0;kb=e;f=yc(e,3996);ad(d+56|0,f);Ab(f);kb=e+16|0}v[23588]=0;U(362,d+480|0,d+56|0,w[d+947|0]);e=v[23588];v[23588]=0;if((e|0)==1){break q}e=d+480|0;Jb(a+1298344|0,e);Ab(e);f=d+56|0;bc(f);m=yc(e,15100);Jb(a+1298356|0,m);Ab(m);v[a+1298404>>2]=12;Ne(f,3,d+952|0);Fc(e,f);Bc(a+1298308|0,e);zb(e);v[a+480228>>2]=256;v[a+480200>>2]=384/(x[a+480188>>1]+3>>>0);if(w[d+947|0]>5){break p}H=d,I=Ib(x[d+1172>>1]),u[H+480>>1]=I;u[d+56>>1]=1;e=d+480|0;f=d+56|0;H=a,I=x[le(e,f)>>1],v[H+480196>>2]=I;H=d,I=Ib(x[d+1174>>1]),u[H+480>>1]=I;u[d+56>>1]=1;H=a,I=B(x[le(e,f)>>1],1e4),v[H+480204>>2]=I;H=d,I=Ec(((Ib(x[d+1176>>1])<<8)+2047>>>0)/4095|0,0),v[H+480>>2]=I;v[d+56>>2]=256;H=a,I=v[Kb(e,f)>>2],v[H+480200>>2]=I;H=d,I=Ib(x[d+1178>>1]),u[H+480>>1]=I;Ff(e,127);f=0;e=x[d+480>>1];while(1){if((e|0)==(f|0)){break p}H=d,I=Ec(((Hj(b)<<8)+2047>>>0)/4095|0,0),u[H+56>>1]=I;u[d+376>>1]=256;H=((f<<5)+a|0)+480284|0,I=x[Wc(d+56|0,d+376|0)>>1],u[H>>1]=I;f=f+1|0;continue}}a=P()|0;O()|0;zb(d+56|0);break a}a=P()|0;O()|0;bc(d+56|0);break a}dd(b,cc(v[d+948>>2]));m=ke(d+880|0,b);v[23588]=0;R(366,d+864|0,m|0);b=v[23588];v[23588]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{if((b|0)!=1){v[23588]=0;U(367,d+480|0,d+864|0,1346458707);b=v[23588];v[23588]=0;if((b|0)==1){break H}v[23588]=0;b=W(156,v[d+480>>2],v[d+488>>2],2)|0;e=v[23588];v[23588]=0;if((e|0)==1){break K}if(!b){break I}v[23588]=0;b=S(271,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break K}if((b-1&65535)>>>0>126){break I}u[a+480188>>1]=b;b=d+480|0;Bb(b);v[23588]=0;U(367,b|0,d+864|0,1397706311);b=v[23588];v[23588]=0;if((b|0)!=1){break L}a=P()|0;O()|0;break c}a=P()|0;O()|0;break b}v[23588]=0;b=W(156,v[d+480>>2],v[d+488>>2],2)|0;e=v[23588];v[23588]=0;if((e|0)==1){break G}if(!b){break I}v[23588]=0;b=S(271,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break G}u[d+56>>1]=b;b=w[a+484376|0];e=v[a+484360>>2];v[23588]=0;f=S(271,d+480|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break G}Ve(Wb(e,b),f);v[23588]=0;b=S(202,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break G}Ff(d+56|0,Dl(b>>>1|0));b=w[a+484376|0];e=v[a+484360>>2];v[23588]=0;U(274,Wb(e,b)|0,d+480|0,x[d+56>>1]);b=v[23588];v[23588]=0;if((b|0)==1){break G}b=d+480|0;Bb(b);v[23588]=0;U(367,b|0,d+864|0,1480806221);b=v[23588];v[23588]=0;if((b|0)!=1){break J}a=P()|0;O()|0;break c}a=P()|0;O()|0;Bb(d+480|0);break c}v[23588]=0;b=W(156,v[d+480>>2],v[d+488>>2],3)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if(b){break F}b=160;while(1){M:{f=b;if(!b){f=0;break M}b=f-1|0;if(w[(d+b|0)+984|0]==32){continue}}break}v[23588]=0;X(337,a+1298332|0,d+984|0,f|0,4);b=v[23588];v[23588]=0;if((b|0)!=1){break E}break D}break D}Bb(d+480|0);f=0;break s}a=P()|0;O()|0;break c}a=P()|0;O()|0;Bb(d+480|0);break c}v[23588]=0;b=S(271,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;X(331,a+1298332|0,d+480|0,b|0,4);b=v[23588];v[23588]=0;if((b|0)!=1){break E}}break D}b=d+480|0;Bb(b);v[23588]=0;U(367,b|0,d+864|0,1413697073);b=v[23588];v[23588]=0;if((b|0)==1){break C}v[23588]=0;b=S(206,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break A}if(b){break B}v[23588]=0;b=Q(155,d+480|0,2648)|0;e=v[23588];v[23588]=0;if((e|0)==1){break A}if(!b){break B}f=0;v[23588]=0;b=S(279,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break A}while(1){if((f|0)==32){break B}e=((f<<5)+a|0)+480280|0;v[e>>2]=v[e>>2]&-1025|!(b>>>f&1)<<10;f=f+1|0;continue}}a=P()|0;O()|0;Bb(d+480|0);break c}a=P()|0;O()|0;break c}b=d+480|0;Bb(b);v[23588]=0;U(367,b|0,d+864|0,1413697074);b=v[23588];v[23588]=0;if((b|0)==1){break z}v[23588]=0;b=W(156,v[d+480>>2],v[d+488>>2],12)|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}N:{if(!b){break N}v[23588]=0;R(368,d+56|0,d+480|0);b=v[23588];v[23588]=0;if((b|0)==1){break y}b=d+56|0;e=Te(b);f=jc(b);g=XT(b);j=Gb(b);n=WT(b);e=B(Dd(Ib(w[e|0]|w[e+1|0]<<8),32,999),1e4);b=Oka(Ib(w[f|0]|w[f+1|0]<<8),0,1e4,0)+32768|0;f=nb;f=b>>>0<32768?f+1|0:f;H=a,I=e+((Ec((f&65535)<<16|b>>>16,f>>>16|0)>>>0)%1e4|0)|0,v[H+480204>>2]=I;H=a,I=Dd(Ib(w[g|0]|w[g+1|0]<<8),1,255),v[H+480196>>2]=I;b=16/(Dd(Ib(w[n|0]|w[n+1|0]<<8),1,16)>>>0)|0;v[a+480216>>2]=b;H=a,I=B(Dd(Ib(w[j|0]|w[j+1|0]<<8),1,16),b),v[H+480220>>2]=I;if(!Ib(x[d+56>>1])){break N}v[23588]=0;b=S(271,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}e=a+480208|0;v[e>>2]=v[e>>2]&-17|!b<<4}b=d+480|0;Bb(b);v[23588]=0;U(367,b|0,d+864|0,1414942540);b=v[23588];v[23588]=0;if((b|0)==1){break x}v[23588]=0;b=W(156,v[d+480>>2],v[d+488>>2],2)|0;e=v[23588];v[23588]=0;if((e|0)==1){break v}if(!b){break w}v[23588]=0;b=S(271,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break v}u[d+56>>1]=b;u[d+376>>1]=x[a+480188>>1];b=x[Wc(d+56|0,d+376|0)>>1];f=0;while(1){if((b|0)==(f|0)){break w}v[23588]=0;e=S(271,d+480|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break v}u[d+56>>1]=e;u[d+376>>1]=4096;H=((f<<5)+a|0)+480286|0,I=x[Wc(d+56|0,d+376|0)>>1]>>>6&255,u[H>>1]=I;f=f+1|0;continue}}a=P()|0;O()|0;Bb(d+480|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Bb(d+480|0);break c}a=P()|0;O()|0;break c}Bb(d+480|0);v[23588]=0;U(367,d+56|0,d+864|0,1296652368);b=v[23588];v[23588]=0;if((b|0)==1){break u}v[23588]=0;b=W(156,v[d+56>>2],v[d+64>>2],56)|0;e=v[23588];v[23588]=0;if((e|0)==1){break d}if(!b){break t}v[23588]=0;R(369,d+56|0,d+480|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}if((Ib(x[d+514>>1])|0)!=4){break t}if((Ib(x[d+528>>1])|0)!=257){break t}H=d,I=Ib(x[d+520>>1]),u[H+376>>1]=I;u[d+848>>1]=16384;e=x[Wc(d+376|0,d+848|0)>>1];b=e>>>24|0;e=(e<<8)+2048|0;b=e>>>0<2048?b+1|0:b;H=a,I=Ec((b&4095)<<20|e>>>12,b>>>12|0),v[H+480200>>2]=I;g=a+480188|0;f=0;while(1){if(Ib(x[d+518>>1])>>>0<=(f&65535)>>>0){break t}v[23588]=0;R(370,d+56|0,d+376|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}O:{if(w[d+376|0]){break O}b=Ib(x[d+378>>1]);if(b>>>0>=x[g>>1]){break O}b=(b<<5)+a|0;H=b+480284|0,I=Ec(((Ib(x[d+382>>1])<<8)+2047>>>0)/4095|0,0),u[H>>1]=I;h=b+480286|0;e=Ib(x[d+380>>1]);b=e>>>26|0;e=(e<<6)+2048|0;b=e>>>0<2048?b+1|0:b;H=h,I=Ec((b&4095)<<20|e>>>12,b>>>12|0)&255,u[H>>1]=I}f=f+1|0;continue}}a=P()|0;O()|0;Bb(d+480|0);break c}a=P()|0;O()|0;break c}b=d+56|0;Bb(b);v[23588]=0;U(371,b|0,d+864|0,1396788530);b=v[23588];v[23588]=0;if((b|0)==1){break e}H=d,I=Fb(v[d+56>>2]),v[H+800>>2]=I;f=c&2;j=d+480|2;n=Fb(v[d+60>>2]);g=a+480190|0;l=a+1298464|0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{while(1){e=v[d+800>>2];if(!Pb(e,n)){b=d+56|0;Vc(b);v[23588]=0;U(371,b|0,d+864|0,1396788560);b=v[23588];v[23588]=0;if((b|0)==1){break f}H=d,I=Fb(v[d+56>>2]),v[H+832>>2]=I;j=d+480|2;n=Fb(v[d+60>>2]);e=a+480190|0;break P}v[23588]=0;b=Q(372,e|0,d+480|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break R}Z:{_:{if(!b){break _}b=Ib(x[d+480>>1]);if((b-4e3&65535)>>>0<61537){break _}if(Ib(x[d+528>>1])>>>0>1){break _}if(Ib(x[d+510>>1])>>>0>1){break _}if(b>>>0>x[g>>1]){u[g>>1]=b}v[23588]=0;k=B(b,104)+a|0;b=k+484380|0;R(373,d+480|0,b|0);h=v[23588];v[23588]=0;$:{aa:{ba:{if((h|0)==1){break ba}h=d+848|0;Ii(h,3,j);v[23588]=0;R(222,d+376|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break aa}h=d+376|0;Dc(((Ib(x[d+480>>1])<<5)+a|0)+946304|0,h);zb(h);if(!f){break _}h=x[d+554>>1]|x[d+556>>1]<<16;v[23588]=0;h=Q(155,e|0,cc(h)-8|0)|0;p=v[23588];v[23588]=0;if((p|0)==1){break ba}if(!h){break _}if(Ib(x[d+510>>1])){break $}h=d+376|0;_c(h,(Ib(w[d+512|0]|w[d+513|0]<<8)|0)==8?8:16,(Ib(w[d+516|0]|w[d+517|0]<<8)|0)==1?1:2,!Ib(w[d+514|0]|w[d+515|0]<<8),0);v[23588]=0;W(219,h|0,b|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break $}a=P()|0;O()|0;break Q}a=P()|0;O()|0;break Q}a=P()|0;O()|0;break Q}b=Mb(d+376|0);h=x[d+530>>1];v[23588]=0;U(268,e|0,b|0,Ib(h)|0);e=v[23588];v[23588]=0;if((e|0)==1){break T}Ce(k+484423|0,b);if((Ib(x[d+510>>1])|0)==1){v[23588]=0;R(374,d+832|0,16382);e=v[23588];v[23588]=0;if((e|0)==1){break Z}v[23588]=0;U(11,d+816|0,0,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break Y}v[23588]=0;X(375,d+848|0,d+832|0,x[d+480>>1],d+816|0);e=v[23588];v[23588]=0;if((e|0)==1){break X}e=v[l>>2];v[23588]=0;U(376,e|0,2,d+848|0);e=v[23588];v[23588]=0;if((e|0)==1){break W}Ab(d+848|0);Ab(d+816|0);bc(d+832|0)}zb(b)}Nf(d+800|0);continue}break}a=P()|0;O()|0;break S}a=P()|0;O()|0;break U}a=P()|0;O()|0;break V}a=P()|0;O()|0;Ab(d+848|0)}Ab(d+816|0)}bc(d+832|0);break S}a=P()|0;O()|0}zb(b);break Q}a=P()|0;O()|0}Vc(d+56|0);break c}ca:{while(1){da:{g=v[d+832>>2];if(!Pb(g,n)){Vc(d+56|0);v[23588]=0;U(371,d+848|0,d+864|0,1447382614);b=v[23588];v[23588]=0;if((b|0)!=1){break ca}a=P()|0;O()|0;break c}v[23588]=0;b=Q(377,g|0,d+480|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break da}ea:{fa:{if(!b){break fa}b=Ib(x[d+480>>1]);if((b-4e3&65535)>>>0<61537){break fa}if(Ib(x[d+534>>1])){break fa}if(b>>>0>x[e>>1]){u[e>>1]=b}v[23588]=0;b=(B(b,104)+a|0)+484380|0;R(378,d+480|0,b|0);l=v[23588];v[23588]=0;if((l|0)==1){break da}l=d+848|0;Ii(l,3,j);v[23588]=0;R(222,d+376|0,l|0);l=v[23588];v[23588]=0;if((l|0)==1){break da}l=d+376|0;Dc(((Ib(x[d+480>>1])<<5)+a|0)+946304|0,l);zb(l);if(!f){break fa}l=x[d+510>>1];k=d+376|0;_c(k,(Ib(x[d+514>>1])|0)==8?8:16,Ib(l)&1?2:1,1,0);v[23588]=0;W(219,k|0,b|0,g|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ea}}Nf(d+832|0);continue}}break}a=P()|0;O()|0;Vc(d+56|0);break c}v[23588]=0;U(371,d+832|0,d+864|0,1413828182);b=v[23588];v[23588]=0;if((b|0)==1){break h}v[23588]=0;U(371,d+816|0,d+864|0,1346719318);b=v[23588];v[23588]=0;if((b|0)==1){break j}v[23588]=0;U(371,d+800|0,d+864|0,1229869908);b=v[23588];v[23588]=0;if((b|0)==1){break l}H=d,I=Fb(v[d+800>>2]),v[H+24>>2]=I;n=d+426|0;l=d+376|2;k=d+480|2;h=Fb(v[d+804>>2]);p=a+480190|0;q=a+480208|0;while(1){ga:{ha:{ia:{ja:{g=v[d+24>>2];if(!Pb(g,h)){Vc(d+800|0);v[23588]=0;U(371,d+376|0,d+864|0,1346458692);b=v[23588];v[23588]=0;if((b|0)!=1){break ja}a=P()|0;O()|0;break k}v[23588]=0;b=Q(379,g|0,d+480|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}if(!b){break ga}if(Ib(x[d+510>>1])){break ga}b=x[d+480>>1];v[23588]=0;e=W(251,a|0,Ib(b)|0,0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break n}if(!e){break ga}b=Ib(x[d+480>>1]);if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=b}b=d+376|0;Ii(b,3,k);v[23588]=0;R(222,d+56|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break ia}b=d+56|0;Dc(e+492|0,b);zb(b);t[e+33|0]=2;if((qe(u[d+514>>1])|0)>0){t[e+15|0]=w[e+15|0]|1;f=qe(u[d+514>>1]);b=f>>>24|0;j=(f<<8&-256)+2047|0;f=b&255;H=e,I=Ec(Rka(j,j>>>0<2047?f+1|0:f,4095,0),nb),v[H+8>>2]=I}j=e+108|0;i=e+236|0;b=0;while(1){ka:{v[d+56>>2]=128;v[d+376>>2]=128;f=b&255;if(f>>>0>=y[Kb(d+56|0,d+376|0)>>2]){v[23588]=0;R(380,d+56|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break ka}H=d,I=Gi(v[d+56>>2]),v[H+376>>2]=I;f=xf(d+56|0);while(1){b=v[d+376>>2];if(Pb(b,f)){b=x[ro(b)>>1];if(!(!b|b>>>0>x[p>>1])){H=(B(b,104)+a|0)+484410|0,I=Ib(x[d+512>>1]),u[H>>1]=I}Lg(d+376|0);continue}break}ru(d+56|0);Mj(e,127,1);Lj(e,0,1);b=Ib(x[d+530>>1]);if(!b){v[e>>2]=0;b=x[d+516>>1];v[23588]=0;X(381,e|0,0,Ib(b)|0,d+848|0);b=v[23588];v[23588]=0;if((b|0)==1){break n}b=x[d+520>>1];v[23588]=0;X(381,e|0,1,Ib(b)|0,d+816|0);b=v[23588];v[23588]=0;if((b|0)==1){break n}b=x[d+518>>1];v[23588]=0;X(381,e|0,2,Ib(b)|0,d+832|0);b=v[23588];v[23588]=0;if((b|0)!=1){break ga}break n}v[23588]=0;U(382,g|0,d+376|0,((b|0)==1?98:102)|0);b=v[23588];v[23588]=0;la:{ma:{na:{if((b|0)!=1){b=Ib(x[d+376>>1]);j=b&1;if(!j){break ha}f=b&24;if(f){break na}f=0;break ma}a=P()|0;O()|0;break m}if((f|0)!=8){break la}f=1}t[e+25|0]=f}oa:{pa:{qa:{ra:{if(!(b&2)){break ra}v[23588]=0;b=W(383,d+360|0,l|0,24)|0;f=v[23588];v[23588]=0;if((f|0)==1){break qa}v[23588]=0;z=+la(384,b|0);f=v[23588];v[23588]=0;if((f|0)==1){break pa}zb(b);if(!(z>20)){break ra}Mj(e,aB(v[q>>2],z),1)}if(Ib(x[d+376>>1])&4){break oa}break ha}a=P()|0;O()|0;break m}a=P()|0;O()|0;zb(b);break m}v[23588]=0;b=W(383,d+344|0,n|0,24)|0;f=v[23588];v[23588]=0;sa:{if((f|0)!=1){v[23588]=0;z=+la(384,b|0);f=v[23588];v[23588]=0;if((f|0)==1){break sa}zb(b);Lj(e,tk(z*127/24),1);break ha}a=P()|0;O()|0;break m}a=P()|0;O()|0;zb(b);break m}else{o=(d+480|0)+(f<<1)|0;H=dc(i,f),I=w[o+52|0],u[H>>1]=I;f=Lb(j,f);H=f,I=Cl(t[o+53|0]+w[f|0]|0),t[H|0]=I;b=b+1|0;continue}}break}a=P()|0;O()|0;break m}b=v[d+380>>2];e=v[d+376>>2];v[23588]=0;g=a+484344|0;R(225,g|0,Cf(e,b)&65535);b=v[23588];v[23588]=0;ta:{if((b|0)!=1){v[d+48>>2]=v[a+480204>>2];v[d+40>>2]=v[a+480196>>2];H=d,I=Fb(v[d+376>>2]),v[H+8>>2]=I;o=c&1;b=d+56|0;r=b|4;A=b|2;C=b|1;D=Fb(v[d+380>>2]);E=a+480188|0;while(1){ua:{va:{wa:{xa:{ya:{za:{b=v[d+8>>2];if(!Pb(b,D)){v[23588]=0;U(367,d+56|0,d+864|0,1414414669);b=v[23588];v[23588]=0;if((b|0)!=1){break za}a=P()|0;O()|0;break ta}if(!o){break ua}c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,24)|0;e=v[23588];v[23588]=0;if((e|0)==1){break ya}if(!c){break ua}v[23588]=0;j=S(271,b|0)|0;c=v[23588];v[23588]=0;Aa:{Ba:{Ca:{Da:{if((c|0)!=1){t[d+496|0]=0;v[d+488>>2]=0;v[d+492>>2]=0;v[d+480>>2]=0;v[d+484>>2]=0;v[23588]=0;R(385,b|0,d+480|0);c=v[23588];v[23588]=0;if((c|0)==1){break Da}v[23588]=0;p=S(271,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ca}v[23588]=0;n=S(271,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Ba}v[23588]=0;l=S(271,b|0)|0;c=v[23588];v[23588]=0;Ea:{if((c|0)==1){break Ea}c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,B(B(l,n),5)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Ea}if(!(c&p>>>0<2)){break ua}v[23588]=0;c=W(226,g|0,j|0,n|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Ea}if(!c){break ua}c=v[g>>2];v[23588]=0;R(386,Zb(c,j)|0,d+480|0);c=v[23588];v[23588]=0;if((c|0)!=1){break Aa}}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}t[d+24|0]=0;c=ee(d+56|0,0,d+24|0);v[23588]=0;c=W(363,d+800|0,l|0,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break va}e=0;Fa:while(1){if((e|0)==(n|0)){od(c);break ua}f=0;k=Zb(v[g>>2],j);F=Df(v[k>>2],v[v[k+48>>2]+12>>2],e);while(1){if((f|0)==(l|0)){e=e+1|0;continue Fa}h=ug(d+56|0);q=x[E>>1];v[23588]=0;R(387,b|0,d+24|0);k=v[23588];v[23588]=0;Ga:{if((k|0)==1){break Ga}k=B(f,6)+F|0;i=h;h=f>>>0<q>>>0;q=h?k:i;i=w[d+24|0];if((i-1&255)>>>0<=119){i=i+1|0;t[q|0]=i;H=dc(v[c>>2],f),I=i,t[H|0]=I}i=w[d+25|0];if(i){t[(h?k+1|0:C)|0]=i;H=dc(v[c>>2],f),I=i,t[H+1|0]=I}i=w[d+28|0];if(i){t[(h?k+2|0:A)|0]=1;t[(h?k+4|0:r)|0]=p?i-16|0:i>>>2|0}k=w[d+947|0];h=w[d+27|0];i=w[d+26|0];s=dc(v[c>>2],f);G=w[s+1|0];s=w[s|0];v[23588]=0;Da(365,a|0,q|0,i|0,h|0,k|0,s|0,G|0,d+48|0,d+40|0);k=v[23588];v[23588]=0;if((k|0)==1){break Ga}f=f+1|0;continue}break}break}a=P()|0;O()|0;od(c);break ta}v[23588]=0;b=W(156,v[d+56>>2],v[d+64>>2],38)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(!b){break wa}v[23588]=0;b=S(271,d+56|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break xa}c=d+480|4;e=a+480188|0;f=0;Ha:{while(1){if(b>>>0<=(f&65535)>>>0){break wa}v[23588]=0;g=W(156,v[d+56>>2],v[d+64>>2],36)|0;j=v[23588];v[23588]=0;Ia:{if((j|0)!=1){if(g){break Ia}break wa}break xa}v[23588]=0;R(388,d+56|0,d+480|0);g=v[23588];v[23588]=0;if((g|0)!=1){Ja:{if(Ib(x[d+480>>1])){break Ja}if(Ib(x[d+482>>1])>>>0>=x[e>>1]){break Ja}g=d+8|0;Ne(g,3,c);v[23588]=0;R(222,d+24|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break Ha}g=d+24|0;Hl(((Ib(x[d+482>>1])<<5)+a|0)+480289|0,g);zb(g)}f=f+1|0;continue}break}break xa}break xa}break xa}a=P()|0;O()|0;break ta}a=P()|0;O()|0;Bb(d+56|0);break ta}Bb(d+56|0);Vc(d+376|0);Vc(d+816|0);Vc(d+832|0);Vc(d+848|0);f=1;break s}a=P()|0;O()|0;break ta}Nf(d+8|0);continue}}a=P()|0;O()|0}Vc(d+376|0);break k}a=P()|0;O()|0;break m}f=0;while(1){if(w[d+477|0]<=f>>>0){break ga}v[23588]=0;R(389,g|0,d+56|0);b=v[23588];v[23588]=0;Ka:{La:{if((b|0)!=1){v[d+8>>2]=33620480;H=d,I=(Ib(x[d+516>>1])|0)!=0,t[H+48|0]=I;H=d,I=(Ib(x[d+518>>1])|0)!=0,t[H+49|0]=I;H=d,I=(Ib(x[d+520>>1])|0)!=0,t[H+50|0]=I;H=d,I=j&(Ib(x[d+522>>1])|0)!=0,t[H+51|0]=I;if(!w[(d+48|0)+f|0]|f>>>0>3){break Ka}b=(f|0)!=3;if(!b&(t[e+100|0]&1)){break Ka}v[23588]=0;i=w[(d+8|0)+f|0];U(390,d+56|0,e|0,i|0);o=v[23588];v[23588]=0;if((o|0)==1){break La}if(!b){t[e+100|0]=w[e+100|0]|16}Ma:{switch(i|0){case 0:if(Ib(x[d+68>>1])&1){b=Ib(x[d+66>>1])&32767}else{b=0}v[e>>2]=b;break Ka;case 2:break Ma;default:break Ka}}if(!(Ib(x[d+68>>1])&2)){break Ka}H=d,I=Ib(x[d+62>>1]),u[H+40>>1]=I;u[d+46>>1]=1;b=x[le(d+40|0,d+46|0)>>1];i=Ml(Ec(((Ib(x[d+58>>1])<<6|48)>>>0)/100|0,0));H=d,I=Ib(x[d+60>>1]),u[H+40>>1]=I;u[d+46>>1]=1;o=tg(256/x[le(d+40|0,d+46|0)>>1]|0);r=x[d+480>>1];A=x[d+64>>1];v[23588]=0;s=Ib(r);r=Ib(A);ma(391,a|0,s|0,w[(r>>>0<6?r:0)+26592|0],255/(b>>>0)|0,i|0,o|0);b=v[23588];v[23588]=0;if((b|0)!=1){break Ka}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}f=f+1|0;continue}}Nf(d+24|0);continue}}Zd(d+864|0);Bb(m)}kb=d+1184|0;return f|0}a=P()|0;O()|0}Vc(d+800|0);break k}a=P()|0;O()|0}Vc(d+816|0);break i}a=P()|0;O()|0}Vc(d+832|0);break g}a=P()|0;O()|0}Vc(d+848|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Bb(d+56|0)}Zd(d+864|0)}Bb(m)}T(a|0);L()}function naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,S=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0;m=kb-1152|0;kb=m;zc(b);a:{if(!ur(b,m+1128|0)){break a}if(!$L(m+1128|0)){break a}if(v[m+1136>>2]!=(Wg(v[b>>2])|0)){break a}if(v[m+1144>>2]!=(df(b)|0)){break a}if(!c){h=1;break a}d=m+1072|0;Ub(d,0,56);o=-2;b:{if(!d){break b}v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+8>>2]=0;o=v[d+32>>2];if(!o){v[d+32>>2]=1088;o=1088}if(!v[d+36>>2]){v[d+36>>2]=1089}e=ob[o|0](v[d+40>>2],1,43784)|0;o=-4;if(!e){break b}v[d+28>>2]=e;v[e+43780>>2]=1;v[e+10992>>2]=0;v[e+10996>>2]=0;v[e>>2]=0;v[e+11008>>2]=15;v[e+11e3>>2]=1;v[e+11004>>2]=0;o=0}if(o){break a}h=v[m+1144>>2];v[m+1068>>2]=h;H=v[m+1148>>2];R=sB(m+1056|0,H);c:{d:{while(1){if(!(!h|!H|(g|0)==1)){v[m+16>>2]=1024;g=m+16|0;S=v[Kb(g,m+1068|0)>>2];d=hc(m+24|0,m+32|0,S);h=v[d+4>>2];d=v[d>>2];v[23588]=0;Ok(165,g,b,d,h);g=v[23588];v[23588]=0;if((g|0)==1){break d}d=m+32|0;g=d;h=S;e=_^-1;while(1){if(h>>>0<4){while(1){if(h){e=v[(((w[g|0]^e)&255)<<2)+63136>>2]^e>>>8;h=h-1|0;g=g+1|0;continue}break}_=e^-1}else{e=v[(((w[g|0]^e)&255)<<2)+63136>>2]^e>>>8;e=e>>>8^v[(((e^w[g+1|0])&255)<<2)+63136>>2];e=e>>>8^v[(((e^w[g+2|0])&255)<<2)+63136>>2];e=e>>>8^v[(((e^w[g+3|0])&255)<<2)+63136>>2];h=h-4|0;g=g+4|0;continue}break}v[m+1076>>2]=S;v[m+1072>>2]=d;v[m+1088>>2]=H;v[m+1084>>2]=v[R>>2]+$;D=kb-16|0;kb=D;g=-2;p=m+1072|0;e:{if(!p){break e}i=v[p+28>>2];if(!i){break e}ca=v[p+4>>2];v[i+11e3>>2]=0;f:{if(v[i+43780>>2]<0){break f}if(v[i+11004>>2]){break e}h=v[i+11008>>2];g=0;v[i+11004>>2]=0;d=v[i+10996>>2];if(!d){X=(h|0)>0?11:10;I=i+11012|0;e=v[p+4>>2];k=v[i+10992>>2];while(1){v[D+12>>2]=e;v[D+8>>2]=32768-k;C=v[p>>2];d=0;e=0;o=0;F=0;J=0;U=0;Y=0;Z=kb-144|0;kb=Z;g:{h:{G=k+I|0;if(G>>>0>=I>>>0){g=v[D+8>>2];V=g+((I^-1)+G|0)|0;r=V+1|0;if(!(r&V)){break h}}v[D+8>>2]=0;v[D+12>>2]=0;n=-3;break g}K=g+G|0;q=v[D+12>>2];A=q+C|0;M=v[i+60>>2];s=v[i+40>>2];g=v[i+36>>2];z=v[i+32>>2];h=v[i+56>>2];f=v[i+4>>2];n=-1;j=C;l=G;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{k=v[i>>2];switch(k|0){case 36:break k;case 39:break n;case 10:break o;case 35:break p;case 17:break q;case 21:break r;case 34:break s;case 42:break w;case 41:break x;case 53:break y;case 52:break z;case 51:break A;case 38:break B;case 27:break C;case 26:break D;case 25:break E;case 24:break F;case 23:break G;case 18:break H;case 16:break I;case 14:break J;case 11:break K;case 9:break L;case 7:break M;case 6:break N;case 3:break O;case 37:break P;case 32:break Q;case 5:break R;case 2:break S;case 1:break T;case 0:break U;default:break j}}v[i+28>>2]=1;h=0;v[i+8>>2]=0;v[i+12>>2]=0;v[i+16>>2]=1;s=0;g=0;z=0;f=0;if(X&1){break T}break v}if((q|0)<=0){v[i>>2]=1;break m}v[i+8>>2]=w[C|0];j=C+1|0}if(j>>>0>=A>>>0){v[i>>2]=2;n=1;break i}g=w[j|0];v[i+12>>2]=g;q=1;e=v[i+8>>2];if(!(((g|e<<8)>>>0)%31|g&32)){q=(e&15)!=8}j=j+1|0;k=36;g=256<<(e>>>4);if(g>>>0>32768|g>>>0>r>>>0){break l}g=0;if(q){break l}break v}if((q|0)<=0){v[i>>2]=5;break m}U=f+8|0;j=C+1|0;h=w[C|0]<<f|h;d=2;break v}if((q|0)<=0){v[i>>2]=32;break m}f=f+8|0;j=C+1|0;break u}k=37;break k}d=1;break v}d=4;break v}d=3;break v}d=7;break v}d=9;break v}d=10;break v}d=11;break v}d=12;break v}d=13;break v}d=14;break v}d=15;break v}d=16;break v}d=17;break v}d=8;break v}d=5;break v}d=6;break v}d=18;break v}k=2;break t}k=1;break t}V:while(1){W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{switch(d|0){case 0:if(f>>>0>2){break Ba}d=1;continue;case 3:break za;case 2:break Aa;case 1:break Ca;case 9:break fa;case 10:break ga;case 11:break ha;case 12:break ia;case 13:break ja;case 14:break ka;case 15:break la;case 16:break ma;case 17:break na;case 8:break ta;case 7:break ua;case 6:break va;case 5:break wa;case 4:break ya;default:break oa}}while(1){if(j>>>0>=A>>>0){v[i>>2]=3;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}}d=h&7;v[i+20>>2]=d;k=d>>>1|0;v[i+24>>2]=k;f=f-3|0;h=h>>>3|0;if(d>>>0>=2){break sa}U=f;break pa}f=U&-8;h=h>>>(U&7)|0;g=0;d=0;break ra}if(j>>>0<A>>>0){break xa}v[i>>2]=7;n=1;break i}while(1){if(j>>>0>=A>>>0){v[i>>2]=6;n=1;break i}h=w[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}d=1;break ra}t[(g+i|0)+10528|0]=w[j|0];j=j+1|0;d=2;break ra}while(1){if(j>>>0>=A>>>0){v[i>>2]=51;n=1;break i}h=w[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}break Z}if(l>>>0<K>>>0){t[l|0]=z;g=g-1|0;l=l+1|0;break _}n=2;k=52;break k}if(l>>>0<K>>>0){break qa}n=2;k=9;break k}if(j>>>0<A>>>0){d=K-l|0;e=A-j|0;d=d>>>0<e>>>0?d:e;d=d>>>0<g>>>0?d:g;g=g-d|0;l=uc(l,j,d)+d|0;j=d+j|0;break Y}v[i>>2]=38;n=1;break i}e=0;Da:{switch(k-1|0){case 0:v[i+44>>2]=288;v[i+48>>2]=32;d=i+3552|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3560|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3568|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3576|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i- -64|0;k=0;while(1){e=144;if((k|0)==144){while(1){k=256;if((e|0)==256){while(1){e=280;if((k|0)==280){while(1){if((e|0)==288){break ca}t[d|0]=8;e=e+1|0;d=d+1|0;continue}}else{t[d|0]=7;k=k+1|0;d=d+1|0;continue}}}else{t[d|0]=9;e=e+1|0;d=d+1|0;continue}}}else{t[d|0]=8;k=k+1|0;d=d+1|0;continue}};case 2:break o;default:break Da}}d=0;break ea}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{switch(d|0){case 0:if(g>>>0>3){break Ha}if(!f){f=0;d=3;continue V}if(f>>>0>7){break Fa}d=4;continue V;case 1:t[(g+i|0)+10528|0]=h;f=f-8|0;h=h>>>8|0;break Ea;default:break Ia}}g=g+1|0;break Ga}g=x[i+10528>>1];if((g|0)==(x[i+10530>>1]^65535)){break _}break n}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(l>>>0>=K>>>0){n=2;k=53;break k}t[l|0]=w[(M-z&V)+I|0];l=l+1|0;M=M+1|0;d=7;break $}while(1){if(j>>>0>=A>>>0){v[i>>2]=27;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;if(s>>>0>f>>>0){continue}break}d=6;break $}if(j>>>0>=A>>>0){v[i>>2]=26;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;d=4;if(f>>>0<15){break $}d=5;break $}while(1){if(j>>>0>=A>>>0){v[i>>2]=25;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;if(s>>>0>f>>>0){continue}break}d=3;break $}if(l>>>0>=K>>>0){n=2;k=24;break k}t[l|0]=g;l=l+1|0;break aa}if(j>>>0>=A>>>0){v[i>>2]=23;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;d=0;if(f>>>0<15){break $}d=1;break $}while(1){if(j>>>0>=A>>>0){v[i>>2]=18;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;if(s>>>0>f>>>0){continue}break}Y=z-16|0;d=3;break ba}if(j>>>0>=A>>>0){v[i>>2]=16;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;d=1;if(f>>>0<15){break ba}d=2;break ba}while(1){if(j>>>0>=A>>>0){v[i>>2]=14;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}d=1;break da}d=g+21600|0;while(1){if(j>>>0>=A>>>0){v[i>>2]=11;n=1;break i}h=w[j|0]<<f|h;j=j+1|0;f=f+8|0;J=t[d|0];if(f>>>0<J>>>0){continue}break}e=g;d=1}while(1){Ja:{Ka:{La:{if(!d){if(e>>>0>2){break La}g=e;J=t[e+21600|0];if(J>>>0<=f>>>0){break Ja}d=9;continue V}g=e<<2;v[(g+i|0)+44>>2]=v[g+64672>>2]+((-1<<J^-1)&h);e=e+1|0;f=f-J|0;h=h>>>J|0;break Ka}g=0;Ub(i+7040|0,0,288);d=0;break da}d=0;continue}d=1;continue}}while(1){Ma:{Na:{Oa:{if(!d){if(y[i+52>>2]<=g>>>0){break Oa}if(f>>>0>2){break Ma}d=10;continue V}t[(w[g+64688|0]+i|0)+7040|0]=h&7;g=g+1|0;f=f-3|0;h=h>>>3|0;break Na}v[i+52>>2]=19;break ca}d=0;continue}d=1;continue}}F=v[i+24>>2];d=0}while(1){Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{switch(d|0){case 0:d=0;if((F|0)<0){break aa}N=Ub(Z,0,64);e=B(F,3488)+i|0;Ub(e+352|0,0,3200);ba=e- -64|0;E=v[i+24>>2];e=v[((E<<2)+i|0)+44>>2];while(1){if((d|0)!=(e|0)){k=(w[d+ba|0]<<2)+N|0;v[k>>2]=v[k>>2]+1;d=d+1|0;continue}break};v[N+64>>2]=0;v[N+68>>2]=0;r=0;d=1;k=0;while(1){if((d|0)!=16){q=d<<2;d=d+1|0;q=v[q+N>>2];k=q+k<<1;v[(N- -64|0)+(d<<2)>>2]=k;r=q+r|0;continue}break};Q=0;q=-1;if((k|0)!=65536&r>>>0>=2){break p}while(1){if(e>>>0>Q>>>0){r=w[Q+ba|0];Ya:{if(!r){break Ya}d=(N- -64|0)+(r<<2)|0;k=v[d>>2];v[d>>2]=k+1;d=0;e=r;while(1){if(e){d=k&1|d<<1;k=k>>>1|0;e=e-1|0;continue}break}if(r>>>0<=10){e=1<<r;k=r<<9|Q;r=B(F,3488)+i|0;while(1){if(d>>>0>1023){break Ya}u[(r+(d<<1)|0)+352>>1]=k;d=d+e|0;continue}}E=B(F,3488)+i|0;k=E+((d&1023)<<1)|0;e=u[k+352>>1];Za:{if(e){k=q;q=e;break Za}u[k+352>>1]=q;k=q-2|0}d=d>>>9|0;while(1){d=d>>>1|0;e=d&1;if(r>>>0>=12){e=(E+(e+(q^-1)<<1)|0)+2400|0;q=u[e>>1];if(!q){u[e>>1]=k;q=k;k=k-2|0}r=r-1|0;continue}break}u[((B(F,3488)+i|0)+(e+(q^-1)<<1)|0)+2400>>1]=Q;q=k}Q=Q+1|0;E=v[i+24>>2];e=v[((E<<2)+i|0)+44>>2];continue}break};d=0;if((E|0)!=2){break Qa}break Ua;case 1:d=u[(((h&1023)<<1)+i|0)+7328>>1];_a:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break _a}break Ta}if(f>>>0<11){break _a}e=10;while(1){d=u[(((h>>>e&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break Ta}}d=11;continue V;case 2:e=u[(((h&1023)<<1)+i|0)+7328>>1];if((e|0)>=0){break Wa}d=10;while(1){k=h>>>d|0;d=d+1|0;e=u[(((k&1)+(e^-1)<<1)+i|0)+9376>>1];if((e|0)<0){continue}break};z=e&65535;break Va;default:break Xa}}d=t[Y+17809|0]+((-1<<s^-1)&h)|0;f=f-s|0;h=h>>>s|0;e=g+i|0;Ub(e+10532|0,(z|0)==16?w[e+10531|0]:0,d);d=d+g|0;break Ua}d=e>>9;z=e&511}f=f-d|0;h=h>>>d|0;if(z>>>0>15){break Sa}t[(g+i|0)+10532|0]=z;d=g+1|0}e=v[i+48>>2];g=v[i+44>>2];k=e+g|0;if(k>>>0<=d>>>0){break Ra}if(f>>>0<=14){if((A-j|0)<=1){g=d;d=1;continue}h=w[j|0]<<f|h|w[j+1|0]<<f+8;j=j+2|0;f=f+16|0}g=d}d=2;continue}if(!((z|0)!=16|g)){g=0;z=16;break q}Y=z-16|0;s=t[z+21575|0];if(s>>>0<=f>>>0){break Pa}d=12;continue V}if((d|0)!=(k|0)){g=d;break r}k=i+10532|0;uc(i- -64|0,k,g);uc(i+3552|0,g+k|0,e);E=v[i+24>>2];g=d}F=E-1|0;v[i+24>>2]=F;d=0;continue}d=3;continue}}o=h;d=2}$a:while(1){ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{switch(d|0){case 0:d=u[(((h&1023)<<1)+i|0)+352>>1];pb:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break pb}break ab}if(f>>>0<11){break pb}e=10;while(1){d=u[(((h>>>e&1)+(d^-1)<<1)+i|0)+2400>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break ab}}d=13;continue V;case 1:e=u[(((h&1023)<<1)+i|0)+352>>1];if((e|0)>=0){break nb}d=10;while(1){g=h>>>d|0;d=d+1|0;e=u[(((g&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break};g=e&65535;break mb;case 3:break db;case 4:break eb;case 5:break ib;case 6:break jb;case 2:break ob;default:break kb}}while(1){d=A-j|0;if(!((K-l|0)>1&(d|0)>=4)){if(f>>>0>14){h=o;break ab}if((d|0)<=1){h=o;d=0;continue $a}h=w[j|0]<<f|o|w[j+1|0]<<f+8;f=f+16|0;j=j+2|0;break ab}if(f>>>0>14){k=j}else{o=(w[j|0]|w[j+1|0]<<8)<<f|o;f=f+16|0;k=j+2|0}g=u[(((o&1023)<<1)+i|0)+352>>1];qb:{if((g|0)<0){d=10;while(1){h=o>>>d|0;d=d+1|0;g=u[(((h&1)+(g^-1)<<1)+i|0)+2400>>1];if((g|0)<0){continue}break}g=g&65535;break qb}d=g>>9}f=f-d|0;h=o>>>d|0;if(g&256){j=k;break lb}if(!(f>>>0>14)){h=(w[k|0]|w[k+1|0]<<8)<<f|h;k=k+2|0;f=f+16|0}r=f;j=k;e=u[(((h&1023)<<1)+i|0)+352>>1];rb:{if((e|0)<0){d=10;while(1){o=h>>>d|0;d=d+1|0;e=u[(((o&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break}e=e&65535;break rb}d=e>>9}t[l|0]=g;f=r-d|0;o=h>>>d|0;if(!(e&256)){t[l+1|0]=e;l=l+2|0;continue}break}l=l+1|0;h=o;g=e;break lb}d=e>>9;g=e&511}f=f-d|0;h=h>>>d|0;if(g>>>0>255){break lb}d=14;continue V}e=g&511;g=256;if((e|0)==256){break X}d=e-257<<2;g=v[d+64160>>2];s=0;if(e-285>>>0<4294967276){break cb}s=v[d+64288>>2];if(s>>>0>f>>>0){d=15;continue V}d=3;continue}if(!g){o=h;g=-1;break gb}g=g-1|0;d=18;continue V}f=f-s|0;o=h>>>s|0;z=((-1<<s^-1)&h)+z|0;break hb}e=u[(((h&1023)<<1)+i|0)+3840>>1];sb:{if((e|0)<0){d=10;while(1){k=h>>>d|0;d=d+1|0;e=u[(((k&1)+(e^-1)<<1)+i|0)+5888>>1];if((e|0)<0){continue}break}e=e&65535;break sb}d=e>>9;e=e&511}f=f-d|0;h=h>>>d|0;d=e<<2;z=v[d+64416>>2];s=0;if(e-30>>>0<4294967270){o=h;break hb}s=v[d+64544>>2];if(s>>>0<=f>>>0){break fb}d=17;continue V}M=l-I|0;d=(M-z&V)+I|0;if((d>>>0<l>>>0?l:d)+g>>>0>K>>>0){h=o;d=7;continue}while(1){if(g>>>0>=3){t[l|0]=w[d|0];t[l+1|0]=w[d+1|0];t[l+2|0]=w[d+2|0];g=g-3|0;d=d+3|0;l=l+3|0;continue}break}if(!g){g=0;break gb}t[l|0]=w[d|0];if((g|0)!=1){t[l+1|0]=w[d+1|0]}l=g+l|0}d=2;continue}d=6;continue}d=u[(((h&1023)<<1)+i|0)+3840>>1];tb:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break tb}break bb}if(f>>>0<11){break tb}e=10;while(1){d=u[(((h>>>e&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break bb}}d=16;continue V}f=f-s|0;g=((-1<<s^-1)&h)+g|0;h=h>>>s|0}if(f>>>0>14){break bb}if((A-j|0)<=1){d=4;continue}h=w[j|0]<<f|h|w[j+1|0]<<f+8;f=f+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!g|!f){break Y}if(f>>>0>7){break Z}d=5;continue}f=f-8|0;z=h&255;h=h>>>8|0;d=6;continue}if(g){break W}g=0}if(t[i+20|0]&1){break u}d=0;continue}d=7;continue}}h=0;d=f>>>3|0;e=j-C|0;e=e>>>0>j>>>0?0:e;d=d>>>0<e>>>0?d:e;if((f&-8)==d<<3){j=j-d|0;e=0;d=0;f=0;if(!(X&1)){break s}k=0;break t}aa(6842,13088,2797,6852);L()}while(1){ub:{vb:{wb:{xb:{yb:{zb:{switch(k|0){case 0:if(e>>>0>3){g=e;f=d;break s}f=0;if(d){break yb}g=e;k=1;continue;case 1:break zb;default:break xb}}if(j>>>0<A>>>0){break vb}v[i>>2]=42;n=1;break i}g=e;f=d;if(d>>>0>7){break wb}k=2;continue}while(1){if(j>>>0>=A>>>0){v[i>>2]=41;n=1;break i}h=w[j|0]<<f|h;e=f>>>0>4294967287;j=j+1|0;d=f+8|0;f=d;if(e){continue}break}e=g}k=h&255;h=h>>>8|0;d=d-8|0;break ub}k=w[j|0];j=j+1|0;e=g;d=f}v[i+16>>2]=v[i+16>>2]<<8|k;e=e+1|0;k=0;continue}}n=0;k=34;break k}k=21;break k}k=17;break k}k=35;break k}k=10;break k}k=39;break k}n=1;break i}g=1}v[i>>2]=k}d=f>>>3|0;e=j-C|0;e=e>>>0>j>>>0?0:e;d=d>>>0<e>>>0?d:e;j=j-d|0;f=f-(d<<3)|0}v[i+4>>2]=f;v[i+60>>2]=M;v[i+40>>2]=s;v[i+36>>2]=g;v[i+32>>2]=z;v[i+56>>2]=(((f&63)>>>0>=32?0:-1<<f)^-1)&h;v[D+12>>2]=j-C;h=l-G|0;v[D+8>>2]=h;if((n|0)<0){break g}f=(h>>>0)%5552|0;g=v[i+28>>2];e=g>>>16|0;k=g&65535;while(1){j=0;if(h){d=G;while(1){if((j|7)>>>0<f>>>0){g=w[d|0]+k|0;o=g+w[d+1|0]|0;q=o+w[d+2|0]|0;r=q+w[d+3|0]|0;l=r+w[d+4|0]|0;z=l+w[d+5|0]|0;C=z+w[d+6|0]|0;k=C+w[d+7|0]|0;e=k+(C+(z+(l+(r+(q+(o+(e+g|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;j=j+8|0;continue}break}j=f&8184;while(1){if((f|0)!=(j|0)){j=j+1|0;k=w[d|0]+k|0;e=k+e|0;d=d+1|0;continue}break}h=h-f|0;e=(e>>>0)%65521|0;k=(k>>>0)%65521|0;G=f+G|0;f=5552;continue}break}g=e<<16|k;v[i+28>>2]=g;if(n){break g}n=0;if(!(X&1)){break g}n=(g|0)==v[i+16>>2]?0:-2}kb=Z+144|0;v[i+43780>>2]=n;g=v[D+12>>2];v[p>>2]=g+v[p>>2];v[p+4>>2]=v[p+4>>2]-g;v[p+8>>2]=g+v[p+8>>2];v[p+48>>2]=v[i+28>>2];g=v[D+8>>2];v[i+10996>>2]=g;d=v[p+16>>2];d=d>>>0>g>>>0?g:d;uc(v[p+12>>2],v[i+10992>>2]+I|0,d);v[p+12>>2]=d+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-d;v[p+20>>2]=d+v[p+20>>2];h=v[i+10996>>2];v[i+10996>>2]=h-d;k=d+v[i+10992>>2]&32767;v[i+10992>>2]=k;if((n|0)<0){break f}if(!((n|0)!=1|ca)){g=-5;break e}if(n){g=0;e=v[p+4>>2];if(!e|!v[p+16>>2]){break e}if((d|0)==(h|0)){continue}break e}break}g=(d|0)==(h|0);break e}h=v[p+16>>2];d=d>>>0<h>>>0?d:h;uc(v[p+12>>2],(v[i+10992>>2]+i|0)+11012|0,d);v[p+12>>2]=d+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-d;v[p+20>>2]=d+v[p+20>>2];h=v[i+10996>>2];v[i+10996>>2]=h-d;v[i+10992>>2]=d+v[i+10992>>2]&32767;if(v[i+43780>>2]){break e}g=(d|0)==(h|0);break e}g=-3}kb=D+16|0;h=v[m+1068>>2]-S|0;v[m+1068>>2]=h;d=H+$|0;H=v[m+1088>>2];$=d-H|0;continue}break}b=m+1072|0;Ab:{if(!b){break Ab}d=v[b+28>>2];if(!d){break Ab}ob[v[b+36>>2]](v[b+40>>2],d);v[b+28>>2]=0}h=0;Bb:{Cb:{if(!(v[m+1140>>2]!=(_|0)|H|(g|0)!=1)){se(m+8|0,v[R>>2],v[R+4>>2]);b=fe(m);g=v[b+4>>2];b=v[b>>2];v[23588]=0;b=Fg(540,m+32|0,v[m+8>>2],v[m+12>>2],b,g);g=v[23588];v[23588]=0;if((g|0)==1){break Cb}v[23588]=0;h=W(870,a|0,b|0,c|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break Bb}Bb(b)}ic(R);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Bb(b);break c}a=P()|0;O()|0}ic(R);T(a|0);L()}kb=m+1152|0;return h|0}function Sga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=C(0),Q=0,R=C(0),S=0,U=0,X=0,Y=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=C(0),ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=C(0);p=kb-11360|0;kb=p;zc(c);a:{while(1){b:{if(!Qb(v[c>>2],v[c+8>>2],4)){break b}e=p+16|0;d=kb-16|0;kb=d;c:{if(!Qb(v[c>>2],v[c+8>>2],3)){f=0;while(1){if((f|0)!=3){Dh(e+f|0);f=f+1|0;continue}break}break c}yv(d+8|0,e);ud(d,c,v[d+8>>2],v[d+12>>2])}kb=d+16|0;d:{e:{if(!Sb(e,14999,3)){e=p+4648|0;d=kb-16|0;kb=d;f:{if(!Qb(v[c>>2],v[c+8>>2],7)){f=0;while(1){if((f|0)!=7){Dh(e+f|0);f=f+1|0;continue}break}break f}Fo(d+8|0,e);ud(d,c,v[d+8>>2],v[d+12>>2])}kb=d+16|0;H=0;i=3;while(1){if((i|0)==7){break d}e=w[(p+4648|0)+i|0];if(e&128){break e}i=i+1|0;H=e|H<<7;continue}}g:{if(Sb(p+16|0,14152,3)){break g}if(!dS(c,13474)){break g}_b(c,Cg(c)+16|0);continue}if(!Sb(p+16|0,30222,3)){continue}if(!Sb(p+16|0,30226,3)){continue}if(!w[p+16|0]){zg(c,2);continue}if(LP(p+16|0)){break b}}i=0;break a}_b(c,H);continue}break}zc(c);e=p+11336|0;MA(e,c);ca=v[p+11336>>2];Y=Je(e);X=Tb(p+11320|0);c=p+4648|0;Ub(c,0,6668);gz(c);c=p+4640|0;v[c>>2]=0;v[c+4>>2]=0;c=p+4632|0;v[c>>2]=0;v[c+4>>2]=0;v[p+4624>>2]=0;v[p+4628>>2]=0;H=0;c=0;h:{while(1){d=Ic(ca,da);aa=p+16|0;I=p+4624|0;e=0;n=kb-17168|0;kb=n;v[n+17164>>2]=0;i:{j:{E=p+4648|0;k:{if(w[E+6152|0]!=255|(d|0)<5){break k}if(!up(E+6152|0,Y)){break k}i=ox(w[Y+1|0],w[Y+2|0],v[E+6148>>2])+tp(Y)|0;v[n+17164>>2]=i;if((d|0)==(i|0)){i=d;break j}l:{if((d|0)>=(i+4|0)){if(up(Y,i+Y|0)){break l}}v[n+17164>>2]=0;break k}if(i){break j}}f=Y;J=Ub(E,0,6668)+6148|0;$=n+17164|0;i=0;j=0;D=d-4|0;q=(D|0)>0?D:0;while(1){m:{n:{o:{p:{if((i|0)==(q|0)){i=d;break p}if(!tI(f)){break n}h=ox(w[f+1|0],w[f+2|0],v[J>>2]);e=h+tp(f)|0;g=4;o=i+4|0;q:{while(1){if(!(g>>>0>2303|h)){if((D|0)<=((g<<1)+i|0)){break q}h=0;m=f+g|0;r:{if(!up(f,m)){break r}k=g-tp(f)|0;y=tp(m)+k|0;if((d|0)<(y+(g+o|0)|0)){break r}if(!up(f,m+y|0)){break r}v[J>>2]=k;h=k;e=g}g=g+1|0;continue}break}if(!h|(d|0)<(e+i|0)){break q}y=d-i|0;g=0;A=0;while(1){s:{t:{if((A|0)!=10){k=(A|0)!=0;F=g;g=f+g|0;g=(F+ox(w[g+1|0],w[g+2|0],h)|0)+tp(g)|0;if((y|0)<(g+4|0)){break s}if(up(f,f+g|0)){break t}k=0}else{k=1}break s}A=A+1|0;continue}break}if(!k){break q}j=e;break p}if((e|0)!=(d|0)|i){break o}i=0;j=d}v[$>>2]=j;e=i;break m}v[J>>2]=0}f=f+1|0;i=i+1|0;continue}break}i=v[n+17164>>2];if((d|0)>=(e+i|0)?i:0){break j}v[I>>2]=e;A=0;break i}d=e+Y|0;v[E+6152>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[I+4>>2]=e;v[I>>2]=e+i;v[I+8>>2]=w[d+3|0]>191?1:2;qa=I,ra=wI(w[d+1|0],w[d+2|0]),v[qa+12>>2]=ra;v[I+16>>2]=4-(w[d+1|0]>>>1&3);qa=I,ra=nx(w[d+1|0],w[d+2|0]),v[qa+20>>2]=ra;if(!aa){A=mx(w[d+1|0]);break i}vI(n+17152|0,d+4|0,i-4|0);if(!(t[d+1|0]&1)){he(n+17152|0,16)}u:{if(v[I+16>>2]==3){A=0;m=n+17152|0;ja=n+3740|0;e=ja;f=0;g=w[d+1|0];i=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[d+2|0]>>>2&3)|0;j=i-((i|0)!=0)|0;$=d;d=w[d+3|0]>191?1:2;v:{if(g&8){i=he(m,9);d=d<<1;f=he(m,d+7|0);break v}i=he(m,d|8)>>>d|0}g=B(j,40);q=g+65008|0;o=g+65328|0;y=B(j,23)+64816|0;l=-1;h=0;w:{while(1){j=w[$+3|0];k=he(m,12);u[e+4>>1]=k;g=he(m,9);u[e+6>>1]=g;if((g&65535)>>>0>288){break w}g=j>>>0>191?f<<4:f;qa=e,ra=he(m,8),t[qa+10|0]=ra;f=he(m,w[$+1|0]&8?4:9);t[e+13|0]=22;t[e+14|0]=0;v[e>>2]=y;u[e+8>>1]=f;x:{if(he(m,1)){f=he(m,2);t[e+11|0]=f;if(!(f&255)){break w}f=he(m,1);u[e+18>>1]=65287;t[e+12|0]=f;if(w[e+11|0]==2){y:{if(!(f&255)){v[e>>2]=q;t[e+18|0]=8;j=39;f=0;break y}v[e>>2]=o;j=30;f=w[$+1|0]&8?8:6}t[e+14|0]=j;t[e+13|0]=f;g=g&3855}f=he(m,10);qa=e,ra=he(m,3),t[qa+21|0]=ra;qa=e,ra=he(m,3),t[qa+22|0]=ra;qa=e,ra=he(m,3),t[qa+23|0]=ra;f=f<<5;break x}t[e+11|0]=0;t[e+12|0]=0;f=he(m,15);qa=e,ra=he(m,4),t[qa+18|0]=ra;j=he(m,3);t[e+20|0]=255;t[e+19|0]=j}t[e+17|0]=f&31;t[e+15|0]=f>>>10;t[e+16|0]=f>>>5&31;h=(k&65535)+h|0;z:{if(w[$+1|0]&8){f=he(m,1);break z}f=x[e+8>>1]>499}t[e+24|0]=f;qa=e,ra=he(m,1),t[qa+25|0]=ra;f=he(m,1);t[e+27|0]=g>>>12&15;t[e+26|0]=f;e=e+28|0;f=g<<4;d=d-1|0;if(d){continue}break}l=(v[m+4>>2]+h|0)>(v[m+8>>2]+(i<<3)|0)?-1:i}if(!((l|0)<0|v[n+17156>>2]>v[n+17160>>2])){h=n+17152|0;i=v[h+4>>2];f=v[h+8>>2];d=n+912|0;g=v[E+6144>>2];e=g-l|0;j=(g|0)<(l|0)?g:l;g=uc(d+12|0,(((e|0)>0?e:0)+E|0)+6156|0,j);e=(f-i|0)/8|0;uc(g+j|0,v[h>>2]+(v[h+4>>2]/8|0)|0,e);vI(d,g,e+j|0);A:{i=v[E+6144>>2]>=(l|0);if(!i){break A}ma=E+2304|0;na=n+8620|0;oa=n+3852|0;while(1){if((w[$+1|0]&8?2:1)>>>0<=A>>>0){break A}pa=Ub(oa,0,4608);d=v[I+8>>2];K=B(B(d,A),28)+ja|0;e=0;ka=(d|0)>0?d:0;G=n+912|0;y=G+7548|0;ba=E+6152|0;while(1){if((e|0)!=(ka|0)){o=B(e,28)+K|0;J=x[o+4>>1];D=v[G+4>>2];d=(G+B(e,39)|0)+16156|0;h=y;q=e;j=kb-48|0;kb=j;ia=w[o+25|0];l=B(!w[o+13|0]+(w[o+14|0]!=0)|0,28)+65648|0;B:{if(w[ba+1|0]&8){e=w[o+27|0];g=w[x[o+8>>1]+65744|0];f=g&3;t[j+47|0]=f;t[j+46|0]=f;f=g>>>2|0;t[j+45|0]=f;t[j+44|0]=f;break B}e=(w[ba+3|0]&16)>>>4&(q|0)!=0;g=e?12:0;r=x[o+8>>1]>>>e|0;while(1){if((r|0)>=0){e=3;f=1;while(1){if((e|0)>=0){k=w[(e+g|0)+65760|0];t[(j+44|0)+e|0]=((r|0)/(f|0)|0)%(k|0);e=e-1|0;f=B(f,k);continue}break}g=g+4|0;r=r-f|0;continue}break}l=g+l|0;e=-16}g=d;f=j;m=f+44|0;r=0;while(1){C:{D:{E:{if((r|0)==4){break E}Q=w[l+r|0];if(!Q){break E}if(e&8){uc(f,g,Q);break D}fa=w[m+r|0];if(!fa){Ub(f,0,Q);Ub(g,0,Q);break D}d=(e|0)>=0?-1:-1<<fa^-1;k=0;while(1){if((k|0)==(Q|0)){break D}M=he(G,fa);t[g+k|0]=(d|0)==(M|0)?-1:M;t[f+k|0]=M;k=k+1|0;continue}}t[f+2|0]=0;t[f|0]=0;t[f+1|0]=0;break C}e=e<<1;r=r+1|0;f=f+Q|0;g=g+Q|0;continue}break}F:{f=w[o+14|0];if(f){e=2-ia|0;m=w[o+23|0]<<e;k=w[o+22|0]<<e;g=w[o+21|0]<<e;d=w[o+13|0];e=0;while(1){if(e>>>0>=f>>>0){break F}M=j+(e+d|0)|0;t[M|0]=g+w[M|0];t[M+1|0]=k+w[M+1|0];t[M+2|0]=m+w[M+2|0];e=e+3|0;continue}}if(!w[o+24|0]){break F}e=0;while(1){if((e|0)==10){break F}d=e+j|0;t[d+11|0]=w[d+11|0]+w[e+65784|0];e=e+1|0;continue}}d=ia+1|0;e=0;s=lx(C(2048),((((w[ba+3|0]&224)==96)<<1)-w[o+10|0]|0)+258|0);while(1){if(w[o+13|0]+(f&255)>>>0>e>>>0){qa=(e<<2)+h|0,sa=lx(s,w[e+j|0]<<d),z[qa>>2]=sa;e=e+1|0;f=w[o+14|0];continue}break}kb=j+48|0;k=(G+B(q,2304)|0)+2940|0;ia=D+J|0;s=C(0);e=v[G+4>>2];f=v[G>>2]+((e|0)/8|0)|0;d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))<<(e&7);l=e|-8;r=f+4|0;S=v[o>>2];U=x[o+6>>1];e=0;while(1){G:{H:{if((U|0)>0){j=e+1|0;e=e+o|0;d=w[e+15|0];fa=(u[(d<<1)+70208>>1]<<1)+65824|0;ga=w[e+18|0];if(d>>>0>=16){M=w[d+70272|0];m=32-M|0;while(1){J=w[S|0]>>>1|0;D=(J|0)>(U|0)?U:J;s=z[h>>2];while(1){e=g>>>27|0;d=5;while(1){e=u[fa+(e<<1)>>1];if((e|0)<0){g=g<<d;f=e&7;e=(g>>>32-f|0)-(e>>3)|0;l=d+l|0;d=f;continue}break}f=e&65535;e=f>>>8|0;l=e+l|0;g=g<<e;d=0;while(1){if((d|0)!=2){F=f&15;I:{if((F|0)==15){l=l+M|0;e=g<<M;while(1){if((l|0)>=0){e=w[r|0]<<l|e;r=r+1|0;l=l-8|0;continue}break}F=(g>>>m|0)+15|0;g=F;J:{if((g|0)<=128){N=z[(g<<2)+70368>>2];break J}ha=g<<3;Q=g;g=g>>>0<1024;ha=g?ha:Q;Q=ha<<1&64;R=C(C((ha&63)-Q|0)/C(Q+(ha&-64)|0));N=C((g?C(16):C(256))*C(C(C(R*C(C(R*C(.2222222238779068))+C(1.3333333730697632)))+C(1))*z[(Q+ha>>6<<2)+70368>>2]))}N=C(C(s*N)*C(e>>31|1));break I}e=g;N=C(s*z[(((e>>>27&16|F)^16)<<2)+70304>>2])}z[k>>2]=N;f=f>>>4|0;k=k+4|0;d=d+1|0;g=(F|0)!=0;l=g+l|0;g=e<<g;continue}break}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}D=D-1|0;if(D){continue}break}h=h+4|0;S=S+1|0;U=U-J|0;if((U|0)<=0){break H}e=(ga|0)>0;ga=ga-1|0;if(e){continue}break}break H}while(1){m=w[S|0]>>>1|0;F=(m|0)>(U|0)?U:m;s=z[h>>2];while(1){e=g>>>27|0;d=5;while(1){e=u[fa+(e<<1)>>1];if((e|0)<0){g=g<<d;f=e&7;e=(g>>>32-f|0)-(e>>3)|0;l=d+l|0;d=f;continue}break}d=e&65535;e=d>>>8|0;l=e+l|0;g=g<<e;e=0;while(1){if((e|0)!=2){f=d&15;z[k>>2]=s*z[(((f|g>>>27&16)^16)<<2)+70304>>2];d=d>>>4|0;k=k+4|0;e=e+1|0;f=(f|0)!=0;l=f+l|0;g=g<<f;continue}break}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}F=F-1|0;if(F){continue}break}h=h+4|0;S=S+1|0;U=U-m|0;if((U|0)<=0){break H}e=(ga|0)>0;ga=ga-1|0;if(e){continue}break}break H}d=1-U|0;while(1){K:{f=w[o+26|0]?70192:70160;e=w[f+(g>>>28|0)|0];if(!(e&8)){e=w[f+((g<<4>>>32-(e&3))+(e>>>3)|0)|0]}f=e&7;l=f+l|0;if((ia|0)<((l+(r-v[G>>2]<<3)|0)-24|0)){break K}d=d-1|0;if(!d){d=w[S|0];if(d>>>0<2){break K}S=S+1|0;s=z[h>>2];h=h+4|0;d=d>>>1|0}g=g<<f;if(e&128){z[k>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}if(e&64){z[k+4>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}d=d-1|0;if(!d){d=w[S|0];if(d>>>0<2){break K}S=S+1|0;s=z[h>>2];h=h+4|0;d=d>>>1|0}if(e&32){z[k+8>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}if(e&16){z[k+12>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}k=k+16|0;continue}break}v[G+4>>2]=ia;break G}e=j;continue}break}e=q+1|0;continue}break}e=w[E+6155|0];L:{if(e&16){D=kb-16|0;kb=D;e=G+2940|0;g=e+2304|0;q=v[K>>2];o=w[K+14|0];f=o+w[K+13|0]|0;d=0;m=D+4|0;v[m+8>>2]=-1;v[m>>2]=-1;v[m+4>>2]=-1;while(1){if((d|0)!=(f|0)){y=d+q|0;j=w[y|0];h=0;M:{while(1){if(h>>>0>=j>>>0){break M}k=h<<2;if(z[k+g>>2]==C(0)){h=h+2|0;if(z[(k|4)+g>>2]==C(0)){continue}}break}v[m+((d>>>0)%3<<2)>>2]=d;j=w[y|0]}d=d+1|0;g=(j<<2)+g|0;continue}break}if(w[K+13|0]){g=v[D+4>>2];d=v[D+8>>2];g=(d|0)<(g|0)?g:d;d=v[D+12>>2];d=(d|0)<(g|0)?g:d;v[D+12>>2]=d;v[D+8>>2]=d;v[D+4>>2]=d}m=G+16195|0;j=o?3:1;g=f-j|0;h=0;while(1){if((h|0)!=(j|0)){f=g+h|0;d=f-j|0;if((d|0)<=v[(D+4|0)+(h<<2)>>2]){d=w[ba+1|0]<<28>>31&3}else{d=w[d+m|0]}t[f+m|0]=d;h=h+1|0;continue}break}q=v[K>>2];o=D+4|0;y=u[K+36>>1]&1;g=0;k=w[ba+1|0]&8?7:64;while(1){j=g+q|0;d=w[j|0];if(d){f=w[ba+3|0]&32;N:{O:{if(v[o+((g>>>0)%3<<2)>>2]>=(g|0)){break O}h=w[g+m|0];if(h>>>0>=k>>>0){break O}N=f?C(1.4142135381698608):C(1);P:{if(w[ba+1|0]&8){f=h<<3;s=z[f+70900>>2];R=z[f+70896>>2];break P}R=lx(C(1),h+1>>>1<<y);f=h&1;s=f?C(1):R;R=f?R:C(1)}R=C(N*R);s=C(N*s);h=0;while(1){if((d|0)!=(h|0)){f=(h<<2)+e|0;N=z[f>>2];z[f+2304>>2]=N*s;z[f>>2]=N*R;h=h+1|0;continue}break}break N}if(!f){break N}sI(e,d)}g=g+1|0;e=(w[j|0]<<2)+e|0;continue}break}kb=D+16|0;break L}if((e&224)!=96){break L}sI(G+2940|0,576)}k=G+7708|0;e=0;while(1){if((e|0)!=(ka|0)){d=w[E+6153|0];q=(w[K+12|0]!=0)<<1<<((B((d>>>3&1)+(d>>>4&1)|0,3)+(w[E+6154|0]>>>2&3)|0)==2);j=(G+B(e,2304)|0)+2940|0;g=j;if(w[K+14|0]){r=v[K>>2]+w[K+13|0]|0;h=((G+B(e,2304)|0)+B(q,72)|0)+2940|0;d=h;f=k;while(1){o=w[r|0];if(o){y=o<<1;l=0;while(1){if((l|0)!=(o|0)){z[f>>2]=z[d>>2];z[f+4>>2]=z[(o<<2)+d>>2];z[f+8>>2]=z[(y<<2)+d>>2];d=d+4|0;l=l+1|0;f=f+12|0;continue}break}r=r+3|0;d=(y<<2)+d|0;continue}break}uc(h,k,f-k|0);f=q-1|0}else{f=31}while(1){d=0;if((f|0)>0){while(1){if((d|0)!=8){y=d<<2;h=y+g|0;la=z[h+72>>2];F=h;N=z[y+70960>>2];R=z[y+70992>>2];h=(17-d<<2)+g|0;s=z[h>>2];z[F+72>>2]=C(la*N)-C(R*s);z[h>>2]=C(la*R)+C(s*N);d=d+1|0;continue}break}g=g+72|0;f=f-1|0;continue}break}d=j;f=B(e,1152)+E|0;g=w[K+11|0];if(q){rI(d,f,71024,q);f=B(q,36)+f|0;d=B(q,72)+d|0}Q:{if((g|0)==2){h=32-q|0;m=kb-80|0;kb=m;q=m|8;o=m|4;while(1){if((h|0)>0){y=uc(m,d,72);g=v[f+20>>2];v[d+16>>2]=v[f+16>>2];v[d+20>>2]=g;g=v[f+12>>2];v[d+8>>2]=v[f+8>>2];v[d+12>>2]=g;g=v[f+4>>2];v[d>>2]=v[f>>2];v[d+4>>2]=g;g=f+24|0;kx(y,d+24|0,g);kx(o,d+48|0,g);kx(q,f,g);d=d+72|0;f=f+36|0;h=h-1|0;continue}break}kb=m+80|0;break Q}rI(d,f,B((g|0)==3,72)+71024|0,32-q|0)}h=0;f=j+72|0;while(1){d=1;if(h>>>0<=31){while(1){if(d>>>0<=17){g=(d<<2)+f|0;z[g>>2]=-z[g>>2];d=d+2|0;continue}break}f=f+144|0;h=h+2|0;continue}break}K=K+28|0;e=e+1|0;continue}break}uI(ma,pa,18,v[I+8>>2],aa,na);A=A+1|0;aa=B(v[I+8>>2],1152)+aa|0;continue}}g=n+912|0;d=v[g+8>>2]>>>3|0;e=v[g+4>>2]+7>>>3|0;j=d-e|0;f=(j|0)<511?j:511;if((j|0)>0){hj(E+6156|0,(g+(j>>>0>511?d-511|0:e)|0)+12|0,f)}v[E+6144>>2]=f;break u}gz(E);break i}q=n+17152|0;f=0;g=0;h=0;A=0;R:{S:{T:{e=d;d=w[d+3|0];i=d>>>6|0;switch(i-1|0){case 2:break R;case 0:break T;default:break S}}g=(d>>>2&12)+4|0;break R}g=32}k=w[e+1|0];U:{if((k&6)==6){i=72428;d=32;break U}if(!(k&8)){i=72431;d=30;break U}d=w[e+2|0];j=d>>>2&3;d=nx(k,d)>>>((i|0)!=3)|0;d=d?d:192;if(d>>>0<=55){i=72452;d=(j|0)==2?12:8;break U}i=72440;d=d>>>0>95?(j|0)!=1?30:27:27}t[n+768|0]=d;t[n+769|0]=(d|0)>(g|0)?g:d;d=i;j=72336;while(1){g=w[n+768|0];if(g>>>0<=f>>>0){f=0;while(1){j=g<<1&510;if(j>>>0>f>>>0){i=f+n|0;V:{if(!w[i+770|0]){d=6;break V}d=2;if((w[e+1|0]&6)==6){break V}d=he(q,2);g=w[n+768|0]}t[i+834|0]=d;f=f+1|0;continue}break}g=n+770|0;o=n+834|0;e=n;f=0;while(1){if((f|0)!=(j|0)){d=w[g|0];i=d?19>>>w[f+o|0]&3|4:0;g=g+1|0;y=B(d,3)-6|0;s=C(0);d=4;while(1){if(d){if(d&i){k=he(q,6);h=(k|0)/3|0;s=C(z[(y+(B(h,-3)+k|0)<<2)+72464>>2]*C(2097152>>>h|0))}z[e>>2]=s;d=d>>>1|0;e=e+4|0;continue}break}f=f+1|0;continue}break}f=w[n+769|0];e=w[n+768|0];e=e>>>0<f>>>0?f:e;while(1){if((e|0)!=(f|0)){t[((f<<1)+n|0)+771|0]=0;f=f+1|0;continue}break}}else{if((f|0)==(A|0)){j=w[d|0]+72336|0;A=w[d+2|0]+f|0;h=w[d+1|0];d=d+3|0}k=f<<1;g=w[he(q,h)+j|0];t[(k+n|0)+770|0]=g;i=w[n+769|0];if(i>>>0>f>>>0){g=w[he(q,h)+j|0];i=w[n+769|0]}t[((k|1)+n|0)+770|0]=i?g:0;f=f+1|0;continue}break}i=0;d=Ub(n+3852|0,0,4608);q=E+2304|0;o=n+8620|0;A=0;W:{while(1){if((A|0)==3){break W}y=d+(i<<2)|0;D=n+17152|0;j=0;J=v[I+16>>2]|1;m=(J|0)>0?J:0;l=576;while(1){if((j|0)!=4){f=y+(B(j,J)<<2)|0;g=0;while(1){if(w[n+768|0]<<1>>>0>g>>>0){X:{k=w[(g+n|0)+770|0];if(!k){break X}if(k>>>0<=16){h=(-1<<k-1)+1|0;e=0;while(1){if((e|0)==(m|0)){break X}qa=(e<<2)+f|0,sa=C(he(D,k)+h|0),z[qa>>2]=sa;e=e+1|0;continue}}e=2<<k-17;h=he(D,(e-(e>>>3|0)|0)+3|0);k=e>>>1|0;$=e|1;e=0;while(1){if((e|0)==(m|0)){break X}F=h;h=(h>>>0)/($>>>0)|0;z[(e<<2)+f>>2]=F-(k+B($,h)|0)|0;e=e+1|0;continue}}g=g+1|0;f=(l<<2)+f|0;l=18-l|0;continue}break}j=j+1|0;continue}break}i=(J<<2)+i|0;if((i|0)==12){j=(A<<2)+n|0;e=d;i=w[n+769|0];f=d+B(i,72)|0;uc(f+2304|0,f,B(w[n+768|0]-i|0,72));g=0;while(1){if(w[n+768|0]>g>>>0){f=0;while(1){if((f|0)!=12){i=(f<<2)+e|0;z[i>>2]=z[j>>2]*z[i>>2];i=i+2304|0;z[i>>2]=z[j+12>>2]*z[i>>2];f=f+1|0;continue}break}j=j+24|0;e=e+72|0;g=g+1|0;continue}break}uI(q,d,12,v[I+8>>2],aa,o);Ub(d,0,4608);aa=B(v[I+8>>2],768)+aa|0;i=0}A=A+1|0;if(v[n+17156>>2]<=v[n+17160>>2]){continue}break}gz(E);A=0;break i}i=1}A=B(mx(w[E+6153|0]),i)}kb=n+17168|0;e=v[p+4624>>2];if((e|0)<0|!e&(A|0)!=0|!(e|A)){break h}Y:{if(e){e=v[p+4636>>2];if((e|0)!=(H|0)?H:0){break h}d=v[p+4632>>2];if((d|0)!=(c|0)?c:0){break h}if(d-3>>>0<4294967294|(e|0)<=0){break Y}v[p+12>>2]=0;qa=p,ra=Ic(ca,da),v[qa+8>>2]=ra;c=v[Jj(p+4624|0,p+12|0,p+8|0)>>2];v[p+12>>2]=0;qa=p,ra=Ic(ca,da),v[qa+8>>2]=ra;Y=c+Y|0;c=ca;f=v[Jj(p+4624|0,p+12|0,p+8|0)>>2];ca=c-f|0;da=da-((f>>31)+(c>>>0<f>>>0)|0)|0;Z:{if(!A){break Z}v[23588]=0;c=p+16|0;W(574,X|0,c|0,c+(B(d,A)<<1)|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break Z}H=V(92948)|0;if((O()|0)==(ea(92948)|0)){_(H|0)|0;v[23588]=0;Z(18);f=v[23588];v[23588]=0;H=e;c=d;if((f|0)!=1){break h}H=P()|0;O()|0}od(X);Uc(p+11336|0);T(H|0);L()}H=e;c=d}if((Rc(v[X>>2],v[X+4>>2])>>>0)/(c>>>0)>>>0>268435456){break h}if(!!ca&(da|0)>=0|(da|0)>0){continue}break h}break}H=e;c=d}i=0;_:{if(!H|!c){break _}d=v[X>>2];e=v[X+4>>2];if(pc(d,e)){break _}if((Rc(d,e)>>>0)/(c>>>0)>>>0>268435456){break _}st(a,b);e=B(b,104)+a|0;d=e+484380|0;qa=d,ra=(Rc(v[X>>2],v[X+4>>2])>>>0)/(c>>>0)|0,v[qa>>2]=ra;a=e+484414|0;b=x[a>>1];u[a>>1]=(c|0)==2?b|65:b&65470|1;Og(d);a=e+484400|0;i=_d(v[d>>2],v[a>>2]);if(!i){break _}$n(Fb(v[X>>2]),Fb(v[X+4>>2]),v[a>>2]);i=_d(v[d>>2],v[d+20>>2])}od(X);Uc(p+11336|0)}kb=p+11360|0;return i|0}function qA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),A=0,E=0,F=0,G=0,I=C(0),J=0,K=0,M=0,N=0,O=C(0);r=kb-1520|0;kb=r;e=r+8|0;M=Ub(e,0,1512),N=-1,v[M+1420>>2]=N;t[r+56|0]=1;v[r+48>>2]=a+b;v[r+40>>2]=a;l=kb-1024|0;kb=l;t[e+1377|0]=1;a:{if(!ps(e)){break a}b=w[e+1375|0];if(!(b&2)){ec(e,34);break a}if(b&4){ec(e,34);break a}if(b&1){ec(e,34);break a}if(v[e+1116>>2]!=1){ec(e,34);break a}b=w[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!hx(e,l+1018|0,6)|w[l+1018|0]!=102|(w[l+1019|0]!=105|w[l+1020|0]!=115)){break b}if(w[l+1021|0]!=104|w[l+1022|0]!=101|w[l+1023|0]!=97){break b}if(($e(e)|0)!=100){break b}if($e(e)){break b}ec(e,38);break a}ec(e,34);break a}if(($e(e)|0)!=1){ec(e,34);break a}if(!hx(e,l+1018|0,6)){ec(e,10);break a}if(!fx(l+1018|0)){ec(e,34);break a}if(gj(e)){ec(e,34);break a}b=$e(e);v[e+4>>2]=b;if(!b){ec(e,34);break a}if(b>>>0>=17){ec(e,5);break a}b=gj(e);v[e>>2]=b;if(!b){ec(e,34);break a}gj(e);gj(e);gj(e);b=$e(e);j=b>>>4|0;v[e+116>>2]=1<<j;g=b&15;v[e+112>>2]=1<<g;if(g-14>>>0<=4294967287){ec(e,20);break a}if((b<<24)+536870912>>24>=0){ec(e,20);break a}c:{if(g>>>0>j>>>0){ec(e,20);break c}if(!($e(e)&1)){ec(e,34);break c}if(!ps(e)){break a}if(!gx(e)){break a}if(!ix(e)){break a}if((wh(e)|0)==3){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=wh(e),t[M|0]=N;f=f+1|0;continue}break}if(!fx(l+1018|0)){ec(e,20);break c}b=ex(e);f=ge(e,b+1|0);v[e+20>>2]=f;if(f){f=0;g=(b|0)>0?b:0;while(1){if((f|0)!=(g|0)){j=wh(e);t[v[e+20>>2]+f|0]=j;f=f+1|0;continue}break}t[b+v[e+20>>2]|0]=0;b=ex(e);v[e+28>>2]=0;v[e+24>>2]=b;d:{if((b|0)<=0){break d}b=ge(e,b<<2);v[e+28>>2]=b;if(b){break d}ec(e,3);break c}while(1){e:{f:{if(v[e+24>>2]>(h|0)){b=ex(e);f=ge(e,b+1|0);g=h<<2;v[g+v[e+28>>2]>>2]=f;if(!v[g+v[e+28>>2]>>2]){break f}f=0;j=(b|0)>0?b:0;while(1){if((f|0)==(j|0)){break e}i=wh(e);t[v[g+v[e+28>>2]>>2]+f|0]=i;f=f+1|0;continue}}if(!(wh(e)&1)){ec(e,20);break c}fI(e,w[e+1376|0]);t[e+1376|0]=0;while(1){b=ix(e);fI(e,b);t[e+1376|0]=0;if(b){continue}break}f=0;if(!gx(e)){break a}if(!mI(e)){if(v[e+100>>2]!=21){break a}v[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){j=b<<24;g=0;while(1){if((g|0)!=8){j=j>>31&79764919^j<<1;g=g+1|0;continue}break}v[(b<<2)+463232>>2]=j;b=b+1|0;continue}break}if((wh(e)|0)==5){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=wh(e),t[M|0]=N;f=f+1|0;continue}break}if(!fx(l+1018|0)){ec(e,20);break c}b=oc(e,8)+1|0;v[e+120>>2]=b;b=ge(e,B(b,2096));v[e+124>>2]=b;if(!b){ec(e,3);break c}Ub(b,0,B(v[e+120>>2],2096));g:{h:{while(1){i:{if(v[e+120>>2]>(E|0)){b=v[e+124>>2];if((oc(e,8)&255)!=66){ec(e,20);break c}if((oc(e,8)&255)!=67){ec(e,20);break c}if((oc(e,8)&255)!=86){ec(e,20);break c}g=b+B(E,2096)|0;M=g,N=oc(e,8)&255|oc(e,8)<<8,v[M>>2]=N;M=g,N=oc(e,8)&255|(oc(e,8)<<8&65280|oc(e,8)<<16),v[M+4>>2]=N;k=g+4|0;f=0;m=oc(e,1);if(!m){f=oc(e,1)}t[g+23|0]=f;h=v[k>>2];if(v[g>>2]){b=h;break i}b=0;if(!h){break i}ec(e,20);break c}b=oc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!oc(e,16)){continue}break}ec(e,20);break c}b=oc(e,6)+1|0;v[e+128>>2]=b;b=ge(e,B(b,1596));v[e+260>>2]=b;k:{if(b){E=0;k=0;l:while(1){if(v[e+128>>2]<=(k|0)){break k}b=oc(e,16);u[((k<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){ec(e,20);break c}if(!b){b=v[e+260>>2]+B(k,1596)|0;M=b,N=oc(e,8),t[M|0]=N;M=b,N=oc(e,16),u[M+2>>1]=N;M=b,N=oc(e,16),u[M+4>>1]=N;M=b,N=oc(e,6),t[M+6|0]=N;M=b,N=oc(e,8),t[M+7|0]=N;j=oc(e,4)+1|0;t[b+8|0]=j;h=b+9|0;f=0;while(1){if((j&255)>>>0>f>>>0){M=f+h|0,N=oc(e,8),t[M|0]=N;f=f+1|0;j=w[b+8|0];continue}break}ec(e,4);break c}f=v[e+260>>2]+B(k,1596)|0;b=oc(e,5);t[f|0]=b;m=f+1|0;j=0;g=-1;while(1)if((b&255)>>>0<=j>>>0){h=g+1|0;g=f+82|0;i=f+65|0;o=f+49|0;n=f+33|0;b=0;while(1){if((b|0)!=(h|0)){M=b+n|0,N=oc(e,3)+1|0,t[M|0]=N;q=b+o|0;p=oc(e,2);t[q|0]=p;j=0;m:{if(!(p&255)){break m}p=oc(e,8);t[b+i|0]=p;if(v[e+120>>2]>(p&255)){break m}ec(e,20);break c}n:{while(1){if(1<<w[q|0]<=(j|0)){break n}p=oc(e,8)-1|0;u[(g+(b<<4)|0)+(j<<1)>>1]=p;j=j+1|0;if(v[e+120>>2]>p<<16>>16){continue}break}ec(e,20);break c}b=b+1|0;continue}break}g=2;M=f,N=oc(e,2)+1|0,t[M+1588|0]=N;b=oc(e,4);v[f+1592>>2]=2;h=0;u[f+338>>1]=0;t[f+1589|0]=b;u[f+340>>1]=1<<b;b=f+338|0;i=0;while(1){if(w[f|0]>i>>>0){o=n+w[i+m|0]|0;j=0;while(1){if(w[o|0]>j>>>0){g=oc(e,w[f+1589|0]);u[b+(v[f+1592>>2]<<1)>>1]=g;g=v[f+1592>>2]+1|0;v[f+1592>>2]=g;j=j+1|0;continue}break}i=i+1|0;continue}break}while(1){if((g|0)>(h|0)){g=x[b+(h<<1)>>1];j=(l+16|0)+(h<<2)|0;u[j+2>>1]=h;u[j>>1]=g;h=h+1|0;g=v[f+1592>>2];continue}break}eI(l+16|0,g,1090);g=v[f+1592>>2];h=((g|0)>1?g:1)-1|0;j=0;o:{while(1){if((h|0)==(j|0)){h=f+838|0;j=0;break o}i=l+16|0;n=x[i+(j<<2)>>1];j=j+1|0;if((n|0)!=x[i+(j<<2)>>1]){continue}break}ec(e,20);break c}while(1){if((g|0)>(j|0)){t[h+j|0]=w[((l+16|0)+(j<<2)|0)+2|0];j=j+1|0;g=v[f+1592>>2];continue}break}q=f+1088|0;j=2;while(1){if((g|0)>(j|0)){v[l+12>>2]=0;v[l+8>>2]=0;g=0;p=(j|0)>0?j:0;i=b+(j<<1)|0;m=65536;n=-1;while(1){if((g|0)!=(p|0)){o=b+(g<<1)|0;h=x[o>>1];if(!((n|0)>=(h|0)|x[i>>1]<=h>>>0)){v[l+12>>2]=g;h=x[o>>1];n=h}if(!((h|0)>=(m|0)|x[i>>1]>=h>>>0)){v[l+8>>2]=g;m=x[o>>1]}g=g+1|0;continue}break}h=q+(j<<1)|0;t[h|0]=v[l+12>>2];t[h+1|0]=v[l+8>>2];j=j+1|0;g=v[f+1592>>2];continue}break}E=(g|0)>(E|0)?g:E;k=k+1|0;continue l}else{b=oc(e,4);t[j+m|0]=b;b=b&255;g=(b|0)>(g|0)?b:g;j=j+1|0;b=w[f|0];continue}}}ec(e,3);break c}b=oc(e,6)+1|0;v[e+264>>2]=b;b=ge(e,B(b,24));v[e+396>>2]=b;if(!b){ec(e,3);break c}k=0;Ub(b,0,B(v[e+264>>2],24));p:{q:{r:{while(1){if(v[e+264>>2]>(k|0)){b=v[e+396>>2];h=oc(e,16);u[((k<<1)+e|0)+268>>1]=h;if((h&65535)>>>0>=3){ec(e,20);break c}g=b+B(k,24)|0;M=g,N=oc(e,24),v[M>>2]=N;b=oc(e,24);v[g+4>>2]=b;if(b>>>0<y[g>>2]){ec(e,20);break c}M=g,N=oc(e,24)+1|0,v[M+8>>2]=N;M=g,N=oc(e,6)+1|0,t[M+12|0]=N;b=oc(e,8);t[g+13|0]=b;if(v[e+120>>2]<=(b&255)){break r}f=0;while(1){b=w[g+12|0];if(b>>>0>f>>>0){h=(l+16|0)+f|0;b=oc(e,3);if(oc(e,1)){i=oc(e,5)}else{i=0}t[h|0]=b+(i<<3);f=f+1|0;continue}break}b=ge(e,b<<4);v[g+20>>2]=b;if(!b){break q}h=0;while(1){if(w[g+12|0]>h>>>0){b=w[(l+16|0)+h|0];f=0;while(1){if((f|0)!=8){s:{if(b>>>f&1){j=oc(e,8);m=f<<1;i=h<<4;u[m+(i+v[g+20>>2]|0)>>1]=j;if(v[e+120>>2]>u[m+(i+v[g+20>>2]|0)>>1]){break s}ec(e,20);break c}u[(v[g+20>>2]+(h<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}h=h+1|0;continue}break}h=ge(e,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);v[g+16>>2]=h;if(!h){ec(e,3);break c}b=0;Ub(h,0,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);while(1){h=v[e+124>>2]+B(w[g+13|0],2096)|0;if(v[h+4>>2]>(b|0)){f=v[h>>2];j=ge(e,f);h=b<<2;v[h+v[g+16>>2]>>2]=j;j=b;if(v[h+v[g+16>>2]>>2]){while(1){if((f|0)>0){f=f-1|0;t[f+v[h+v[g+16>>2]>>2]|0]=(j|0)%w[g+12|0];j=(j|0)/w[g+12|0]|0;continue}break}b=b+1|0;continue}else{ec(e,3);break c}}break}k=k+1|0;continue}break}b=oc(e,6)+1|0;v[e+400>>2]=b;b=ge(e,B(b,40));v[e+404>>2]=b;if(!b){ec(e,3);break c}Ub(b,0,B(v[e+400>>2],40));i=0;while(1){if(v[e+400>>2]>(i|0)){b=v[e+404>>2];if(oc(e,16)){ec(e,20);break c}h=b+B(i,40)|0;b=ge(e,B(v[e+4>>2],3));v[h+4>>2]=b;if(!b){ec(e,3);break c}if(oc(e,1)){b=oc(e,4)+1|0}else{b=1}t[h+8|0]=b;t:{if(oc(e,1)){b=oc(e,8)+1|0;u[h>>1]=b;f=0;g=v[e+4>>2];if((g|0)<(b&65535)){ec(e,20);break c}while(1){if(x[h>>1]<=f>>>0){break t}g=oc(e,jm(g-1|0));b=B(f,3);t[b+v[h+4>>2]|0]=g;g=oc(e,jm(v[e+4>>2]-1|0));t[(b+v[h+4>>2]|0)+1|0]=g;g=v[e+4>>2];b=b+v[h+4>>2]|0;j=w[b|0];if((g|0)<=(j|0)){ec(e,20);break c}b=w[b+1|0];if((b|0)>=(g|0)){ec(e,20);break c}f=f+1|0;if((b|0)!=(j|0)){continue}break}ec(e,20);break c}u[h>>1]=0}if(oc(e,2)){ec(e,20);break c}g=0;b=0;f=0;u:{if(w[h+8|0]>=2){while(1){if(v[e+4>>2]<=(b|0)){break u}f=oc(e,4);j=B(b,3);t[(j+v[h+4>>2]|0)+2|0]=f;b=b+1|0;if(w[(j+v[h+4>>2]|0)+2|0]<w[h+8|0]){continue}break}ec(e,20);break c}while(1){if(v[e+4>>2]<=(f|0)){break u}t[(v[h+4>>2]+B(f,3)|0)+2|0]=0;f=f+1|0;continue}}v:{while(1){if(w[h+8|0]<=g>>>0){break v}oc(e,8);b=g+h|0;M=b,N=oc(e,8),t[M+9|0]=N;f=oc(e,8);t[b+24|0]=f;if(v[e+128>>2]<=w[b+9|0]){ec(e,20);break c}g=g+1|0;if(v[e+264>>2]>(f&255)){continue}break}ec(e,20);break c}i=i+1|0;continue}break}M=e,N=oc(e,6)+1|0,v[M+408>>2]=N;h=e+412|0;j=0;w:{while(1){if(v[e+408>>2]<=(j|0)){break w}b=h+B(j,6)|0;M=b,N=oc(e,1),t[M|0]=N;M=b,N=oc(e,16),u[M+2>>1]=N;M=b,N=oc(e,16),u[M+4>>1]=N;f=oc(e,8);t[b+1|0]=f;if(x[b+2>>1]){ec(e,20);break c}if(x[b+4>>1]){ec(e,20);break c}j=j+1|0;if(v[e+400>>2]>(f&255)){continue}break}ec(e,20);break c}kI(e);v[e+992>>2]=0;h=E<<1;f=0;while(1){if(v[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=ge(e,v[e+116>>2]<<2),v[M+800>>2]=N;M=b,N=ge(e,v[e+116>>2]<<1&2147483646),v[M+928>>2]=N;g=ge(e,h);v[b+996>>2]=g;j=v[b+800>>2];if(g?!j|!v[b+928>>2]:1){ec(e,3);break c}Ub(j,0,v[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!dI(e,0,v[e+112>>2])){break a}if(!dI(e,1,v[e+116>>2])){break a}v[e+104>>2]=v[e+112>>2];h=v[e+116>>2];v[e+108>>2]=h;b=v[e+264>>2];i=(b|0)>0?b:0;b=(h|0)/2|0;g=0;while(1){if((f|0)!=(i|0)){j=v[e+396>>2]+B(f,24)|0;k=v[j+4>>2];n=b>>>0>k>>>0?k:b;k=v[j>>2];j=(n-(b>>>0>k>>>0?k:b)>>>0)/y[j+8>>2]|0;g=(g|0)<(j|0)?j:g;f=f+1|0;continue}break}b=h<<1&2147483646;h=B(v[e+4>>2],(g<<2)+4|0);b=b>>>0>h>>>0?b:h;v[e+12>>2]=b;x:{if(!v[e+80>>2]){break x}h=v[e+92>>2];if((h|0)!=v[e+84>>2]){break p}if(h>>>0>=(b+v[e+88>>2]|0)+1512>>>0){break x}ec(e,3);break c}y:{if(v[e+1380>>2]==-1){v[e+52>>2]=w[e+48|0]?0:v[e+32>>2]-v[e+36>>2]|0;break y}v[e+52>>2]=0}f=1;break a}ec(e,20);break c}ec(e,3);break c}aa(7304,13110,4196,8789);L()}z:{if(f&255){j=Gn(e,b);break z}j=ge(e,b);v[g+8>>2]=j}if(!j){ec(e,3);break c}i=0;A:{if(!m){f=0;while(1){b=v[k>>2];if((f|0)>=(b|0)){break A}B:{C:{if(w[g+23|0]){if(!oc(e,1)){break C}}b=oc(e,5)+1|0;t[f+j|0]=b;if((b&255)!=32){i=i+1|0;break B}ec(e,20);break c}t[f+j|0]=255}f=f+1|0;continue}}h=oc(e,5);f=0;while(1){b=v[k>>2];if((f|0)>=(b|0)){break A}m=oc(e,jm(b-f|0));h=h+1|0;if((h|0)>=32){ec(e,20);break c}b=f+m|0;if((b|0)>v[k>>2]){ec(e,20);break c}else{Ub(f+j|0,h,m);f=b;continue}}}D:{E:{F:{if(w[g+23|0]){if(b>>2>(i|0)){break F}if(v[e+16>>2]<(b|0)){v[e+16>>2]=b;b=v[k>>2]}b=ge(e,b);v[g+8>>2]=b;if(!b){ec(e,3);break c}uc(b,j,v[k>>2]);fj(e,j,v[k>>2]);j=v[g+8>>2];t[g+23|0]=0;b=v[k>>2]}h=0;i=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(i|0)){h=((w[f+j|0]-11&255)>>>0<244)+h|0;f=f+1|0;continue}break}v[g+2092>>2]=h;b=ge(e,b<<2);v[g+32>>2]=b;if(b){m=g+2092|0;f=0;break E}ec(e,3);break c}v[g+2092>>2]=i;m=g+2092|0;G:{if(!i){f=0;h=0;break G}b=ge(e,i);v[g+8>>2]=b;if(!b){ec(e,3);break c}b=Gn(e,v[m>>2]<<2);v[g+32>>2]=b;if(!b){ec(e,3);break c}f=Gn(e,v[m>>2]<<2);if(!f){break D}b=v[k>>2];h=v[m>>2]}b=(h<<3)+b|0;if(b>>>0<=y[e+16>>2]){break E}v[e+16>>2]=b}n=v[k>>2];b=0;h=kb-128|0;kb=h;o=Ub(h,0,128);h=(n|0)>0?n:0;while(1){H:{I:{if((b|0)!=(h|0)){if(w[b+j|0]==255){break I}h=b}if((h|0)==(n|0)){b=1;if(!v[g+2092>>2]){break H}aa(15698,13110,1103,7548);L()}b=h+j|0;i=w[b|0];if(i>>>0<32){bI(g,0,h,0,i,f);q=1;i=w[b|0]+1|0;b=1;J:{while(1){if((b|0)==(i|0)){K:while(1){L:{b=1;h=h+1|0;if((n|0)<=(h|0)){break H}F=h+j|0;i=w[F|0];if((i|0)==255){continue}b=i;if(b>>>0>=32){break L}while(1){if((b|0)<=0){b=0;break H}G=o+(b<<2)|0;p=v[G>>2];if(!p){b=b-1|0;continue}break}v[G>>2]=0;bI(g,hm(p),h,q,i,f);q=q+1|0;i=w[F|0];if((i|0)==(b|0)){continue}while(1){if((b|0)>=(i|0)){continue K}F=o+(i<<2)|0;if(v[F>>2]){break J}v[F>>2]=p+(1<<32-i);i=i-1|0;continue}}break}}else{v[o+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}aa(15202,13110,1118,7548);L()}aa(15742,13110,1133,7548);L()}aa(15209,13110,1104,7548);L()}b=b+1|0;continue}break}kb=o+128|0;if(!b){if(w[g+23|0]){fj(e,f,0)}ec(e,20);break c}b=v[m>>2];if(b){b=ge(e,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){ec(e,3);break c}b=ge(e,(v[m>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){ec(e,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;b=0;i=0;M:{N:{O:{if(w[g+23|0]){while(1){i=v[g+2092>>2];if((i|0)<=(b|0)){break O}h=b<<2;M=h+v[g+2084>>2]|0,N=hm(v[h+v[g+32>>2]>>2]),v[M>>2]=N;b=b+1|0;continue}}while(1){if(v[g+4>>2]>(b|0)){if(aI(w[g+23|0],w[b+j|0])){M=v[g+2084>>2]+(i<<2)|0,N=hm(v[v[g+32>>2]+(b<<2)>>2]),v[M>>2]=N;i=i+1|0}b=b+1|0;continue}break}if(v[g+2092>>2]!=(i|0)){break N}}eI(v[g+2084>>2],i,1091);v[v[g+2084>>2]+(v[g+2092>>2]<<2)>>2]=-1;h=0;b=v[g+(w[g+23|0]?2092:4)>>2];p=(b|0)>0?b:0;P:{while(1){if((h|0)!=(p|0)){b=h;i=w[g+23|0];b=i?v[(b<<2)+f>>2]:b;F=w[b+j|0];Q:{if(!aI(i,F)){break Q}G=h<<2;n=hm(v[G+v[g+32>>2]>>2]);b=v[g+2092>>2];i=0;while(1){if((b|0)>=2){o=b>>>1|0;J=o+i|0;q=n>>>0<y[v[g+2084>>2]+(J<<2)>>2];b=q?o:b-o|0;i=q?i:J;continue}break}b=i<<2;if((n|0)!=v[b+v[g+2084>>2]>>2]){break P}if(w[g+23|0]){v[b+v[g+2088>>2]>>2]=v[f+G>>2];t[v[g+8>>2]+i|0]=F;break Q}v[b+v[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break M}aa(12151,13110,1230,9932);L()}aa(7489,13110,1200,9932);L()}}if(w[g+23|0]){fj(e,f,v[m>>2]<<2);fj(e,v[g+32>>2],v[m>>2]<<2);fj(e,j,v[k>>2]);v[g+32>>2]=0}i=g;b=0;f=0;while(1){if((b|0)!=1024){u[(i+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=v[i+(w[i+23|0]?2092:4)>>2];b=(b|0)<32767?b:32767;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){R:{if(w[v[i+8>>2]+f|0]>10){break R}S:{if(w[i+23|0]){b=hm(v[v[i+2084>>2]+(f<<2)>>2]);break S}b=v[v[i+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break R}u[(i+(b<<1)|0)+36>>1]=f;b=(1<<w[v[i+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=oc(e,4);t[i+21|0]=b;b=b&255;if(b>>>0>=3){ec(e,20);break c}if(b){M=i,O=cI(oc(e,32)),z[M+12>>2]=O;M=i,O=cI(oc(e,32)),z[M+16>>2]=O;M=i,N=oc(e,4)+1|0,t[M+20|0]=N;M=i,N=oc(e,1),t[M+22|0]=N;f=v[i>>2];h=v[k>>2];T:{if(w[i+21|0]==1){A=H(Fs(+C(C(Ap(+C(h|0)))/C(f|0))));U:{if(D(A)<2147483648){b=~~A;break U}b=-2147483648}A=+(f|0);K=H(bk(+C(C(b|0)+C(1)),A));V:{if(D(K)<2147483648){f=~~K;break V}f=-2147483648}b=((f|0)<=(h|0))+b|0;s=C(b|0);if(bk(+C(s+C(1)),A)<=+(h|0)){f=-1}else{A=H(bk(+s,A));W:{if(D(A)<2147483648){f=~~A;break W}f=-2147483648}f=(f|0)>(h|0)?-1:b}if((f|0)>=0){break T}ec(e,20);break c}f=B(f,h)}v[i+24>>2]=f;if(!f){ec(e,20);break c}n=Gn(e,f<<1);if(!n){break h}f=0;while(1){j=v[i+24>>2];if((j|0)>(f|0)){b=oc(e,w[i+20|0]);if((b|0)==-1){fj(e,n,v[i+24>>2]<<1);ec(e,20);break c}else{u[n+(f<<1)>>1]=b;f=f+1|0;continue}}break}X:{Y:{if(w[i+21|0]==1){o=w[i+23|0];Z:{if(o){f=v[m>>2];if(f){break Z}break X}f=v[k>>2]}b=ge(e,B(v[i>>2],f)<<2);v[i+28>>2]=b;if(!b){fj(e,n,v[i+24>>2]<<1);ec(e,3);break c}h=0;b=v[(o?m:k)>>2];m=(b|0)>0?b:0;q=i+2088|0;s=C(0);while(1){if((h|0)==(m|0)){break Y}g=h;g=o?v[v[q>>2]+(g<<2)>>2]:g;j=v[i>>2];f=0;b=1;while(1){if((f|0)<(j|0)){I=C(s+C(C(C(x[n+(((g>>>0)/(b>>>0)>>>0)%y[i+24>>2]<<1)>>1])*z[i+16>>2])+z[i+12>>2]));z[v[i+28>>2]+(B(h,j)+f<<2)>>2]=I;s=w[i+22|0]?I:s;f=f+1|0;j=v[i>>2];if((f|0)>=(j|0)){continue}k=v[i+24>>2];Oka(k,0,b,0);if(nb){fj(e,n,k<<1);ec(e,20);break c}else{b=B(b,k);continue}}break}h=h+1|0;continue}}b=ge(e,j<<2);v[i+28>>2]=b;if(!b){break g}f=0;s=C(0);while(1){j=v[i+24>>2];if((j|0)<=(f|0)){break X}I=C(s+C(C(C(x[n+(f<<1)>>1])*z[i+16>>2])+z[i+12>>2]));z[v[i+28>>2]+(f<<2)>>2]=I;s=w[i+22|0]?I:s;f=f+1|0;continue}}t[i+21|0]=2;j=v[i+24>>2]}fj(e,n,j<<1)}E=E+1|0;continue}break}ec(e,3);break c}ec(e,3);break c}fj(e,n,v[i+24>>2]<<1);ec(e,3);break c}ec(e,20);break c}ec(e,3);break c}t[b+v[v[e+28>>2]+(h<<2)>>2]|0]=0;h=h+1|0;continue}}ec(e,3);break c}ec(e,20)}f=0}kb=l+1024|0;_:{$:{if(!f){v[d>>2]=v[r+104>>2]?1:v[r+108>>2];break $}b=ge(r+8|0,1512);if(b){M=c,N=v[uc(b,r+8|0,1512)+32>>2]-a|0,v[M>>2]=N;v[d>>2]=0;break _}}oI(r+8|0);b=0}kb=r+1520|0;return b}function UG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;s=kb-48|0;kb=s;a:{if(c>>>0<=2){c=c<<2;I=v[c+79532>>2];J=v[c+79520>>2];while(1){c=v[b+4>>2];b:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=sd(b)}if(Wk(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=sd(b)}e:{f:{while(1){if(t[g+4955|0]==(c|32)){g:{if(g>>>0>6){break g}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=sd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){v[b+4>>2]=v[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}i=kb-16|0;kb=i;l=(p(C(C(o|0)*C(N))),j(2));b=l&2147483647;h:{if(b-8388608>>>0<=2130706431){r=b<<25;c=(b>>>7|0)+1065353216|0;break h}r=l<<25;c=l>>>7|2147418112;if(b>>>0>=2139095040){break h}r=0;c=0;if(!b){break h}c=b;b=E(b);Lf(i,c,0,0,0,b+81|0);k=v[i>>2];h=v[i+4>>2];r=v[i+8>>2];c=v[i+12>>2]^65536|16265-b<<16}v[s>>2]=k;v[s+4>>2]=h;v[s+8>>2]=r;v[s+12>>2]=l&-2147483648|c;kb=i+16|0;k=v[s+8>>2];h=v[s+12>>2];i=v[s>>2];l=v[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(t[g+9928|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=sd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=v[b+4>>2];o:{if((g|0)!=v[b+104>>2]){v[b+4>>2]=g+1;g=w[g|0];break o}g=sd(b)}if((g&-33)==88){g=d;c=0;f=kb-432|0;kb=f;p:{q:{d=v[b+4>>2];if((d|0)!=v[b+104>>2]){v[b+4>>2]=d+1;c=w[d|0];break q}d=0;break p}d=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!d){c=sd(b);break y}if((c|0)!=48){l=1073676288;if((c|0)==46){break w}break v}d=v[b+4>>2];if((d|0)==v[b+104>>2]){break x}n=1;v[b+4>>2]=d+1;c=w[d|0]}d=1;continue}n=1;break s}c=v[b+4>>2];z:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break z}c=sd(b)}if((c|0)==48){break u}F=1}break t}while(1){c=r;r=c-1|0;u=u-!c|0;F=1;c=v[b+4>>2];A:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break A}c=sd(b)}if((c|0)==48){continue}break}n=1}while(1){e=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|e-97>>>0<6)){d=c;break r}d=46;if((c|0)!=46){break C}if(F){break r}F=1;r=k;u=h;break B}c=(c|0)>57?e-87|0:M;D:{if((h|0)<=0&k>>>0<=7|(h|0)<0){x=c+(x<<4)|0;break D}if(!h&k>>>0<=28){bh(f+48|0,c);Jd(f+32|0,G,H,i,l,0,0,0,1073414144);G=v[f+32>>2];H=v[f+36>>2];i=v[f+40>>2];l=v[f+44>>2];Jd(f+16|0,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2],G,H,i,l);Gg(f,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2],m,q,A,D);A=v[f+8>>2];D=v[f+12>>2];m=v[f>>2];q=v[f+4>>2];break D}if(!c|z){break D}Jd(f+80|0,G,H,i,l,0,0,0,1073610752);Gg(f- -64|0,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2],m,q,A,D);A=v[f+72>>2];D=v[f+76>>2];z=1;m=v[f+64>>2];q=v[f+68>>2]}c=k+1|0;h=c?h:h+1|0;k=c;n=1}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0]}else{c=sd(b)}continue}}d=0;continue}break}E:{if(!n){c=v[b+116>>2];F:{G:{if((c|0)>0|(c|0)>=0){c=v[b+4>>2];v[b+4>>2]=c-1;if(!g){break G}v[b+4>>2]=c-2;if(!F){break F}v[b+4>>2]=c-3;break F}if(g){break F}}li(b,0,0)}Vi(f+96|0,+(o|0)*0);m=v[f+96>>2];q=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2];break E}if((h|0)<=0&k>>>0<=7|(h|0)<0){i=k;l=h;while(1){x=x<<4;c=i+1|0;l=c?l:l+1|0;i=c;if((c|0)!=8|l){continue}break}}H:{I:{J:{if((d&-33)==80){i=TG(b,g);c=nb;l=c;if(i|(c|0)!=-2147483648){break H}if(g){c=v[b+116>>2];if((c|0)>0|(c|0)>=0){break J}break I}m=0;q=0;li(b,0,0);c=0;b=0;break E}i=0;l=0;if(v[b+116>>2]<0){break H}}v[b+4>>2]=v[b+4>>2]-1}i=0;l=0}if(!x){Vi(f+112|0,+(o|0)*0);m=v[f+112>>2];q=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break E}b=F?r:k;h=(F?u:h)<<2|b>>>30;b=i+(b<<2)|0;d=h+l|0;d=b>>>0<i>>>0?d+1|0:d;k=b-32|0;h=d-(b>>>0<32)|0;b=h;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){v[116064]=68;bh(f+160|0,o);Jd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Jd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);m=v[f+128>>2];q=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break E}b=I-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(h|0)){if((x|0)>=0){while(1){Gg(f+416|0,m,q,A,D,0,0,0,-1073807360);c=VS(m,q,A,D,1073610752);b=(c|0)<0;Gg(f+400|0,m,q,A,D,b?m:v[f+416>>2],b?q:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=k;k=b-1|0;h=h-!b|0;A=v[f+408>>2];D=v[f+412>>2];m=v[f+400>>2];q=v[f+404>>2];x=x<<1|(c|0)>=0;if((x|0)>=0){continue}break}}d=h-((I>>31)+(k>>>0<I>>>0)|0)|0;b=(k-I|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<J>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:J;K:{if((c|0)>=113){bh(f+384|0,o);r=v[f+392>>2];u=v[f+396>>2];G=v[f+384>>2];H=v[f+388>>2];h=0;b=0;break K}Vi(f+352|0,Vj(1,144-c|0));bh(f+336|0,o);G=v[f+336>>2];H=v[f+340>>2];r=v[f+344>>2];u=v[f+348>>2];WG(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],G,H,r,u);K=v[f+376>>2];L=v[f+380>>2];h=v[f+372>>2];b=v[f+368>>2]}c=!(x&1)&((Hm(m,q,A,D,0,0,0,0)|0)!=0&(c|0)<32);pn(f+320|0,c+x|0);Jd(f+304|0,G,H,r,u,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;Gg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,h,K,L);b=c;Jd(f+288|0,G,H,r,u,b?0:m,b?0:q,b?0:A,b?0:D);Gg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Lx(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,h,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];h=v[f+252>>2];if(!Hm(b,c,d,h,0,0,0,0)){v[116064]=68}VG(f+224|0,b,c,d,h,k);m=v[f+224>>2];q=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break E}v[116064]=68;bh(f+208|0,o);Jd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Jd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);m=v[f+176>>2];q=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2]}v[s+16>>2]=m;v[s+20>>2]=q;v[s+24>>2]=b;v[s+28>>2]=c;kb=f+432|0;k=v[s+24>>2];h=v[s+28>>2];i=v[s+16>>2];l=v[s+20>>2];break a}if(v[b+116>>2]<0){break n}v[b+4>>2]=v[b+4>>2]-1}g=b;f=o;x=d;d=0;o=0;e=kb-8976|0;kb=e;K=I+J|0;L=0-K|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}b=v[g+4>>2];if((b|0)==v[g+104>>2]){break N}v[g+4>>2]=b+1;c=w[b|0];break M}}else{b=v[g+4>>2];if((b|0)!=v[g+104>>2]){d=1;v[g+4>>2]=b+1;c=w[b|0]}else{d=1;c=sd(g)}continue}break}c=sd(g)}n=1;if((c|0)!=48){break L}while(1){b=k;k=b-1|0;h=h-!b|0;b=v[g+4>>2];O:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break O}c=sd(g)}if((c|0)==48){continue}break}d=1}v[e+784>>2]=0;P:{Q:{b=(c|0)==46;m=c-48|0;R:{S:{T:{U:{if(b|m>>>0<=9){while(1){V:{if(b&1){if(!n){k=i;h=l;n=1;break V}b=!d;break U}b=i+1|0;l=b?l:l+1|0;i=b;if((o|0)<=2044){F=(c|0)==48?F:i;b=(e+784|0)+(o<<2)|0;if(z){m=(B(v[b>>2],10)+c|0)-48|0}v[b>>2]=m;d=1;c=z+1|0;b=(c|0)==9;z=b?0:c;o=b+o|0;break V}if((c|0)==48){break V}v[e+8960>>2]=v[e+8960>>2]|1;F=18396}b=v[g+4>>2];W:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break W}c=sd(g)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}k=n?k:i;h=n?h:l;if(!(!d|(c&-33)!=69)){m=TG(g,x);b=nb;q=b;X:{if(m|(b|0)!=-2147483648){break X}if(!x){break R}m=0;q=0;if(v[g+116>>2]<0){break X}v[g+4>>2]=v[g+4>>2]-1}if(!d){break S}h=h+q|0;b=k+m|0;h=b>>>0<m>>>0?h+1|0:h;k=b;break Q}b=!d;if((c|0)<0){break T}}if(v[g+116>>2]<0){break T}v[g+4>>2]=v[g+4>>2]-1}if(!b){break Q}}v[116064]=28}i=0;l=0;li(g,0,0);c=0;b=0;break P}b=v[e+784>>2];if(!b){Vi(e,+(f|0)*0);i=v[e>>2];l=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break P}if(!((k|0)!=(i|0)|(h|0)!=(l|0)|(i>>>0>9&(l|0)>=0|(l|0)>0)|(b>>>J|0?(J|0)<=30:0))){bh(e+48|0,f);pn(e+32|0,b);Jd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);i=v[e+16>>2];l=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break P}if(k>>>0>(I|0)/-2>>>0&(h|0)>=0|(h|0)>0){v[116064]=68;bh(e+96|0,f);Jd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Jd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);i=v[e+64>>2];l=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break P}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){v[116064]=68;bh(e+144|0,f);Jd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Jd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);i=v[e+112>>2];l=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break P}if(z){if((z|0)<=8){b=(e+784|0)+(o<<2)|0;g=v[b>>2];while(1){g=B(g,10);z=z+1|0;if((z|0)!=9){continue}break}v[b>>2]=g}o=o+1|0}Y:{n=k;if((F|0)>(k|0)|(F|0)>8|(k|0)>17){break Y}if((n|0)==9){bh(e+192|0,f);pn(e+176|0,v[e+784>>2]);Jd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);i=v[e+160>>2];l=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break P}if((n|0)<=8){bh(e+272|0,f);pn(e+256|0,v[e+784>>2]);Jd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);bh(e+224|0,v[(0-n<<2)+79520>>2]);HP(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);i=v[e+208>>2];l=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break P}b=(J+B(n,-3)|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}bh(e+352|0,f);pn(e+336|0,c);Jd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);bh(e+304|0,v[(n<<2)+79448>>2]);Jd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);i=v[e+288>>2];l=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break P}while(1){c=o;o=c-1|0;if(!v[(e+784|0)+(o<<2)>>2]){continue}break}b=(n|0)%9|0;Z:{if(!b){z=0;b=0;break Z}z=0;d=(n|0)<0?b+9|0:b;_:{if(!c){b=0;c=0;break _}k=v[(0-d<<2)+79520>>2];l=1e9/(k|0)|0;m=0;g=0;b=0;while(1){h=m;i=(e+784|0)+(g<<2)|0;o=v[i>>2];m=(o>>>0)/(k>>>0)|0;h=h+m|0;v[i>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;n=h?n-9|0:n;m=B(l,o-B(k,m)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!m){break _}v[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}n=(n-d|0)+9|0}while(1){o=(e+784|0)+(b<<2)|0;g=(n|0)<36;$:{while(1){aa:{if(g){break aa}if((n|0)!=36){break $}if(y[o>>2]<=10384592){break aa}n=36;break $}d=c+2047|0;m=0;while(1){i=d&2047;x=(e+784|0)+(i<<2)|0;d=v[x>>2];l=d>>>3|0;h=d<<29;k=h+m|0;d=l;d=h>>>0>k>>>0?d+1|0:d;h=d;if(!h&k>>>0<1000000001){m=0}else{m=Rka(k,h,1e9,0);d=Oka(m,nb,-1e9,-1)+k|0;k=d}v[x>>2]=k;c=(i|0)!=(c-1&2047)?c:(b|0)==(i|0)?c:k?c:i;d=i-1|0;if((b|0)!=(i|0)){continue}break}z=z-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;k=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[k>>2]=v[k>>2]|v[d+(c<<2)>>2]}n=n+9|0;v[(e+784|0)+(b<<2)>>2]=m;continue}break}ba:{ca:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;da:{while(1){d=b;g=0;ea:{while(1){fa:{b=d+g&2047;if((b|0)==(c|0)){break fa}b=v[(e+784|0)+(b<<2)>>2];i=v[(g<<2)+79472>>2];if(b>>>0<i>>>0){break fa}if(b>>>0>i>>>0){break ea}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break ea}k=0;h=0;g=0;i=0;l=0;while(1){b=d+g&2047;if((b|0)==(c|0)){c=c+1&2047;v[((c<<2)+e|0)+780>>2]=0}pn(e+768|0,v[(e+784|0)+(b<<2)>>2]);Jd(e+752|0,k,h,i,l,0,0,1342177280,1075633366);Gg(e+736|0,v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2],v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2]);i=v[e+744>>2];l=v[e+748>>2];k=v[e+736>>2];h=v[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}bh(e+720|0,f);Jd(e+704|0,k,h,i,l,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);i=v[e+712>>2];l=v[e+716>>2];k=0;h=0;m=v[e+704>>2];q=v[e+708>>2];x=z+113|0;o=x-I|0;n=(o|0)<(J|0);b=n?(o|0)>0?o:0:J;if((b|0)<=112){break da}break ba}z=h+z|0;b=c;if((d|0)==(b|0)){continue}break}o=1e9>>>h|0;m=-1<<h^-1;g=0;b=d;while(1){i=g;g=(e+784|0)+(d<<2)|0;x=v[g>>2];i=i+(x>>>h|0)|0;v[g>>2]=i;i=!i&(b|0)==(d|0);b=i?b+1&2047:b;n=i?n-9|0:n;g=B(o,m&x);d=d+1&2047;if((d|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(k|0)){v[(e+784|0)+(c<<2)>>2]=g;c=k;continue ca}v[l>>2]=v[l>>2]|1;continue}break}break}Vi(e+656|0,Vj(1,225-b|0));WG(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],m,q,i,l);G=v[e+696>>2];H=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];Vi(e+640|0,Vj(1,113-b|0));vP(e+672|0,m,q,i,l,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);k=v[e+672>>2];h=v[e+676>>2];r=v[e+680>>2];u=v[e+684>>2];Lx(e+624|0,m,q,i,l,k,h,r,u);Gg(e+608|0,A,D,G,H,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);i=v[e+616>>2];l=v[e+620>>2];m=v[e+608>>2];q=v[e+612>>2]}g=d+4&2047;ga:{if((g|0)==(c|0)){break ga}g=v[(e+784|0)+(g<<2)>>2];ha:{if(g>>>0<=499999999){if(!g&(d+5&2047)==(c|0)){break ha}Vi(e+496|0,+(f|0)*.25);Gg(e+480|0,k,h,r,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);r=v[e+488>>2];u=v[e+492>>2];k=v[e+480>>2];h=v[e+484>>2];break ha}if((g|0)!=5e8){Vi(e+592|0,+(f|0)*.75);Gg(e+576|0,k,h,r,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);r=v[e+584>>2];u=v[e+588>>2];k=v[e+576>>2];h=v[e+580>>2];break ha}O=+(f|0);if((d+5&2047)==(c|0)){Vi(e+528|0,O*.5);Gg(e+512|0,k,h,r,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);r=v[e+520>>2];u=v[e+524>>2];k=v[e+512>>2];h=v[e+516>>2];break ha}Vi(e+560|0,O*.75);Gg(e+544|0,k,h,r,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);r=v[e+552>>2];u=v[e+556>>2];k=v[e+544>>2];h=v[e+548>>2]}if((b|0)>111){break ga}vP(e+464|0,k,h,r,u,0,0,0,1073676288);if(Hm(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break ga}Gg(e+448|0,k,h,r,u,0,0,0,1073676288);r=v[e+456>>2];u=v[e+460>>2];k=v[e+448>>2];h=v[e+452>>2]}Gg(e+432|0,m,q,i,l,k,h,r,u);Lx(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,G,H);i=v[e+424>>2];l=v[e+428>>2];m=v[e+416>>2];q=v[e+420>>2];ia:{if((-2-K|0)>=(x&2147483647)){break ia}v[e+408>>2]=i;v[e+412>>2]=l&2147483647;v[e+400>>2]=m;v[e+404>>2]=q;Jd(e+384|0,m,q,i,l,0,0,0,1073610752);d=VS(v[e+400>>2],v[e+404>>2],v[e+408>>2],v[e+412>>2],1081081856);c=(d|0)<0;i=c?i:v[e+392>>2];l=c?l:v[e+396>>2];m=c?m:v[e+384>>2];q=c?q:v[e+388>>2];z=((d|0)>=0)+z|0;if((Hm(k,h,r,u,0,0,0,0)|0)!=0&(c?n:n&(b|0)!=(o|0))?0:(L|0)>=(z+110|0)){break ia}v[116064]=68}VG(e+368|0,m,q,i,l,z);i=v[e+368>>2];l=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[s+40>>2]=b;v[s+44>>2]=c;v[s+32>>2]=i;v[s+36>>2]=l;kb=e+8976|0;k=v[s+40>>2];h=v[s+44>>2];i=v[s+32>>2];l=v[s+36>>2];break a;case 3:break j;default:break m}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}break i}ja:{c=v[b+4>>2];ka:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ka}c=sd(b)}if((c|0)==40){g=1;break ja}h=2147450880;if(v[b+116>>2]<0){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];la:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break la}c=sd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}ma:{if(d){if(g){break ma}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(g){continue}break}break a}v[116064]=28;li(b,0,0)}h=0}v[a>>2]=i;v[a+4>>2]=l;v[a+8>>2]=k;v[a+12>>2]=h;kb=s+48|0}function Rfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;d=kb-384|0;kb=d;zc(b);a:{if(!vo(b,d+368|0)){break a}if(!vR(d+368|0)){break a}q=ke(d+344|0,b);o=Tb(d+328|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!c){v[23588]=0;R(637,d+40|0,q|0);b=v[23588];v[23588]=0;if((b|0)==1){break z}break B}v[23588]=0;R(638,d+40|0,q|0);b=v[23588];v[23588]=0;if((b|0)==1){break A}}b=d+40|0;Ut(o,b);Zd(b);v[23588]=0;U(639,b|0,o|0,1413891155);b=v[23588];v[23588]=0;C:{D:{if((b|0)!=1){v[23588]=0;e=Q(640,d+40|0,14081)|0;b=v[23588];v[23588]=0;if((b|0)==1){break D}Bb(d+40|0);if(!c){break b}if(!(e^1)){break C}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Bb(d+40|0);break c}v[23588]=0;R(246,a|0,4194304);b=v[23588];v[23588]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[23588]=0;U(639,d+304|0,o|0,1280592212);b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;b=S(160,v[d+304>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}v[23588]=0;U(444,d+304|0,a+1298308|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break g}i=a+484360|0;j=a+484376|0;Lc(Wb(v[i>>2],w[j|0]));k=Tb(d+288|0);t[d+287|0]=0;v[23588]=0;U(641,d+272|0,o|0,1196314451);b=v[23588];v[23588]=0;if((b|0)==1){break i}A=d,C=Fb(v[d+272>>2]),v[A+264>>2]=C;p=d+252|0;r=Fb(v[d+276>>2]);E:{F:{while(1){b=v[d+264>>2];if(!Pb(b,r)){break F}l=ke(d+40|0,b);v[23588]=0;e=Q(642,l|0,d+24|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break E}b=1;if(!(!e|w[d+33|0]!=1)){A=a,C=Dd(w[d+34|0],x[a+480188>>1],127),u[A+480188>>1]=C;v[23588]=0;h=S(643,d+208|0)|0;b=v[23588];v[23588]=0;G:{H:{I:{J:{K:{if((b|0)!=1){b=d+192|0;qf(b,d+24|0,9,1);v[23588]=0;R(222,d+160|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break K}b=d+8|0;hc(b,p,10);e=b;b=d+160|0;Nl(e,b);zb(b);b=Wb(v[a+484360>>2],w[j|0]);if(pc(v[b>>2],v[b+4>>2])){break H}v[23588]=0;b=S(272,i|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break J}if((b|0)!=255){break I}b=2;break G}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=Wb(v[a+484360>>2],w[j|0])}v[23588]=0;U(5,d+160|0,5,p|0);e=v[23588];v[23588]=0;if((e|0)==1){break n}v[23588]=0;R(273,b|0,d+160|0);b=v[23588];v[23588]=0;if((b|0)==1){break o}Ab(d+160|0);v[23588]=0;R(638,d+192|0,l|0);b=v[23588];v[23588]=0;if((b|0)==1){break p}A=d,C=Fb(v[d+192>>2]),v[A+184>>2]=C;n=Fb(v[d+196>>2]);L:{M:{while(1){b=v[d+184>>2];if(!Pb(b,n)){b=0;if(x[d+244>>1]==65535|x[d+246>>1]==65535){break L}b=w[j|0];e=v[a+484360>>2];v[23588]=0;Y(644,Wb(e,b)|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;R(645,k|0,h|0);e=v[23588];v[23588]=0;b=0;if((e|0)!=1){break L}}b=P()|0;O()|0;break m}Ao(d+160|0,b);Zh(d+8|0,v[b>>2],v[b+4>>2]);e=1;N:{g=v[d+8>>2];O:{if((g|0)!=1212960847){b=0;if((g|0)!=1312903248){break O}while(1){if(x[a+480188>>1]<=b>>>0){break O}v[23588]=0;g=W(156,v[d+160>>2],v[d+168>>2],2)|0;f=v[23588];v[23588]=0;if((f|0)!=1){if(!g){break O}v[23588]=0;R(260,d+136|0,d+160|0);g=v[23588];v[23588]=0;P:{Q:{R:{S:{if((g|0)!=1){switch(w[d+136|0]){case 4:break Q;case 2:break R;case 0:break S;default:break P}}break q}g=Oc(d+136|0);A=Lb(v[h>>2],b),C=w[g|0]^128,t[A|0]=C;g=d+144|0;Db(g,v[d+232>>2],b);Ze(g,0);break P}A=Lb(v[h>>2],b),C=128,t[A|0]=C;g=d+144|0;Db(g,v[d+232>>2],b);Ze(g,1);break P}A=Lb(v[h>>2],b),C=128,t[A|0]=C;g=d+144|0;Db(g,v[d+232>>2],b);Ze(g,0)}b=b+1|0;continue}break}break q}if(y[d+12>>2]<9){break O}b=0;v[23588]=0;Q(188,d+160|0,2)|0;e=v[23588];v[23588]=0;g=65535;if((e|0)==1){break N}while(1){T:{v[23588]=0;e=W(156,v[d+160>>2],v[d+168>>2],1)|0;f=v[23588];v[23588]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{if((f|0)!=1){if(!e){break T}v[23588]=0;f=S(206,d+160|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break q}e=0;switch(f|0){case 0:break T;case 14:break V;case 13:break W;case 12:break X;case 8:break Y;case 7:break Z;case 4:break _;case 1:break $;default:break O}}break q}e=Wb(v[a+484360>>2],w[j|0]);if(x[d+244>>1]==65535){A=d,C=El(v[e>>2],v[e+4>>2]),u[A+244>>1]=C}e=El(v[e>>2],v[e+4>>2]);v[23588]=0;u[d+246>>1]=e;e=Q(646,d+160|0,d+287|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}aa:{ba:{switch(e-254|0){case 1:e=65535;break aa;case 0:break ba;default:break aa}}e=65534}f=w[j|0];m=v[a+484360>>2];v[23588]=0;R(522,Wb(m,f)|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break q}g=(g&65535)==65535?b:g;break U}v[23588]=0;e=S(194,d+160|0)|0;f=v[23588];v[23588]=0;ca:{da:{if((f|0)!=1){if(e>>>0>=(g&65535)>>>0){break da}e=x[d+248>>1];break ca}break q}e=e-g|0;u[d+248>>1]=e}Ve(Wb(v[a+484360>>2],w[j|0]),e&65535);break U}v[23588]=0;e=S(206,d+160|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}t[d+251|0]=e;break U}v[23588]=0;e=S(206,d+160|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}t[d+250|0]=e;break U}v[23588]=0;f=Q(617,d+160|0,d+144|0)|0;m=v[23588];v[23588]=0;if((m|0)!=1){if(w[d+144|0]|!f|(w[d+146|0]|w[d+145|0]!=255)){break O}if(w[d+147|0]|w[d+148|0]!=1){break O}if(!w[d+149|0]){break U}break O}break q}v[23588]=0;R(534,d+152|0,d+160|0);e=v[23588];v[23588]=0;ea:{fa:{ga:{ha:{if((e|0)!=1){m=Oc(d+152|0);e=v[h>>2];z=fd(e,v[d+212>>2]);f=w[d+152|0];if(z>>>0<=f>>>0){break U}switch(w[Te(d+152|0)|0]){case 4:break fa;case 2:break ga;case 0:break ha;default:break ea}}break q}A=Lb(e,f),C=w[m|0]^128,t[A|0]=C;e=d+144|0;Db(e,v[d+232>>2],w[d+152|0]);Ze(e,0);break ea}A=Lb(e,f),C=128,t[A|0]=C;e=d+144|0;Db(e,v[d+232>>2],w[d+152|0]);Ze(e,1);break ea}A=Lb(e,f),C=128,t[A|0]=C;e=d+144|0;Db(e,v[d+232>>2],w[d+152|0]);Ze(e,0)}ia:{if(s){break ia}s=0;e=v[k+4>>2];if(!hq(v[k>>2],e)){break U}f=e-56|0;e=w[d+152|0];if(w[Lb(v[f>>2],e)|0]!=w[Lb(v[h>>2],e)|0]){break ia}Db(d+144|0,v[f+24>>2],e);e=Cb(v[v[d+144>>2]>>2],v[d+148>>2]);Db(d+136|0,v[d+232>>2],w[d+152|0]);if((Cb(v[v[d+136>>2]>>2],v[d+140>>2])|0)==(e|0)){break U}}s=1;break U}v[23588]=0;R(260,d+144|0,d+160|0);e=v[23588];v[23588]=0;if((e|0)==1){break q}e=v[d+220>>2];m=fd(e,v[d+224>>2]);f=w[d+144|0];if(m>>>0<=f>>>0){break U}m=Oc(d+144|0);A=Lb(e,f),C=(w[m|0]>>>2|0)+1|0,t[A|0]=C}b=b+1|0;continue}break}e=1}Bb(d+160|0);if(!e){break M}Nm(d+184|0);continue}break}break q}b=1}Zd(d+192|0)}Tt(h)}Bb(l);if(!b){Nf(d+264|0);continue}break}e=0;if((b|0)!=2){break w}}e=0;Gj(i,0);b=v[k>>2];if(pc(b,v[k+4>>2])){break w}if(!(c&2)){break x}v[23588]=0;U(641,d+160|0,o|0,1347244868);b=v[23588];v[23588]=0;if((b|0)==1){break y}A=d,C=Fb(v[d+160>>2]),v[A+8>>2]=C;e=a+480190|0;g=d+53|0;h=d+57|0;j=Fb(v[d+164>>2]);l=w[d+287|0];while(1){b=v[d+8>>2];if(!Pb(b,j)){Vc(d+160|0);b=v[k>>2];break x}ja:{ka:{la:{if(!l){v[23588]=0;f=Q(647,b|0,d+40|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break ka}if(!f){break ja}f=x[d+92>>1];i=f+1|0;u[d+144>>1]=i;if(f>>>0>3998){break la}A=a,C=x[le(e,d+144|0)>>1],u[A+480190>>1]=C;v[23588]=0;R(648,d+40|0,(B(i&65535,104)+a|0)+484380|0);f=v[23588];v[23588]=0;if((f|0)==1){break ka}f=d+24|0;uR(f,g);v[23588]=0;R(222,d+192|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){f=d+192|0;Dc(((x[d+144>>1]<<5)+a|0)+946304|0,f);zb(f);break la}break ka}v[23588]=0;f=Q(649,b|0,d+40|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break ka}if(!f){break ja}f=x[d+96>>1];i=f+1|0;u[d+144>>1]=i;if(f>>>0>3998){break la}A=a,C=x[le(e,d+144|0)>>1],u[A+480190>>1]=C;v[23588]=0;R(650,d+40|0,(B(i&65535,104)+a|0)+484380|0);f=v[23588];v[23588]=0;if((f|0)==1){break ka}f=d+24|0;uR(f,h);v[23588]=0;R(222,d+192|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break ka}f=d+192|0;Dc(((x[d+144>>1]<<5)+a|0)+946304|0,f);zb(f)}f=x[d+144>>1];if((f-1&65535)>>>0>3998){break ja}i=_c(d+40|0,8,1,0,2);v[23588]=0;W(219,i|0,(B(f,104)+a|0)+484380|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break ja}}b=P()|0;O()|0;Vc(d+160|0);break j}Nf(d+8|0);continue}}b=P()|0;O()|0;break k}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break j}b=Yz(b,0);v[a+480196>>2]=w[b+43|0];v[a+480204>>2]=B(w[b+42|0],1e4);Ve(Wb(v[a+484360>>2],w[a+484376|0]),x[b+40>>1]);b=0;while(1){if(x[a+480188>>1]>b>>>0){e=(b<<5)+a|0;g=e+480280|0;ef(g);h=Yz(v[k>>2],0);A=e+480286|0,C=w[Lb(v[h+12>>2],b)|0],u[A>>1]=C;A=e+480284|0,C=w[Lb(v[h>>2],b)|0],u[A>>1]=C;Db(d+40|0,v[h+24>>2],b);A=g,C=v[g>>2]&-257|(Cb(v[v[d+40>>2]>>2],v[d+44>>2])?256:0),v[A>>2]=C;b=b+1|0;continue}break}v[23588]=0;b=Q(1,d+192|0,(w[d+287|0]?17096:16969)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break r}Jb(a+1298344|0,b);Ab(b);v[23588]=0;b=Q(1,d+24|0,10087)|0;e=v[23588];v[23588]=0;if((e|0)==1){break s}Jb(a+1298356|0,b);Ab(b);v[a+1298404>>2]=5;e=1;if(!(c&1)|!x[a+480188>>1]){break w}v[23588]=0;U(641,d+8|0,o|0,1146045008);b=v[23588];v[23588]=0;if((b|0)==1){break t}b=v[d+12>>2];c=v[d+8>>2];v[23588]=0;l=a+484344|0;R(225,l|0,Cf(c,b)&65535);b=v[23588];v[23588]=0;if((b|0)==1){break v}A=d,C=Fb(v[d+8>>2]),v[A+144>>2]=C;r=Fb(v[d+12>>2]);while(1){j=v[d+144>>2];if(!Pb(j,r)){ma:{na:{b=v[k>>2];e=v[k+4>>2];if(hq(b,e)>>>0<2){break na}j=a+484348|0;g=0;while(1){if(hq(b,e)>>>0<=g>>>0){break na}i=v[a+484344>>2];n=v[j>>2];h=yj(v[a+484360>>2],g&255);m=v[h>>2];c=Yz(b,g);f=x[c+36>>1];if(ye(i,n,x[dc(m,f)>>1])){v[23588]=0;e=Q(360,h|0,f|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ma}oa:{if(!s){break oa}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break oa}Db(d+40|0,v[c+24>>2],b);f=Cb(v[v[d+40>>2]>>2],v[d+44>>2]);h=Zb(v[l>>2],e);pa:{if(f){Ae(h,Fh(wo(Ue(Oe(d+40|0,20,145),0),b&65535)));break pa}Ae(h,Fh(wo(Ue(Oe(d+40|0,9,w[Lb(v[c>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;Ae(Zb(v[l>>2],e),Fh(Ue(Oe(b,16,w[c+43|0]),0)));Ae(Zb(v[l>>2],e),Fh(Ue(Oe(b,17,w[c+42|0]),0)));e=v[k+4>>2];b=v[k>>2]}g=g+1|0;continue}}Vc(d+8|0);e=1;break w}b=P()|0;O()|0;break u}b=v[j>>2];v[23588]=0;b=S(160,b|0)|0;c=v[23588];v[23588]=0;qa:{ra:{sa:{ta:{ua:{va:{wa:{if((c|0)==1){break wa}v[23588]=0;c=S(157,j|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break wa}if((b|0)!=(c|0)){break qa}b=v[j>>2];v[23588]=0;b=Q(651,b|0,8)|0;c=v[23588];v[23588]=0;if((c|0)==1){break wa}if(!b){break qa}v[23588]=0;i=Q(646,j|0,d+287|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ra}v[23588]=0;p=S(194,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break sa}v[23588]=0;b=W(226,l|0,i|0,p|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break sa}if(!b){break qa}f=0;while(1){if((f|0)==(p|0)){break qa}b=Zb(v[l>>2],i);c=Df(v[b>>2],v[v[b+48>>2]+12>>2],f);v[23588]=0;b=S(194,j|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break va}xa:{if(b>>>0>=3){v[23588]=0;U(190,d+160|0,j|0,b-2|0);b=v[23588];v[23588]=0;if((b|0)==1){break ta}b=d+160|0;h=kc(d+40|0,b);Bb(b);while(1){b=v[h>>2];v[23588]=0;b=W(156,b|0,v[d+48>>2],3)|0;e=v[23588];v[23588]=0;if((e|0)==1){break xa}if(b){v[23588]=0;R(260,d+160|0,h|0);b=v[23588];v[23588]=0;ya:{za:{Aa:{Ba:{if((b|0)!=1){u[d+136>>1]=x[a+480188>>1]-1;A=d,C=w[Oc(d+160|0)|0],u[A+264>>1]=C;e=x[Wc(d+136|0,d+264|0)>>1];g=c+B(e,6)|0;b=t[d+160|0];if((b|0)>=0){break ya}v[23588]=0;b=S(206,h|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break ua}if(w[d+287|0]){break Aa}if((b|0)!=255){break Ba}b=254;break za}break ua}if(b>>>0>128){break za}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break za}b=b>>>0<85?b+36|0:b}t[g|0]=b;b=w[d+160|0]}if(b&64){v[23588]=0;b=S(206,h|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break ua}t[g+1|0]=b+1;b=w[d+160|0]}if(b&32){v[23588]=0;b=S(206,h|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break ua}t[d+136|0]=b;t[g+2|0]=1;t[d+264|0]=127;A=g,C=w[Xb(d+136|0,d+264|0)|0]+1>>>1|0,t[A+4|0]=C;b=w[d+160|0]}if(!(b&16)){continue}v[23588]=0;R(260,d+136|0,h|0);b=v[23588];v[23588]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((b|0)!=1){b=w[Oc(d+136|0)|0];t[g+5|0]=b;switch(w[d+136|0]-1|0){case 72:break Da;case 71:break Ea;case 70:break Fa;case 61:break Ga;case 60:break Ha;case 53:break Ia;case 52:break Ja;case 51:break Ka;case 50:break Ma;case 43:break Na;case 42:break Oa;case 41:break Pa;case 40:break Qa;case 31:break Ra;case 30:break Sa;case 23:break Ta;case 22:break Ua;case 21:break Va;case 20:break Wa;case 18:break Xa;case 17:break Ya;case 15:break Za;case 16:break _a;case 14:break $a;case 13:break ab;case 12:break bb;case 11:break cb;case 10:break db;case 3:break eb;case 2:break fb;case 1:break gb;case 0:break hb;default:break Ca}}break ua}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b<<4|15;continue}t[g+5|0]=b<<3|15;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b<<4;continue}t[g+5|0]=b<<3&240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b|240;continue}t[g+5|0]=b>>>1|240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b&15;continue}if(b>>>0<=1){t[g+5|0]=b|240;continue}t[g+5|0]=b>>>1&15;continue}t[(c+B(e,6)|0)+3|0]=2;A=g,C=St(b,w[d+287|0])|240,t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=2;A=g,C=St(b,w[d+287|0]),t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=3;A=g,C=St(b,w[d+287|0])|240,t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=3;A=g,C=St(b,w[d+287|0]),t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=4;if(w[d+287|0]){continue}t[g+5|0]=(b&252)>>>2;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&1|16;continue}t[(c+B(e,6)|0)+3|0]=6;t[g+5|0]=b&240;continue}t[(c+B(e,6)|0)+3|0]=6;t[g+5|0]=(b&240)>>>4;continue}t[(c+B(e,6)|0)+3|0]=20;continue}t[(c+B(e,6)|0)+3|0]=5;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|48;continue}t[(c+B(e,6)|0)+3|0]=7;t[g+5|0]=b|240;continue}t[(c+B(e,6)|0)+3|0]=7;continue}t[(c+B(e,6)|0)+3|0]=8;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|64;continue}t[(c+B(e,6)|0)+3|0]=10;v[23588]=0;b=S(206,h|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break La}break ua}t[(c+B(e,6)|0)+3|0]=15;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|192;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|208;continue}t[(c+B(e,6)|0)+3|0]=12;b=(b&254)>>>1|0}t[g+5|0]=b;v[23588]=0;Q(188,h|0,1)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}break ua}t[(c+B(e,6)|0)+3|0]=14;t[g+5|0]=0;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|176;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|224;continue}t[(c+B(e,6)|0)+3|0]=16;continue}t[(c+B(e,6)|0)+3|0]=17;continue}t[(c+B(e,6)|0)+3|0]=1;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|32;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|128;continue}t[(c+B(e,6)|0)+3|0]=0;continue}break}Bb(h)}f=f+1|0;continue}break}break ua}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;Bb(h);break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}Nf(d+144|0);continue}}Vc(d+272|0);tR(k);Bb(d+304|0);break b}b=P()|0;O()|0}Vc(d+8|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;Bb(d+160|0);break m}b=P()|0;O()|0;break l}b=P()|0;O()|0;Ab(d+160|0);break l}b=P()|0;O()|0;break l}Zd(d+192|0)}Tt(h)}Bb(l)}Vc(d+272|0);break h}b=P()|0;O()|0}tR(k);break f}b=P()|0;O()|0}Bb(d+304|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}Zd(o);Bb(q);T(b|0);L()}Zd(o);Bb(q)}kb=d+384|0;return e|0}function Lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=kb-480|0;kb=d;zc(b);h=d+472|0;e=Ou(b,h);if(!e){WS(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!e){break k}if(!XS(d+472|0)){break k}if(!c){A=1;break k}H=ke(d+448|0,b);v[23588]=0;R(493,d+432|0,H|0);b=v[23588];v[23588]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((b|0)!=1){v[23588]=0;U(494,d+408|0,d+432|0,20041);b=v[23588];v[23588]=0;if((b|0)==1){break u}v[23588]=0;e=S(178,v[d+408>>2])|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}if(!e){break l}v[23588]=0;e=Q(495,d+408|0,d+312|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}if(!e){break l}v[23588]=0;R(246,a|0,16384);b=v[23588];v[23588]=0;if((b|0)==1){break m}v[a+480208>>2]=8;v[23588]=0;e=W(264,a+1074312|0,9,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;e=W(264,e|0,114,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;e=Q(265,e|0,21)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;Q(265,e|0,30)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;e=Q(1,d+296|0,8240)|0;b=v[23588];v[23588]=0;if((b|0)==1){break r}Jb(a+1298344|0,e);Ab(e);v[23588]=0;e=Q(1,d+280|0,10672)|0;b=v[23588];v[23588]=0;if((b|0)==1){break q}Jb(a+1298356|0,e);Ab(e);v[23588]=0;g=Q(1,d+264|0,17466)|0;b=v[23588];v[23588]=0;if((b|0)==1){break p}e=15022;b=w[d+476|0];switch(b-16|0){case 1:break n;case 0:break t;default:break s}}f=P()|0;O()|0;break a}f=P()|0;O()|0;break b}e=15003;break n}if(!b){break o}e=21619;break n}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}e=13174}v[23588]=0;h=Q(1,d+248|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;U(2,d+208|0,g|0,h|0);b=v[23588];v[23588]=0;if((b|0)==1){break f}e=d+208|0;Jb(a+1298368|0,e);Ab(e);Ab(h);Ab(g);v[a+1298404>>2]=5;b=d+96|0;Ne(b,3,d+312|0);v[23588]=0;R(222,e|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break g}b=d+208|0;Bc(a+1298308|0,b);zb(b);b=d+232|0;Dj(b,3,d+344|0);v[23588]=0;R(222,d+96|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break h}v[23588]=0;U(11,d+208|0,5,d+96|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}b=d+208|0;Jb(a+1298320|0,b);Ab(b);zb(d+96|0);v[a+480200>>2]=w[d+368|0]+1;I=a,J=Dd(w[d+369|0],1,255),v[I+480196>>2]=J;I=a,J=B(Dd(w[d+370|0],4,255),1e4),v[I+480204>>2]=J;h=v[a+484360>>2];e=a+484376|0;b=w[e|0];v[23588]=0;da(340,Wb(h,b)|0,d+408|0,x[d+364>>1],65535,65535);b=v[23588];v[23588]=0;if((b|0)==1){break m}Ve(Wb(v[a+484360>>2],w[e|0]),x[d+366>>1]);u[a+480188>>1]=0;b=0;while(1){if((b|0)==32){v[23588]=0;U(494,d+208|0,d+432|0,17741);b=v[23588];v[23588]=0;if((b|0)!=1){b=d+208|0;h=hd(d+408|0,b);Bb(b);b=v[h>>2];v[23588]=0;e=S(160,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;X(331,a+1298332|0,h|0,e|0,0);b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;U(494,d+208|0,d+432|0,21321);b=v[23588];v[23588]=0;if((b|0)!=1){b=d+208|0;j=hd(h,b);Bb(b);b=v[j>>2];v[23588]=0;e=S(178,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}v:{w:{if(e){v[23588]=0;U(494,d+208|0,d+432|0,16723);b=v[23588];v[23588]=0;if((b|0)==1){break v}v[23588]=0;g=S(206,j|0)|0;b=v[23588];v[23588]=0;x:{if((b|0)!=1){h=c&2;i=a+480190|0;while(1){if(g>>>0<=(n&255)>>>0){break x}v[23588]=0;r=S(206,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}if(!r){break x}e=v[j+8>>2];b=v[j>>2];v[23588]=0;e=W(156,b|0,e|0,56)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}if(!e){break x}if(r>>>0>x[i>>1]){u[i>>1]=r}v[23588]=0;p=B(r,104)+a|0;A=p+484380|0;R(277,A|0,0);b=v[23588];v[23588]=0;if((b|0)==1){break w}uo(A);v[23588]=0;U(314,j|0,((r<<5)+a|0)+946304|0,32);b=v[23588];v[23588]=0;if((b|0)==1){break w}v[23588]=0;R(317,j|0,p+484423|0);b=v[23588];v[23588]=0;if((b|0)==1){break w}y:{if(w[d+476|0]<=15){v[23588]=0;f=S(194,j|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break y}break w}v[23588]=0;f=S(157,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}}v[p+484404>>2]=f<<1;v[23588]=0;e=S(157,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}v[A>>2]=e;v[23588]=0;e=S(157,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}l=p+484384|0;v[l>>2]=e;v[23588]=0;e=S(157,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}F=p+484388|0;v[F>>2]=e;if(e){b=p+484414|0;u[b>>1]=x[b>>1]|2;v[F>>2]=e+v[l>>2]}v[23588]=0;e=S(206,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}if(w[d+476|0]<=15){u[p+484410>>1]=e}v[23588]=0;r=S(206,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}b=p+484414|0;e=x[b>>1];o=8;if(r&1){e=e|1;u[b>>1]=e;v[A>>2]=v[A>>2]>>>1;v[l>>2]=v[l>>2]>>>1;v[F>>2]=v[F>>2]>>>1;o=16}u[b>>1]=e&65531|r<<1&4;b=_c(d+96|0,o,1,0,((r&12)!=0)<<3);z:{if(!h){break z}v[23588]=0;W(219,b|0,A|0,d+208|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break z}break w}n=n+1|0;continue}}break w}Bb(d+208|0)}v[23588]=0;U(494,d+208|0,d+432|0,18761);b=v[23588];v[23588]=0;A:{if((b|0)!=1){b=d+208|0;k=hd(j,b);Bb(b);b=v[k>>2];v[23588]=0;e=S(178,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break m}if(!e){break A}s=Tb(d+96|0);y=Tb(d+232|0);z=Tb(d+192|0);v[23588]=0;U(494,d+168|0,d+432|0,17750);b=v[23588];v[23588]=0;B:{if((b|0)==1){break B}b=v[d+180>>2];e=d- -64|0;v[e>>2]=v[d+176>>2];v[e+4>>2]=b;v[d+72>>2]=v[d+184>>2];v[23588]=0;b=v[d+172>>2];v[d+56>>2]=v[d+168>>2];v[d+60>>2]=b;R(496,d+56|0,s|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}v[23588]=0;U(494,d+144|0,d+432|0,17744);b=v[23588];v[23588]=0;if((b|0)==1){break B}b=v[d+156>>2];v[d+40>>2]=v[d+152>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+160>>2];v[23588]=0;b=v[d+148>>2];v[d+32>>2]=v[d+144>>2];v[d+36>>2]=b;R(496,d+32|0,y|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}v[23588]=0;U(494,d+120|0,d+432|0,17734);b=v[23588];v[23588]=0;if((b|0)==1){break B}b=v[d+132>>2];v[d+16>>2]=v[d+128>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+136>>2];v[23588]=0;b=v[d+124>>2];v[d+8>>2]=v[d+120>>2];v[d+12>>2]=b;R(496,d+8|0,z|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}v[23588]=0;p=S(206,k|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break B}j=d+208|1;A=a+480190|0;o=0;while(1){if(p>>>0<=(o&255)>>>0){mo(z);mo(y);mo(s);break A}v[23588]=0;R(260,d+80|0,k|0);b=v[23588];v[23588]=0;C:{if((b|0)!=1){E=Oc(d+80|0);D:{E:{if(!w[d+80|0]){break E}h=v[k+8>>2];e=v[k>>2];b=w[E|0];v[23588]=0;e=W(156,e|0,h|0,B(b,14)+32|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break B}if(!e){break E}v[23588]=0;m=W(251,a|0,w[d+80|0],0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break B}if(m){break D}}b=w[E|0];v[23588]=0;Q(188,k|0,B(b,14)+32|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break C}break B}v[23588]=0;U(314,k|0,m+492|0,32);b=v[23588];v[23588]=0;if((b|0)==1){break B}l=m+88|0;F=m+68|0;r=m+48|0;i=m+236|0;b=0;n=0;while(1){if(w[E|0]<=(n&255)>>>0){break C}v[23588]=0;R(497,k|0,d+208|0);e=v[23588];v[23588]=0;if((e|0)==1){break B}e=w[d+208|0];F:{if(!e|e>>>0>x[A>>1]){break F}if(w[j|0]>=129){t[j|0]=128}while(1){e=b&255;g=w[d+209|0];if(e>>>0>g>>>0){e=v[s+4>>2];b=v[s>>2];v[23588]=0;X(498,r|0,w[d+211|0],b|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}e=v[y+4>>2];b=v[y>>2];v[23588]=0;X(498,F|0,w[d+213|0],b|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}e=v[z+4>>2];b=v[z>>2];v[23588]=0;X(498,l|0,w[d+221|0],b|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break B}v[m>>2]=x[d+214>>1]+1>>>1;e=w[d+208|0];G:{if(w[d+211|0]&64){u[(B(e,104)+a|0)+484410>>1]=w[d+210|0];break G}b=(B(e,104)+a|0)+484414|0;u[b>>1]=x[b>>1]|32768}u[d+118>>1]=w[d+212|0]<<1;u[d+116>>1]=254;C=B(e,104)+a|0;I=C+484408|0,J=x[Wc(d+118|0,d+116|0)>>1],u[I>>1]=J;t[C+484418|0]=w[(w[d+219|0]&3)+26660|0];e=C+484419|0;G=w[d+218|0];t[e|0]=G;h=w[d+217|0]+3>>>2|0;t[C+484420|0]=h;t[C+484421|0]=w[d+216|0];b=g+1|0;if(G){g=Ml(Ec(((h<<8|G>>>1)>>>0)/(G>>>0)|0,0))}else{g=255}t[e|0]=g;if(!(w[d+213|0]&64)){break F}e=C+484414|0;u[e>>1]=x[e>>1]|32}else{I=dc(i,e),J=w[d+208|0],u[I>>1]=J;b=b+1|0;continue}break}}n=n+1|0;continue}}break B}o=o+1|0;continue}}f=P()|0;O()|0;mo(z);mo(y);mo(s);break c}f=P()|0;O()|0;break c}A=1;s=Tb(d+232|0);H:{if(!(c&1)){break H}v[23588]=0;U(494,d+208|0,d+432|0,21076);b=v[23588];v[23588]=0;I:{J:{K:{L:{M:{N:{if((b|0)!=1){g=hd(k,d+208|0);b=v[g>>2];v[23588]=0;c=S(178,b|0)|0;b=v[23588];v[23588]=0;O:{P:{Q:{if((b|0)!=1){Bb(d+208|0);if(!c){break O}v[23588]=0;e=S(194,g|0)|0;c=v[23588];v[23588]=0;b=1;if((c|0)==1){break Q}v[23588]=0;h=e+1|0;R(499,s|0,h|0);c=v[23588];v[23588]=0;if((c|0)==1){break Q}while(1){if((b|0)==(h|0)){break O}v[23588]=0;e=S(194,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break P}v[23588]=0;U(190,d+96|0,g|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break P}c=d+96|0;e=kc(d+208|0,c);hd(Pg(v[s>>2],b),e);Bb(e);b=b+1|0;Bb(c);continue}}f=P()|0;O()|0;Bb(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}v[23588]=0;U(494,d+208|0,d+432|0,16720);b=v[23588];v[23588]=0;if((b|0)==1){break K}k=hd(g,d+208|0);b=v[k>>2];v[23588]=0;c=S(178,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break L}Bb(d+208|0);if(!c){break N}v[23588]=0;G=S(206,k|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break J}o=0;R:{S:{T:while(1){U:{if(G>>>0<=(o&65535)>>>0){v[23588]=0;Q(155,k|0,1)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break U}break J}n=32;V:{if(w[d+476|0]<16){break V}v[23588]=0;R(500,k|0,d+208|0);b=v[23588];v[23588]=0;if((b|0)==1){break R}n=w[d+208|0];if(n>>>0<=x[a+480188>>1]|n>>>0>32){break V}u[a+480188>>1]=n}b=0;while(1){h=b&65535;if(h>>>0>=n>>>0){o=o+1|0;continue T}v[23588]=0;e=S(194,k|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break S}if(!(!e|h>>>0>31|h>>>0<x[a+480188>>1])){u[a+480188>>1]=b+1}b=b+1|0;continue}}break}v[23588]=0;z=a+484344|0;R(225,z|0,G|0);b=v[23588];v[23588]=0;if((b|0)==1){break J}F=d+208|2;m=0;while(1){if((m|0)==(G|0)){break N}C=Mb(d+96|0);W:{if(w[d+476|0]<16){j=32;h=64;break W}v[23588]=0;R(500,k|0,d+208|0);b=v[23588];v[23588]=0;if((b|0)==1){break M}c=w[d+209|0];j=w[d+208|0];b=d+80|0;qf(b,F,16,3);v[23588]=0;R(222,d+192|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break M}b=d+192|0;Bc(C,b);zb(b);h=c+1|0}v[23588]=0;c=W(226,z|0,m&65535,h|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break M}X:{if(!c){v[23588]=0;Q(188,k|0,j<<1)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break X}break M}b=v[z>>2];v[23588]=0;R(281,Zb(b,m)|0,C|0);b=v[23588];v[23588]=0;if((b|0)==1){break M}r=h-1|0;p=0;while(1){E=p&65535;if(E>>>0>=j>>>0){break X}v[23588]=0;c=S(194,k|0)|0;b=v[23588];v[23588]=0;Y:{if((b|0)!=1){if(!c){break Y}b=v[s>>2];if(Cf(b,v[s+4>>2])>>>0<=c>>>0|E>>>0>=x[a+480188>>1]){break Y}D=Pg(b,c);zc(D);c=0;Z:while(1){e=c;if(h>>>0<=e>>>0){break Y}c=v[D+8>>2];b=v[D>>2];v[23588]=0;c=W(156,b|0,c|0,1)|0;b=v[23588];v[23588]=0;_:{$:{aa:{ba:{ca:{if((b|0)!=1){if(!c){break Y}b=Zb(v[z>>2],m);b=jd(v[b>>2],v[v[b+48>>2]+12>>2],e,E);v[23588]=0;g=S(206,D|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}f=g>>>2|0;switch((g&3)-1|0){case 2:break $;case 1:break aa;case 0:break ba;default:break ca}}break M}c=(e+f|0)+1|0;continue}c=0;if(!e){continue}c=Zb(v[z>>2],m);i=jd(v[c>>2],v[v[c+48>>2]+12>>2],e-1|0,E);while(1){c=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[i+4|0]|w[i+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;c=e+1|0;if((e|0)==(r|0)){continue Z}b=B(x[a+480188>>1],6)+b|0;g=f&255;e=c;f=f-1|0;if(g){continue}break}continue}if(e>>>0<=f>>>0){break _}c=Zb(v[z>>2],m);g=jd(v[c>>2],v[v[c+48>>2]+12>>2],f,E);c=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;break _}if(f&1){v[23588]=0;g=S(206,D|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}t[b|0]=g>>>0>120?-1:g}if(f&2){v[23588]=0;g=S(206,D|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}t[b+1|0]=g}n=0;c=0;da:{if(f&4){v[23588]=0;c=S(206,D|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break da}}o=0;if(f&8){v[23588]=0;i=S(206,D|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break da}n=i&15;o=i>>>4|0}l=0;i=0;if(f&16){v[23588]=0;i=S(206,D|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break da}}if(f&32){v[23588]=0;l=S(206,D|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break da}}g=c;q=kb-32|0;kb=q;c=q+24|0;SS(c,n,i);y=Oc(c);c=q+16|0;SS(c,((o-1&255)>>>0<6?o+15|0:o)&255,l);l=Oc(c);ea:{fa:{ga:{if(w[q+24|0]==10){i=w[l|0];c=w[y|0]&15;t[y|0]=c?-1:i;c=i|c<<8;f=w[q+16|0];if((f|0)!=10){break ga}f=0;t[q+16|0]=0;break ga}if(w[q+16|0]!=10){break fa}c=w[l|0]&15;t[l|0]=c?-1:0;c=c<<8;f=w[q+24|0]}if(c-256>>>0>4294967038){break fa}if(Ki(f)>>>0>=Ki(10)>>>0){break fa}t[b+5|0]=c;t[b+2|0]=15;t[b+3|0]=10;t[b+4|0]=c>>>8;break ea}if(g){t[b+2|0]=1;t[b+4|0]=g+2>>>2}Vu(q+24|0,y,q+16|0,l);c=w[q+16|0];ha:{ia:{i=w[q+24|0];if(i){if((i|0)==20|(i|0)!=(c&255)){break ia}c=i}break ha}if(!(c&255)){t[b+5|0]=w[y|0];t[b+3|0]=i;break ea}if(!g){Bo(q+8|0,b,i,w[y|0],c&255,w[l|0]);break ea}if(Ki(i)>>>0>Ki(c&255)>>>0){t[b+5|0]=w[y|0];t[b+3|0]=i;break ea}}t[b+5|0]=w[l|0];t[b+3|0]=c}kb=q+32|0;break _}break M}c=e+1|0;continue}}break M}p=p+1|0;continue}}zb(C);m=m+1|0;continue}}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}v[23588]=0;U(494,d+208|0,d+432|0,20048);b=v[23588];v[23588]=0;ja:{ka:{if((b|0)!=1){h=hd(k,d+208|0);b=v[h>>2];v[23588]=0;c=S(178,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ka}Bb(d+208|0);if(!c){break H}e=a+484348|0;while(1){if(!Bf(v[a+484344>>2],v[e>>2])){break H}c=v[h+8>>2];b=v[h>>2];v[23588]=0;c=W(156,b|0,c|0,16)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ja}if(!c){break H}v[23588]=0;R(385,h|0,d+208|0);b=v[23588];v[23588]=0;if((b|0)!=1){b=v[a+484344>>2];v[23588]=0;R(386,Zb(b,0)|0,d+208|0);b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;Bb(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;zb(C);break I}f=P()|0;O()|0;Bb(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0}Vc(s);break c}Vc(s);break l}f=P()|0;O()|0;Bb(d+208|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}i=(b<<5)+a|0;g=i+480280|0;ef(g);h=t[(b+d|0)+371|0];e=h<<1&254;u[i+480284>>1]=(e|0)==254?256:e;la:{if((h|0)<0){v[g>>2]=v[g>>2]|1024;break la}u[a+480188>>1]=b+1}v[23588]=0;R(501,d+408|0,i+480289|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}b=b+1|0;continue}}f=P()|0;O()|0;break c}Bb(d+408|0);Zd(d+432|0);Bb(H)}kb=d+480|0;return A|0}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(d+96|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;Ab(h);break d}f=P()|0;O()|0}Ab(g)}Bb(d+408|0)}Zd(d+432|0)}Bb(H);T(f|0);L()}function Rja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=kb-240|0;kb=d;zc(b);e=kb-16|0;kb=e;h=d+216|0;Au(e+8|0,h);g=v[e+12>>2];nc(e,v[b>>2],v[b+8>>2],v[e+8>>2],v[e+12>>2]);j=v[e+4>>2];if((j|0)==(g|0)){_b(b,v[e+12>>2])}kb=e+16|0;e=(g|0)==(j|0);if(!e){AU(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!BU(d+216|0)){break n}if(!c){f=1;break n}Bd(a,1024);ag(a);v[a+480208>>2]=v[a+480208>>2]|12;_f(a+1074312|0,21);e=Ib(x[d+232>>1]);if(e){v[a+480204>>2]=B(e,1e4)}e=Ib(x[d+230>>1]);if(e){v[a+480196>>2]=e}if(!w[d+226|0]){oh(a,1)}MB(b,a+1298308|0,cc(v[d+220>>2])-14|0);b=ke(d+112|0,b);v[23588]=0;R(338,d+200|0,b|0);e=v[23588];v[23588]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((e|0)!=1){Bb(b);v[23588]=0;U(339,d+112|0,d+200|0,1395544366);b=v[23588];v[23588]=0;if((b|0)==1){break s}v[23588]=0;b=S(275,v[d+112>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}if(!b){break r}v[23588]=0;b=S(271,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}v[23588]=0;e=S(271,d+112|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}v[23588]=0;Q(188,d+112|0,4)|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}f=a+484376|0;g=w[f|0];h=v[a+484360>>2];v[23588]=0;da(340,Wb(h,g)|0,d+112|0,b|0,65535,65535);b=v[23588];v[23588]=0;if((b|0)==1){break y}Ve(Wb(v[a+484360>>2],w[f|0]),e);b=d+112|0;Bb(b);v[23588]=0;U(339,b|0,d+200|0,1346458708);b=v[23588];v[23588]=0;if((b|0)==1){break x}v[23588]=0;e=S(275,v[d+112>>2])|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}v[23588]=0;e=S(271,d+112|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break w}u[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}v[23588]=0;b=S(271,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break w}v[23588]=0;R(225,a+484344|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break w}b=0;v[23588]=0;o=S(279,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break w}switch(o-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}e=P()|0;O()|0;Bb(b);break a}e=P()|0;O()|0;Bb(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bb(d+112|0);break b}if(o){break t}}b=1}Bb(d+112|0);if(!b){break o}v[23588]=0;U(339,d+176|0,d+200|0,1398157625);b=v[23588];v[23588]=0;if((b|0)==1){break d}v[23588]=0;b=S(275,v[d+176>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}if(!b){break q}v[23588]=0;Q(188,d+176|0,2)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}v[23588]=0;b=S(279,d+176|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}G=a,H=Qe((+(b>>>0)*2.3283064365386963e-10+ +(y[a+480204>>2]/1e4>>>0))*1e4),v[G+480204>>2]=H;b=0;v[23588]=0;Q(341,d+176|0,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}f=x[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){G=d,H=Ib(x[(d+112|0)+(b<<1)>>1]),v[G+48>>2]=H;v[d+32>>2]=180;e=v[td(d+48|0,d+32|0)>>2]-90|0;g=e>>31;G=((b<<5)+a|0)+480284|0,H=Ic(Pka(e<<7|45,g<<7|e>>>25,90,0),nb)+128|0,u[G>>1]=H;b=b+1|0;continue}else{z:{v[23588]=0;Q(188,d+176|0,16)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break z}break c}}break}v[23588]=0;b=W(156,v[d+176>>2],v[d+184>>2],2)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}A:{if(b){v[23588]=0;b=S(271,d+176|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break A}u[d+48>>1]=b;u[d+32>>1]=256;G=a,H=x[Wc(d+48|0,d+32|0)>>1],v[G+480200>>2]=H}v[23588]=0;Q(188,d+176|0,128)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}v[23588]=0;b=Q(341,d+176|0,d+48|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if(!b){break q}e=x[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){G=d,H=Ib(x[(d+48|0)+(b<<1)>>1]),v[G+32>>2]=H;v[d+16>>2]=128;G=((b<<5)+a|0)+480286|0,H=v[td(d+32|0,d+16|0)>>2]/2&255,u[G>>1]=H;b=b+1|0;continue}else{v[a+480228>>2]=v[a+480228>>2]<<1;break q}}break c}break c}e=P()|0;O()|0;break b}Bb(d+112|0);break p}Bb(d+176|0);v[23588]=0;U(339,d+112|0,d+200|0,1413830740);b=v[23588];v[23588]=0;B:{C:{if((b|0)!=1){v[23588]=0;b=S(275,v[d+112>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break e}if(!b){break B}v[23588]=0;R(342,d+112|0,d+48|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}if((Ib(x[d+58>>1])|0)!=65535){break C}v[23588]=0;Q(188,d+112|0,1)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break C}break e}e=P()|0;O()|0;break b}v[23588]=0;b=S(202,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break e}v[23588]=0;X(331,a+1298332|0,d+112|0,b|0,2);b=v[23588];v[23588]=0;if((b|0)==1){break e}}Bb(d+112|0);v[23588]=0;U(339,d+48|0,d+200|0,1229869908);b=v[23588];v[23588]=0;if((b|0)==1){break h}v[23588]=0;b=S(275,v[d+48>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}if(b){D:{v[23588]=0;b=S(271,d+48|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break i}E:{F:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break F}v[23588]=0;e=W(156,v[d+48>>2],v[d+56>>2],B(f,(b>>>14&2)+50|0)|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break g}if(!e){break F}u[a+480190>>1]=f;g=a+480190|0;h=d+130|0;j=(b|0)>=0;b=1;G:{H:{I:{J:{while(1){if(f>>>0<(b&65535)>>>0){v[23588]=0;b=S(271,d+48|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break G}break g}K:{if(j){p=b}else{v[23588]=0;e=S(271,d+48|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break K}p=e+1|0}u[d+16>>1]=p;v[23588]=0;R(343,d+48|0,d+112|0);e=v[23588];v[23588]=0;if((e|0)==1){break J}e=x[d+16>>1];if((e-4e3&65535)>>>0>=61537){G=a,H=x[le(g,d+16|0)>>1],u[G+480190>>1]=H;m=x[d+234>>1]|x[d+236>>1]<<16;v[23588]=0;X(344,d+112|0,(B(e,104)+a|0)+484380|0,cc(m)|0,o|0);e=v[23588];v[23588]=0;if((e|0)==1){break I}e=d+32|0;Il(e,2,h);v[23588]=0;R(222,d+176|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break H}e=d+176|0;Dc(((x[d+16>>1]<<5)+a|0)+946304|0,e);zb(e)}b=b+1|0;continue}break}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}if((b|0)!=4){break E}u[d+112>>1]=x[a+480190>>1];u[d+176>>1]=255;h=a+480192|0;b=d+176|0;G=h,H=x[Wc(d+112|0,b)>>1],u[G>>1]=H;v[23588]=0;U(339,b|0,d+200|0,1229278806);b=v[23588];v[23588]=0;if((b|0)==1){break j}L:{M:while(1){v[23588]=0;b=W(156,v[d+48>>2],v[d+56>>2],15)|0;e=v[23588];v[23588]=0;if((e|0)==1){break L}if(b){v[23588]=0;R(345,d+48|0,d+32|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}b=Ib(x[d+32>>1]);if(b>>>0>=x[h>>1]){continue}e=B(b,104)+a|0;t[e+484524|0]=w[d+40|0];f=w[d+39|0];t[e+484523|0]=255;t[e+484525|0]=f;v[23588]=0;b=b+1&65535;e=W(251,a|0,b|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break k}if(!e){continue}G=d,H=Ib(w[d+37|0]|w[d+38|0]<<8),u[G+112>>1]=H;u[d+16>>1]=4095;G=e,H=x[Wc(d+112|0,d+16|0)>>1],v[G>>2]=H;b=w[d+35|0];if((b|0)==255){continue}v[23588]=0;b=Q(155,d+176|0,B(b,34)+2|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}if(!b){continue}v[23588]=0;R(346,d+176|0,d+112|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}t[e+60|0]=w[e+60|0]|1;b=x[d+112>>1];v[d+20>>2]=16;v[d+24>>2]=240;G=d,H=Ib(b),v[G+16>>2]=H;b=JB(d+16|0);v[23588]=0;R(291,e+48|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}g=v[e+52>>2];f=v[e+48>>2];b=0;while(1){j=$d(f,g);if(j>>>0<=b>>>0){b=w[d+36|0];if((b|0)!=255){t[e- -64|0]=b;t[e+63|0]=b;t[e+60|0]=w[e+60|0]|4}if(pc(f,g)){continue M}b=j-1|0;t[e+62|0]=b;t[e+61|0]=b;t[e+60|0]=w[e+60|0]|2;continue M}else{t[d+16|0]=64;j=(d+112|0)+(b<<1)|0;t[d+12|0]=w[j+2|0];m=Xb(d+16|0,d+12|0);i=Eb(f,b);t[i+2|0]=w[m|0];u[i>>1]=w[j+3|0];b=b+1|0;continue}}}break}Bb(d+176|0);break D}break k}Bb(d+48|0);break p}}}Bb(d+48|0);v[23588]=0;U(347,d+176|0,d+200|0,1145131092);b=v[23588];v[23588]=0;if((b|0)==1){break m}G=d,H=Fb(v[d+176>>2]),v[G+16>>2]=H;m=a+484344|0;A=c&1;q=d+48|4;C=Fb(v[d+180>>2]);r=(o|0)!=841887798;s=a+480188|0;D=(o|0)!=841887796;while(1){N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{g=v[d+16>>2];if(!Pb(g,C)){Vc(d+176|0);v[23588]=0;U(339,d+112|0,d+200|0,1346458702);b=v[23588];v[23588]=0;if((b|0)!=1){break _}e=P()|0;O()|0;break b}v[23588]=0;Q(188,g|0,4)|0;b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;i=S(271,g|0)|0;b=v[23588];v[23588]=0;$:{if((b|0)!=1){v[23588]=0;j=S(271,g|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break P}j=r?j:(j>>>0)/y[a+480196>>2]|0;if(!A|i>>>0>255){break N}v[23588]=0;b=W(226,m|0,i|0,j|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break P}if(b){break $}break N}e=P()|0;O()|0;break O}if(!r){h=0;v[23588]=0;Q(188,g|0,4)|0;b=v[23588];v[23588]=0;if((b|0)==1){break P}while(1){z=h&65535;if(z>>>0>=x[s>>1]){break N}v[23588]=0;b=S(271,g|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Z}v[23588]=0;U(190,d+48|0,g|0,b+(b&1)&65535);b=v[23588];v[23588]=0;if((b|0)==1){break Q}b=d+48|0;f=kc(d+112|0,b);Bb(b);v[d+48>>2]=0;v[d+52>>2]=0;e=0;aa:{while(1){b=v[f>>2];v[23588]=0;b=W(156,b|0,v[d+120>>2],6)|0;k=v[23588];v[23588]=0;if((k|0)==1){break aa}k=v[d+48>>2];if(b&k>>>0<j>>>0){b=Zb(v[m>>2],i);b=jd(v[b>>2],v[v[b+48>>2]+12>>2],k,z);v[23588]=0;R(348,d+32|0,f|0);k=v[23588];v[23588]=0;ba:{ca:{if((k|0)!=1){k=d+32|0;l=Oc(k);E=Te(k);F=Mi(k);p=jc(k);n=t[d+32|0];if((n-1&255)>>>0>95){break ca}t[b|0]=n+13;if(!v[d+52>>2]){break ba}t[b+3|0]=19;v[d+12>>2]=15;G=b,H=w[td(q,d+12|0)|0]|208,t[G+5|0]=H;break ba}break R}if((n|0)>=0){break ba}if(v[d+52>>2]){t[b+3|0]=19;v[d+12>>2]=15;G=b,H=w[td(q,d+12|0)|0]|192,t[G+5|0]=H;break ba}t[b|0]=254}if(w[l|0]){t[b+2|0]=1;t[d+12|0]=64;G=b,H=w[Xb(l,d+12|0)|0],t[G+4|0]=H}l=w[E|0];if(l){t[b+1|0]=l}l=w[F|0];n=w[p|0];if(l|n){Pf(b,l,n)}l=d+48|0;b=w[k+5|0];if(b&128){v[23588]=0;k=S(206,f|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break R}b=k|b<<8&32512}e=b+e|0;yB(l,e,v[a+480196>>2]);continue}break}Bb(f);h=h+1|0;continue}break}break R}h=0;b=Zb(v[m>>2],i);b=jd(v[b>>2],v[v[b+48>>2]+12>>2],0,0);da:while(1){f=0;if((h|0)==(j|0)){break N}while(1){if(x[s>>1]<=(f&65535)>>>0){h=h+1|0;continue da}v[23588]=0;R(349,d+48|0,g|0);e=v[23588];v[23588]=0;if((e|0)!=1){t[d+12|0]=0;ea:{if(!D){e=v[d+48>>2];v[d+112>>2]=e;i=d+112|0;k=Oc(i);l=Te(i);n=Mi(i);if(e<<24>>24>0){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}e=w[k|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[k|0]}t[b+1|0]=e<<4&48|w[l|0]>>>4;i=w[l|0]&15;t[d+12|0]=i;e=w[n|0];t[b+5|0]=e;break ea}e=v[d+48>>2];v[d+8>>2]=e;v[d+4>>2]=e;e=d+32|0;yu(e,d+4|0,b);i=d+112|0;qB(i,d+12|0,b+5|0);pB(i,e);G=b,H=w[b+1|0]|w[Lb(d+48|0,0)|0]&48,t[G+1|0]=H;e=w[b+5|0];i=w[d+12|0]}Pf(b,i,e&255);e=w[b+3|0];fa:{if(e>>>0>11){break fa}e=1<<e;ga:{if(!(e&2240)){if(!(e&12)){break fa}if(!w[b+5|0]){break ga}break fa}e=w[b+5|0];i=e&240;if(i){t[b+5|0]=i;break fa}if(e){break fa}}t[b+3|0]=0}b=b+6|0;f=f+1|0;continue}break}break}e=P()|0;O()|0;break O}e=P()|0;O()|0;break O}v[23588]=0;b=S(275,v[d+112>>2])|0;e=v[23588];v[23588]=0;ha:{ia:{ja:{ka:{la:{if((e|0)!=1){if(b){f=Mb(d+48|0);e=a+484348|0;b=0;ma:{while(1){na:{v[23588]=0;g=W(156,v[d+112>>2],v[d+120>>2],1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break na}if(!g){break ma}if(Bf(v[a+484344>>2],v[e>>2])>>>0<=b>>>0){break ma}v[23588]=0;U(350,d+112|0,f|0,32);g=v[23588];v[23588]=0;if((g|0)==1){break na}g=v[m>>2];v[23588]=0;R(281,Zb(g,b)|0,f|0);g=v[23588];v[23588]=0;if((g|0)==1){break na}b=b+1|0;continue}break}e=P()|0;O()|0;zb(f);break la}zb(f)}b=d+112|0;Bb(b);v[23588]=0;U(339,b|0,d+200|0,1414679374);b=v[23588];v[23588]=0;if((b|0)==1){break ka}v[23588]=0;b=S(275,v[d+112>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break T}if(!b){break ha}f=Mb(d+48|0);e=a+480188|0;b=0;while(1){v[23588]=0;g=W(156,v[d+112>>2],v[d+120>>2],1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break ja}if(!(g&x[e>>1]>b>>>0)){break ia}v[23588]=0;U(350,d+112|0,f|0,32);g=v[23588];v[23588]=0;if((g|0)==1){break ja}Hl(((b<<5)+a|0)+480289|0,f);b=b+1|0;continue}}e=P()|0;O()|0}Bb(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;zb(f);break S}zb(f)}b=d+112|0;Bb(b);v[23588]=0;U(347,b|0,d+200|0,1145129300);b=v[23588];v[23588]=0;if((b|0)==1){break U}G=d,H=Fb(v[d+112>>2]),v[G+48>>2]=H;e=c&2;f=Fb(v[d+116>>2]);g=a+480190|0;oa:{pa:{qa:{ra:{sa:{ta:{while(1){b=v[d+48>>2];if(!Pb(b,f)){Vc(d+112|0);b=Mb(d+48|0);if((o|0)!=841887798){break sa}v[23588]=0;c=Q(1,d+112|0,9450)|0;e=v[23588];v[23588]=0;if((e|0)==1){break ta}Jb(b,c);Ab(c);break ra}v[23588]=0;c=S(271,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break V}ua:{if(!(!e|c>>>0>=x[g>>1])){c=B(c,104)+a|0;h=x[c+484518>>1];h=_c(d+176|0,h&1?16:8,h&64?2:1,1,0);v[23588]=0;W(219,h|0,c+484484|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ua}}Nf(d+48|0);continue}break}break V}e=P()|0;O()|0;break W}v[23588]=0;U(339,d+112|0,d+200|0,1447383635);c=v[23588];v[23588]=0;va:{wa:{xa:{ya:{za:{if((c|0)!=1){v[23588]=0;c=S(275,v[d+112>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break qa}if(!c){break wa}v[23588]=0;c=S(279,d+112|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break za}v[23588]=0;R(266,d+32|0,4295);e=v[23588];v[23588]=0;if((e|0)==1){break ya}v[d+16>>2]=c>>>4;v[23588]=0;v[d+12>>2]=c&15;X(351,d+176|0,d+32|0,d+16|0,d+12|0);c=v[23588];v[23588]=0;if((c|0)==1){break xa}c=d+176|0;Jb(b,c);Ab(c);bc(d+32|0);break va}e=P()|0;O()|0;break W}e=P()|0;O()|0;break X}e=P()|0;O()|0;break X}e=P()|0;O()|0;bc(d+32|0);break X}v[23588]=0;c=Q(1,d+176|0,8469)|0;e=v[23588];v[23588]=0;if((e|0)==1){break Y}Jb(b,c);Ab(c)}Bb(d+112|0)}v[23588]=0;c=Q(1,d+32|0,8469)|0;e=v[23588];v[23588]=0;if((e|0)==1){break pa}Jb(a+1298344|0,c);Ab(c);v[23588]=0;c=Q(1,d+16|0,10083)|0;e=v[23588];v[23588]=0;if((e|0)==1){break oa}Jb(a+1298356|0,c);Ab(c);Jb(a+1298368|0,b);v[a+1298404>>2]=14;Ab(b);f=1;break o}e=P()|0;O()|0;break X}e=P()|0;O()|0;break W}e=P()|0;O()|0;break W}e=P()|0;O()|0;break O}e=P()|0;O()|0}Bb(d+112|0)}Ab(b);break b}e=P()|0;O()|0;Vc(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}Bb(d+112|0);break b}e=P()|0;O()|0;Bb(f);break O}e=P()|0;O()|0;break O}e=P()|0;O()|0}Vc(d+176|0);break b}Nf(d+16|0);continue}}f=0}Zd(d+200|0)}kb=d+240|0;return f|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;break f}e=P()|0;O()|0;Bb(d+176|0);break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break b}e=P()|0;O()|0}Bb(d+48|0);break b}e=P()|0;O()|0;Bb(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bb(d+176|0)}Zd(d+200|0)}T(e|0);L()}function JV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=kb-464|0;kb=d;zc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!di(b,d+456|0)){break F}if(!OB(d+456|0)){break F}if(!c){p=1;break F}q=ke(d+432|0,b);v[23588]=0;R(261,d+416|0,q|0);b=v[23588];v[23588]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){v[23588]=0;U(262,d+240|0,d+416|0,1229866575);b=v[23588];v[23588]=0;if((b|0)==1){break da}v[23588]=0;p=Q(263,d+240|0,d+400|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break fa}Bb(d+240|0);if(!p){break G}v[23588]=0;R(246,a|0,524288);b=v[23588];v[23588]=0;ga:{if((b|0)==1){break ga}ag(a);v[a+480208>>2]=12;H=a+480188|0,I=Dd(Ib(x[d+408>>1]),1,127),u[H>>1]=I;H=d,I=Ib(x[d+400>>1]),u[H+240>>1]=I;u[d+344>>1]=255;H=a+480192|0,I=x[Wc(d+240|0,d+344|0)>>1],u[H>>1]=I;H=d,I=Ib(x[d+402>>1]),u[H+240>>1]=I;u[d+344>>1]=3999;H=a+480190|0,I=x[Wc(d+240|0,d+344|0)>>1],u[H>>1]=I;v[23588]=0;b=W(264,a+1074312|0,6,1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break ga}v[23588]=0;b=Q(265,b|0,21)|0;e=v[23588];v[23588]=0;if((e|0)==1){break ga}v[23588]=0;Q(265,b|0,13)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break ea}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Bb(d+240|0);break b}v[23588]=0;b=Q(1,d+384|0,9242)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}Jb(a+1298344|0,b);Ab(b);v[23588]=0;b=Q(1,d+368|0,10267)|0;e=v[23588];v[23588]=0;if((e|0)==1){break d}Jb(a+1298356|0,b);Ab(b);v[23588]=0;R(266,d+344|0,4339);b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;R(267,d+320|0,d+456|4);b=v[23588];v[23588]=0;if((b|0)==1){break g}v[23588]=0;R(267,d+296|0,d+456|5);b=v[23588];v[23588]=0;if((b|0)==1){break i}v[23588]=0;X(111,d+240|0,d+344|0,d+320|0,d+296|0);b=v[23588];v[23588]=0;if((b|0)==1){break j}b=d+240|0;Jb(a+1298368|0,b);Ab(b);Ab(d+296|0);Ab(d+320|0);b=d+344|0;bc(b);v[a+1298404>>2]=14;v[23588]=0;U(262,b|0,d+416|0,1312902469);b=v[23588];v[23588]=0;if((b|0)==1){break k}v[23588]=0;b=S(160,v[d+344>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break m}v[23588]=0;g=a+1298308|0;U(268,d+344|0,g|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break m}v[23588]=0;U(262,d+320|0,d+416|0,1397706311);b=v[23588];v[23588]=0;if((b|0)==1){break n}h=a+484360|0;e=a+484376|0;Lc(Wb(v[h>>2],w[e|0]));k=Ib(x[d+404>>1]);ha:{ia:{while(1){if(k>>>0<=(f&65535)>>>0){break ha}v[23588]=0;b=W(156,v[d+320>>2],v[d+328>>2],46)|0;j=v[23588];v[23588]=0;ja:{if((j|0)!=1){if(!b){break ha}v[23588]=0;R(269,d+320|0,d+240|0);b=v[23588];v[23588]=0;if((b|0)!=1){if(!Re(g)){break ja}v[23588]=0;R(270,g|0,d+240|0);b=v[23588];v[23588]=0;if((b|0)!=1){break ja}}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[23588]=0;j=S(271,d+320|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break ca}b=Wb(v[a+484360>>2],w[e|0]);if(!pc(v[b>>2],v[b+4>>2])){v[23588]=0;b=S(272,h|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break ca}if((b|0)==255){break ha}b=Wb(v[a+484360>>2],w[e|0])}v[23588]=0;U(5,d+296|0,14,d+240|0);i=v[23588];v[23588]=0;if((i|0)!=1){v[23588]=0;R(273,b|0,d+296|0);b=v[23588];v[23588]=0;if((b|0)==1){break ia}Ab(d+296|0);b=w[e|0];i=v[a+484360>>2];v[23588]=0;U(274,Wb(i,b)|0,d+320|0,j|0);b=v[23588];v[23588]=0;if((b|0)==1){break ca}f=f+1|0;continue}break}b=P()|0;O()|0;break o}b=P()|0;O()|0;Ab(d+296|0);break o}Gj(h,0);v[23588]=0;U(262,d+296|0,d+416|0,1229869908);b=v[23588];v[23588]=0;if((b|0)==1){break ba}v[23588]=0;b=S(275,v[d+296>>2])|0;f=v[23588];v[23588]=0;if((f|0)==1){break p}ka:{if(!b){break ka}g=a+480192|0;f=1;la:{while(1){b=f&65535;if(b>>>0>x[g>>1]){v[23588]=0;U(262,d+216|0,d+416|0,1447382614);b=v[23588];v[23588]=0;if((b|0)!=1){break la}break p}v[23588]=0;R(276,d+296|0,d+240|0);e=v[23588];v[23588]=0;if((e|0)==1){break p}e=x[d+270>>1];v[23588]=0;b=W(251,a|0,b|0,Ib(e)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break p}ma:{na:{if(!b){break na}if(Ib(x[d+270>>1])>>>0>3999){break na}e=d+128|0;LB(e,2,d+240|0);v[23588]=0;R(222,d+152|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break ma}e=d+152|0;Dc(b+492|0,e);zb(e);h=d+128|0;LB(h,2,d+240|0);v[23588]=0;R(222,e|0,h|0);e=v[23588];v[23588]=0;if((e|0)==1){break p}e=d+152|0;Dc(((Ib(x[d+270>>1])<<5)+a|0)+946304|0,e);zb(e);v[b>>2]=0;H=b,I=qe(u[d+286>>1])+128&65535,v[H+8>>2]=I;xc(b+8|0,256);t[b+15|0]=w[b+15|0]|1;b=x[d+270>>1];v[23588]=0;b=B(Ib(b),104)+a|0;R(277,b+484380|0,0);e=v[23588];v[23588]=0;if((e|0)==1){break p}H=d,I=Ib(x[d+272>>1]),u[H+152>>1]=I;u[d+128>>1]=64;H=b+484410|0,I=x[Wc(d+152|0,d+128|0)>>1]<<2,u[H>>1]=I;H=b+484404|0,I=cc(x[d+274>>1]|x[d+276>>1]<<16),v[H>>2]=I;e=cc(x[d+282>>1]|x[d+284>>1]<<16);if(!e){break na}h=Ib(x[d+288>>1]);if(!(h&3)){break na}k=e;e=cc(x[d+278>>1]|x[d+280>>1]<<16);v[b+484388>>2]=k+e;v[b+484384>>2]=e;b=b+484414|0;e=x[b>>1];u[b>>1]=e|2;if(!(h&2)){break na}u[b>>1]=e|6}f=f+1|0;continue}break}break p}b=v[d+228>>2];v[d+32>>2]=v[d+224>>2];v[d+36>>2]=b;v[d+40>>2]=v[d+232>>2];v[23588]=0;b=v[d+220>>2];v[d+24>>2]=v[d+216>>2];v[d+28>>2]=b;X(278,d+24|0,0,a|0,0);b=v[23588];v[23588]=0;if((b|0)==1){break p}v[23588]=0;U(262,d+192|0,d+416|0,1346719318);b=v[23588];v[23588]=0;if((b|0)==1){break p}b=v[d+204>>2];v[d+8>>2]=v[d+200>>2];v[d+12>>2]=b;v[d+16>>2]=v[d+208>>2];v[23588]=0;b=v[d+196>>2];v[d>>2]=v[d+192>>2];v[d+4>>2]=b;X(278,d|0,1,a|0,w[d+460|0]>2|0);b=v[23588];v[23588]=0;if((b|0)==1){break p}e=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break ka}f=v[((b<<2)+a|0)+900380>>2];if(!(!f|t[f+60|0]&1)){v[f>>2]=32767}b=b+1|0;continue}}Bb(d+296|0);v[23588]=0;U(262,d+240|0,d+416|0,1346458708);b=v[23588];v[23588]=0;if((b|0)==1){break q}v[23588]=0;b=S(178,v[d+240>>2])|0;f=v[23588];v[23588]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){v[23588]=0;U(262,d+296|0,d+416|0,1347305805);b=v[23588];v[23588]=0;if((b|0)==1){break t}v[23588]=0;Q(188,d+296|0,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break v}b=x[d+406>>1];v[23588]=0;m=a+484344|0;R(225,m|0,Ib(b)|0);b=v[23588];v[23588]=0;if((b|0)==1){break v}b=d+128|0;A=b|3;C=b|1;i=Tb(d+176|0);D=a+480188|0;h=0;while(1){if(Ib(x[d+406>>1])>>>0<=l>>>0){od(i);e=h;Bb(d+296|0);if(!(c&4)){break $}f=0;if(!E){break aa}g=x[a+480188>>1];b=0;f=1;while(1){if((b|0)==(g|0)){break aa}h=(b<<5)+a|0;t[h+480288|0]=1;h=h+480280|0;v[h>>2]=v[h>>2]|67108864;b=b+1|0;continue}}v[23588]=0;b=S(271,d+240|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break x}v[23588]=0;f=S(279,d+240|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break y}v[23588]=0;U(190,d+128|0,d+240|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break z}f=d+128|0;j=kc(d+152|0,f);Bb(f);v[23588]=0;f=W(226,m|0,l&65535,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break B}oa:{if(f){o=Mb(d+112|0);v[23588]=0;R(280,d+296|0,o|0);f=v[23588];v[23588]=0;if((f|0)==1){break oa}f=v[m>>2];v[23588]=0;R(281,Zb(f,l)|0,o|0);f=v[23588];v[23588]=0;if((f|0)==1){break oa}n=0;f=Zb(v[m>>2],l);y=Df(v[f>>2],v[v[f+48>>2]+12>>2],0);Lc(i);F=(b>>>0>1?b:1)-1|0;pa:while(1){b=v[j>>2];v[23588]=0;b=W(156,b|0,v[d+160>>2],1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break C}qa:{if(!b){break qa}v[23588]=0;f=S(206,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break C}if(!f){H=d,I=Fb(v[i>>2]),v[H+104>>2]=I;f=Fb(v[i+4>>2]);while(1){b=v[d+104>>2];if(Pb(b,f)){Ae(Zb(v[m>>2],l),Ue(Oe(d+128|0,w[b|0],w[b+1|0]),n));Se(d+104|0);continue}else{Lc(i);if((n|0)==(F|0)){break qa}b=Zb(v[m>>2],l);n=n+1|0;y=Df(v[b>>2],v[v[b+48>>2]+12>>2],n);continue pa}}}Fj(d+128|0);e=x[D>>1];v[23588]=0;b=S(206,j|0)|0;g=v[23588];v[23588]=0;ra:{sa:{if((g|0)!=1){r=B(f-1|0,6)+y|0;s=e>>>0<f>>>0;k=s?d+128|0:r;ta:{if(!(b&1)){break ta}v[23588]=0;f=S(206,j|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break C}if((f|0)!=31){if((f-1&255)>>>0>252){break ta}e=(B(f>>>4|0,12)+(f&15)|0)+13|0}else{e=255}t[k|0]=e}if(!(b&2)){break ra}v[23588]=0;f=S(206,j|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break sa}}break C}t[(s?C:r+1|0)|0]=f}if(!(b&60)){continue}f=0;e=0;if(b&4){v[23588]=0;e=S(206,j|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break C}}if(b&8){v[23588]=0;f=S(206,j|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break C}}g=0;z=0;if(b&16){v[23588]=0;z=S(206,j|0)|0;G=v[23588];v[23588]=0;if((G|0)==1){break C}}if(b&32){v[23588]=0;g=S(206,j|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break C}}b=d+104|0;BV(b,z,g);g=Oc(b);b=d+96|0;BV(b,e,f);f=Oc(b);b=w[d+96|0];ua:{if((b|0)!=13){if(b){break ua}b=0;if(w[d+104|0]==13){break ua}}Ji(d+104|0,d+96|0);Ji(g,f);b=w[d+96|0]}Bo(d+88|0,k,w[d+104|0],w[g|0],b&255,w[f|0]);if(AV(w[d+88|0],w[d+89|0])){b=v[fc(d+80|0,Fb(v[i>>2]))>>2];v[23588]=0;U(282,i|0,b|0,d+88|0);b=v[23588];v[23588]=0;if((b|0)==1){break C}}b=w[(s?A:r+3|0)|0];if((b|0)==43){E=1;continue}if((b|0)!=31){continue}h=1;continue}break}zb(o)}Bb(j);l=l+1|0;continue}break}break C}e=0;f=0;if(c&4){break aa}break H}b=P()|0;O()|0;break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[d+176>>2]=-1778364416;v[d+180>>2]=-16756736;v[23588]=0;U(262,d+296|0,d+416|0,1146310725);b=v[23588];v[23588]=0;if((b|0)==1){break E}v[23588]=0;b=S(275,v[d+296>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break D}if(b){v[23588]=0;k=S(271,d+296|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break D}j=a+480188|0;b=0;g=f;while(1){va:{if((b|0)==(k|0)){v[23588]=0;R(283,d+296|0,d+176|0);b=v[23588];v[23588]=0;if((b|0)!=1){break va}break D}v[23588]=0;h=S(206,d+296|0)|0;i=v[23588];v[23588]=0;wa:{xa:{if((i|0)!=1){if(x[j>>1]<=b>>>0){break wa}if(!f){break xa}i=((b<<5)+a|0)+480280|0;v[i>>2]=v[i>>2]&-67108865|((h|0)!=0)<<26;break wa}break D}if(h){break wa}g=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}f=g&1}Bb(d+296|0);if(!f){break $}v[23588]=0;b=Md(a+906300|0,0);Y(284,b|0);f=v[23588];v[23588]=0;if((f|0)==1){break _}v[b+16>>2]=810369604;v[b+20>>2]=1869112133;v[b+24>>2]=655376;v[b+28>>2]=0;v[d+296>>2]=0;g=b+48|0;xV(b+32|0,g,d+296|0);v[23588]=0;f=Q(55,d+152|0,9516)|0;h=v[23588];v[23588]=0;if((h|0)==1){break Z}KB(g,f);zb(f);v[23588]=0;f=Q(55,d+128|0,9480)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Y}Lu(b+80|0,f);zb(f);v[23588]=0;R(285,b+4|0,8);f=v[23588];v[23588]=0;if((f|0)==1){break _}wV(d+296|0,w[d+177|0],w[d+179|0],w[d+181|0],w[d+183|0]);f=v[d+300>>2];b=v[b+4>>2];g=v[d+296>>2];t[b|0]=g;t[b+1|0]=g>>>8;t[b+2|0]=g>>>16;t[b+3|0]=g>>>24;t[b+4|0]=f;t[b+5|0]=f>>>8;t[b+6|0]=f>>>16;t[b+7|0]=f>>>24}if(!e){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}v[d+104>>2]=B(b,127)>>>5;v[23588]=0;R(286,d+176|0,4096);e=v[23588];v[23588]=0;if((e|0)==1){break X}v[23588]=0;R(287,d+112|0,d+104|0);e=v[23588];v[23588]=0;if((e|0)==1){break W}v[23588]=0;U(288,d+296|0,d+176|0,d+112|0);e=v[23588];v[23588]=0;if((e|0)==1){break V}e=d+296|0;Ge(d+72|0,e);hf(ze(f,b),v[d+72>>2],v[d+76>>2]);zb(e);zb(d+112|0);e=d+176|0;$b(e);v[23588]=0;R(286,e|0,4078);e=v[23588];v[23588]=0;if((e|0)==1){break T}v[23588]=0;R(287,d+112|0,d+104|0);e=v[23588];v[23588]=0;if((e|0)==1){break S}v[23588]=0;U(288,d+296|0,d+176|0,d+112|0);e=v[23588];v[23588]=0;if((e|0)==1){break R}e=d+296|0;Ge(d- -64|0,e);hf(ze(f,b+32|0),v[d+64>>2],v[d+68>>2]);zb(e);zb(d+112|0);e=d+176|0;$b(e);v[23588]=0;R(286,e|0,4069);e=v[23588];v[23588]=0;if((e|0)==1){break P}v[23588]=0;R(287,d+112|0,d+104|0);e=v[23588];v[23588]=0;if((e|0)==1){break O}v[23588]=0;U(288,d+296|0,d+176|0,d+112|0);e=v[23588];v[23588]=0;if((e|0)==1){break N}e=d+296|0;Ge(d+56|0,e);hf(ze(f,b- -64|0),v[d+56>>2],v[d+60>>2]);zb(e);zb(d+112|0);e=d+176|0;$b(e);v[23588]=0;R(286,e|0,4042);e=v[23588];v[23588]=0;if((e|0)==1){break L}v[23588]=0;R(287,d+112|0,d+104|0);e=v[23588];v[23588]=0;if((e|0)==1){break K}v[23588]=0;U(288,d+296|0,d+176|0,d+112|0);e=v[23588];v[23588]=0;if((e|0)==1){break J}e=d+296|0;Ge(d+48|0,e);hf(ze(f,b+96|0),v[d+48>>2],v[d+52>>2]);b=b+1|0;zb(e);zb(d+112|0);$b(d+176|0);continue}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break U}b=P()|0;O()|0;zb(d+112|0)}$b(d+176|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break Q}b=P()|0;O()|0;zb(d+112|0)}$b(d+176|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break M}b=P()|0;O()|0;zb(d+112|0)}$b(d+176|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break I}b=P()|0;O()|0;zb(d+112|0)}$b(d+176|0);break r}v[23588]=0;U(262,d+296|0,d+416|0,1397575756);b=v[23588];v[23588]=0;ya:{if((b|0)!=1){v[23588]=0;b=S(178,v[d+296>>2])|0;f=v[23588];v[23588]=0;if((f|0)!=1){za:{f=1;if(!(c&2)|b^1){break ya}c=a+480190|0;while(1){e=f&65535;if(e>>>0>x[c>>1]){break ya}v[23588]=0;b=S(279,d+296|0)|0;g=v[23588];v[23588]=0;Aa:{if((g|0)!=1){v[23588]=0;g=S(279,d+296|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break za}if(!(b&7)){break Aa}e=(B(e,104)+a|0)+484380|0;v[e>>2]=g;b=_c(d+176|0,b&4?32:b&2?16:8,1,1,0);v[23588]=0;W(219,b|0,e|0,d+296|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break Aa}break za}break za}f=f+1|0;continue}}}b=P()|0;O()|0;Bb(d+296|0);break r}b=P()|0;O()|0;break r}Bb(d+296|0);Bb(d+240|0);Bb(d+320|0);Bb(d+344|0)}Zd(d+416|0);Bb(q)}kb=d+464|0;return p|0}b=P()|0;O()|0;break r}b=P()|0;O()|0;Bb(d+296|0);break r}b=P()|0;O()|0;zb(o);break A}b=P()|0;O()|0}Bb(j);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0}od(i);break u}b=P()|0;O()|0}Bb(d+296|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0}Bb(d+240|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;Bb(d+296|0)}Bb(d+320|0);break l}b=P()|0;O()|0;break l}b=P()|0;O()|0}Bb(d+344|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;Ab(d+296|0);break h}b=P()|0;O()|0}Ab(d+320|0);break f}b=P()|0;O()|0}bc(d+344|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}Zd(d+416|0)}Bb(q);T(b|0);L()}function mfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0;f=kb-496|0;kb=f;zc(b);i=kb-16|0;kb=i;g=f+288|0;MQ(i+8|0,g);e=v[i+12>>2];n=b;nc(i,v[b>>2],v[b+8>>2],v[i+8>>2],v[i+12>>2]);b=v[i+4>>2];if((b|0)==(e|0)){_b(n,v[i+12>>2])}kb=i+16|0;b=(b|0)==(e|0);if(!b){LQ(g)}a:{if(!b){break a}if(!NQ(f+288|0)){break a}if(!c){d=1;break a}Bd(a,134217728);b=f+8|0;Sf(b,3956);v[23588]=0;U(674,f+120|0,b|0,x[f+292>>1]);b=v[23588];v[23588]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=f+120|0;Jb(a+1298344|0,b);Ab(b);bc(f+8|0);b=yc(b,8934);Jb(a+1298356|0,b);Ab(b);v[a+480188>>2]=4;v[a+1298404>>2]=14;V=a,X=Ib(x[f+424>>1]),v[V+480196>>2]=X;b=x[f+428>>1];v[a+480260>>2]=56;v[a+480264>>2]=13696;V=a,X=KQ(Ib(b)),v[V+480204>>2]=X;Iq(Wb(v[a+484360>>2],w[a+484376|0]),f+296|0,w[f+294|0]);q=a+480190|0;m=a+480188|0;o=Tb(f+272|0);z=Tb(f+256|0);h:{i:{j:{k:{while(1){if(Ib(x[f+488>>1])>>>0<=(l&65535)>>>0){break k}v[23588]=0;b=S(271,n|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break g}u[f+232>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}d=Ib(x[f+490>>1]);if((Ib(x[f+292>>1])|0)==2){v[23588]=0;b=S(279,n|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break h}d=b-2|0}v[23588]=0;U(190,f+8|0,n|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}b=f+8|0;h=kc(f+120|0,b);Bb(b);C=x[le(q,f+232|0)>>1];u[q>>1]=C;v[23588]=0;j=B(x[f+232>>1],104)+a|0;e=j+484380|0;R(277,e|0,1);b=v[23588];v[23588]=0;l:{m:{n:{if((b|0)==1){break n}if(Ib(x[f+292>>1])>>>0>1){break m}v[23588]=0;R(675,h|0,j+484423|0);b=v[23588];v[23588]=0;if((b|0)==1){break n}v[23588]=0;Q(188,h|0,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break n}v[23588]=0;U(325,h|0,((x[f+232>>1]<<5)+a|0)+946304|0,30);b=v[23588];v[23588]=0;if((b|0)!=1){break l}}e=P()|0;O()|0;break f}b=Mb(f+8|0);v[23588]=0;U(350,h|0,b|0,257);i=v[23588];v[23588]=0;o:{p:{if((i|0)==1){break p}Ce(j+484423|0,b);v[23588]=0;Q(188,h|0,1)|0;i=v[23588];v[23588]=0;if((i|0)==1){break p}v[23588]=0;U(350,h|0,b|0,31);i=v[23588];v[23588]=0;if((i|0)==1){break p}Dc(((x[f+232>>1]<<5)+a|0)+946304|0,b);if(!(t[f+128|0]&1)){break o}v[23588]=0;Q(188,h|0,1)|0;i=v[23588];v[23588]=0;if((i|0)!=1){break o}}e=P()|0;O()|0;zb(b);break f}zb(b)}v[23588]=0;R(676,h|0,f+8|0);b=v[23588];v[23588]=0;q:{if((b|0)==1){break q}d=kb-16|0;kb=d;i=cc(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24));v[e>>2]=i;t[d+15|0]=w[f+12|0];t[d+14|0]=64;V=e,X=w[Xb(d+15|0,d+14|0)|0]<<2,u[V+30>>1]=X;g=cc(w[f+14|0]|w[f+15|0]<<8|(w[f+16|0]<<16|w[f+17|0]<<24));v[e+4>>2]=g;b=cc(w[f+14|0]|w[f+15|0]<<8|(w[f+16|0]<<16|w[f+17|0]<<24))+cc(w[f+18|0]|w[f+19|0]<<8|(w[f+20|0]<<16|w[f+21|0]<<24))|0;v[e+8>>2]=b;if(g>>>0>=i>>>0){g=i-1|0;v[e+4>>2]=g}if(b>>>0>i>>>0){v[e+8>>2]=i;b=i}r:{if(b>>>0<g>>>0){v[e+4>>2]=0;v[e+8>>2]=0;break r}if(b>>>0<=g>>>0){break r}u[e+34>>1]=x[e+34>>1]|2;V=Eb(e+68|0,0),X=g,v[V>>2]=X}kb=d+16|0;s:{t:{switch(Ib(x[f+292>>1])|0){case 2:t[j+484417|0]=w[f+26|0]<<3;break;case 0:break s;default:break t}}v[23588]=0;R(214,z|0,C|0);b=v[23588];v[23588]=0;if((b|0)==1){break q}v[23588]=0;R(677,o|0,C|0);b=v[23588];v[23588]=0;if((b|0)==1){break q}i=Nd(v[o>>2],x[f+232>>1]-1|0);Lc(i);v[23588]=0;b=S(271,n|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}e=v[n+8>>2];d=v[n>>2];v[23588]=0;e=W(156,d|0,e|0,b<<3)|0;d=v[23588];v[23588]=0;if((d|0)==1){break j}if(e){v[23588]=0;R(678,i|0,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}d=0;v[f+248>>2]=0;if(!(!(w[j+484414|0]&2)|b)){b=v[j+484384>>2];v[f+240>>2]=b;e=v[j+484388>>2];v[23588]=0;v[f+244>>2]=e-b;R(679,i|0,f+240|0);b=v[23588];v[23588]=0;if((b|0)!=1){break s}e=P()|0;O()|0;break f}while(1){if(b>>>0<=(d&65535)>>>0){break s}v[23588]=0;e=S(279,n|0)|0;g=v[23588];v[23588]=0;u:{if((g|0)==1){break u}v[23588]=0;v[f+240>>2]=e;e=S(279,n|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break u}v[23588]=0;v[f+244>>2]=e;R(679,i|0,f+240|0);e=v[23588];v[23588]=0;if((e|0)==1){break u}d=d+1|0;continue}break}e=P()|0;O()|0;break f}Bb(h);break c}Bb(h);l=l+1|0;continue}break}e=P()|0;O()|0;break f}v:{w:{x:{y:{if(Ib(x[f+292>>1])){A=w[f+295|0];u[f+238>>1]=4;D=128;break y}v[23588]=0;D=S(271,n|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){e=P()|0;O()|0;break e}b=x[f+292>>1];A=w[f+295|0];u[f+238>>1]=4;if(!Ib(b)){break x}}i=v[n+8>>2];e=0;while(1){z:{if((e&65535)>>>0>=D>>>0){break z}v[23588]=0;b=S(271,n|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break w}if((b|0)==65535){break z}v[23588]=0;A=S(271,n|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}v[23588]=0;b=S(271,n|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break w}u[f+238>>1]=b;if(b>>>0>127){break c}V=m,X=x[le(m,f+238|0)>>1],u[V>>1]=X;v[23588]=0;Q(188,n|0,B(b,A)<<2)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}e=e+1|0;continue}break}v[23588]=0;Q(155,n|0,i|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break v}}b=x[m>>1];v[23588]=0;E=Q(680,f+240|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){J=a+484344|0;N=c&1;F=Ib(x[f+426>>1]);b=0;i=0;while(1){A:{B:{C:{D:{if((b&65535)>>>0>=D>>>0){break D}E:{if(!Ib(x[f+292>>1])){d=x[f+238>>1];e=b;break E}v[23588]=0;e=S(271,n|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break A}if((e|0)==65535){break D}v[23588]=0;A=S(271,n|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break A}v[23588]=0;d=S(271,n|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break A}u[f+238>>1]=d}g=v[n+8>>2];h=v[n>>2];v[23588]=0;r=g;G=A&65535;g=G<<2;d=W(156,h|0,r|0,B(g,d&65535)|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break A}if(!d){break D}if(!N){break C}v[23588]=0;K=e&65535;e=W(226,J|0,K|0,G|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break A}if(!e){break C}s=0;F:while(1){if((s|0)==(G|0)){break B}e=0;d=Zb(v[J>>2],K);j=Df(v[d>>2],v[v[d+48>>2]+12>>2],s);H=0;r=0;G:{H:{I:{switch((F&3)-1|0){case 0:r=!(s&3);break H;case 1:r=!(s&1);break H;case 2:break I;default:break G}}r=(s&3)!=3}}while(1){if(x[f+238>>1]<=e>>>0){s=s+1|0;continue F}d=v[E>>2];v[23588]=0;R(349,f+232|0,n|0);g=v[23588];v[23588]=0;if((g|0)==1){break A}h=B(e,9)+d|0;d=f+232|0;g=Oc(d);p=Te(d);m=j+B(e,6)|0;t[m+1|0]=w[f+232|0];k=w[g|0];t[m|0]=k;g=w[Mi(d)|0];t[m+5|0]=g;l=m+5|0;if(k){t[m|0]=k+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;g=w[l|0]}k=g&255;p=w[p|0];J:{if(p>>>0>=240){d=k|(p&15)<<8;if(d){V=l,X=tk(+(KQ(d)>>>0)/1e4),t[V|0]=X;t[m+3|0]=17;break J}t[m+3|0]=0;break J}I=k>>>4|0;M=k<<4;d=I|M;K:{switch(p|0){case 0:d=j+B(e,6)|0;if(g&255){t[d+3|0]=1;break J}t[d+3|0]=0;break J;case 1:t[(j+B(e,6)|0)+3|0]=2;break J;case 2:t[(j+B(e,6)|0)+3|0]=3;break J;case 3:t[f+228|0]=15;V=h,X=w[Xb(l,f+228|0)|0]|16,t[V|0]=X;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 4:t[f+228|0]=15;V=h,X=w[Xb(l,f+228|0)|0]|32,t[V|0]=X;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=g;t[h|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 6:t[h+7|0]=0;t[h+2|0]=g;t[h|0]=0;t[h+1|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 7:t[(j+B(e,6)|0)+3|0]=23;i=0;break J;case 8:t[(j+B(e,6)|0)+3|0]=0;i=d;break J;case 9:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Xb(l,f+228|0)|0]|16,t[V|0]=X;break J;case 10:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Xb(l,f+228|0)|0]|32,t[V|0]=X;break J;case 11:t[h+3|0]=d;t[(j+B(e,6)|0)+3|0]=0;break J;case 12:d=j+B(e,6)|0;t[d+4|0]=g;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break J;case 13:p=j+B(e,6)|0;L:{M:{if(k&240){t[(j+B(e,6)|0)+2|0]=4;d=(g&240)>>>4|0;break M}if(!(k&15)){break L}t[(j+B(e,6)|0)+2|0]=3;d=g&15}t[p+4|0]=d}t[h+3|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 14:t[(j+B(e,6)|0)+3|0]=19;t[l|0]=!(g&255);break J;case 15:t[(j+B(e,6)|0)+3|0]=16;t[l|0]=(g&240)>>>4;F=g&15;break J;case 16:t[h+5|0]=0;t[h+4|0]=g;t[(j+B(e,6)|0)+3|0]=0;break J;case 17:t[h+6|0]=k&15?g:0;t[(j+B(e,6)|0)+3|0]=0;break J;case 18:t[(j+B(e,6)|0)+3|0]=14;break J;case 19:t[h+8|0]=0;t[h+7|0]=g;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 20:t[(j+B(e,6)|0)+3|0]=12;break J;case 22:d=w[m+1|0];N:{if(!d){break N}k=v[o>>2];if(yd(k,v[o+4>>2])>>>0<d>>>0){break N}g=g-1|0;t[l|0]=g;v[23588]=0;S(681,f+120|0)|0;p=v[23588];v[23588]=0;if((p|0)==1){break A}v[f+228>>2]=9;d=Nd(k,d-1|0);V=f,X=yd(v[d>>2],v[d+4>>2]),v[V+116>>2]=X;if(y[Kb(f+228|0,f+116|0)>>2]<=(g&255)>>>0){break N}d=j+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[l|0]}t[(j+B(e,6)|0)+3|0]=0;break J;case 23:d=w[m+1|0];O:{if(!d){break O}k=v[o>>2];if(yd(k,v[o+4>>2])>>>0<d>>>0){break O}g=g-1|0;t[l|0]=g;d=Nd(k,d-1|0);k=v[d>>2];p=yd(k,v[d+4>>2]);d=g&255;if(p>>>0<=d>>>0){break O}d=Nd(k,d);g=x[d+8>>1];P:{if(g){break P}g=0;k=x[q>>1];if(!Yh(k)){break P}g=k+1|0;u[q>>1]=g;u[d+8>>1]=g}t[m+1|0]=g}t[(j+B(e,6)|0)+3|0]=0;break J;case 24:d=w[m+1|0];Q:{if(!d){break Q}k=v[o>>2];if(yd(k,v[o+4>>2])>>>0<d>>>0){break Q}g=g-1|0;t[l|0]=g;v[23588]=0;S(681,f+8|0)|0;p=v[23588];v[23588]=0;if((p|0)==1){break A}v[f+228>>2]=9;d=Nd(k,d-1|0);V=f,X=yd(v[d>>2],v[d+4>>2]),v[V+116>>2]=X;if(y[Kb(f+228|0,f+116|0)>>2]>(g&255)>>>0){d=j+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[l|0]}d=dc(v[z>>2],w[m+1|0]-1|0);g=x[d>>1];R:{if(g){break R}g=0;k=x[q>>1];if(!Yh(k)){break R}g=k+1|0;u[q>>1]=g;u[d>>1]=g}t[m+1|0]=g}t[(j+B(e,6)|0)+3|0]=0;break J;case 25:d=w[m+1|0];S:{if(!d){break S}k=v[o>>2];if(yd(k,v[o+4>>2])>>>0<d>>>0){break S}g=g-1|0;t[l|0]=g;d=Nd(k,d-1|0);k=v[d>>2];p=yd(k,v[d+4>>2]);d=g&255;if(p>>>0<=d>>>0){break S}d=Nd(k,d);g=x[d+10>>1];T:{if(g){break T}g=0;k=x[q>>1];if(!Yh(k)){break T}g=k+1|0;u[q>>1]=g;u[d+10>>1]=g}t[m+1|0]=g}t[(j+B(e,6)|0)+3|0]=0;break J;case 29:t[(j+B(e,6)|0)+3|0]=11;t[l|0]=d;if(k&15){t[l|0]=M|15;break J}if((g&255)>>>0<16){break J}t[l|0]=I|240;break J;case 32:if(k&240){t[h+3|0]=I;t[(j+B(e,6)|0)+3|0]=0;break J}t[(j+B(e,6)|0)+3|0]=19;t[l|0]=g&15|192;break J;case 33:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Xb(l,f+228|0)|0]|208,t[V|0]=X;break J;case 34:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Xb(l,f+228|0)|0]|144,t[V|0]=X;break J;case 73:t[(j+B(e,6)|0)+3|0]=10;break J;case 78:if((g&112|128)==224){t[(j+B(e,6)|0)+3|0]=19;break J}t[(j+B(e,6)|0)+3|0]=0;break J;case 79:d=j+B(e,6)|0;if((g&255)>>>0<=31){t[d+3|0]=16;F=0;break J}t[d+3|0]=17;break J;default:break K}}t[(j+B(e,6)|0)+3|0]=0}k=0;g=w[h+3|0];if(!(w[m+2|0]|!g)){U:{if(g>>>0>=16){t[m+2|0]=5;g=g>>>4|0;break U}t[m+2|0]=6}t[m+4|0]=g;k=1}V:{if(w[m+3|0]){break V}d=w[h+1|0];W:{if(d){t[m+3|0]=2;break W}d=w[h+2|0];if(d){t[m+3|0]=3;break W}d=w[h|0];if(d){t[m+3|0]=19;break W}d=w[h+7|0];if(d){t[m+3|0]=4;t[h+8|0]=d;break W}d=w[h+4|0];if(d){t[m+3|0]=5;t[h+5|0]=d;break W}d=w[h+3|0];if(!(!d|k)){t[m+3|0]=11;t[l|0]=d;if(d&15){d=d|-16;break W}if(!(d&240)){break V}d=d|15;break W}d=w[h+6|0];if(d){t[m+3|0]=8;break W}if(r){t[m+3|0]=20;r=0;d=97;break W}r=0;if(H){break V}d=i&255;if(!d){break V}t[m+3|0]=24;t[l|0]=i;if(i&15){d=i|-16}else{if(!(d&240)){H=1;break V}d=i|15}H=1}t[l|0]=d}e=e+1|0;continue}}}v[a+480228>>2]=256/x[a+480188>>1];k=1;oh(a,1);if(Ib(x[f+292>>1])){X:{while(1){b=v[n+8>>2];i=v[n>>2];v[23588]=0;b=W(156,i|0,b|0,2)|0;i=v[23588];v[23588]=0;if((i|0)==1){break A}if(!b){break X}v[23588]=0;b=S(271,n|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break A}if((b|0)==65535){break X}v[23588]=0;Q(188,n|0,2)|0;b=v[23588];v[23588]=0;if((b|0)==1){break A}v[23588]=0;b=S(279,n|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){v[23588]=0;Q(188,n|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break A}v[23588]=0;Q(188,n|0,34)|0;b=v[23588];v[23588]=0;if((b|0)==1){break A}}Y:{if(!(c&2)){break Y}while(1){b=k&65535;if(b>>>0>C>>>0){break Y}Z:{e=(B(b,104)+a|0)+484380|0;if(!v[e>>2]){break Z}c=_c(f+232|0,8,1,0,0);v[23588]=0;W(219,c|0,e|0,n|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break A}c=v[o>>2];if(yd(c,v[o+4>>2])>>>0<b>>>0){break Z}j=b-1|0;g=Nd(c,j);c=0;b=0;m=kb-112|0;kb=m;_:{h=v[e>>2];if(!_d(h,v[e+20>>2])){break _}q=v[g>>2];i=yd(q,v[g+4>>2]);if(i>>>0<2){break _}d=ko(m+8|0,e);v[d+20>>2]=0;v[d>>2]=0;$:{while(1){if((c|0)==(i|0)){break $}aa:{l=Nd(q,c);s=v[l>>2];if(s>>>0>=h>>>0){break aa}l=v[l+4>>2];if(l>>>0>h-s>>>0|268435456-l>>>0<b>>>0){break aa}b=b+l|0;v[d>>2]=b;c=c+1|0;continue}break}i=c}if(!Og(d)){break _}l=d+68|0;b=0;c=0;while(1){if((c|0)==(i|0)){Em(e);b=ko(e,d);v[b+4>>2]=0;v[b+8>>2]=v[b>>2];u[b+34>>1]=x[b+34>>1]|2;break _}r=v[d+20>>2]+b|0;q=v[e+20>>2];h=Nd(v[g>>2],c);uc(r,q+v[h>>2]|0,v[h+4>>2]);v[h>>2]=b;if(c-10>>>0>=4294967287){V=Eb(l,c-1|0),X=b,v[V>>2]=X}c=c+1|0;b=v[h+4>>2]+b|0;continue}}kb=m+112|0;b=x[dc(v[z>>2],j)>>1];if(b){Uz(e,(B(b,104)+a|0)+484380|0,0,v[e>>2],0)}b=Nd(v[o>>2],j);V=f,X=Fb(v[b>>2]),v[V+232>>2]=X;c=Fb(v[b+4>>2]);while(1){b=v[f+232>>2];if(!Pb(b,c)){break Z}i=x[b+8>>1];if(i){Uz(e,(B(i,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],1)}i=x[b+10>>1];if(i){Uz(e,(B(i,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],0)}mq(f+232|0);continue}}k=k+1|0;continue}}Rt(E);d=1;break b}v[23588]=0;Q(188,n|0,B(g,x[f+238>>1])|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break B}break A}b=b+1|0;continue}break}e=P()|0;O()|0;Rt(E);break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break f}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;bc(f+8|0);break d}e=P()|0;O()|0;break e}Bb(h)}od(z);JQ(o)}T(e|0);L()}d=0}od(z);JQ(o)}kb=f+496|0;return d|0}function xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=kb-592|0;kb=d;zc(b);a:{if(!SA(b,d+512|0)){break a}if(!TP(d+512|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(SP(d+512|0),nb))){break a}b:{if(!c){break b}Bd(a,4);ag(a);t[a+1074368|0]=4;k=Mb(d+496|0);c:{d:{e:{f:{l=d+550|0;g:{if(!(Sb(l,17762,20)|v[d+572>>2]!=276)){if(x[d+570>>1]<260){break g}e=VA(d+529|0,0,20)?1154:34;break e}if(!Sb(l,17741,20)){e=1;break e}g=d- -64|0;Dj(g,3,l);v[23588]=0;R(222,d+104|0,g|0);g=v[23588];v[23588]=0;h:{i:{if((g|0)!=1){v[23588]=0;U(11,d+208|0,5,d+104|0);g=v[23588];v[23588]=0;if((g|0)==1){break i}g=d+208|0;Jb(k,g);Ab(g);zb(d+104|0);if(Sb(l,17579,8)){break h}e=1048;break e}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(d+104|0);break c}if(!Sb(l,17479,12)){e=16;if(!Sb(d+562|0,17783,8)){break e}t[a+1074368|0]=5;break e}if(Sb(l,11577,20)){break f}}e=48;break e}if(!Sb(l,27088,15)){v[23588]=0;g=Q(265,a+1074312|0,54)|0;e=v[23588];v[23588]=0;C=1;if((e|0)==1){break d}v[23588]=0;Q(265,g|0,51)|0;g=v[23588];v[23588]=0;e=16;if((g|0)==1){break d}break e}j:{if(Sb(l,27104,14)){if(Sb(l,27119,14)){break j}}v[23588]=0;g=Q(265,a+1074312|0,57)|0;e=v[23588];v[23588]=0;if((e|0)==1){break d}v[23588]=0;Q(265,g|0,51)|0;g=v[23588];v[23588]=0;e=16;if((g|0)!=1){break e}break d}e=Sb(l,17567,11)?16:256}g=d+104|0;s=d+529|0;Dj(g,3,s);v[23588]=0;R(222,d+208|0,g|0);g=v[23588];v[23588]=0;k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){g=d+208|0;Bc(a+1298308|0,g);zb(g);v[a+480260>>2]=1;v[a+480264>>2]=31999;Ve(Wb(v[a+484360>>2],w[a+484376|0]),x[d+578>>1]);u[a+480188>>1]=x[d+580>>1];u[d+208>>1]=x[d+584>>1];u[d+104>>1]=255;F=a+480192|0,G=x[Wc(g,d+104|0)>>1],u[F>>1]=G;g=x[d+588>>1];if(g){v[a+480196>>2]=g}g=x[d+590>>1];if(g){g=B(g,1e4);g=g>>>0<1e7?g:1e7;v[a+480204>>2]=g>>>0>32e4?g:32e4}g=x[d+586>>1];v[a+480208>>2]=g<<4&16|g<<3&32768;f=w[a+484376|0];n=v[a+484360>>2];v[23588]=0;da(340,Wb(n,f)|0,b|0,x[d+576>>1],65535,65535);f=v[23588];v[23588]=0;if((f|0)==1){break d}f=g>>>12&1?(e|0)==34?146:e:e;if(!(x[d+576>>1]|f&1024)){g=w[a+484376|0];e=v[a+484360>>2];v[23588]=0;Y(731,Wb(e,g)|0);g=v[23588];v[23588]=0;if((g|0)==1){break d}}v[23588]=0;Q(155,b|0,v[d+572>>2]+60|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(x[d+570>>1]>=260){v[23588]=0;U(732,b|0,d+512|0,a|0);g=v[23588];v[23588]=0;if((g|0)==1){break d}}t[d+495|0]=0;z=c&2;D=d+122|0;o=d+241|0;n=Tb(d+480|0);E=a+480192|0;g=-1;p=1;while(1){e=p&65535;if(e>>>0>x[E>>1]){if(!(!(f&2)|q&255)){f=VA(s,0,20)?f|16:f}if(x[d+570>>1]>259){break o}if(c&3){v[23588]=0;U(732,b|0,d+512|0,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break n}}if(!z){break o}o=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>x[o>>1]){break o}i=v[n>>2];v[23588]=0;W(219,Eb(i,c-1|0)|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}v[23588]=0;i=S(157,b|0)|0;h=v[23588];v[23588]=0;r:{s:{if((h|0)!=1){zg(b,4);v[23588]=0;U(733,b|0,d+208|0,(i?i:263)|0);i=v[23588];v[23588]=0;if((i|0)==1){break p}t:{if((f|0)==1){i=v[d+208>>2];if((i|0)!=263){f=16;if((i|0)!=245){break t}v[a+1074308>>2]=16777381;v[23588]=0;f=Q(1,d+192|0,13270)|0;i=v[23588];v[23588]=0;if((i|0)!=1){Jb(k,f);Ab(f);f=17;break t}f=P()|0;O()|0;break k}v[a+1074308>>2]=16777395;v[23588]=0;f=Q(1,d+176|0,13185)|0;i=v[23588];v[23588]=0;if((i|0)!=1){Jb(k,f);Ab(f);f=17;break t}f=P()|0;O()|0;break k}if(w[d+235|0]|w[d+236|0]<<8){break t}i=v[d+208>>2];if(!(!(f&2)|(w[d+237|0]|w[d+238|0]<<8|(w[d+239|0]<<16|w[d+240|0]<<24))|(i|0)!=263)){f=f|16;break t}if(!(!(f&256)|(i|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(i|0)==33?f:0}v[23588]=0;i=W(251,a|0,e|0,0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break p}if(!i){break r}i=((e<<2)+a|0)+900380|0;e=v[i>>2];v[23588]=0;R(734,d+208|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break p}e=w[d+234|0];u:{if((g|0)==-1){g=e;break u}if(!(f&32)|(e|0)==(g|0)){break u}f=f&-161|128}e=w[d+235|0]|w[d+236|0]<<8;if(!e){break r}v[23588]=0;h=w[d+455|0];j=w[d+451|0]|w[d+452|0]<<8;m=w[d+450|0];r=w[d+449|0];U(735,d+160|0,a|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break q}f=h|(j|(m|r))?f&-4:f;i=v[i>>2]+236|0;e=12;h=v[d+160>>2];j=Rc(h,v[d+164>>2]);v:{while(1){w:{if((e|0)==108){if(x[d+570>>1]>259){Lc(n)}e=0;v[23588]=0;i=Q(736,d+144|0,w[d+235|0]|w[d+236|0]<<8)|0;h=v[23588];v[23588]=0;if((h|0)!=1){break w}f=P()|0;O()|0;break v}m=dc(i,e);if(j>>>0>x[m>>1]){F=m,G=x[dc(h,x[dc(i,e)>>1])>>1],u[F>>1]=G}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){h=w[d+235|0]|w[d+236|0]<<8;if(e>>>0>=h>>>0){e=0;if(x[d+570>>1]<=259){break s}B:{while(1){if(e>>>0>=h>>>0){break s}j=w[Eb(v[n>>2],e)+3|0];h=v[Eb(v[i>>2],e)>>2];v[23588]=0;U(190,d- -64|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=v[23588];v[23588]=0;if((h|0)!=1){j=d- -64|0;h=kc(d+104|0,j);Bb(j);j=v[d+160>>2];if(!(!z|Rc(j,v[d+164>>2])>>>0<=e>>>0)){m=x[dc(j,e)>>1];j=Eb(v[n>>2],e);j=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);v[23588]=0;v[d+56>>2]=j;v[d>>2]=j;j=fa(737,(B(m,104)+a|0)+484380|0,d|0,h|0,d+495|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break B}A=j^1|A}Bb(h);e=e+1|0;h=w[d+235|0]|w[d+236|0]<<8;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;Bb(h);break x}v[23588]=0;R(738,b|0,d+104|0);h=v[23588];v[23588]=0;if((h|0)==1){break y}h=d- -64|0;j=w[d+118|0];C:{if(!(j&48|w[d+121|0]!=173)){_c(h,8,1,0,10);break C}_c(h,j&16?16:8,j&32?3:1,0,2)}v[23588]=0;R(739,n|0,h|0);h=v[23588];v[23588]=0;if((h|0)!=1){F=Eb(v[i>>2],e),G=v[d+104>>2],v[F>>2]=G;m=w[d+121|0];h=v[d+160>>2];if(Rc(h,v[d+164>>2])>>>0>e>>>0){j=x[dc(h,e)>>1];v[23588]=0;h=(B(j,104)+a|0)+484380|0;R(740,d+104|0,h|0);r=v[23588];v[23588]=0;if((r|0)==1){break A}t[h+38|0]=w[o+202|0];t[h+39|0]=w[o+203|0];t[h+40|0]=w[o+204|0];t[h+41|0]=w[o+205|0];h=d+88|0;Il(h,3,D);v[23588]=0;R(222,d- -64|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break z}h=d- -64|0;Dc(((j<<5)+a|0)+946304|0,h);zb(h);f=(w[d+118|0]&3)==3?(f&2)>>>1|0?f|4:f:f}q=m|q;e=e+1|0;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0}wc(i)}od(d+160|0);break k}f=P()|0;O()|0;break k}wc(i);od(d+160|0)}p=p+1|0;continue}}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}D:{if(!(A&1)){break D}v[23588]=0;c=Q(1,d+104|0,16594)|0;e=v[23588];v[23588]=0;E:{if((e|0)!=1){e=v[a+1298464>>2];v[23588]=0;U(376,e|0,2,c|0);e=v[23588];v[23588]=0;if((e|0)==1){break E}Ab(c);break D}f=P()|0;O()|0;break k}f=P()|0;O()|0;Ab(c);break k}v[23588]=0;c=Q(402,b|0,5561)|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}if(c){v[23588]=0;c=S(157,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}v[23588]=0;X(331,a+1298332|0,b|0,c|0,0);c=v[23588];v[23588]=0;if((c|0)==1){break n}f=f|16}v[23588]=0;o=Q(402,b|0,14043)|0;c=v[23588];v[23588]=0;if((c|0)==1){break l}if(o){v[23588]=0;c=S(157,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}v[23588]=0;e=a+901404|0;U(741,b|0,e|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break l}UA(e);f=f|16}v[23588]=0;c=Q(402,b|0,13805)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}if(!c){break m}v[23588]=0;c=S(157,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){u[d+208>>1]=c>>>5;F=d,G=Bf(v[a+484344>>2],v[a+484348>>2]),u[F+64>>1]=G;c=x[Wc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break m}v[23588]=0;R(565,b|0,d+208|0);i=v[23588];v[23588]=0;F:{if((i|0)==1){break F}i=v[a+484344>>2];v[23588]=0;R(566,Zb(i,e)|0,d+208|0);i=v[23588];v[23588]=0;if((i|0)==1){break F}e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[23588]=0;c=Q(402,b|0,13810)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}G:{if(!c){break G}v[23588]=0;c=S(157,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){u[d+208>>1]=(c>>>0)/20;u[d+64>>1]=x[a+480188>>1];c=x[Wc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}v[23588]=0;U(413,b|0,((e<<5)+a|0)+480289|0,20);i=v[23588];v[23588]=0;if((i|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,8)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=v[b+8>>2];v[23588]=0;Q(414,a|0,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break K}f=(c|0)==v[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){v[a+1074308>>2]=17367040;v[23588]=0;c=Q(1,d+208|0,14650)|0;e=v[23588];v[23588]=0;if((e|0)!=1){Jb(k,c);Ab(c);break L}f=P()|0;O()|0;break k}if(!(f&2)){break L}v[a+1074308>>2]=18219008;v[23588]=0;c=Q(1,d+208|0,14814)|0;e=v[23588];v[23588]=0;if((e|0)==1){break J}Jb(k,c);Ab(c)}M:{N:{O:{P:{Q:{R:{S:{if(!Sb(l,17579,8)){v[23588]=0;c=W(383,d- -64|0,d+558|0,12)|0;e=v[23588];v[23588]=0;if((e|0)==1){break S}v[23588]=0;U(11,d+160|0,1,c|0);e=v[23588];v[23588]=0;if((e|0)==1){break R}v[23588]=0;e=S(742,d+160|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Q}v[a+1074308>>2]=e;Ab(d+160|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;zb(c);f=24}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;nu(a+1074312|0)}c=f&32;T:{if(!c){break T}t[a+1074368|0]=5;if(!o){qq(a+901404|0)}if(x[d+570>>1]<260){break T}v[23588]=0;W(264,a+1074312|0,4,1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}}if(!sh(v[k+4>>2],w[k+11|0])){break M}if(!(f&256)|q&255|g+1>>>0>1){break N}v[23588]=0;c=Q(1,d+160|0,8252)|0;g=v[23588];v[23588]=0;if((g|0)==1){break O}Jb(k,c);Ab(c);break M}f=P()|0;O()|0;break k}f=P()|0;O()|0;break P}f=P()|0;O()|0;Ab(d+160|0)}zb(c);break k}f=P()|0;O()|0;break k}if(c){v[23588]=0;c=Q(1,d+160|0,11989)|0;g=v[23588];v[23588]=0;if((g|0)!=1){Jb(k,c);Ab(c);break M}f=P()|0;O()|0;break k}v[23588]=0;c=Q(1,d+160|0,9700)|0;g=v[23588];v[23588]=0;if((g|0)==1){break I}Jb(k,c);Ab(c)}t[d+55|0]=0;U:{if(x[a+480192>>1]){v[23588]=0;c=Q(422,a|0,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break U}t[d+55|0]=c}v[23588]=0;X(423,a|0,b|0,1,d+55|0);b=v[23588];v[23588]=0;if((b|0)==1){break U}e=v[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(w[d+55|0]){if(e>>>0>18284543){break ha}v[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}v[23588]=0;b=Q(1,d+40|0,17579)|0;c=v[23588];v[23588]=0;if((c|0)==1){break fa}c=v[a+1074308>>2];v[23588]=0;R(743,d+24|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break ea}v[23588]=0;U(2,d+88|0,b|0,d+24|0);c=v[23588];v[23588]=0;if((c|0)==1){break da}c=d+88|0;Jb(k,c);Ab(c);Ab(d+24|0);Ab(b);e=v[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=v[a+484344>>2];f=v[a+484348>>2];if(!ye(b,f,254)){b=w[a+484376|0];c=v[a+484360>>2];v[23588]=0;Y(744,Wb(c,b)|0);b=v[23588];v[23588]=0;if((b|0)==1){break U}f=v[a+484348>>2];b=v[a+484344>>2]}if(ye(b,f,255)){break ia}hA(Wb(v[a+484360>>2],w[a+484376|0]),255,65535)}v[23588]=0;R(745,d+24|0,4105);b=v[23588];v[23588]=0;if((b|0)==1){break ba}b=x[d+570>>1];v[d+20>>2]=b>>>8;v[23588]=0;v[d+4>>2]=b&255;R(433,d+8|0,d+4|0);b=v[23588];v[23588]=0;if((b|0)==1){break aa}v[23588]=0;X(419,d+88|0,d+24|0,d+20|0,d+8|0);b=v[23588];v[23588]=0;if((b|0)==1){break $}c=d+88|0;b=Jb(a+1298344|0,c);Ab(c);Ab(d+8|0);bc(d+24|0);Jb(a+1298368|0,k);v[a+1298404>>2]=C?8:v[a+1074308>>2]?8:5;if(!w[d+495|0]){break W}Jb(a+1298380|0,b);v[23588]=0;c=Q(1,d+88|0,15250)|0;g=v[23588];v[23588]=0;if((g|0)==1){break Z}Jb(b,c);Ab(c);v[23588]=0;b=Q(1,d+24|0,10051)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Y}Jb(a+1298356|0,b);Ab(b);v[23588]=0;b=Q(1,d+8|0,10052)|0;c=v[23588];v[23588]=0;if((c|0)==1){break X}Jb(a+1298392|0,b);break V}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ca}f=P()|0;O()|0;Ab(d+24|0)}Ab(b);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break _}f=P()|0;O()|0;Ab(d+8|0)}bc(d+24|0);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[23588]=0;b=Q(1,d+88|0,10052)|0;c=v[23588];v[23588]=0;if((c|0)==1){break H}Jb(a+1298356|0,b)}Ab(b);wc(n);Ab(k);break b}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0}wc(n);break c}f=P()|0;O()|0}Ab(k);T(f|0);L()}e=1}kb=d+592|0;return e|0}function xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=kb-336|0;kb=e;zc(b);a:{b:{c:{if(!Wt(b,e+240|0)){break c}if(!fR(e+240|0)){break c}if(!Qb(v[b>>2],v[b+8>>2],Ec(eR(e+240|0),nb))){break c}if(!c){s=1;break c}Bd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;i=Mb(e+224|0);d=x[e+280>>1];j=(d|0)==20479?x[e+294>>1]:d-16464|0;d:{e:{f:{g:{h:{i:{switch(d>>>12|0){case 0:if((d|0)!=520){break d}v[23588]=0;d=Q(1,e+208|0,12229)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Jb(i,d);break e}b=P()|0;O()|0;break a;case 1:j:{if(x[e+302>>1]|(d|0)!=4896){break j}if(!(x[e+278>>1]&65455|(w[e+292|0]|w[e+272|0]&15))){k:{if(t[e+291|0]<0){v[a+1074308>>2]=18219008;v[23588]=0;d=Q(1,e+208|0,14727)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break k}b=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[23588]=0;d=Q(1,e+208|0,13270)|0;f=v[23588];v[23588]=0;if((f|0)==1){break h}}Jb(i,d);Ab(d);v[23588]=0;f=1;W(264,a+1074312|0,81,1)|0;d=v[23588];v[23588]=0;g=1;if((d|0)!=1){break d}break b}if(w[e+293|0]|(w[e+292|0]|x[e+278>>1])){break j}v[23588]=0;d=Q(1,e+208|0,9436)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Jb(i,d);break e}b=P()|0;O()|0;break a}v[23588]=0;d=Q(1,e+208|0,8454)|0;f=v[23588];v[23588]=0;k=1;if((f|0)!=1){Jb(i,d);Ab(d);break f}b=P()|0;O()|0;break a;case 2:v[23588]=0;d=Q(1,e+208|0,6776)|0;f=v[23588];v[23588]=0;g=1;if((f|0)!=1){Jb(i,d);Ab(d);break f}b=P()|0;O()|0;break a;case 3:l:{m:{n:{o:{if(d>>>0<=12820){v[23588]=0;f=Q(1,e+208|0,8517)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Jb(i,f);Ab(f);break o}b=P()|0;O()|0;break a}v[23588]=0;R(431,e+208|0,4018);f=v[23588];v[23588]=0;if((f|0)==1){break n}v[23588]=0;v[e+192>>2]=x[e+280>>1]-12820;U(432,e+48|0,e+208|0,e+192|0);f=v[23588];v[23588]=0;if((f|0)==1){break m}f=e+48|0;Jb(i,f);Ab(f);bc(e+208|0)}f=x[e+280>>1];if(f>>>0<12807){break g}h=v[e+296>>2];if(h){break l}break g}b=P()|0;O()|0;break a}b=P()|0;O()|0;bc(e+208|0);break a}f=WC(f,h);h=yo(e+48|0);v[h+32>>2]=f;v[23588]=0;R(434,a+1298408|0,h|0);f=v[23588];v[23588]=0;if((f|0)!=1){break g}b=P()|0;O()|0;break a;case 4:p:{q:{if((d|0)==16640){v[23588]=0;f=Q(1,e+208|0,8300)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Jb(i,f);Ab(f);f=81;break q}b=P()|0;O()|0;break a}v[23588]=0;U(435,e+48|0,d|0,x[e+294>>1]);f=v[23588];v[23588]=0;r:{if((f|0)!=1){f=e+48|0;Jb(i,f);Ab(f);v[a+480260>>2]=1;if((j|0)<4201){break r}v[23588]=0;W(264,a+1074312|0,7,1)|0;h=v[23588];v[23588]=0;f=38;if((h|0)==1){break b}break q}b=P()|0;O()|0;break a}f=38;if((j|0)<2386){break p}}v[23588]=0;W(264,a+1074312|0,f|0,1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break b}}h=(d|0)!=16640;g=1;f=0;break d;case 5:d=d&4095;v[a+1074308>>2]=d<<16|(d>>>0>296?x[e+294>>1]:0)&65535;v[23588]=0;d=Q(1,e+208|0,17579)|0;f=v[23588];v[23588]=0;s:{t:{u:{if((f|0)!=1){f=v[a+1074308>>2];v[23588]=0;R(140,e+192|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break u}f=0;v[23588]=0;U(2,e+48|0,d|0,e+192|0);h=v[23588];v[23588]=0;if((h|0)==1){break t}h=e+48|0;Jb(i,h);Ab(h);Ab(e+192|0);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break s}b=P()|0;O()|0;Ab(e+192|0)}Ab(d);break a;case 6:v[23588]=0;d=Q(1,e+208|0,8300)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Jb(i,d);Ab(d);v[23588]=0;W(264,a+1074312|0,81,1)|0;d=v[23588];v[23588]=0;h=0;if((d|0)==1){break b}break d}b=P()|0;O()|0;break a;case 7:v[23588]=0;d=Q(1,e+208|0,8312)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Jb(i,d);break e}b=P()|0;O()|0;break a;default:break i}}if((d|0)!=51712){break d}v[23588]=0;d=Q(1,e+208|0,9235)|0;h=v[23588];v[23588]=0;if((h|0)!=1){Jb(i,d);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[23588]=0;f=W(264,a+1074312|0,7,1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}v[23588]=0;f=W(264,f|0,23,1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}v[23588]=0;f=W(264,f|0,38,1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}v[23588]=0;W(264,f|0,107,1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break b}g=1;v[a+480260>>2]=1;f=0;h=0;if(d>>>0>12820){break d}}v[23588]=0;Y(666,e+192|0);d=v[23588];v[23588]=0;v:{w:{x:{if((d|0)!=1){d=x[e+280>>1];v[e+160>>2]=d>>>8&15;v[23588]=0;v[e+136>>2]=d&255;R(433,e+176|0,e+136|0);d=v[23588];v[23588]=0;if((d|0)==1){break x}f=0;v[23588]=0;da(667,e+48|0,e+192|0,i|0,e+160|0,e+176|0);d=v[23588];v[23588]=0;if((d|0)==1){break w}d=e+48|0;Jb(i,d);Ab(d);Ab(e+176|0);bc(e+192|0);break d}b=P()|0;O()|0;break a}b=P()|0;O()|0;break v}b=P()|0;O()|0;Ab(e+176|0)}bc(e+192|0);break a}Ab(d);h=0}v[23588]=0;d=Q(1,e+192|0,15007)|0;l=v[23588];v[23588]=0;y:{z:{A:{B:{C:{D:{E:{F:{if((l|0)!=1){Jb(a+1298344|0,d);Ab(d);v[23588]=0;d=Q(1,e+176|0,10424)|0;l=v[23588];v[23588]=0;if((l|0)==1){break F}Jb(a+1298356|0,d);Ab(d);l=Jb(a+1298368|0,i);v[a+1298404>>2]=v[a+1074308>>2]?8:5;if(g){v[23588]=0;d=Q(265,a+1074312|0,77)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;d=Q(265,d|0,78)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;d=Q(265,d|0,79)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;d=Q(265,d|0,80)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;d=Q(265,d|0,82)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;d=Q(265,d|0,96)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}v[23588]=0;Q(265,d|0,113)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}}d=x[e+280>>1];g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|d>>>0>12819|f}v[23588]=0;d=a+901404|0;Y(668,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break b}if(!f){qq(d)}d=e+160|0;Ii(d,1,e+240|0);v[23588]=0;R(222,e+48|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break C}d=e+48|0;Bc(a+1298308|0,d);zb(d);d=x[e+278>>1];if(d&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(d&1){v[a+480208>>2]=v[a+480208>>2]|131072}f=x[e+280>>1];if(!(d&64?0:(f|0)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}d=w[e+289|0];v[a+480196>>2]=d;if(!(!k|(d|0)!=255?d:0)){v[a+480196>>2]=6}d=w[e+290|0];v[a+480204>>2]=d>>>0<33?k?125e4:32e4:B(d,1e4);t[e+48|0]=w[e+288|0];t[e+160|0]=64;d=w[Xb(e+48|0,e+160|0)|0];v[a+480200>>2]=d<<2;if(!(d|f>>>0>4895)){v[a+480200>>2]=256}g=w[e+291|0];if(x[e+282>>1]!=1|g>>>0>7){break E}v[e+48>>2]=(g<<4)+16;v[e+160>>2]=127;f=v[td(e+48|0,e+160|0)>>2];break D}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}f=32;if((g|16)==18){break D}d=g&127;f=48;if(!d){break D}v[e+48>>2]=d;v[e+160>>2]=16;f=v[Pe(e+48|0,e+160|0)>>2]}v[a+480228>>2]=f;d=0;q=v[a+1074308>>2]!=0|g<<24>>24<0;if(!q){H=a,I=Ec(Rka(f<<3|5,f>>>29|0,11,0),nb),v[H+480228>>2]=I}r=a+480188|0;u[r>>1]=4;v[a+480232>>2]=h?(j|0)<3299?64:36:36;f=Hc(e+152|0);while(1){if((d|0)==32){d=a+480188|0;if(!x[d>>1]){u[d>>1]=1}d=w[a+484376|0];h=v[a+484360>>2];v[23588]=0;da(340,Wb(h,d)|0,b|0,x[e+272>>1],255,254);d=v[23588];v[23588]=0;if((d|0)!=1){q=Tb(e+160|0);v[23588]=0;W(217,b|0,q|0,x[e+274>>1])|0;d=v[23588];v[23588]=0;if((d|0)!=1){r=Tb(e+136|0);v[23588]=0;W(217,b|0,r|0,x[e+276>>1])|0;d=v[23588];v[23588]=0;G:{if((d|0)!=1){if(w[e+293|0]!=252){break B}d=0;v[23588]=0;R(669,b|0,e+48|0);h=v[23588];v[23588]=0;if((h|0)==1){break G}while(1){if((d|0)==32){break B}h=w[(e+48|0)+d|0];H:{if(!(h&32)){break H}if(k){Sc(e+32|0,f,d);if(Cb(v[v[e+32>>2]>>2],v[e+36>>2])){break H}}u[((d<<5)+a|0)+480284>>1]=(((h&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break A}break A}b=P()|0;O()|0;break z}b=P()|0;O()|0;break a}h=(d<<5)+a|0;j=h+480280|0;ef(j);g=w[(d+e|0)+304|0];o=g&127;I:{if((g|0)!=255){g=g<<24>>24;u[r>>1]=d+1;if(q){u[h+480284>>1]=g&8?204:51}if((g|0)>=0){break I}}v[j>>2]=1024}if((o-16&255)>>>0<=13){u[h+480284>>1]=128;h=e+48|0;Sc(h,f,d);po(h)}d=d+1|0;continue}}b=P()|0;O()|0;break a}u[e+48>>1]=x[e+274>>1];u[e+32>>1]=3999;f=x[Wc(e+48|0,e+32|0)>>1];u[a+480190>>1]=f;j=c&2;o=e+96|0;d=0;g=0;h=0;J:{K:{L:{while(1){if((f&65535)>>>0<=d>>>0){if(!k){break K}if(!(!(g&1)|h&65535)&x[e+280>>1]!=4864){break L}v[23588]=0;d=h&65535;f=W(264,a+1074312|0,79,d>>>0>1|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break A}v[23588]=0;d=d>>>0<2;f=W(264,f|0,107,d|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break A}v[23588]=0;W(264,f|0,38,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break A}v[23588]=0;d=h&65535;Q(133,l|0,(d>>>0>1?17140:17147)|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break A}if(d>>>0<2){break K}v[a+480228>>2]=48;break K}f=dc(v[q>>2],d);f=w[f|0]|w[f+1|0]<<8;v[23588]=0;f=Q(155,b|0,f<<4)|0;n=v[23588];v[23588]=0;if((n|0)==1){break J}M:{N:{if(!f){break N}v[23588]=0;f=Q(670,b|0,e+48|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break J}if(!f){break N}v[23588]=0;f=d+1|0;n=(B(f,104)+a|0)+484380|0;U(671,e+48|0,n|0,k|0);m=v[23588];v[23588]=0;if((m|0)==1){break J}m=e+16|0;Ii(m,1,o);v[23588]=0;R(222,e+32|0,m|0);m=v[23588];v[23588]=0;if((m|0)==1){break M}m=((f<<5)+a|0)+946304|0;f=e+32|0;Dc(m,f);zb(f);if(w[e+48|0]>1){break N}O:{if(!j|!v[e+64>>2]){break O}f=cR(e+48|0);v[23588]=0;f=Q(155,b|0,f|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break A}if(!f){break O}f=e+32|0;bR(f,w[e+78|0],w[e+79|0],x[e+282>>1]==1);v[23588]=0;W(219,f|0,n|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break A}g=1}h=x[e+88>>1]|h}d=d+1|0;f=x[a+480190>>1];continue}break}break A}v[23588]=0;d=Q(1,e+48|0,9700)|0;f=v[23588];v[23588]=0;if((f|0)==1){break A}Jb(l,d);Ab(d)}s=1;if(!(c&1)){break y}c=x[e+280>>1];u[e+32>>1]=x[e+276>>1];u[e+16>>1]=255;y=x[Wc(e+32|0,e+16|0)>>1];v[23588]=0;k=a+484344|0;R(225,k|0,y|0);d=v[23588];v[23588]=0;if((d|0)==1){break J}z=c>>>0<4896;c=e+32|0;m=c|5;D=c|3;A=c|4;E=c|2;F=c|1;G=a+480188|0;h=0;o=0;n=0;while(1){if((h|0)==(y|0)){if(!z){break y}a=x[a+480188>>1];if((a|0)>(n+o|0)|(a|0)<=(o-n|0)){break y}d=Bf(v[k>>2],v[k+4>>2])-1&65535;b=0;P:{if(Bf(v[k>>2],v[k+4>>2])>>>0<=d>>>0){break P}while(1){c=b&65535;if(c>>>0>d>>>0){break P}a=bg(v[k>>2],c);f=v[a>>2];if(Pb(f,v[a+4>>2])){a=Fb(f);f=Fb(v[bg(v[k>>2],c)+4>>2]);c=kb-16|0;kb=c;v[c+8>>2]=a;while(1){if(Pb(a,f)){if(w[a+3|0]==31){t[a+3|0]=20;t[a+5|0]=w[a+5|0]|128}a=v[Ck(c+8|0)>>2];continue}break}kb=c+16|0}b=b+1|0;continue}}break y}v[23588]=0;c=W(226,k|0,h&65535,64)|0;d=v[23588];v[23588]=0;if((d|0)==1){break J}Q:{if(!c){break Q}c=dc(v[r>>2],h);c=w[c|0]|w[c+1|0]<<8;if(!c){break Q}v[23588]=0;c=Q(155,b|0,c<<4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break J}if(!c){break Q}v[23588]=0;Q(188,b|0,2)|0;c=v[23588];v[23588]=0;if((c|0)==1){break J}d=0;c=Zb(v[k>>2],h);c=Df(v[c>>2],v[v[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break Q}f=d;v[23588]=0;l=S(206,b|0)|0;d=v[23588];v[23588]=0;R:{if((d|0)!=1){if(l){break R}d=64;if(f>>>0>62){continue}c=Zb(v[k>>2],h);d=f+1|0;c=Df(v[c>>2],v[v[c+48>>2]+12>>2],d);continue}break A}g=l&31;d=B(g,6)+c|0;p=ug(e+32|0);j=g>>>0<x[G>>1];C=j?d:p;if(l&32){v[23588]=0;R(260,e+16|0,b|0);g=v[23588];v[23588]=0;S:{T:{U:{if((g|0)!=1){p=Oc(e+16|0);g=w[e+16|0];if(g>>>0>239){break U}g=aR((B(g>>>4|0,12)+(g&15)|0)+13|0);break T}break A}V:{switch(g-254|0){case 0:break T;case 1:break V;default:break S}}g=0}t[C|0]=g}t[(j?d+1|0:F)|0]=w[p|0]}W:{if(!(l&64)){break W}v[23588]=0;p=S(206,b|0)|0;g=v[23588];v[23588]=0;X:{if((g|0)!=1){g=j?d+2|0:E;p=p<<24>>24;t[e+16|0]=p;if((p|0)>-64){break X}t[g|0]=2;t[(j?d+4|0:A)|0]=w[e+16|0]^128;break W}break A}t[g|0]=1;t[e+15|0]=64;H=j?d+4|0:A,I=w[Xb(e+16|0,e+15|0)|0],t[H|0]=I}Y:{if(!(l&128)){break Y}v[23588]=0;R(260,e+16|0,b|0);g=v[23588];v[23588]=0;Z:{_:{if((g|0)!=1){RA(C,w[e+16|0],w[Oc(e+16|0)|0],0);l=j?d+3|0:D;g=w[l|0];if((g|0)==10){break Z}if((g|0)==31){break _}if((g|0)!=20){break Y}d=j?d+5|0:m;g=w[d|0];if((g&240)!=160|x[e+280>>1]>4895){break Y}t[d|0]=g&15^136;break Y}break A}d=w[(j?d+5|0:m)|0];if(d>>>0>15){z=0;break Y}if(d>>>0<=7){n=n+1|0;break Y}o=((d|0)!=8)+o|0;break Y}if(w[(j?d+5|0:m)|0]|x[e+280>>1]>4865){break Y}t[l|0]=37}d=f;continue}}h=h+1|0;continue}}}b=P()|0;O()|0;od(r)}od(q);break a}od(r);od(q);Ab(i)}kb=e+336|0;return s|0}b=P()|0;O()|0}Ab(i);T(b|0);L()}function Pd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=kb-16|0;kb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){f=v[116096];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=f>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+464424|0;d=v[a+464432>>2];a=v[d+8>>2];l:{if((b|0)==(a|0)){m=464384,n=Ska(-2,c)&f,v[m>>2]=n;break l}v[a+12>>2]=b;v[b+8>>2]=a}a=d+8|0;b=c<<3;v[d+4>>2]=b|3;b=b+d|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[116098];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;d=(c|a)+(b>>>a|0)|0;a=d<<3;b=a+464424|0;g=v[a+464432>>2];a=v[g+8>>2];m:{if((b|0)==(a|0)){f=Ska(-2,d)&f;v[116096]=f;break m}v[a+12>>2]=b;v[b+8>>2]=a}v[g+4>>2]=h|3;c=g+h|0;a=d<<3;d=a-h|0;v[c+4>>2]=d|1;v[a+g>>2]=d;if(k){b=(k&-8)+464424|0;e=v[116101];a=1<<(k>>>3);n:{if(!(a&f)){v[116096]=a|f;a=b;break n}a=v[b+8>>2]}v[b+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=b;v[e+8>>2]=a}a=g+8|0;v[116101]=c;v[116098]=d;break a}j=v[116097];if(!j){break k}b=(0-j&j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+464688>>2];e=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;d=c>>>0<e>>>0;e=d?c:e;b=d?a:b;c=a;continue}break}i=v[b+24>>2];d=v[b+12>>2];if((d|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=d;v[d+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;d=a;c=a+20|0;a=v[c>>2];if(a){continue}c=d+16|0;a=v[d+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[116097];if(!j){break k}e=0-h|0;f=0;p:{if(h>>>0<256){break p}f=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|h>>>a+21&1)+28|0}c=v[(f<<2)+464688>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=e>>>0){break t}d=c;e=g;if(e){break t}e=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|d)){d=0;a=2<<f;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+464688>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<e>>>0;e=c?b:e;d=c?a:d;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!d|v[116098]-h>>>0<=e>>>0){break k}f=v[d+24>>2];b=v[d+12>>2];if((d|0)!=(b|0)){a=v[d+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=d+20|0;a=v[c>>2];if(!a){a=v[d+16>>2];if(!a){break i}c=d+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[116098];if(c>>>0>=h>>>0){d=v[116101];b=c-h|0;u:{if(b>>>0>=16){v[116098]=b;a=d+h|0;v[116101]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[116101]=0;v[116098]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[116099];if(i>>>0>h>>>0){b=i-h|0;v[116099]=b;c=v[116102];a=c+h|0;v[116102]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;b=j;if(v[116214]){c=v[116216]}else{v[116217]=-1;v[116218]=-1;v[116215]=4096;v[116216]=4096;v[116214]=l+12&-16^1431655768;v[116219]=0;v[116207]=0;c=4096}g=b+c|0;e=0-c|0;c=g&e;if(c>>>0<=h>>>0){break a}d=v[116206];if(d){b=v[116204];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[464828]&4){break f}v:{w:{d=v[116102];if(d){a=464832;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=rp(0);if((b|0)==-1){break g}f=c;d=v[116215];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=h>>>0|f>>>0>2147483646){break g}d=v[116206];if(d){a=v[116204];e=a+f|0;if(d>>>0<e>>>0|a>>>0>=e>>>0){break g}}a=rp(f);if((b|0)!=(a|0)){break v}break e}f=e&g-i;if(f>>>0>2147483646){break g}b=rp(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=f>>>0)){b=v[116216];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((rp(b)|0)!=-1){f=b+f|0;b=a;break e}rp(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}d=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[116207]=v[116207]|4}if(c>>>0>2147483646){break d}b=v[23509];c=c+3&-4;a=b+c|0;x:{y:{if(!c|a>>>0>b>>>0){if(_w()>>>0>=a>>>0){break y}if(xa(a|0)|0){break y}a=v[23509]}else{a=b}v[116064]=48;b=-1;break x}v[23509]=a}if(_w()>>>0<a>>>0){if(!(xa(a|0)|0)){break d}}v[23509]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=h+40>>>0){break d}}a=v[116204]+f|0;v[116204]=a;if(a>>>0>y[116205]){v[116205]=a}z:{A:{B:{g=v[116102];if(g){a=464832;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break B}a=v[a+8>>2];if(a){continue}break}break A}a=v[116100];if(!(a>>>0<=b>>>0?a:0)){v[116100]=b}a=0;v[116209]=f;v[116208]=b;v[116104]=-1;v[116105]=v[116214];v[116211]=0;while(1){d=a<<3;c=d+464424|0;v[d+464432>>2]=c;v[d+464436>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116099]=c;a=a+b|0;v[116102]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116103]=v[116218];break z}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break A}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[116102]=c;b=v[116099]+f|0;a=b-a|0;v[116099]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[116103]=v[116218];break z}if(y[116100]>b>>>0){v[116100]=b}d=b+f|0;c=464832;C:{while(1){if((d|0)!=v[c>>2]){a=464832;c=v[c+8>>2];if(c){continue}break C}break}a=464832;if(w[c+12|0]&8){break C}v[c>>2]=b;v[c+4>>2]=v[c+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;d=d+(d+8&7?-8-d&7:0)|0;i=h+j|0;a=d-i|0;D:{if((d|0)==(g|0)){v[116102]=i;a=v[116099]+a|0;v[116099]=a;v[i+4>>2]=a|1;break D}if(v[116101]==(d|0)){v[116101]=i;a=v[116098]+a|0;v[116098]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break D}e=v[d+4>>2];if((e&3)==1){f=e&-8;E:{if(e>>>0<=255){b=e>>>3|0;e=v[d+8>>2];c=v[d+12>>2];if((c|0)==(e|0)){m=464384,n=v[116096]&Ska(-2,b),v[m>>2]=n;break E}v[e+12>>2]=c;v[c+8>>2]=e;break E}h=v[d+24>>2];b=v[d+12>>2];F:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break F}G:{e=d+20|0;c=v[e>>2];if(c){break G}e=d+16|0;c=v[e>>2];if(c){break G}b=0;break F}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break E}e=v[d+28>>2];c=(e<<2)+464688|0;H:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break H}m=464388,n=v[116097]&Ska(-2,e),v[m>>2]=n;break E}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break E}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break E}v[b+20>>2]=c;v[c+24>>2]=b}d=d+f|0;e=v[d+4>>2];a=a+f|0}v[d+4>>2]=e&-2;v[i+4>>2]=a|1;v[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+464424|0;c=v[116096];a=1<<(a>>>3);I:{if(!(c&a)){v[116096]=a|c;a=b;break I}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break D}e=31;if(a>>>0<=16777215){b=a>>>8|0;e=b+1048320>>>16&8;b=b<<e;d=b+520192>>>16&4;b=b<<d;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(d|e))|0;e=(b<<1|a>>>b+21&1)+28|0}v[i+28>>2]=e;v[i+16>>2]=0;v[i+20>>2]=0;d=(e<<2)+464688|0;J:{c=v[116097];b=1<<e;K:{if(!(c&b)){v[116097]=b|c;v[d>>2]=i;v[i+24>>2]=d;break K}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[d>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break J}b=e>>>29|0;e=e<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=i;v[i+24>>2]=c}v[i+12>>2]=i;v[i+8>>2]=i;break D}a=v[c+8>>2];v[a+12>>2]=i;v[c+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=c;v[i+8>>2]=a}a=j+8|0;break a}while(1){L:{c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break L}}a=v[a+8>>2];continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116099]=c;a=a+b|0;v[116102]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116103]=v[116218];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116211];v[c+16>>2]=v[116210];v[c+20>>2]=a;a=v[116209];v[c+8>>2]=v[116208];v[c+12>>2]=a;v[116210]=c+8;v[116209]=f;v[116208]=b;v[116211]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break z}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){b=(e&-8)+464424|0;c=v[116096];a=1<<(e>>>3);M:{if(!(c&a)){v[116096]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break z}a=31;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;v[g+16>>2]=0;v[g+20>>2]=0;b=(a<<2)+464688|0;N:{d=v[116097];c=1<<a;O:{if(!(d&c)){v[116097]=c|d;v[b>>2]=g;break O}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);d=v[b>>2];while(1){b=d;if((e|0)==(v[b+4>>2]&-8)){break N}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=v[c+16>>2];if(d){continue}break}v[c+16>>2]=g}v[g+24>>2]=b;v[g+12>>2]=g;v[g+8>>2]=g;break z}a=v[b+8>>2];v[a+12>>2]=g;v[b+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=b;v[g+8>>2]=a}a=v[116099];if(a>>>0<=h>>>0){break d}b=a-h|0;v[116099]=b;c=v[116102];a=c+h|0;v[116102]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;v[116064]=48;break a}P:{if(!f){break P}c=v[d+28>>2];a=(c<<2)+464688|0;Q:{if(v[a>>2]==(d|0)){v[a>>2]=b;if(b){break Q}j=Ska(-2,c)&j;v[116097]=j;break P}v[f+(v[f+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break P}}v[b+24>>2]=f;a=v[d+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[d+20>>2];if(!a){break P}v[b+20>>2]=a;v[a+24>>2]=b}R:{if(e>>>0<=15){a=e+h|0;v[d+4>>2]=a|3;a=a+d|0;v[a+4>>2]=v[a+4>>2]|1;break R}v[d+4>>2]=h|3;f=d+h|0;v[f+4>>2]=e|1;v[e+f>>2]=e;if(e>>>0<=255){b=(e&-8)+464424|0;c=v[116096];a=1<<(e>>>3);S:{if(!(c&a)){v[116096]=a|c;a=b;break S}a=v[b+8>>2]}v[b+8>>2]=f;v[a+12>>2]=f;v[f+12>>2]=b;v[f+8>>2]=a;break R}a=31;if(e>>>0<=16777215){a=e>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|e>>>a+21&1)+28|0}v[f+28>>2]=a;v[f+16>>2]=0;v[f+20>>2]=0;b=(a<<2)+464688|0;T:{c=1<<a;U:{if(!(c&j)){v[116097]=c|j;v[b>>2]=f;break U}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(e|0)){break T}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=f}v[f+24>>2]=b;v[f+12>>2]=f;v[f+8>>2]=f;break R}a=v[b+8>>2];v[a+12>>2]=f;v[b+8>>2]=f;v[f+24>>2]=0;v[f+12>>2]=b;v[f+8>>2]=a}a=d+8|0;break a}V:{if(!i){break V}c=v[b+28>>2];a=(c<<2)+464688|0;W:{if(v[a>>2]==(b|0)){v[a>>2]=d;if(d){break W}m=464388,n=Ska(-2,c)&j,v[m>>2]=n;break V}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=d;if(!d){break V}}v[d+24>>2]=i;a=v[b+16>>2];if(a){v[d+16>>2]=a;v[a+24>>2]=d}a=v[b+20>>2];if(!a){break V}v[d+20>>2]=a;v[a+24>>2]=d}X:{if(e>>>0<=15){a=e+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break X}v[b+4>>2]=h|3;d=b+h|0;v[d+4>>2]=e|1;v[d+e>>2]=e;if(k){c=(k&-8)+464424|0;g=v[116101];a=1<<(k>>>3);Y:{if(!(a&f)){v[116096]=a|f;a=c;break Y}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[116101]=d;v[116098]=e}a=b+8|0}kb=l+16|0;return a|0}function T6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=kb-32|0;kb=g;a:{b:{c:{d:{e:{if(ve(b,21619)){Mb(a);break e}if(ve(b,9843)){b=kb-128|0;kb=b;f=Mb(a);v[23588]=0;Y(134,b+96|0);a=v[23588];v[23588]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[23588]=0;v[b+64>>2]=0;R(1054,b+80|0,b- -64|0);a=v[23588];v[23588]=0;if((a|0)==1){break p}v[23588]=0;a=Q(800,f|0,b+80|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break o}zb(b+80|0);v[23588]=0;a=Q(941,a|0,16736)|0;c=v[23588];v[23588]=0;q:{if((c|0)==1){break q}v[23588]=0;v[b+64>>2]=7;R(1054,b+80|0,b- -64|0);c=v[23588];v[23588]=0;if((c|0)==1){break n}v[23588]=0;a=Q(800,a|0,b+80|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break m}zb(b+80|0);v[23588]=0;a=Q(941,a|0,16736)|0;c=v[23588];v[23588]=0;if((c|0)==1){break q}v[23588]=0;v[b+64>>2]=0;R(1054,b+80|0,b- -64|0);c=v[23588];v[23588]=0;if((c|0)==1){break l}v[23588]=0;a=Q(800,a|0,b+80|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}c=b+80|0;zb(c);v[23588]=0;c=Q(55,c|0,14699)|0;d=v[23588];v[23588]=0;if((d|0)==1){break j}d=Hb(c);zb(c);if(!d){break i}v[23588]=0;Q(941,a|0,14699)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(b+80|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(b+80|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(b+80|0);break h}a=P()|0;O()|0;break h}c=Tb(b- -64|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=v[b+108>>2];if(d){v[23588]=0;v[b+16>>2]=d;R(1054,b+32|0,b+16|0);d=v[23588];v[23588]=0;if((d|0)==1){break D}v[23588]=0;U(967,b+48|0,8924,b+32|0);d=v[23588];v[23588]=0;if((d|0)==1){break C}v[23588]=0;R(183,c|0,b+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break B}zb(b+48|0);zb(b+32|0)}if(!Qd(w[b+112|0])){break x}v[23588]=0;d=Q(55,b+48|0,12690)|0;e=v[23588];v[23588]=0;if((e|0)==1){break z}v[23588]=0;R(183,c|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break y}zb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;zb(b+48|0)}zb(b+32|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;zb(d);break r}if(!Qd(w[b+113|0])){break w}v[23588]=0;d=Q(55,b+48|0,12461)|0;e=v[23588];v[23588]=0;if((e|0)==1){break v}v[23588]=0;R(183,c|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break u}zb(d)}if(Qd(w[b+114|0])){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;zb(d);break r}v[23588]=0;d=Q(55,b+32|0,11054)|0;e=v[23588];v[23588]=0;E:{if((e|0)!=1){v[23588]=0;R(183,c|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break E}zb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;zb(d);break r}if(pc(v[c>>2],v[c+4>>2])){break f}v[23588]=0;a=Q(941,a|0,16766)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;d=Q(55,b|0,16736)|0;e=v[23588];v[23588]=0;F:{G:{H:{if((e|0)!=1){v[23588]=0;U(1055,b+16|0,c|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break H}v[23588]=0;Q(800,a|0,b+16|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break G}zb(b+16|0);zb(d);break f}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;zb(b+16|0)}zb(d);break r}a=P()|0;O()|0}Xe(c)}Ef(b+96|0)}zb(f);break a}Xe(c);Ef(b+96|0);kb=b+128|0;break e}if(ve(b,8092)){v[g>>2]=0;Bp(a,g);break e}if(ve(b,8070)){v[g>>2]=7;Bp(a,g);break e}if(ve(b,10774)){v[g>>2]=0;Bp(a,g);break e}if(ve(b,10546)){Nc(a,14699);break e}if(ve(b,11323)){b=Nc(g,14699);c=Hb(b);v[23588]=0;Q(55,a|0,(c?15771:15441)|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break d}zb(b);break e}if(ve(b,7372)){b=kb-48|0;kb=b;$D(b+16|0);v[23588]=0;Y(151,b|0);c=v[23588];v[23588]=0;I:{J:{K:{L:{if((c|0)!=1){v[23588]=0;U(152,b+32|0,b+16|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break L}v[23588]=0;R(1015,a|0,b+32|0);a=v[23588];v[23588]=0;if((a|0)==1){break K}Ab(b+32|0);Ab(b);Ab(b+16|0);kb=b+48|0;break e}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;Ab(b+32|0)}Ab(b)}Ab(b+16|0);break a}if(ve(b,9859)){b=kb-16|0;kb=b;e=kb-16|0;kb=e;v[e+8>>2]=101;c=kb-112|0;kb=c;f=Tb(c+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[e+8>>2];if(d&1){v[23588]=0;R(140,c- -64|0,19988498);d=v[23588];v[23588]=0;if((d|0)==1){break $}v[23588]=0;R(124,f|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break _}Ab(c- -64|0);d=v[e+8>>2]}if(!(d&4)){break Y}v[23588]=0;d=ga(141)|0;h=v[23588];v[23588]=0;if((h|0)==1){break X}if(!d){break Z}break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;Ab(c- -64|0);break N}v[23588]=0;Y(142,c- -64|0);d=v[23588];v[23588]=0;aa:{if((d|0)!=1){v[23588]=0;R(124,f|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break aa}Ab(c- -64|0);break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;Ab(c- -64|0);break N}ba:{d=v[e+8>>2];if(!(d&32)){break ba}v[23588]=0;Y(134,c- -64|0);d=v[23588];v[23588]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((d|0)!=1){v[23588]=0;R(143,c+48|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break da}d=sh(v[c+52>>2],w[c+59|0]);Ab(c+48|0);if(!d){v[23588]=0;Y(144,c+32|0);d=v[23588];v[23588]=0;if((d|0)==1){break ua}v[23588]=0;R(143,c+16|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break ta}v[23588]=0;U(145,c+48|0,c+32|0,c+16|0);d=v[23588];v[23588]=0;if((d|0)==1){break sa}v[23588]=0;R(124,f|0,c+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break ra}Ab(c+48|0);Ab(c+16|0);bc(c+32|0)}d=Yo(c- -64|0);if(!sh(v[d+4>>2],w[d+11|0])){v[23588]=0;Y(146,c+32|0);h=v[23588];v[23588]=0;if((h|0)==1){break oa}v[23588]=0;U(147,c+48|0,c+32|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break na}v[23588]=0;R(124,f|0,c+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break ma}Ab(c+48|0);bc(c+32|0)}v[23588]=0;R(148,c+48|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break ka}d=sh(v[c+52>>2],w[c+59|0]);Ab(c+48|0);if(!d){v[23588]=0;Y(144,c+32|0);d=v[23588];v[23588]=0;if((d|0)==1){break ja}v[23588]=0;R(148,c+16|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break ia}v[23588]=0;U(145,c+48|0,c+32|0,c+16|0);d=v[23588];v[23588]=0;if((d|0)==1){break ha}v[23588]=0;R(124,f|0,c+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break ga}Ab(c+48|0);Ab(c+16|0);bc(c+32|0)}Ef(c- -64|0);d=v[e+8>>2];break ba}d=P()|0;O()|0;break N}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break pa}d=P()|0;O()|0;break qa}d=P()|0;O()|0;Ab(c+48|0)}Ab(c+16|0)}bc(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break la}d=P()|0;O()|0;Ab(c+48|0)}bc(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ea}d=P()|0;O()|0;break fa}d=P()|0;O()|0;Ab(c+48|0)}Ab(c+16|0)}bc(c+32|0);break ca}d=P()|0;O()|0}Ef(c- -64|0);break N}va:{if(!(d&64)){break va}v[23588]=0;d=ga(141)|0;h=v[23588];v[23588]=0;if((h|0)==1){break X}if(d){break va}d=c- -64|0;Mb(d);v[23588]=0;R(124,f|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break O}Ab(c- -64|0)}if(w[e+8|0]&128){v[23588]=0;Y(149,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break W}v[23588]=0;R(124,f|0,c- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break V}Ab(c- -64|0)}v[23588]=0;h=Q(1,c- -64|0,21619)|0;d=v[23588];v[23588]=0;if((d|0)==1){break U}v[23588]=0;U(150,c|0,f|0,h|0);d=v[23588];v[23588]=0;if((d|0)==1){break T}v[23588]=0;Y(151,c+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break S}v[23588]=0;U(152,b|0,c|0,c+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break R}Ab(c+48|0);Ab(c);Ab(h);Sl(f);kb=c+112|0;break M}d=P()|0;O()|0;break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;Ab(c- -64|0);break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;break P}d=P()|0;O()|0;break Q}d=P()|0;O()|0;Ab(c+48|0)}Ab(c)}Ab(h);break N}d=P()|0;O()|0;Ab(c- -64|0)}Sl(f);T(d|0);L()}kb=e+16|0;v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(b);kb=b+16|0;break e}break b}if(ve(b,10475)){b=kb-48|0;kb=b;yr(b);v[23588]=0;R(143,b+32|0,b|0);c=v[23588];v[23588]=0;wa:{xa:{if((c|0)!=1){v[23588]=0;R(1015,a|0,b+32|0);a=v[23588];v[23588]=0;if((a|0)==1){break xa}Ab(b+32|0);Ef(b);kb=b+48|0;break e}a=P()|0;O()|0;break wa}a=P()|0;O()|0;Ab(b+32|0)}Ef(b);break a}if(ve(b,11286)){b=kb-32|0;kb=b;yr(b);v[23588]=0;R(1015,a|0,Yo(b)|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ef(b);kb=b+32|0;break e}a=P()|0;O()|0;Ef(b);break a}if(ve(b,9872)){b=kb-48|0;kb=b;yr(b+16|0);c=v[b+28>>2];ya:{if(c){v[23588]=0;v[b+12>>2]=c;R(1054,a|0,b+12|0);a=v[23588];v[23588]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;Ef(b+16|0);break a}Mb(a)}Ef(b+16|0);kb=b+48|0;break e}if(ve(b,12680)){yr(g);b=w[g+16|0];v[23588]=0;Q(55,a|0,(Qd(b)?15441:15771)|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){Ef(g);break e}a=P()|0;O()|0;Ef(g);break a}if(ve(b,9888)){yr(g);b=w[g+17|0];v[23588]=0;Q(55,a|0,(Qd(b)?15441:15771)|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){Ef(g);break e}a=P()|0;O()|0;Ef(g);break a}if(ve(b,12133)){yr(g);b=w[g+18|0];v[23588]=0;Q(55,a|0,(Qd(b)?15441:15771)|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){Ef(g);break e}a=P()|0;O()|0;Ef(g);break a}if(ve(b,12435)){b=kb-16|0;kb=b;c=kb-32|0;kb=c;d=Mb(b);v[23588]=0;Y(134,c|0);f=v[23588];v[23588]=0;za:{Aa:{Ba:{if((f|0)!=1){v[23588]=0;R(135,d|0,Yo(c)|0);f=v[23588];v[23588]=0;if((f|0)==1){break Ba}Ef(c);kb=c+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;Ef(c)}Ab(d);break a}v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(b);kb=b+16|0;break e}break b}if(ve(b,8213)){b=kb-16|0;kb=b;c=kb-48|0;kb=c;d=Mb(b);v[23588]=0;R(137,c+16|0,4138);f=v[23588];v[23588]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((f|0)!=1){v[c+12>>2]=15;v[c+8>>2]=0;v[23588]=0;v[c+4>>2]=0;da(138,c+32|0,c+16|0,c+12|0,c+8|0,c+4|0);f=v[23588];v[23588]=0;if((f|0)==1){break Ga}v[23588]=0;Q(98,d|0,c+32|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break Fa}Ab(c+32|0);bc(c+16|0);kb=c+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;Ab(c+32|0)}bc(c+16|0)}Ab(d);T(a|0);L()}v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(b);kb=b+16|0;break e}break b}if(ve(b,6825)){b=kb-16|0;kb=b;jn(b,0,19565);v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(b);kb=b+16|0;break e}break b}if(ve(b,6458)){b=kb-48|0;kb=b;c=yc(b+16|0,17626);v[23588]=0;R(1056,b|0,2);d=v[23588];v[23588]=0;Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){v[23588]=0;U(2,b+32|0,c|0,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break Ka}v[23588]=0;R(1015,a|0,b+32|0);a=v[23588];v[23588]=0;if((a|0)==1){break Ja}Ab(b+32|0);Ab(b);Ab(c);kb=b+48|0;break e}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;Ab(b+32|0)}Ab(b)}Ab(c);break a}if(ve(b,11309)){b=kb-16|0;kb=b;jn(b,0,17965);v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(b);kb=b+16|0;break e}break b}if(ve(b,10482)){b=kb-16|0;kb=b;vr(b,0);v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(b);kb=b+16|0;break e}break b}if(ve(b,10457)){b=kb-16|0;kb=b;vr(b,2);v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(b);kb=b+16|0;break e}break b}if(ve(b,10442)){b=kb-16|0;kb=b;vr(b,3);v[23588]=0;R(1015,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(b);kb=b+16|0;break e}break b}Mb(a)}kb=g+32|0;break c}a=P()|0;O()|0;zb(b);break a}return}a=P()|0;O()|0;Ab(b)}T(a|0);L()}function aba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;g=kb-48|0;kb=g;b=v[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){_f(a+1074312|0,0)}i=a+1074308|0;b=g+32|0;h=a+1074312|0;Db(b,h,0);d=Cb(v[v[g+32>>2]>>2],v[g+36>>2]);e=a+480180|0;c=v[e>>2];Db(b,h,0);o=d&(c&16777248)!=0;C=Cb(v[v[g+32>>2]>>2],v[g+36>>2]);D=v[e>>2];a:{d=v[a+1074308>>2];if(d>>>0>18874367){break a}d=!o;f=a+480192|0;c=1;while(1){b:{b=c&65535;if(b>>>0<=x[f>>1]){b=v[((b<<2)+a|0)+900380>>2];if(!b){break b}v[g+32>>2]=B(w[b+20|0],100)>>>6;v[g+16>>2]=100;F=b,G=v[Kb(g+32|0,g+16|0)>>2],t[F+20|0]=G;if(!(d|y[i>>2]<18350080)){break b}j=t[b+26|0];t[b+26|0]=((j>>31|1)+j|0)/2;if(!(d|y[i>>2]<18285314)){break b}WA(Hh(b,2),v[e>>2]);j=v[a+1074308>>2];c:{if(j>>>0<18284544){break c}if(j>>>0>18285135){break b}if(!w[b+34|0]){break c}if(!vj(w[b+31|0])){break c}Ob(h,2,1);if(y[i>>2]>18285135){break b}}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))){break b}Ob(h,1,1)}d:{if(!(v[a+480180>>2]&16777248)|y[i>>2]>18285313&o){break d}c=x[a+480190>>1]+1&65535;b=1;while(1){if((b|0)==(c|0)){break d}d=B(b,104)+a|0;e=d+484419|0;if(!(w[e|0]|!(w[d+484421|0]|w[d+484420|0]))){t[e|0]=255}b=b+1|0;continue}}d=a+901404|0;f=Hz(d);while(1){if((d|0)!=(f|0)){b=d;j=go(b);while(1){if((b|0)!=(j|0)){c=w[b|0];e:{f:{if((c-97&255)>>>0<=5){k=c-32|0;break f}if(!(c-88>>>0<2|c-120>>>0<2)){k=99;if((c|0)==75|(c|0)==107){break f}break e}k=122}t[b|0]=k}b=b+1|0;continue}break}d=d+32|0;continue}break}d=v[a+1074308>>2];break a}c=c+1|0;continue}}g:{h:{i:{if((d|0)==18874368|d>>>0>18874895){break i}if(!(v[a+480180>>2]&16777252)){break h}f=x[a+480192>>1]+1&65535;c=0;b=1;while(1){if((b|0)==(f|0)){if(!c){break i}Ob(h,3,1);d=v[i>>2]}else{e=v[((b<<2)+a|0)+900380>>2];if(!(!e|!w[e+31|0])){t[e+33|0]=13;c=1}b=b+1|0;continue}break}}if((d|0)==19005440|d>>>0>19006225){break g}}if(!(v[a+480180>>2]&16777248)){break g}Db(g+32|0,h,0);if(!Cb(v[v[g+32>>2]>>2],v[g+36>>2])){Db(g+16|0,h,1);if(!Cb(v[v[g+16>>2]>>2],v[g+20>>2])){break g}}c=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(c|0)){break g}d=v[((b<<2)+a|0)+900380>>2];if(!(!d|!w[d+19|0]|!(t[d+80|0]&1))){t[d+19|0]=0}b=b+1|0;continue}}j:{k:{l:{m:{n:{if(y[i>>2]>19007232){break n}b=a+906300|0;d=fk(b);while(1){if((b|0)==(d|0)){break n}c=g+16|0;e=b+80|0;GM(c,e);v[23588]=0;X(235,g+32|0,0,8,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break m}zb(g+16|0);c=g+32|0;Lu(e,c);b=b+160|0;zb(c);continue}}o:{p:{q:{if(v[a+480180>>2]!=4){break q}c=v[i>>2];if(c>>>0<19007257){break o}if(c>>>0>19071235){break p}if(w[a+1074368|0]!=4){break q}wy(a,5)}c=v[i>>2]}if(c>>>0>19202054){break l}d=19202048;if((c|0)==19202048){break k}}f=x[a+480192>>1]+1&65535;d=1;while(1){if((d|0)==(f|0)){break l}e=v[((d<<2)+a|0)+900380>>2];r:{if(!e|!w[e+20|0]|!w[e+31|0]){break r}b=e+236|0;j=zq(b);while(1){if((b|0)!=(j|0)){l=x[b>>1];b=b+2|0;if(!l){continue}break r}break}t[e+20|0]=0}d=d+1|0;continue}}a=P()|0;O()|0;zb(g+16|0);T(a|0);L()}d=c;if(c>>>0>19267583){break j}}e=!o;f=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(f|0)){break j}c=v[((b<<2)+a|0)+900380>>2];s:{if(!c){break s}d=t[c+26|0];t[c+26|0]=((d>>31|1)+d|0)/2;d=v[i>>2];if(!(e|d>>>0<18350080)){break s}t[c+19|0]=w[c+19|0]+3>>>2}b=b+1|0;continue}}t:{if(d>>>0>19398673){break t}c=x[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break t}e=v[((e<<2)+a|0)+900380>>2];if(!e|w[e+65|0]==255){b=b+1|0;continue}else{Ob(h,94,1);d=v[i>>2]}break}}u:{if(d>>>0>19399427){break u}c=x[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break u}e=v[((e<<2)+a|0)+900380>>2];if(!e|w[e+36|0]>1){b=b+1|0;continue}else{Ob(h,101,1);d=v[i>>2]}break}}v:{if(d>>>0>19923027){break v}c=x[a+480190>>1];b=1;while(1){d=b&65535;if(d>>>0>c>>>0){break v}d=B(d,104)+a|0;if(!_d(v[d+484380>>2],v[d+484400>>2])|!(w[d+484414|0]&20)){b=b+1|0;continue}else{Ob(h,116,1)}break}}b=kb-16|0;kb=b;u[g+12>>1]=0;v[g+8>>2]=a;Db(b+8|0,a+1074312|0,0);F=g,G=Cb(v[v[b+8>>2]>>2],v[b+12>>2]),t[F+14|0]=G;kb=b+16|0;q=v[g+8>>2];r=v[g+12>>2];b=a+484344|0;k=b;z=Bf(v[b>>2],v[b+4>>2])-1&65535;d=kb-32|0;kb=d;w:{if(Bf(v[b>>2],v[b+4>>2])>>>0<=z>>>0){break w}while(1){b=A&65535;if(b>>>0>z>>>0){break w}c=bg(v[k>>2],b);e=v[c>>2];if(Pb(e,v[c+4>>2])){c=Fb(e);E=Fb(v[bg(v[k>>2],b)+4>>2]);v[d+24>>2]=q;v[d+28>>2]=r;v[d+8>>2]=q;v[d+12>>2]=r;j=d+8|0;p=kb-16|0;kb=p;v[p+8>>2]=c;while(1){if(Pb(c,E)){l=kb-16|0;kb=l;s=x[j+4>>1];b=s+1|0;u[j+4>>1]=b;f=v[j>>2];u[j+4>>1]=x[f+480188>>1]>(b&65535)>>>0?b:0;x:{if(gh(w[c|0])){break x}e=v[f+1074308>>2];y:{n=v[f+480180>>2];z:{A:{if((n|0)==2){if(e>>>0>18415615){break A}if(w[c+3|0]!=23){break z}wf(c+5|0,64);break z}if(n&16777248){B:{C:{if(e>>>0>=18285314){if(w[j+6|0]){break C}f=0;b=0;if(e>>>0>18874367){break B}}D:{switch(w[c+3|0]-20|0){case 3:wf(c+5|0,128);break C;case 0:break D;default:break C}}b=w[c+5|0];if((b|0)!=208){if((b|0)!=192){break C}t[c|0]=254;t[c+3|0]=0;break C}t[c+3|0]=0}E:{F:{G:{if(e>>>0>=18350080){if(w[j+6|0]){break G}f=0;b=0;if(e>>>0>18874367){break B}}b=w[c+3|0];if(b>>>0>29){break F}f=1;if(!(1<<b&536873152)){break F}break E}f=0;b=0;if(e>>>0>18874367){break B}b=w[c+3|0]}f=0}b=(b|0)==24|(b|0)==22}H:{if(!(b?1:f)){break H}f=w[c+5|0];b=f&15;if(!b|(b|0)==15){break H}f=f&240;if(!f|(f|0)==240){break H}t[c+5|0]=w[c+3|0]==24?f:b}I:{if((e|0)==19005440|e>>>0>19005699){break I}b=x[v[j>>2]+480192>>1];if(w[j+6|0]|(!b|b>>>0>=w[c+1|0])){break I}t[c+4|0]=0;t[c+2|0]=1}if(w[c+3|0]!=18|w[c+5|0]!=17){break A}if(e>>>0>19468801){break y}Db(l+8|0,v[j>>2]+1074312|0,22);if(!Cb(v[v[l+8>>2]>>2],v[l+12>>2])|v[v[j>>2]+480208>>2]&4){break A}t[c+5|0]=0;break A}if((n|0)!=4){break A}b=!w[j+6|0];J:{if((b|e>>>0<18285314)&e>>>0<18874368){break J}if(e>>>0>19137025){break y}if(w[c+3|0]!=23|w[c+5|0]<65){break J}t[c+3|0]=0}K:{L:{M:{if(!(b&e>>>0<18874368?0:e>>>0>=18415616)){f=w[c+3|0];b=w[c+2|0];if((f|0)!=10|(b|0)!=11){break M}f=0;t[c+3|0]=0;break K}if(e>>>0>18874639){break L}f=w[c+3|0];b=w[c+2|0]}if((b|0)!=11|(f|0)!=4){break K}b=w[c+4|0];if(!(b|w[j+6|0])){f=4;break K}f=4;m=w[c+5|0];if(!m){break K}t[c+2|0]=0;F=c,G=Bu(m+(b<<4)|0),t[F+5|0]=G;break K}if(e>>>0>19007240){break y}f=w[c+3|0]}if(w[c+5|0]|(f|0)!=16){break A}t[c+3|0]=0}if(e>>>0>18874367){break y}}f=w[c+3|0];m=w[c+5|0]&240;N:{O:{if((f|0)!=28|(m|0)!=96){b=0}else{if(!w[j+6|0]|(n|0)!=4){break O}b=e>>>0<18350080}if(!(b|(f|0)==20&(m|0)==96)){break N}}b=B(s,-6)+c|0;while(1){if(b>>>0<c>>>0){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;continue}break}f=w[c+3|0]}if((f|0)!=20|(m|0)!=224){break y}b=B(s,-6)+c|0;while(1){if(b>>>0>=c>>>0){break y}if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;continue}}b=w[c+2|0];if(!((b|0)!=8|e>>>0>19333174|(e|0)==19333120)){e=w[c+4|0];b=w[c+3|0];if(!(!e|(b|0)!=7)){t[c+3|0]=11;break x}P:{Q:{switch(b-5|0){default:if((b|0)!=26){break x}break;case 1:break x;case 2:break P;case 0:break Q}}f=w[c+5|0];if(!(f&15)){t[c+2|0]=0;t[c+3|0]=5;t[c+5|0]=f|e&15;break x}R:{switch(b-5|0){case 1:break x;case 0:case 2:break P;default:break R}}if((b|0)!=26){break x}}t[c+2|0]=0;break x}if(!(w[c+3|0]|((n|0)==16777216|(b|0)!=15))){t[c+2|0]=0;t[c+3|0]=10;t[c+5|0]=w[c+4|0]<<3;break x}if(w[c+3|0]!=10|e>>>0>19922963|(b|0)!=15){break x}if(w[c+4|0]?w[c+5|0]:1){t[c+2|0]=0;break x}t[c+3|0]=0}kb=l+16|0;c=v[Ck(p+8|0)>>2];continue}break}b=v[j+4>>2];v[d+16>>2]=v[j>>2];v[d+20>>2]=b;kb=p+16|0}A=A+1|0;continue}}v[g+32>>2]=q;v[g+36>>2]=r;kb=d+32|0;S:{b=y[a+1074308>>2]<19267584;if(b&o){b=41872;while(1){if((b|0)==42216){break S}d=v[i>>2];c=v[b+4>>2];Ob(h,v[b>>2],d>>>0>=c>>>0|(d|0)==(c&-65536));b=b+8|0;continue}}if(!(b&((D|0)==4&C))){break S}b=42224;while(1){if((b|0)==42464){break S}Ob(h,v[b>>2],y[i>>2]>=y[b+4>>2]);b=b+8|0;continue}}T:{U:{d=v[a+480180>>2];if(d&16777248){b=42464;while(1){if((b|0)==42520){break U}d=v[i>>2];c=v[b+4>>2];e=c&-65536;if(!(d>>>0>=e>>>0&(c>>>0<=d>>>0|d>>>0<=e>>>0))){_f(h,v[b>>2])}b=b+8|0;continue}}b=42592;c=42528;V:{switch(d-2|0){case 2:while(1){if((c|0)==42592){break U}if(y[i>>2]<y[c+4>>2]){_f(h,v[c>>2])}c=c+8|0;continue};case 0:break V;default:break T}}while(1){if((b|0)==42680){break U}if(y[i>>2]<y[b+4>>2]){_f(h,v[b>>2])}b=b+8|0;continue}}d=v[a+480180>>2]}W:{if((d|0)==4){b=v[i>>2];if(b>>>0>18415615){break W}Ob(h,98,1)}b=v[i>>2]}c=8;if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){d=b+77|0;Db(g+32|0,h,d);_f(Ob(h,b+86|0,Cb(v[v[g+32>>2]>>2],v[g+36>>2])),d);b=b+1|0;continue}break}b=v[i>>2]}X:{if(b>>>0>=18284544){if(b>>>0>18874627){break X}c=6;if((b|0)==18874368){break X}}Ob(h,c,1)}b=v[a+1074308>>2];Y:{if(w[a+480208|0]&16){if(b>>>0<=19136511){_f(h,7);break Y}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break Y}Ob(h,7,1);break Y}if((b|0)==19922944|b>>>0>19922997){break Y}_f(h,7)}Db(g+32|0,h,31);Z:{if(!Cb(v[v[g+32>>2]>>2],v[g+36>>2])){break Z}b=v[i>>2];if(b>>>0<19071234|b>>>0>19398722){break Z}c=x[a+480192>>1];b=1;while(1){d=b&65535;if(d>>>0>c>>>0){break Z}_:{d=v[((d<<2)+a|0)+900380>>2];if(!d){break _}e=w[d+65|0];if(!(w[d+60|0]&4)|(e|0)==255|e>>>0<=w[d- -64|0]){break _}Ob(h,97,1);break Z}b=b+1|0;continue}}d=v[a+480180>>2];$:{if(!(d&16777218)){break $}c=x[a+480190>>1];b=1;while(1){e=b&65535;if(e>>>0>c>>>0){break $}b=b+1|0;if(!(w[(B(e,104)+a|0)+484415|0]&2)){continue}break}aa:{ba:{ca:{if(!(!x[a+480192>>1]|(d|0)!=16777216)){b=v[i>>2];if(b>>>0<19398688){break ba}if(b>>>0>19464277){break ca}Ob(h,109,1)}b=v[i>>2]}if((b|0)==19922944|b>>>0>19922996){break aa}}_f(h,111);b=v[i>>2]}d=v[a+480180>>2];if(!((d|0)!=2|b>>>0>19464191)){Ob(h,108,1);break $}if((d|0)==2){break $}_f(h,108)}b=v[i>>2];da:{ea:{if(b>>>0<19333186){break ea}if(b>>>0<=19923013){if(!(v[a+480180>>2]&16777252)){break ea}b=a+906300|0;d=fk(b);while(1){if((b|0)!=(d|0)){fa:{if((w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24))!=1146637647|(w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24))!=-271958638){break fa}if((fd(v[b+4>>2],v[b+8>>2])|0)!=32){break fa}c=Nc(g+32|0,16817);Lu(b+80|0,c);zb(c)}b=b+160|0;continue}break}b=v[i>>2]}if(b>>>0>19988488){break da}}if(!(v[a+480180>>2]&16777252)){break da}b=a+906300|0;d=fk(b);while(1){if((b|0)==(d|0)){break da}a=b;b=b+160|0;if(!yi(v[a+16>>2],v[a+20>>2])){continue}break}Ob(h,117,1)}kb=g+48|0}function k5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=kb-32|0;kb=h;d=Nc(h+16|0,11520);e=eh(c,d);zb(d);a:{b:{c:{d:{e:{if(e){fl(a,v[b+24>>2]+1298356|0);break e}d=Nc(h+16|0,10926);e=eh(c,d);zb(d);if(e){fl(a,v[b+24>>2]+1298344|0);break e}d=Nc(h+16|0,11350);e=eh(c,d);zb(d);if(e){fl(a,v[b+24>>2]+1298392|0);break e}d=Nc(h+16|0,10918);e=eh(c,d);zb(d);if(e){fl(a,v[b+24>>2]+1298380|0);break e}d=Nc(h+16|0,8203);e=eh(c,d);zb(d);if(e){c=h+16|0;d=v[v[b+24>>2]+480184>>2];b=32624;f:{g:{while(1){if((b|0)==32672){break g}if((d|0)!=v[b>>2]){b=b+12|0;continue}break}jn(c,0,v[b+8>>2]);break f}Mb(c)}v[23588]=0;R(1015,a|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}Ab(h+16|0);break e}d=Nc(h+16|0,10903);e=eh(c,d);zb(d);if(e){j=v[v[b+24>>2]+480184>>2];c=kb+-64|0;kb=c;b=32624;f=Yf(c+48|0);i=h+16|0;d=Mb(i);while(1){if((b|0)!=32672){if((j|0)==v[b>>2]){e=v[b+4>>2];v[23588]=0;e=Q(1,c+32|0,e|0)|0;g=v[23588];v[23588]=0;h:{i:{j:{k:{l:{m:{if((g|0)!=1){v[23588]=0;U(845,c+24|0,f|0,e|0);g=v[23588];v[23588]=0;if((g|0)==1){break k}if(!w[c+28|0]){break h}if(!sh(v[d+4>>2],w[d+11|0])){v[23588]=0;g=Q(1,c+8|0,17737)|0;m=v[23588];v[23588]=0;if((m|0)==1){break m}v[23588]=0;Q(98,d|0,g|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break l}Ab(g)}v[23588]=0;Q(98,d|0,e|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;Ab(g);break j}b=P()|0;O()|0}Ab(e)}Ab(d);lM(f);T(b|0);L()}Ab(e)}b=b+12|0;continue}break}lM(f);kb=c- -64|0;v[23588]=0;R(1015,a|0,i|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(h+16|0);break e}c=P()|0;O()|0;Ab(h+16|0);break a}d=Nc(h+16|0,8269);e=eh(c,d);zb(d);if(e){fl(a,v[b+24>>2]+1298368|0);break e}d=Nc(h+16|0,5623);e=eh(c,d);zb(d);if(e){fl(a,v[b+24>>2]+1298320|0);break e}d=Nc(h+16|0,11924);e=eh(c,d);zb(d);if(e){c=h+16|0;yh(c,v[b+24>>2]+1298308|0);b=v[b+24>>2];v[23588]=0;U(1009,a|0,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(h+16|0);break e}c=P()|0;O()|0;zb(h+16|0);break a}d=Nc(h+16|0,11293);e=eh(c,d);zb(d);if(e){c=v[b+24>>2]+1298408|0;b=v[c+4>>2];n:{if(!pc(v[c>>2],b)){d=kb-32|0;kb=d;v[d+8>>2]=0;v[d+12>>2]=0;v[d+16>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;c=1;b=b-40|0;o:{if(v[b>>2]!=v[d>>2]|v[b+4>>2]!=v[d+4>>2]|(v[b+8>>2]!=v[d+8>>2]|v[b+12>>2]!=v[d+12>>2])){break o}if(v[b+16>>2]!=v[d+16>>2]){break o}c=v[b+24>>2]!=v[d+24>>2]|v[b+28>>2]!=v[d+28>>2]}kb=d+32|0;if(c){break n}}Mb(a);break e}m=h+16|0;g=kb-256|0;kb=g;c=v[b+12>>2];v[g+136>>2]=v[b+8>>2];v[g+140>>2]=c;c=v[b+20>>2];v[g+144>>2]=v[b+16>>2];v[g+148>>2]=c;c=v[b+28>>2];v[g+152>>2]=v[b+24>>2];v[g+156>>2]=c;c=v[b+4>>2];v[g+128>>2]=v[b>>2];v[g+132>>2]=c;cN(g+208|0,g+128|0);e=v[b+32>>2];if(e){c=v[b+12>>2];v[g+104>>2]=v[b+8>>2];v[g+108>>2]=c;c=v[b+20>>2];v[g+112>>2]=v[b+16>>2];v[g+116>>2]=c;c=v[b+28>>2];v[g+120>>2]=v[b+24>>2];v[g+124>>2]=c;c=v[b+4>>2];v[g+96>>2]=v[b>>2];v[g+100>>2]=c;b=g+160|0;cN(b,g+96|0);uc(g+52|0,b,44);b=Mw(v[g+72>>2]+1900|0,v[g+68>>2]+1|0,v[g+64>>2])-Mw(1970,1,1)|0;b=Oka(b,b>>31,86400,0);c=B(v[g+60>>2],3600);b=b+c|0;d=nb+(c>>31)|0;d=b>>>0<c>>>0?d+1|0:d;c=B(v[g+56>>2],60);f=c;b=c+b|0;c=(c>>31)+d|0;c=b>>>0<f>>>0?c+1|0:c;d=v[g+52>>2];f=d;b=d+b|0;d=(d>>31)+c|0;d=ZG(iH(b,b>>>0<f>>>0?d+1|0:d),nb);f=nb;c=2147483647;l=xe(+(e>>>0)/18.2);b=-1;p:{if(l>=0x8000000000000000){break p}c=-2147483648;b=0;if(l<=-0x8000000000000000){break p}if(D(l)<0x8000000000000000){c=D(l)>=1?~~(l>0?F(H(l*2.3283064365386963e-10),4294967295):I((l-+(~~l>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~l>>>0;break p}b=0}e=b+d|0;d=c+f|0;b=iH(e,b>>>0>e>>>0?d+1|0:d);j=kb-16|0;kb=j;i=ZG(b,nb);b=nb;n=b;v[j+12>>2]=0;v[j+8>>2]=0;v[j+4>>2]=0;b=Mw(1970,1,1)+Pka(i,b,86400,0)|0;f=b>>31;d=Oka(b,f,1e4,0)+14780|0;c=nb;e=d;c=d>>>0<14780?c+1|0:c;k=Pka(d,c,-14609700,-1)+b|0;d=f+nb|0;d=b>>>0>k>>>0?d+1|0:d;o=Pka(e,c,365242500,0);k=o+k|0;d=nb+d|0;d=k>>>0<o>>>0?d+1|0:d;o=Pka(e,c,-146097e4,-1);k=o+k|0;d=nb+d|0;d=k>>>0<o>>>0?d+1|0:d;c=Pka(e,c,3652425,0);e=nb;o=e;p=k;k=Oka(c,e,-365,-1);e=p+k|0;d=nb+d|0;d=e>>>0<k>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){d=o-!c|0;c=c-1|0;e=Oka(c,d,-365,-1)+b|0;d=f+nb|0;d=b>>>0>e>>>0?d+1|0:d;b=e;e=(c|0)/-4|0;b=b+e|0;d=(e>>31)+d|0;d=b>>>0<e>>>0?d+1|0:d;e=b;b=(c|0)/100|0;f=b;e=e+b|0;b=(b>>31)+d|0;b=e>>>0<f>>>0?b+1|0:b;d=(c|0)/-400|0;f=d;e=d+e|0;d=(d>>31)+b|0;d=e>>>0<f>>>0?d+1|0:d}f=c;b=Oka(e,d,100,0)+52|0;c=nb;b=Pka(b,b>>>0<52?c+1|0:c,3060,0);c=b+2|0;d=(c|0)/12|0;v[j+12>>2]=f+d;v[j+8>>2]=(c+B(d,-12)|0)+1;b=Oka(b,nb,306,0)+5|0;d=nb;b=Pka(b,b>>>0<5?d+1|0:d,-10,-1)+e|0;v[j+4>>2]=b+1;v[g+248>>2]=0;v[g+240>>2]=0;v[g+244>>2]=0;v[g+232>>2]=0;v[g+236>>2]=0;v[g+228>>2]=v[j+12>>2]-1900;v[g+224>>2]=v[j+8>>2]-1;b=v[j+4>>2];q=g,r=Qka(Pka(i,n,3600,0),nb,24),v[q+216>>2]=r;v[g+220>>2]=b;b=Pka(i,n,60,0);c=nb;q=g,r=Qka(b,c,60),v[q+212>>2]=r;b=Oka(b,c,-60,0)+i|0;v[g+208>>2]=b;kb=j+16|0}c=g+8|0;uc(c,g+208|0,44);b=kb-176|0;kb=b;e=Mb(b+160|0);v[23588]=0;d=Q(1,b+144|0,13386)|0;f=v[23588];v[23588]=0;q:{r:{s:{t:{u:{if((f|0)!=1){f=v[c+20>>2];if(!f){break r}v[23588]=0;v[b+112>>2]=f+1900;R(97,b+128|0,b+112|0);f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;j=Q(98,e|0,b+128|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break u}Ab(b+128|0);i=v[c+16>>2];if(i>>>0>11){break r}v[23588]=0;f=Q(1,b+112|0,16764)|0;n=v[23588];v[23588]=0;v:{w:{x:{y:{z:{A:{if((n|0)!=1){v[23588]=0;v[b+80>>2]=i+1;R(99,b+96|0,b+80|0);i=v[23588];v[23588]=0;if((i|0)==1){break A}v[23588]=0;U(2,b+128|0,f|0,b+96|0);i=v[23588];v[23588]=0;if((i|0)==1){break z}v[23588]=0;j=Q(98,j|0,b+128|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break y}Ab(b+128|0);Ab(b+96|0);Ab(f);if(v[c+12>>2]-32>>>0>=4294967265){break v}break r}a=P()|0;O()|0;break t}a=P()|0;O()|0;break w}a=P()|0;O()|0;break x}a=P()|0;O()|0;Ab(b+128|0)}Ab(b+96|0)}Ab(f);break t}v[23588]=0;f=Q(1,b+96|0,16764)|0;i=v[23588];v[23588]=0;B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if((i|0)!=1){v[23588]=0;R(99,b+80|0,c+12|0);i=v[23588];v[23588]=0;if((i|0)==1){break _}v[23588]=0;U(2,b+128|0,f|0,b+80|0);i=v[23588];v[23588]=0;if((i|0)==1){break Z}v[23588]=0;j=Q(98,j|0,b+128|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break Y}Ab(b+128|0);Ab(b+80|0);Ab(f);n=v[c>>2];f=v[c+8>>2];i=v[c+4>>2];if(!(n|(f|i))|f>>>0>23|i>>>0>59){break r}v[23588]=0;f=Q(1,b+128|0,13591)|0;i=v[23588];v[23588]=0;if((i|0)==1){break V}v[23588]=0;j=Q(98,j|0,f|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break U}Ab(f);if(v[c+32>>2]>0){v[23588]=0;f=Q(1,b+80|0,15554)|0;i=v[23588];v[23588]=0;if((i|0)==1){break T}Jb(d,f);Ab(f)}v[23588]=0;R(99,b+32|0,c+8|0);f=v[23588];v[23588]=0;if((f|0)==1){break S}v[23588]=0;f=Q(1,b+16|0,14600)|0;i=v[23588];v[23588]=0;if((i|0)==1){break R}v[23588]=0;U(2,b+48|0,b+32|0,f|0);i=v[23588];v[23588]=0;if((i|0)==1){break Q}v[23588]=0;R(99,b|0,c+4|0);i=v[23588];v[23588]=0;if((i|0)==1){break P}v[23588]=0;U(2,b- -64|0,b+48|0,b|0);i=v[23588];v[23588]=0;if((i|0)==1){break O}v[23588]=0;j=Q(98,j|0,b- -64|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break N}Ab(b- -64|0);Ab(b);Ab(b+48|0);Ab(f);Ab(b+32|0);if(n>>>0<62){break I}v[23588]=0;U(100,m|0,j|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break H}break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;break W}a=P()|0;O()|0;break X}a=P()|0;O()|0;Ab(b+128|0)}Ab(b+80|0)}Ab(f);break t}a=P()|0;O()|0;break t}a=P()|0;O()|0;Ab(f);break t}a=P()|0;O()|0;break t}a=P()|0;O()|0;break t}a=P()|0;O()|0;break J}a=P()|0;O()|0;break K}a=P()|0;O()|0;break L}a=P()|0;O()|0;break M}a=P()|0;O()|0;Ab(b- -64|0)}Ab(b)}Ab(b+48|0)}Ab(f)}Ab(b+32|0);break t}v[23588]=0;f=Q(1,b+48|0,14600)|0;i=v[23588];v[23588]=0;if((i|0)==1){break G}v[23588]=0;R(99,b+32|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break F}v[23588]=0;U(2,b- -64|0,f|0,b+32|0);c=v[23588];v[23588]=0;if((c|0)==1){break E}v[23588]=0;c=Q(98,j|0,b- -64|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break D}Ab(b- -64|0);Ab(b+32|0);Ab(f);v[23588]=0;Q(98,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break r}}a=P()|0;O()|0;break t}a=P()|0;O()|0;break t}a=P()|0;O()|0;break B}a=P()|0;O()|0;break C}a=P()|0;O()|0;Ab(b- -64|0)}Ab(b+32|0)}Ab(f);break t}a=P()|0;O()|0;break t}a=P()|0;O()|0;break s}a=P()|0;O()|0;Ab(b+128|0)}Ab(d)}Ab(e);T(a|0);L()}ad(m,e)}Ab(d);Ab(e);kb=b+176|0;kb=g+256|0;v[23588]=0;R(1015,a|0,m|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(h+16|0);break e}c=P()|0;O()|0;Ab(h+16|0);break a}d=Nc(h+16|0,12125);e=eh(c,d);zb(d);if(e){c=h+16|0;JP(c,v[b+24>>2]+1298332|0);$:{if(!Re(c)){break $}d=v[v[b+24>>2]+480180>>2];aa:{ba:{if((d|0)==33554432){break ba}c=1;if((d|0)==32){break aa}if((d|0)==16384){break ba}if((d|0)==16777216){break aa}}c=2}ca:{switch(c-1|0){case 0:v[23588]=0;R(1016,h|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){Bc(h+16|0,h);zb(h);break $}break b;case 1:break ca;default:break $}}if(Re(h+16|0)){v[23588]=0;R(1017,h|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}Bc(h+16|0,h);zb(h)}if(!Re(h+16|0)){break $}v[23588]=0;R(1016,h|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}Bc(h+16|0,h);zb(h)}b=v[b+24>>2];v[23588]=0;U(1009,a|0,b|0,h+16|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(h+16|0);break e}break b}d=Nc(h+16|0,5475);e=eh(c,d);zb(d);if(e){c=h+16|0;JP(c,v[b+24>>2]+1298332|0);b=v[b+24>>2];v[23588]=0;U(1009,a|0,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(h+16|0);break e}c=P()|0;O()|0;zb(h+16|0);break a}f=c;c=Nc(h+16|0,7295);d=eh(f,c);zb(c);if(d){a=Mb(a);q=h,r=Fb(v[b+68>>2]),v[q+16>>2]=r;b=Fb(v[b+72>>2]);c=1;while(1){d=v[h+16>>2];if(!Pb(d,b)){break e}if(!(c&1)){v[23588]=0;Q(941,a|0,21589)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}}v[23588]=0;Q(800,a|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}mq(h+16|0);c=0;continue}}Nc(a,21619)}kb=h+32|0;return}c=P()|0;O()|0;Ab(h+16|0);break a}c=P()|0;O()|0;zb(a);break a}c=P()|0;O()|0;zb(h+16|0)}T(c|0);L()}function AW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:{n=Gh(b,13779);if(!n){break a}o=a+480192|0;b:while(1){if(!Qb(v[b>>2],v[b+8>>2],6)){break a}c:{f=Cg(b);d:{if((f|0)==(Um(13598)|0)){break d}c=w[21595]|w[21596]<<8|(w[21597]<<16|w[21598]<<24);if(!(f&1616928864)|f&-2139062144){break d}if((c|0)!=(f|0)){break c}}zg(b,4);break a}l=1;c=Sg(b);while(1){d=l&65535;if(d>>>0>x[o>>1]){continue b}d=v[((d<<2)+a|0)+900380>>2];if(d){e:{g=0;if((Um(16720)|0)==(f|0)){_b(b,c);break e}e=kb-48|0;kb=e;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{switch(f-1349079874|0){default:if((f|0)==1095062094){break v}if((f|0)==1095126087){break s}if((f|0)==1129524782){break B}if((f|0)==1145263150){break Y}if((f|0)==1145979182){break X}if((f|0)==1179463214){break z}if((f|0)==1851469358){break F}if((f|0)==1179931728){break n}$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((f|0)!=1196830254){if((f|0)==1229341486){break U}if((f|0)==1229345326){break T}if((f|0)==1264266798){break G}if((f|0)==1296182830){break S}if((f|0)==1296248366){break Q}if((f|0)==1297100334){break R}if((f|0)==1297110852){break q}if((f|0)==1298747438){break D}if((f|0)==1313692462){break H}if((f|0)==1313751342){break Z}if((f|0)==1345203758){break ja}if((f|0)==1346711086){break l}if((f|0)==1346720334){break w}if((f|0)==1346722606){break J}if((f|0)==1346784327){break t}if((f|0)==1347175726){break da}if((f|0)==1347179310){break ea}if((f|0)==1347437358){break O}if((f|0)==1347441454){break P}if((f|0)==1347443502){break M}if((f|0)==1347628590){break W}if((f|0)==1347633710){break ca}if((f|0)==1347634478){break ba}if((f|0)==1347703884){break o}if((f|0)==1347831112){break y}if((f|0)==1347833672){break x}if((f|0)==1349076270){break k}if((f|0)==1349076315){break I}if((f|0)==1349078085){break $}if((f|0)==1349078099){break aa}if((f|0)==1349079131){break L}if((f|0)==1378758190){break p}if((f|0)==1381183022){break A}if((f|0)==1447374382){break m}if((f|0)==1447383630){break u}if((f|0)==1447385902){break K}if((f|0)==1447447623){break r}if((f|0)==1447839022){break ha}if((f|0)==1447842606){break ia}if((f|0)==1448106798){break N}if((f|0)==1448226350){break C}if((f|0)==1448291886){break V}if((f|0)==1448297006){break ga}if((f|0)==1448297774){break fa}if((f|0)!=1682320942){if((f|0)==1718508334){break E}if((f|0)!=1179594286|c>>>0>4){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=mv(b,c),v[p>>2]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+15|0]=q;break g}if(c>>>0>4){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=mv(b,c),v[p+4>>2]=q;break g}if(c>>>0>4){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=mv(b,c),v[p+8>>2]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+61|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+62|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+63|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d- -64|0,q=Cd(b,c),t[p|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+81|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+82|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+83|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+84|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+101|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+102|0]=q;break g;case 0:if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+103|0]=q;break g;case 3:break _;case 1:case 2:break f}}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+104|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+16|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+17|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+18|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+19|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+20|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+21|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+22|0]=q;break g}if(c>>>0>2){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=UC(b,c),u[p+28>>1]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+30|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+31|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=TC(b,c),t[p+26|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+27|0]=q;break g}ae(e,b,c);i=kc(e+24|0,e);Bb(e);j=Hh(d,0);h=v[j>>2];while(1){if($d(h,v[j+4>>2])>>>0<=g>>>0){Bb(i);break g}v[23588]=0;k=S(197,i|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break j}h=v[j>>2];p=Eb(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}}ae(e,b,c);i=kc(e+24|0,e);Bb(e);j=Hh(d,1);h=v[j>>2];while(1){if($d(h,v[j+4>>2])>>>0<=g>>>0){Bb(i);break g}v[23588]=0;k=S(197,i|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){h=v[j>>2];p=Eb(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}ae(e,b,c);i=kc(e+24|0,e);Bb(e);j=Hh(d,2);h=v[j>>2];while(1){if($d(h,v[j+4>>2])>>>0<=g>>>0){Bb(i);break g}v[23588]=0;k=S(197,i|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){h=v[j>>2];p=Eb(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}ae(e,b,c);i=kc(e+24|0,e);Bb(e);j=Hh(d,0);h=v[j>>2];while(1){if($d(h,v[j+4>>2])>>>0<=g>>>0){Bb(i);break g}v[23588]=0;k=S(198,i|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){h=v[j>>2];p=Eb(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}ae(e,b,c);i=kc(e+24|0,e);Bb(e);j=Hh(d,1);h=v[j>>2];while(1){if($d(h,v[j+4>>2])>>>0<=g>>>0){Bb(i);break g}v[23588]=0;k=S(198,i|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){h=v[j>>2];p=Eb(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}ae(e,b,c);i=kc(e+24|0,e);Bb(e);j=Hh(d,2);h=v[j>>2];while(1){if($d(h,v[j+4>>2])>>>0<=g>>>0){Bb(i);break g}v[23588]=0;k=S(198,i|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){h=v[j>>2];p=Eb(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>128){break f}h=d+108|0;ae(e,b,c);i=kc(e+24|0,e);Bb(e);while(1){if((g|0)==128){Bb(i);break g}v[23588]=0;j=S(198,i|0)|0;k=v[23588];v[23588]=0;if((k|0)!=1){p=Lb(h,g),q=j,t[p|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>256){break f}h=d+236|0;ae(e,b,c);i=kc(e+24|0,e);Bb(e);while(1){if((g|0)==128){Bb(i);break g}v[23588]=0;j=S(197,i|0)|0;k=v[23588];v[23588]=0;if((k|0)!=1){p=dc(h,g),q=j,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>32){break f}j=d+492|0;ae(e,b,c);i=kc(e+24|0,e);Bb(e);h=Mb(e);while(1){if((c|0)==(g|0)){break h}v[23588]=0;k=S(199,i|0)|0;m=v[23588];v[23588]=0;ka:{if((m|0)==1){break ka}v[23588]=0;Q(200,h|0,k|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break ka}g=g+1|0;continue}break}g=P()|0;O()|0;zb(h);break i}if(c>>>0>32){break f}j=d+524|0;ae(e,b,c);i=kc(e+24|0,e);Bb(e);h=Mb(e);la:{while(1){if((c|0)!=(g|0)){v[23588]=0;k=S(199,i|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break la}v[23588]=0;Q(200,h|0,k|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break la}g=g+1|0;continue}break}Dc(j,h);zb(h);Bb(i);break g}g=P()|0;O()|0;zb(h);break i}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+34|0]=q;break g}if(c>>>0>2){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=UC(b,c),u[p+12>>1]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+23|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+24|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+25|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+35|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+36|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+105|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+85|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+65|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+100|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+80|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Cd(b,c),t[p+60|0]=q;break g}if(c>>>0>1){break f}if(!Qb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=TC(b,c),t[p+33|0]=q;break g}g=1;i=Jo(b,c);if(!Io(i)){break f}t[d+14|0]=i;break f}p=d,q=B(kv(b,c),1e4)+(y[d+40>>2]%1e4|0)|0,v[p+40>>2]=q;break g}h=(kv(b,c)>>>0)%1e4|0;g=v[d+40>>2];v[d+40>>2]=h+g-(g>>>0)%1e4;break g}v[e+24>>2]=240;p=e,q=Jo(b,c),v[p>>2]=q;Rg(d+48|0,v[Kb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=Jo(b,c),v[p>>2]=q;Rg(d+68|0,v[Kb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=Jo(b,c),v[p>>2]=q;Rg(d+88|0,v[Kb(e+24|0,e)>>2]);break g}g=P()|0;O()|0}Bb(i);T(g|0);L()}Dc(j,h);zb(h);Bb(i)}g=1}kb=e+48|0;if(!g){_b(b,c);break e}if((Um(16725)|0)==(f|0)){e=w[d+15|0];t[d+15|0]=0;t[d+100|0]=w[d+100|0]&224|(e>>>5&4|e>>>6&1);t[d+60|0]=e>>>1&2|(e<<1&4|(w[d+60|0]&240|e&1));t[d+80|0]=w[d+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}}}l=l+1|0;continue}}}return n|0}function WV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=kb-304|0;kb=e;zc(b);if(Tq(b,17792)){o=Mb(e+288|0);v[23588]=0;f=Q(230,b|0,o|0)|0;g=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){if(!f){break a}v[23588]=0;f=Q(245,b|0,e+280|0)|0;g=v[23588];v[23588]=0;g:{if((g|0)==1){break g}if(!f){break a}if(!aC(w[e+280|0],w[e+281|0])){break a}f=Ec($B(e+280|0),nb);g=v[b+8>>2];m=v[b>>2];v[23588]=0;f=W(156,m|0,g|0,f|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break g}if(!f){break a}if(!c){break b}v[23588]=0;R(246,a|0,4096);d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;R(247,a+1298308|0,o|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}d=w[e+282|0];u[a+480188>>1]=32;u[a+480192>>1]=d;oh(a,1);v[23588]=0;d=Q(1,e+264|0,9436)|0;f=v[23588];v[23588]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){Jb(a+1298344|0,d);Ab(d);v[23588]=0;d=Q(1,e+248|0,7053)|0;f=v[23588];v[23588]=0;if((f|0)==1){break p}Jb(a+1298356|0,d);Ab(d);v[23588]=0;Y(248,e+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break o}t[e+216|0]=w[e+281|0];v[23588]=0;t[e+8|0]=w[e+280|0];R(249,e+232|0,e+8|0);d=v[23588];v[23588]=0;if((d|0)==1){break n}v[23588]=0;X(250,e+96|0,e+48|0,e+216|0,e+232|0);d=v[23588];v[23588]=0;if((d|0)==1){break m}d=e+96|0;Jb(a+1298368|0,d);Ab(d);Ab(e+232|0);bc(e+48|0);v[a+1298404>>2]=5;if(w[e+280|0]<2){break i}u[e+96>>1]=8192;v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}u[e+48>>1]=d;r=a,s=B(x[le(e+96|0,e+48|0)>>1],1e4)>>>8|0,v[r+480204>>2]=s;v[23588]=0;t[e+96|0]=1;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break j}t[e+48|0]=d;r=a,s=w[kf(e+96|0,e+48|0)|0],v[r+480196>>2]=s;v[23588]=0;Q(188,b|0,3)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break h}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break l}b=P()|0;O()|0;Ab(e+232|0)}bc(e+48|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+96|0]=32;v[23588]=0;d=S(206,b|0)|0;f=v[23588];v[23588]=0;q:{if((f|0)!=1){t[e+48|0]=d;r=a,s=B(w[kf(e+96|0,e+48|0)|0],1e4),v[r+480204>>2]=s;v[23588]=0;t[e+96|0]=1;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}t[e+48|0]=d;r=a,s=w[kf(e+96|0,e+48|0)|0],v[r+480196>>2]=s;v[23588]=0;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break h}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;m=Tb(e+232|0);p=e+96|12;n=Tb(e+216|0);h=a+480190|0;i=1;while(1){r:{s:{d=i&65535;if(d>>>0>x[a+480192>>1]){break s}v[23588]=0;f=W(251,a|0,d|0,0)|0;d=v[23588];v[23588]=0;t:{if((d|0)==1){break t}if(!f){break s}v[23588]=0;d=Q(240,b|0,f+492|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break t}if(!d){break s}v[23588]=0;k=S(206,b|0)|0;d=v[23588];v[23588]=0;u:{v:{w:{if((d|0)!=1){Ub(e+96|0,0,120);if(!k){break r}x:{if(w[e+280|0]){v[23588]=0;d=Q(252,b|0,e+96|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break w}if(!d){break r}if(w[e+280|0]){break x}}d=hc(e+88|0,p,96);g=v[d+4>>2];d=v[d>>2];v[23588]=0;Ok(165,e+48|0,b,d,g);d=v[23588];v[23588]=0;if((d|0)==1){break v}if(!v[e+52>>2]){break r}}g=f+236|0;d=0;break u}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){if((d|0)!=120){r=dc(g,d),s=(w[(e+96|0)+d|0]+x[h>>1]|0)+1|0,u[r>>1]=s;d=d+1|0;continue}break}v[23588]=0;d=f+48|0;U(253,e+8|0,d|0,b|0);g=v[23588];v[23588]=0;if((g|0)==1){break e}v[23588]=0;g=f+68|0;U(253,e+32|0,g|0,b|0);j=v[23588];v[23588]=0;if((j|0)==1){break e}v[23588]=0;j=f+88|0;U(253,e+80|0,j|0,b|0);l=v[23588];v[23588]=0;if((l|0)==1){break e}v[23588]=0;R(254,b|0,e+72|0);l=v[23588];v[23588]=0;if((l|0)==1){break f}v[f>>2]=(w[e+73|0]|w[e+74|0]<<8)&4095;l=w[e+73|0]|w[e+74|0]<<8;Pu(w[e+75|0]|w[e+76|0]<<8,d,0);Pu(w[e+75|0]|w[e+76|0]<<8,g,1);Pu(w[e+75|0]|w[e+76|0]<<8,j,2);r=e,s=Fb(v[d>>2]),v[r+48>>2]=s;l=l>>>12&3;q=Fb(v[f+52>>2]);while(1){d=v[e+48>>2];if(Pb(d,q)){t[e+44|0]=64;t[e+70|0]=((w[d+2|0]<<6)- -64>>>0)/127;r=d,s=w[Xb(e+44|0,e+70|0)|0],t[r+2|0]=s;Le(e+48|0);continue}else{r=e,s=Fb(v[g>>2]),v[r+48>>2]=s;d=Fb(v[f+72>>2])}break}while(1){g=v[e+48>>2];if(Pb(g,d)){t[e+44|0]=64;t[e+70|0]=((w[g+2|0]<<6)+128>>>0)/255;r=g,s=w[Xb(e+44|0,e+70|0)|0],t[r+2|0]=s;Le(e+48|0);continue}break}r=e,s=Fb(v[j>>2]),v[r+48>>2]=s;j=1<<l;l=Fb(v[f+92>>2]);while(1){d=v[e+48>>2];if(Pb(d,l)){g=d;d=t[d+2|0];d=Oka(d^-128,d>>31^-1,j,0);f=nb;y:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break y}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}r=g,s=Ic(d,f)^128,t[r+2|0]=s;Le(e+48|0);continue}else{f=x[h>>1]+1|0;u[e+70>>1]=f;d=0;f=f&65535;g=4e3-f|0;g=g>>>0>4e3?0:g;z:{A:{B:{while(1){if((d|0)==(k|0)){break A}if((d|0)==(g|0)){v[23588]=0;Q(188,b|0,20)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break A}b=P()|0;O()|0;break d}v[23588]=0;j=d+f|0;Q(240,b|0,((j<<5)+a|0)+946304|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break z}v[23588]=0;R(255,b|0,e+48|0);l=v[23588];v[23588]=0;C:{if((l|0)==1){break C}v[23588]=0;R(256,e+48|0,(B(j,104)+a|0)+484380|0);j=v[23588];v[23588]=0;if((j|0)==1){break C}v[23588]=0;u[e+44>>1]=w[e+72|0]|d<<8&32512|((w[e+67|0]&3)!=0)<<15;R(257,n|0,e+44|0);j=v[23588];v[23588]=0;if((j|0)==1){break B}d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23588]=0;R(257,m|0,e+70|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[e+48>>2]=3999;v[e+44>>2]=k+x[h>>1];r=h,s=v[td(e+48|0,e+44|0)>>2],u[r>>1]=s;break r}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}}}b=P()|0;O()|0;break d}d=Mb(e+96|0);v[23588]=0;f=Q(230,b|0,d|0)|0;g=v[23588];v[23588]=0;D:{E:{F:{G:{H:{if((g|0)!=1){I:{if(f){v[23588]=0;U(11,e+48|0,7,d|0);f=v[23588];v[23588]=0;if((f|0)==1){break I}f=e+48|0;Jb(a+1298320|0,f);Ab(f)}zb(d);d=0;J:{while(1){if((d|0)==32){v[23588]=0;d=Q(258,b|0,e+32|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break G}if(!d){break F}d=v[e+32>>2];if(d>>>0<12){break H}f=v[b+8>>2];g=v[b>>2];v[23588]=0;d=W(156,g|0,f|0,d-11|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break G}if(d){break J}break H}f=(d<<5)+a|0;ef(f+480280|0);v[23588]=0;R(231,b|0,f+480289|0);f=v[23588];v[23588]=0;if((f|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}d=v[e+32>>2]-11|0;v[e+80>>2]=d;h=Tb(e+96|0);v[23588]=0;U(234,b|0,h|0,d|0);d=v[23588];v[23588]=0;K:{if((d|0)!=1){v[e+48>>2]=50529027;d=e+48|0;r=e,s=B(v[Kb(e+80|0,d)>>2],85),v[r+72>>2]=s;g=Mb(d);v[e+8>>2]=v[e+36>>2];d=v[Kb(e+72|0,e+8|0)>>2];v[23588]=0;R(46,g|0,d|0);d=v[23588];v[23588]=0;L:{if((d|0)==1){break L}d=0;M:{while(1){f=v[e+80>>2];if(f>>>0<=d>>>0){break M}i=v[h>>2];k=w[Lb(i,d)|0];j=f;f=d+1|0;if(!((k|0)!=255|j-f>>>0<2)){f=t[Lb(i,f)|0];i=w[Lb(i,d+2|0)|0];r=e,s=zh(g),v[r+8>>2]=s;k=v[mj(e+24|0,e+8|0)>>2];v[23588]=0;X(237,g|0,k|0,i|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){d=d+3|0;continue}break L}v[23588]=0;R(47,g|0,k<<24>>24);i=v[23588];v[23588]=0;d=f;if((i|0)!=1){continue}break}break L}v[23588]=0;X(235,e+8|0,5,7,g|0);d=v[23588];v[23588]=0;if((d|0)!=1){N:{f=e+8|0;d=Bc(g,f);zb(f);f=Mc(d);i=Hb(d);v[23588]=0;da(236,a+1298332|0,f|0,i|0,74,0);f=v[23588];v[23588]=0;if((f|0)==1){break N}zb(d);ic(h);break H}}}b=P()|0;O()|0;zb(g);break K}b=P()|0;O()|0}ic(h);break d}}b=P()|0;O()|0;zb(d);break d}d=w[a+484376|0];f=v[a+484360>>2];v[23588]=0;U(238,Wb(f,d)|0,b|0,w[e+285|0]|w[e+286|0]<<8);d=v[23588];v[23588]=0;if((d|0)==1){break G}i=c&1;if(i){v[23588]=0;R(225,a+484344|0,w[e+283|0]|w[e+284|0]<<8);d=v[23588];v[23588]=0;if((d|0)==1){break G}}h=a+484344|0;f=b;d=0;while(1){O:{if((w[e+283|0]|w[e+284|0]<<8)>>>0>d>>>0){b=v[f+8>>2];g=v[f>>2];v[23588]=0;b=W(156,g|0,b|0,4)|0;g=v[23588];v[23588]=0;if((g|0)==1){break D}if(b){break O}}if(!(c&2)){break F}d=0;c=a+480190|0;while(1){b=x[c>>1];if(d>>>0>=b>>>0){d=0;f=a+480190|0;while(1){if(b>>>0<=d>>>0){break F}c=x[dc(v[n>>2],d)>>1];g=c&255;P:{if(!g){break P}h=v[m>>2];g=g-1&65535;if(Rc(h,v[m+4>>2])>>>0<=g>>>0){break P}j=b;b=x[dc(h,g)>>1]+(c>>>8&127)&65535;if(j>>>0<b>>>0){break P}b=B(b,104);g=b+a|0;c=g+484380|0;h=v[c>>2];if(!_d(h,v[g+484400>>2])){break P}g=b;b=a+484380|0;g=g+b|0;i=x[g+34>>1];b=b+B(d+1|0,104)|0;v[b>>2]=h;u[b+34>>1]=x[b+34>>1]&65534|i&1;if(!Og(b)){break P}uc(v[b+20>>2],v[g+20>>2],Ij(v[c>>2],x[c+34>>1]))}d=d+1|0;b=x[f>>1];continue}}b=x[dc(v[n>>2],d)>>1];if(b&255){d=d+1|0;continue}d=d+1|0;g=B(d,104)+a|0;b=_c(e+96|0,u[g+484414>>1]&1?16:8,1,0,b<<16>>16>=0?0:6);v[23588]=0;W(219,b|0,g+484380|0,f|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}break}b=P()|0;O()|0;break d}v[23588]=0;b=S(157,f|0)|0;g=v[23588];v[23588]=0;Q:{R:{S:{T:{if((g|0)!=1){v[23588]=0;U(190,e+48|0,f|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break T}b=e+48|0;g=kc(e+96|0,b);Bb(b);if(!i){break R}v[23588]=0;b=S(206,g|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break Q}v[23588]=0;Q(188,g|0,1)|0;k=v[23588];v[23588]=0;if((k|0)==1){break Q}v[23588]=0;b=W(226,h|0,d&65535,b+1|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break Q}if(!b){break R}v[23588]=0;b=Q(232,g|0,e+48|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break E}if(!b){break S}b=v[h>>2];v[23588]=0;R(233,Zb(b,d)|0,e+48|0);b=v[23588];v[23588]=0;if((b|0)!=1){break S}break E}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=v[h>>2];v[23588]=0;U(239,Zb(b,d)|0,1,g|0);b=v[23588];v[23588]=0;if((b|0)==1){break E}}Bb(g);d=d+1|0;continue}break}break E}b=P()|0;O()|0;break d}od(n);od(m);break b}b=P()|0;O()|0;Bb(g);break d}b=P()|0;O()|0;break d}i=i+1|0;continue}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0}od(n);od(m)}zb(o);T(b|0);L()}d=1}zb(o)}kb=e+304|0;return d|0}function $ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=kb-368|0;kb=e;zc(b);g=e+344|0;f=dC(b,g);if(!f){Tu(g)}a:{b:{c:{d:{e:{if(!f){break e}if(!HU(e+344|0)){break e}if(!Qb(v[b>>2],v[b+8>>2],Ec(72,0))){break e}if(!c){d=1;break e}Bd(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;g=w[e+353|0];u[a+480190>>1]=63;u[a+480188>>1]=g;f:{g:{while(1){if((g&65535)>>>0<=d>>>0){h:{Ub(e+272|0,0,64);d=1;i:{while(1){j:{g=d&65535;if(g>>>0>x[a+480190>>1]){iC(b,a+1298308|0);g=e+264|0;d=kb-16|0;kb=d;k:{if(!Qb(v[b>>2],v[b+8>>2],8)){t[d|0]=0;ci(g,8,d);break k}bn(d+8|0,g);ud(d,b,v[d+8>>2],v[d+12>>2])}kb=d+16|0;n=Tb(e+248|0);g=x[e+354>>1];if(!g){break i}d=0;v[23588]=0;g=W(321,b|0,n|0,B(g,w[e+353|0])<<1)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break j}g=P()|0;O()|0;break a}f=(B(g,104)+a|0)+484380|0;nd(f,1);i=g+(e+272|0)|0;g=Me(b);t[i|0]=g;if(g<<24>>24>=0){A=f,C=FU(b)<<1,v[A>>2]=C}d=d+1|0;continue}break}if(!g){break f}}d=v[n>>2];gc(e+240|0,d,fd(d,v[n+4>>2])>>>1|0);l=Tb(e+224|0);v[23588]=0;R(322,l|0,x[e+356>>1]<<8);d=v[23588];v[23588]=0;if((d|0)==1){break h}d=0;l:{m:{n:{while(1){g=d&65535;d=x[e+356>>1];if(g>>>0>=d>>>0){break m}v[e+176>>2]=d-g;v[e+120>>2]=2e3;d=e+176|0;f=v[td(d,e+120|0)>>2];d=Tb(d);v[23588]=0;f=W(321,b|0,d|0,f<<8)|0;h=v[23588];v[23588]=0;if((h|0)==1){break l}if(!f){break n}f=fc(e+216|0,Fb(v[l+4>>2]));h=Fb(v[d>>2]);j=Fb(v[e+180>>2]);f=v[f>>2];v[23588]=0;X(323,l|0,f|0,h|0,j|0);f=v[23588];v[23588]=0;if((f|0)!=1){ic(d);d=g+2e3|0;continue}break}break c}ic(d);d=0;break g}se(e+200|0,v[l>>2],v[l+4>>2]);$g(e+208|0,v[e+200>>2],v[e+204>>2]);p=a+484376|0;d=w[p|0];g=v[a+484360>>2];v[23588]=0;R(324,Wb(g,d)|0,x[e+354>>1]);d=v[23588];v[23588]=0;if((d|0)==1){break d}q=a+484344|0;s=c&1;j=0;while(1){if(x[e+354>>1]<=j>>>0){h=c&2;g=1;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{while(1){c=g&65535;if(c>>>0>x[a+480190>>1]){break v}v[23588]=0;d=w[c+(e+272|0)|0];U(325,b|0,((c<<5)+a|0)+946304|0,d&63);f=v[23588];v[23588]=0;if((f|0)==1){break t}A:{B:{if(d<<24>>24<0){break B}v[23588]=0;d=S(326,b|0)|0;f=v[23588];v[23588]=0;C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)==1){break J}c=B(c,104)+a|0;f=c+484392|0;v[f>>2]=d<<1;v[23588]=0;d=S(326,b|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break I}if(d>>>0>=2){v[c+484396>>2]=v[f>>2]+(d<<1);d=c+484414|0;u[d>>1]=x[d>>1]|8}v[23588]=0;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break s}t[e+40|0]=d;t[e+144|0]=64;A=c+484410|0,C=w[Xb(e+40|0,e+144|0)|0]<<2,u[A>>1]=C;v[23588]=0;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break J}t[c+484417|0]=d<<4;c=c+484380|0;uo(c);if(!v[c>>2]){break B}v[23588]=0;f=S(206,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break D}d=0;switch(f|0){case 4:case 5:break C;case 2:case 3:break F;case 1:break G;case 0:break H;default:break g}}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}if(h){f=Tb(e+40|0);j=v[b+8>>2];i=v[b>>2];k=v[c>>2];v[23588]=0;j=W(156,i|0,j|0,k|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break r}if(!j){break w}d=v[c>>2];v[23588]=0;U(327,b|0,f|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break r}A=e,C=Fb(v[f>>2]),v[A+144>>2]=C;j=Fb(v[e+44>>2]);while(1){d=v[e+144>>2];if(Pb(d,j)){i=d;d=w[d|0];t[i|0]=d<<7|(d^-1)<<24>>>25;He(e+144|0);continue}break}se(e+168|0,v[f>>2],v[e+44>>2]);d=v[fe(e+160|0)>>2];v[23588]=0;d=Fg(328,e+176|0,v[e+168>>2],v[e+172>>2],d,v[e+164>>2]);j=v[23588];v[23588]=0;K:{if((j|0)!=1){j=_c(e+144|0,16,1,0,16);v[23588]=0;W(219,j|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break K}Bb(d);ic(f);break B}g=P()|0;O()|0;break o}g=P()|0;O()|0;Bb(d);break o}c=v[c>>2];break E}f=Tb(e+40|0);d=v[c>>2];v[23588]=0;U(329,e+144|0,b|0,d|0);d=v[23588];v[23588]=0;L:{M:{N:{if((d|0)!=1){d=e+144|0;j=Lm(f,d);ic(d);if(h){se(e+112|0,v[j>>2],v[e+44>>2]);d=v[fe(e+104|0)>>2];v[23588]=0;d=Fg(328,e+120|0,v[e+112>>2],v[e+116>>2],d,v[e+108>>2]);i=v[23588];v[23588]=0;if((i|0)==1){break N}i=_c(e+144|0,8,1,0,2);v[23588]=0;W(219,i|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break M}Bb(d)}ic(j);break B}g=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break L}_(g|0)|0;d=0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){break u}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}g=P()|0;O()|0;Bb(d)}ic(f);break b}if(h){d=_c(e+40|0,(f|0)==2?8:16,1,0,0);v[23588]=0;W(219,d|0,c|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break B}g=P()|0;O()|0;break b}c=B(v[c>>2],f-1|0)}v[23588]=0;Q(188,b|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break B}}g=P()|0;O()|0;break b}j=Tb(e+40|0);d=v[c>>2];v[23588]=0;U(330,e+144|0,b|0,d|0);d=v[23588];v[23588]=0;O:{P:{if((d|0)!=1){i=e+144|0;d=Lm(j,i);ic(i);if(!h){break O}if((f|0)!=5){break P}A=e,C=Fb(v[d>>2]),v[A+144>>2]=C;k=Fb(v[e+44>>2]);while(1){i=v[e+144>>2];if(!Pb(i,k)){break P}m=i;i=w[i|0];t[m|0]=w[(i>>>7|0)+26353|0]^i;He(e+144|0);continue}}g=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break x}_(g|0)|0;d=0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){break A}g=P()|0;O()|0;break x}se(e+72|0,v[d>>2],v[e+44>>2]);i=v[fe(e- -64|0)>>2];v[23588]=0;i=Fg(328,e+80|0,v[e+72>>2],v[e+76>>2],i,v[e+68>>2]);k=v[23588];v[23588]=0;if((k|0)==1){break z}f=(f|0)==5;f=_c(e+144|0,f?16:8,1,0,f?16:1);v[23588]=0;W(219,f|0,c|0,i|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break y}Bb(i)}ic(d)}g=g+1|0;continue}break}ic(j);break g}g=P()|0;O()|0;break x}g=P()|0;O()|0;Bb(i)}ic(j);break b}ic(f);break g}Q:{R:{S:{T:{U:{V:{W:{d=x[e+358>>1]|w[e+360|0]<<16;if(d){c=Tb(e+144|0);v[23588]=0;b=W(321,b|0,c|0,d|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break q}if(!b){break U}se(e+32|0,v[c>>2],v[c+4>>2]);b=fe(e+24|0);g=v[b+4>>2];b=v[b>>2];v[23588]=0;b=Fg(328,e+40|0,v[e+32>>2],v[e+36>>2],b,g);g=v[23588];v[23588]=0;if((g|0)==1){break W}v[23588]=0;X(331,a+1298332|0,b|0,d|0,1);d=v[23588];v[23588]=0;if((d|0)==1){break V}Bb(b);ic(c)}v[23588]=0;Y(332,e+8|0);b=v[23588];v[23588]=0;if((b|0)==1){break T}v[23588]=0;U(213,e+144|0,e+8|0,w[e+352|0]);b=v[23588];v[23588]=0;if((b|0)==1){break S}b=e+144|0;Jb(a+1298344|0,b);Ab(b);bc(e+8|0);v[23588]=0;b=Q(1,b|0,10046)|0;c=v[23588];v[23588]=0;if((c|0)==1){break R}Jb(a+1298356|0,b);Ab(b);v[23588]=0;b=Q(1,e+8|0,5104)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Q}Jb(a+1298368|0,b);Ab(b);v[a+1298404>>2]=10;d=1;break g}g=P()|0;O()|0;break p}g=P()|0;O()|0;Bb(b);break p}ic(c);d=0;break g}g=P()|0;O()|0;break b}g=P()|0;O()|0;bc(e+8|0);break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}ic(f);break g}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break o}g=P()|0;O()|0}ic(c);break b}ic(f);break b}A=dc(v[Wb(v[a+484360>>2],w[p|0])>>2],j),C=j,u[A>>1]=C;X:{Y:{if(!s){break Y}v[23588]=0;r=j&65535;d=W(226,q|0,r|0,64)|0;g=v[23588];v[23588]=0;if((g|0)==1){break X}if(!d){break Y}f=x[a+480188>>1];i=0;while(1){d=f&65535;if(d>>>0<=i>>>0){break Y}d=dc(v[e+240>>2],B(d,j)+i|0);d=w[d|0]|w[d+1|0]<<8;Z:{if(d>>>0>=x[e+356>>1]){break Z}g=0;y=0-i|0;z=d<<8;d=Zb(v[q>>2],j);d=jd(v[d>>2],v[v[d+48>>2]+12>>2],0,i&65535);while(1){if((g|0)==64){break Z}Cq(e+176|0,v[e+208>>2],v[e+212>>2],(g<<2)+z|0,4);f=v[e+176>>2];h=Lb(f,0);m=w[h|0]&63;t[d|0]=m?m+48|0:0;k=Lb(f,1);t[d+1|0]=w[k|0]<<2&60|w[h|0]>>>6;o=w[k|0];h=Lb(f,2);k=w[Lb(f,3)|0];f=w[h|0];h=k<<4|f>>>4;u[e+40>>1]=h;f=f<<2&60|o>>>6;_:{if(!(w[Lb(e+264|0,f>>>3|0)|0]>>>(f&7)&1)|!(h?1:f)){break _}t[d+5|0]=h;o=k>>>4|0;t[d+4|0]=o;$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{switch(f|0){case 0:case 1:case 2:case 32:case 33:case 34:Pf(d,f&15,h&255);if(!w[d+4|0]){break _}t[d+2|0]=f>>>0<32?3:4;break _;case 9:t[d+3|0]=10;t[d+5|0]=h>>>1;if(h>>>0<512){break _}t[d+2|0]=15;t[d+4|0]=k>>>5;break _;case 10:case 42:if(h>>>0>254){break ja}f=f&15;break;case 50:break aa;case 48:break ba;case 43:break ca;case 47:break da;case 17:case 18:case 26:case 27:break ea;case 22:case 25:case 28:case 29:case 30:break fa;case 16:case 19:case 20:case 21:case 23:case 31:break ga;case 13:break ha;case 11:case 15:break ia;case 3:case 4:case 5:case 6:case 7:case 12:break ka;default:break $}}Pf(d,f,h&255);break _}t[d+3|0]=19;t[d+5|0]=o|(f>>>0<32?16:32);if(k&15){t[d+2|0]=3;t[d+4|0]=(h&240)>>>4;break _}t[d+2|0]=4;t[d+4|0]=h&15;break _}t[d+3|0]=(f|0)==11?12:16;A=d,C=Bu(h),t[A+5|0]=C;break _}t[d+3|0]=14;if((h&255)>>>0<64){break _}t[d+5|0]=0;break _}t[d+3|0]=19;t[d+5|0]=h&15|f<<4;break _}t[d+3|0]=19;u[e+120>>1]=15;A=d,C=w[Wc(e+40|0,e+120|0)|0]|f<<4,t[A+5|0]=C;break _}t[d+3|0]=19;if(h&255){t[d+5|0]=h&15|((f|0)==17?16:(f|0)==26?16:32);if(!(k&240)){break _}t[d+2|0]=f>>>0>25?6:5;break _}t[d+5|0]=o|(f>>>0>25?-80:-96);break _}if(!h){break $}t[d+3|0]=17;v[e+120>>2]=8;v[e+80>>2]=h+4;A=d,C=tg(v[Pe(e+120|0,e+80|0)>>2]/8|0),t[A+5|0]=C;break _}t[d+3|0]=14;k=B(y,6)+d|0;m=x[a+480188>>1];f=0;while(1){if((f|0)==(m|0)){break _}h=k+B(f,6)|0;if(!w[h+3|0]){t[h+3|0]=12;A=h,C=Bu(r),t[A+5|0]=C}f=f+1|0;continue}}t[d+3|0]=9;f=h&7;if(f){t[d+5|0]=w[f+26345|0];break _}f=h>>>4|0;if((f|0)==128){break $}t[d+5|0]=f;if(!(h&2048)){t[d+5|0]=f^128;break _}t[d+5|0]=f^-1;break _}t[d+5|0]=0;t[d+3|0]=0;if(!m){t[d|0]=255;break _}t[d+3|0]=25;break _}t[d+3|0]=0}g=g+1|0;f=x[a+480188>>1];d=B(f,6)+d|0;continue}}i=i+1|0;continue}}j=j+1|0;continue}break}g=P()|0;O()|0;break b}break c}}else{tB(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;g=x[a+480188>>1];continue}break}g=P()|0;O()|0;break b}ic(l)}ic(n)}kb=e+368|0;return d|0}g=P()|0;O()|0;break b}g=P()|0;O()|0;ic(d)}ic(l)}ic(n);T(g|0);L()}function RG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,D=0,E=0,F=0,G=0,H=C(0),I=0;e=kb-144|0;kb=e;d=Ub(e,0,144);v[d+76>>2]=-1;v[d+44>>2]=a;v[d+32>>2]=1117;v[d+84>>2]=a;x=c;a=0;h=kb-304|0;kb=h;a:{b:{c:{d:{if(v[d+4>>2]){break d}Xw(d);if(v[d+4>>2]){break d}break c}g=w[b|0];if(!g){break a}e:{f:{g:{h:{while(1){i:{c=g&255;j:{if(Wk(c)){while(1){g=b;b=b+1|0;if(Wk(w[g+1|0])){continue}break}li(d,0,0);while(1){b=v[d+4>>2];k:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break k}b=sd(d)}if(Wk(b)){continue}break}b=v[d+4>>2];c=v[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;c=b>>31;i=b;e=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;f=b;b=i+b|0;i=c+e|0;m=b;n=b>>>0<f>>>0?i+1|0:i;break j}l:{m:{n:{if((c|0)==37){c=w[b+1|0];if((c|0)==42){break n}if((c|0)!=37){break m}}li(d,0,0);o:{if(w[b|0]==37){while(1){c=v[d+4>>2];p:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;g=w[c|0];break p}g=sd(d)}if(Wk(g)){continue}break}b=b+1|0;break o}c=v[d+4>>2];if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;g=w[c|0];break o}g=sd(d)}if(w[b|0]!=(g|0)){b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if((g|0)>=0){break a}f=0;if(y){break a}break c}c=v[d+4>>2]-v[d+44>>2]|0;g=c>>31;f=c;c=n+v[d+124>>2]|0;e=m+v[d+120>>2]|0;c=e>>>0<m>>>0?c+1|0:c;i=e;e=f+e|0;f=c+g|0;m=e;n=e>>>0<i>>>0?f+1|0:f;g=b;break j}l=0;b=b+2|0;break l}if(!(!ak(c)|w[b+2|0]!=36)){e=kb-16|0;v[e+12>>2]=x;c=c-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+x|0;v[e+8>>2]=c+4;l=v[c>>2];b=b+3|0;break l}l=v[x>>2];x=x+4|0;b=b+1|0}c=0;while(1){e=w[b|0];if(ak(e)){b=b+1|0;c=(B(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){o=0;r=(l|0)!=0;e=w[b+1|0];b=b+1|0;a=0}g=b+1|0;k=3;f=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=w[b+1|0]==104;g=b?e:g;k=b?-2:-1;break q;case 43:e=b+2|0;b=w[b+1|0]==108;g=b?e:g;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;g=b}b=w[g|0];e=(b&47)==3;D=e?1:k;p=e?b|32:b;s:{if((p|0)==91){break s}t:{if((p|0)!=110){if((p|0)!=99){break t}c=(c|0)>1?c:1;break s}SG(l,D,m,n);break j}li(d,0,0);while(1){b=v[d+4>>2];u:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break u}b=sd(d)}if(Wk(b)){continue}break}b=v[d+4>>2];e=v[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;f=b>>31;j=b;e=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;i=b;b=j+b|0;n=e+f|0;n=b>>>0<i>>>0?n+1|0:n;m=b}j=c;s=c>>31;li(d,c,s);b=v[d+4>>2];v:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;break v}if((sd(d)|0)<0){break f}}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(p-88|0){default:b=p-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:UG(h+8|0,d,D,0);b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]!=(0-b|0)|v[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((p|16)==115){Ub(h+32|0,-1,257);t[h+32|0]=0;if((p|0)!=115){break x}t[h+65|0]=0;t[h+46|0]=0;u[h+42>>1]=0;u[h+44>>1]=0;break x}e=w[g+1|0];f=(e|0)==94;Ub(h+32|0,f,257);t[h+32|0]=0;b=f?g+2|0:g+1|0;B:{C:{D:{g=w[(f?2:1)+g|0];if((g|0)!=45){if((g|0)==93){break D}k=(e|0)!=94;break B}k=(e|0)!=94;t[h+78|0]=k;break C}k=(e|0)!=94;t[h+126|0]=k}b=b+1|0}g=b;while(1){e=w[g|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=w[g+1|0];if(!f|(f|0)==93){break E}i=g+1|0;b=w[g-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;t[b+(h+32|0)|0]=k;e=w[i|0];if(e>>>0>b>>>0){continue}break}}g=i}t[(e+h|0)+33|0]=k;g=g+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}j=0;i=0;e=0;f=0;s=0;E=kb-16|0;kb=E;G:{if((b|0)==1){v[116064]=28;break G}while(1){c=v[d+4>>2];H:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break H}c=sd(d)}if(Wk(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}s=(c|0)==45?-1:0;c=v[d+4>>2];if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break I}c=sd(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=v[d+4>>2];O:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break O}c=sd(d)}if((c&-33)==88){b=16;c=v[d+4>>2];P:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break P}c=sd(d)}if(w[c+79201|0]<16){break M}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}li(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>w[c+79201|0]){break N}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}li(d,0,0);v[116064]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=B(b,10)+e|0;f=b>>>0<429496729;c=v[d+4>>2];Q:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break Q}c=sd(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}j=b}R:{if(e>>>0>9){break R}k=Oka(j,0,10,0);f=nb;b=e;while(1){c=v[d+4>>2];S:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break S}c=sd(d)}e=c-48|0;q=e>>>0>9;j=b+k|0;i=j>>>0<b>>>0?f+1|0:f;if((i|0)==429496729&j>>>0>=2576980378|i>>>0>429496729|q){break R}k=Oka(j,i,10,0);f=nb;b=e;if((f|0)==-1&k>>>0<=(b^-1)>>>0|(f|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){f=w[c+79201|0];if(f>>>0<b>>>0){while(1){e=B(b,e)+f|0;j=e>>>0<119304647;c=v[d+4>>2];T:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break T}c=sd(d)}f=w[c+79201|0];if(j&f>>>0<b>>>0){continue}break}j=e}if(b>>>0<=f>>>0){break L}while(1){k=Oka(j,i,b,0);e=nb;f=f&255;if((e|0)==-1&(f^-1)>>>0<k>>>0){break L}c=f+k|0;e=c>>>0<f>>>0?e+1|0:e;j=c;i=e;c=v[d+4>>2];U:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break U}c=sd(d)}f=w[c+79201|0];if(b>>>0<=f>>>0){break L}vf(E,b,0,0,0,j,i,0,0);if(!(v[E+8>>2]|v[E+12>>2])){continue}break}break L}k=t[(B(b,23)>>>5&7)+79457|0];e=w[c+79201|0];if(e>>>0<b>>>0){while(1){f=f<<k|e;j=f>>>0<134217728;c=v[d+4>>2];V:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break V}c=sd(d)}e=w[c+79201|0];if(j&e>>>0<b>>>0){continue}break}j=f}if(b>>>0<=e>>>0){break L}f=k;q=f&31;if((f&63)>>>0>=32){f=0;q=-1>>>q|0}else{f=-1>>>q|0;q=f|(1<<q)-1<<32-q}if(!f&j>>>0>q>>>0){break L}while(1){c=k&31;F=e&255;if((k&63)>>>0>=32){e=j<<c;c=0}else{e=(1<<c)-1&j>>>32-c|i<<c;c=j<<c}j=F|c;i=e;c=v[d+4>>2];W:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break W}c=sd(d)}e=w[c+79201|0];if(b>>>0<=e>>>0){break L}if((f|0)==(i|0)&j>>>0<=q>>>0|f>>>0>i>>>0){continue}break}}if(w[c+79201|0]>=b>>>0){break K}while(1){c=v[d+4>>2];X:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break X}c=sd(d)}if(w[c+79201|0]<b>>>0){continue}break}v[116064]=68;j=-1;i=-1;s=0}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=s;c=b^j;j=c-b|0;e=b>>31;i=(e^i)-((b>>>0>c>>>0)+e|0)|0}kb=E+16|0;b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]==(0-b|0)&v[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break g}if(!(!l|(p|0)!=112)){v[l>>2]=j;break w}SG(l,D,j,i);break w}if(!l){break w}b=v[h+16>>2];c=v[h+20>>2];e=v[h+8>>2];f=v[h+12>>2];Y:{switch(D|0){case 0:G=l,H=pF(e,f,b,c),z[G>>2]=H;break w;case 1:G=l,I=Hw(e,f,b,c),A[G>>3]=I;break w;case 2:break Y;default:break w}}v[l>>2]=e;v[l+4>>2]=f;v[l+8>>2]=b;v[l+12>>2]=c;break w}i=(p|0)==99;c=i?c+1|0:31;Z:{if((D|0)==1){e=l;if(r){e=Pd(c<<2);if(!e){break h}}v[h+296>>2]=0;v[h+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=v[d+4>>2];$:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break $}e=sd(d)}if(!w[(e+h|0)+33|0]){break _}t[h+27|0]=e;e=Xr(h+28|0,h+27|0,1,h+296|0);if((e|0)==-2){continue}o=0;if((e|0)==-1){break f}if(a){v[(b<<2)+a>>2]=v[h+28>>2];b=b+1|0}if(!((b|0)==(c|0)&r)){continue}break}f=1;b=c;c=b<<1|1;e=ls(a,c<<2);if(e){continue}break e}break}o=0;c=a;if(h+296|0?v[h+296>>2]:0){break f}break Z}if(r){b=0;e=Pd(c);if(!e){break h}while(1){a=e;while(1){e=v[d+4>>2];aa:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break aa}e=sd(d)}if(!w[(e+h|0)+33|0]){c=0;o=a;break Z}t[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}f=1;b=c;c=b<<1|1;e=ls(a,c);if(e){continue}break}o=a;a=0;break e}b=0;if(l){while(1){a=v[d+4>>2];ba:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ba}a=sd(d)}if(w[(a+h|0)+33|0]){t[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;o=a;break Z}}}while(1){a=v[d+4>>2];ca:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ca}a=sd(d)}if(w[(a+h|0)+33|0]){continue}break}a=0;o=0;c=0}e=v[d+4>>2];f=v[d+116>>2];if((f|0)>0|(f|0)>=0){e=e-1|0;v[d+4>>2]=e}f=e-v[d+44>>2]|0;k=f;e=f+v[d+120>>2]|0;f=v[d+124>>2]+(f>>31)|0;f=e>>>0<k>>>0?f+1|0:f;if(!(f|e)|((e|0)!=(j|0)|(f|0)!=(s|0))&(p|0)==99){break i}if(r){v[l>>2]=a}da:{if(i){break da}if(c){v[(b<<2)+c>>2]=0}if(!o){o=0;break da}t[b+o|0]=0}a=c}b=v[d+4>>2]-v[d+44>>2]|0;e=b>>31;i=b;c=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;c=b>>>0<m>>>0?c+1|0:c;f=b;b=i+b|0;e=c+e|0;m=b;n=b>>>0<f>>>0?e+1|0:e;y=((l|0)!=0)+y|0}b=g+1|0;g=w[g+1|0];if(g){continue}break a}break}a=c;break g}f=1;o=0;a=0;break e}f=r;break b}f=r}if(y){break b}}y=-1}if(!f){break a}Nb(o);Nb(a)}kb=h+304|0;kb=d+144|0;return y}function Xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;k=kb-208|0;kb=k;if(!Lt(a)){e=k+48|0;sQ(e,a);f=k+176|0;qf(f,e,128,2);e=k+192|0;Fc(e,f);Dc(b+492|0,e);zb(e)}u[c+34>>1]=x[c+34>>1]&65489;h=k+192|0;f=kb-32|0;kb=f;a:{b:{switch(w[a+128|0]-4|0){default:v[f+28>>2]=0;io(h,0,f+28|0);break a;case 0:case 4:break b}}t[f+28|0]=w[a+129|0];t[f+24|0]=100;e=f+24|0;g=w[Xb(f+28|0,e)|0];t[f+24|0]=w[a+130|0];t[f+20|0]=100;e=w[Xb(e,f+20|0)|0];v[f+28>>2]=e;c:{if(w[a+140|0]&16){j=Ib(w[a+150|0]|w[a+151|0]<<8);o=Ib(w[a+152|0]|w[a+153|0]<<8);l=v[c>>2];r=+(l>>>0)/6553600;g=Aq(r*+((j|g<<16)>>>0));v[f+24>>2]=l-g;s=f,y=Aq(r*+((o|e<<16)>>>0)),v[s+20>>2]=y;s=f,y=v[Kb(f+24|0,f+20|0)>>2],v[s+28>>2]=y;break c}j=v[c>>2];o=v[c+20>>2];if(!_d(j,o)){break c}l=j>>>7|0;g=B(l,(g<<7>>>0)/100|0);v[f+24>>2]=j-g;v[f+20>>2]=B(l,(e<<7>>>0)/100|0);e=v[Kb(f+24|0,f+20|0)>>2];l=x[c+34>>1];j=B(Ld(l),j);d:{if(l&1){gc(f+8|0,o,j);o=v[f+8>>2];l=Ld(x[c+34>>1]);j=o+(B(l,e+g|0)<<1)|0;n=u[o+(B(g,l)<<1)>>1];l=0-l<<1;while(1){e:{f:{if(e){p=u[j>>1]-n|0;o=p>>31;if((o^p)-o>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;j=j+l|0;continue}break}break d}gc(f,o,j);o=v[f>>2];l=Ld(x[c+34>>1]);n=0-l|0;j=o+B(l,e+g|0)|0;l=t[o+B(g,l)|0];while(1){g:{h:{if(e){p=t[j|0]-l|0;o=p>>31;if((o^p)-o>>>0>=6){break h}}else{e=0}break g}e=e-1|0;j=j+n|0;continue}break}}v[f+28>>2]=e}io(h,g,f+28|0)}kb=f+32|0;o=jc(h);if(!(!v[o>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;e=v[k+192>>2];v[c+4>>2]=e;v[c+8>>2]=e+v[o>>2]}e=w[a+134|0];if((e-1&255)>>>0<=198){t[k+48|0]=e;t[k+176|0]=100;e=(w[Xb(k+48|0,k+176|0)|0]<<7>>>0)/100|0}else{e=128}t[k+47|0]=e;t[k+48|0]=64;e=k+47|0;f=k+48|0;s=c,y=w[kf(e,f)|0]>>>1|0,u[s+32>>1]=y;t[k+48|0]=64;s=b,y=w[Xb(e,f)|0],v[s+4>>2]=y;v[c+24>>2]=40460;Bl(c,+t[a+139|0]/12+ +(0-w[a+143|0]|0)+ +t[a+138|0]/1536);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){Mj(b,127,1);Lj(b,0,1)}i:{if(!_d(v[c>>2],v[c+20>>2])){break i}b=w[a+140|0];if(b&1){b=v[c>>2];e=v[c+20>>2];j:{if(!_d(b,e)|b>>>0<2){break j}k:{l:{switch(Fk(x[c+34>>1])-1|0){case 3:f=0;h=b>>>1|0;while(1){if((f|0)!=(h|0)){qc(e+(f<<2)|0,e+(b+(f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:f=0;h=b>>>1|0;while(1){if((f|0)!=(h|0)){ly(e+(f<<1)|0,e+(b+(f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}f=0;h=b>>>1|0;while(1){if((f|0)!=(h|0)){Ji(e+f|0,e+(b+(f^-1)|0)|0);f=f+1|0;continue}break}}uj(c,d)}b=w[a+140|0]}if(b&4){m:{e=v[c>>2];b=v[c+20>>2];if(!_d(e,b)){break m}f=x[c+34>>1];e=B(Ld(f),e);n:{o:{switch(_m(f)-1|0){case 1:f=0;while(1){if((e|0)!=(f|0)){h=b+(f<<1)|0;u[h>>1]=x[h>>1]^-1;f=f+1|0;continue}break};break n;case 0:break o;default:break m}}f=0;while(1){if((e|0)!=(f|0)){h=b+f|0;t[h|0]=w[h|0]^-1;f=f+1|0;continue}break}}uj(c,d)}}i=w[a+170|0]!=2|w[a+171|0]>100?i:w[a+172|0]<101;b=x[c+34>>1];if(!(!(w[a+141|0]?1:i|w[a+160|0]!=0)|b&1)){e=Kt(v[c>>2],Ld(b)<<1&254);if(!e){break i}b=e;h=v[c>>2];g=x[c+34>>1];j=B(Ld(g),h);f=v[c+20>>2];g=Ij(h,g);h=kb-16|0;kb=h;v[h+12>>2]=j;xc(h+12|0,g);j=v[h+12>>2];while(1){if(j){u[b>>1]=t[f|0]<<8;f=f+1|0;b=b+2|0;j=j-1|0;continue}break}kb=h+16|0;u[c+34>>1]=x[c+34>>1]|1;qQ(c,e,v[c>>2],d)}p:{if(t[a+141|0]>=0){break p}gc(k+48|0,v[c+20>>2],B(v[c>>2],Ld(x[c+34>>1])));f=v[k+52>>2];e=v[k+48>>2];q:while(1){if((0-t[a+141|0]|0)<=(m|0)){break p}g=u[e>>1];h=dc(e,f);b=e;while(1)if((b|0)==(h|0)){m=m+1|0;continue q}else{g=ld(u[b>>1]-ld(g,1)|0,1);u[b>>1]=g;b=b+2|0;continue}}}r:{if(!i){break r}gc(k+48|0,v[c+20>>2],B(v[c>>2],Ld(x[c+34>>1])));i=v[k+52>>2];b=(i|0)/2|0;h=b>>31;n=b;b=w[a+172|0];g=w[a+171|0];e=g;f=0-(b>>>0<e>>>0)|0;b=b-e|0;e=f<<24|b>>>8;j=b<<24;f=n+j|0;b=e+h|0;b=Ic(Pka(f,f>>>0<j>>>0?b+1|0:b,i,i>>31),nb);f=b;j=b>>31;b=g<<24;g=b;e=b>>31;b=v[k+48>>2];m=dc(b,i);while(1){if((b|0)==(m|0)){break r}i=u[b>>1];i=Oka(g,e,i,i>>31)+838860800|0;h=nb;s=b,y=Ic(Pka(i,i>>>0<838860800?h+1|0:h,1677721600,0),nb),u[s>>1]=y;b=b+2|0;e=e+j|0;i=f+g|0;e=i>>>0<f>>>0?e+1|0:e;g=i;continue}}s:{if(!w[a+160|0]){break s}gc(k+176|0,v[c+20>>2],B(v[c>>2],Ld(x[c+34>>1])));b=w[a+163|0];i=w[a+162|0];t:{if(w[a+161|0]<=1){f=0;e=v[k+180>>2];h=0;break t}f=v[k+180>>2];e=(f|0)/2|0;j=e>>31;g=e;e=w[a+164|0];h=0-(i>>>0>e>>>0)|0;e=e-i|0;m=e<<23;g=g+m|0;e=(h<<23|e>>>9)+j|0;f=Ic(Pka(g,g>>>0<m>>>0?e+1|0:e,f,f>>31),nb);e=v[k+180>>2];h=(e|0)/2|0;j=h>>31;n=h;h=w[a+165|0];m=0-(b>>>0>h>>>0)|0;g=h-b|0;h=m<<23|g>>>9;m=g<<23;g=n+m|0;h=h+j|0;h=Ic(Pka(g,g>>>0<m>>>0?h+1|0:h,e,e>>31),nb)}g=b<<23;i=i<<23;j=(k+48|0)+((w[a+160|0]&2)<<2)|0;m=0;b=v[k+176>>2];l=dc(b,e);e=0;while(1){if((b|0)==(l|0)){break s}n=(u[b>>1]>>1)-e|0;v[k+56>>2]=n;p=n;n=(i|0)/8388608|0;m=ld(B(p,n),8)+m|0;v[k+52>>2]=m;e=ld(B(m,n),6)+e|0;e=ld(ld(B(e,(g|0)/8388608|0),6)+e|0,2);v[k+48>>2]=e;s=b,y=ed(v[j>>2]),u[s>>1]=y;b=b+2|0;g=h+g|0;i=f+i|0;continue}}u:{if(t[a+141|0]<=0){break u}gc(k+48|0,v[c+20>>2],B(v[c>>2],Ld(x[c+34>>1])));m=0;f=v[k+52>>2];e=v[k+48>>2];v:while(1){if(t[a+141|0]<=(m|0)){break u}g=u[e>>1];i=dc(e,f);b=e;while(1)if((b|0)==(i|0)){m=m+1|0;continue v}else{g=((u[b>>1]<<1)+g|0)/3|0;u[b>>1]=g;b=b+2|0;continue}}}b=v[c+20>>2];f=x[c+34>>1];e=B(v[c>>2],Ld(f));w:{if(f&1){gc(k+32|0,b,e);j=kb-16|0;kb=j;b=v[k+32>>2];m=dc(b,v[k+36>>2]);l=kb-16|0;kb=l;v[l+12>>2]=b;q=j+8|0;f=io(q,b,l+12|0);x:{if((b|0)==(m|0)){break x}e=b+2|0;if((m|0)==(e|0)){break x}s=(nk(x[e>>1],x[v[f>>2]>>1])?0:4)+f|0,y=e,v[s>>2]=y;h=f+4|0;while(1){g=e;i=e+2|0;if((m|0)!=(i|0)){e=g+4|0;if((m|0)==(e|0)){v[l+12>>2]=m;e=x[g+2>>1];if(!nk(e,x[v[f>>2]>>1])){f=h;if(nk(e,x[v[f>>2]>>1])){break x}}v[f>>2]=i;break x}n=x[v[f>>2]>>1];p=x[e>>1];g=x[g+2>>1];y:{if(nk(p,g)){if(nk(p,n)){v[f>>2]=e}if(nk(g,x[v[h>>2]>>1])){continue}break y}if(nk(g,n)){v[f>>2]=i}i=e;if(nk(p,x[v[h>>2]>>1])){continue}}v[h>>2]=i;continue}break}v[l+12>>2]=g}kb=l+16|0;v[j+4>>2]=0-u[v[j+8>>2]>>1];s=j,y=u[v[jc(q)>>2]>>1],v[s>>2]=y;z:{e=v[Pe(j+4|0,j)>>2];if((e|0)>32766|!e){break z}while(1){if((b|0)==(m|0)){break z}u[b>>1]=(B(u[b>>1],32767)|0)/(e|0);b=b+2|0;continue}}break w}gc(k+24|0,b,e);j=kb-16|0;kb=j;b=v[k+24>>2];m=Lb(b,v[k+28>>2]);l=kb-16|0;kb=l;v[l+12>>2]=b;q=j+8|0;f=io(q,b,l+12|0);A:{if((b|0)==(m|0)){break A}e=b+1|0;if((m|0)==(e|0)){break A}s=(tl(w[e|0],w[v[f>>2]])?0:4)+f|0,y=e,v[s>>2]=y;h=f+4|0;while(1){g=e;i=e+1|0;if((m|0)!=(i|0)){e=g+2|0;if((m|0)==(e|0)){v[l+12>>2]=m;e=w[g+1|0];if(!tl(e,w[v[f>>2]])){f=h;if(tl(e,w[v[f>>2]])){break A}}v[f>>2]=i;break A}n=w[v[f>>2]];p=w[e|0];g=w[g+1|0];B:{if(tl(p,g)){if(tl(p,n)){v[f>>2]=e}if(tl(g,w[v[h>>2]])){continue}break B}if(tl(g,n)){v[f>>2]=i}i=e;if(tl(p,w[v[h>>2]])){continue}}v[h>>2]=i;continue}break}v[l+12>>2]=g}kb=l+16|0;v[j+4>>2]=0-t[v[j+8>>2]];s=j,y=t[v[jc(q)>>2]],v[s>>2]=y;C:{e=v[Pe(j+4|0,j)>>2];if((e|0)>126|!e){break C}while(1){if((b|0)==(m|0)){break C}t[b|0]=(B(t[b|0],127)|0)/(e|0);b=b+1|0;continue}}}kb=j+16|0;D:{if((w[a+134|0]-101&255)>>>0>98){break D}f=x[c+34>>1];e=B(v[c>>2],Ld(f));b=v[c+20>>2];if(f&1){i=k+16|0;v[i>>2]=b;v[i+4>>2]=(b+(e<<1)|0)-b>>1;b=(3276800-(w[a+134|0]<<14)|0)/100|0;h=0-b|0;f=32768-b|0;e=v[i>>2];g=dc(e,v[i+4>>2]);while(1){if((e|0)!=(g|0)){i=u[e>>1];E:{if((i|0)>(b|0)){n=f+((B(b,i-b|0)|0)/(f|0)|0)|0;break E}n=((B(b,b+i|0)|0)/(f|0)|0)-f|0;if((h|0)>(i|0)){break E}n=(B(f,i)|0)/(b|0)|0}s=e,y=ed(n),u[s>>1]=y;e=e+2|0;continue}break}break D}i=tn(k+8|0,b,b+e|0);e=v[i>>2];b=(3276800-(w[a+134|0]<<14)|0)/100|0;h=0-b|0;f=32768-b|0;g=Lb(e,v[i+4>>2]);while(1){if((e|0)!=(g|0)){i=t[e|0]<<8;F:{if((i|0)>(b|0)){n=f+((B(b,i-b|0)|0)/(f|0)|0)|0;break F}n=((B(b,b+i|0)|0)/(f|0)|0)-f|0;if((h|0)>(i|0)){break F}n=(B(f,i)|0)/(b|0)|0}s=e,y=oS((n|0)/256|0),t[s|0]=y;e=e+1|0;continue}break}}pQ(c);if(w[a+128|0]!=8){break i}b=w[a+131|0];if(!b){break i}e=v[o>>2];if(!e){break i}s=Eb(c+68|0,0),y=v[k+192>>2]+B(e,b+1|0)|0,v[s>>2]=y;b=v[k+192>>2];v[c+12>>2]=b;v[c+16>>2]=b+v[o>>2];h=v[o>>2];i=w[a+131|0];if(h>>>0>268435456/(i>>>0)>>>0){break i}f=v[c>>2];e=B(h,i);if(f>>>0>268435456-e>>>0){break i}f=e+f|0;e=Fk(x[c+34>>1]);j=Kt(f,e);if(!j){break i}g=b+B(h,i+1|0)|0;v[c>>2]=f;b=j;j=v[c+20>>2];i=v[k+192>>2];h=uc(b,j,B(e,i+v[o>>2]|0));m=j+B(e,i)|0;a=w[a+131|0];b=0;while(1){if((a|0)==(b|0)){uc(h+B(e,g)|0,j+B(e,i+v[o>>2]|0)|0,B(e,f-g|0));qQ(c,h,f,d)}else{b=b+1|0;l=v[o>>2];uc(h+B(e,i+B(b,l)|0)|0,m,B(e,l));continue}break}}kb=k+208|0}function Caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=kb-784|0;kb=d;zc(b);a:{b:{c:{d:{e:{f:{if(!di(b,d+776|0)){break f}if(!dM(v[d+776>>2],v[d+780>>2])){break f}if(!wA(b,d+768|0)){break f}g=v[d+768>>2];if(!cM(g)){break f}f=1313423693;if((g|0)!=1179012417){f=1414090313;if((g|0)!=538987841){break f}}m=ke(d+744|0,b);j=Tb(d+728|0);g:{h:{i:{j:{k:{l:{m:{if(!c){v[23588]=0;X(851,d+136|0,m|0,((g|0)==1179012417?1:2)|0,f|0);b=v[23588];v[23588]=0;if((b|0)!=1){break m}a=P()|0;O()|0;break a}v[23588]=0;U(852,d+136|0,m|0,((g|0)==1179012417?1:2)|0);b=v[23588];v[23588]=0;if((b|0)==1){break l}}b=d+136|0;Ut(j,b);Zd(b);v[23588]=0;U(853,d+704|0,j|0,f|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;b=S(178,v[d+704>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break k}e=0;if(!b){break g}v[23588]=0;b=Q(854,d+704|0,d+624|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}if(!b){break g}b=w[d+689|0];if(!b){break g}v[23588]=0;e=W(156,v[d+704>>2],v[d+712>>2],b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break k}if(!c|e^1){break g}v[23588]=0;R(246,a|0,8388608);b=v[23588];v[23588]=0;if((b|0)==1){break k}v[a+480208>>2]=w[d+688|0]<<4&16^28;u[d+136>>1]=w[d+689|0];u[d+496>>1]=127;p=a,q=x[Wc(d+136|0,d+496|0)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+690|0];v[a+480204>>2]=B(w[d+691|0],1e4);v[a+480200>>2]=w[d+696|0]<<1;v[23588]=0;R(136,a+1298344|0,((g|0)==1179012417?16935:16901)|0);b=v[23588];v[23588]=0;if((b|0)==1){break k}v[23588]=0;b=Q(1,d+608|0,13170)|0;e=v[23588];v[23588]=0;if((e|0)==1){break i}Jb(a+1298356|0,b);Ab(b);v[a+1298404>>2]=5;b=d+496|0;aA(b,2,d+624|0);v[23588]=0;R(222,d+136|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break j}k=(g|0)!=1179012417;b=d+136|0;Bc(a+1298308|0,b);zb(b);l=(g|0)==1179012417;b=0;while(1){n:{o:{p:{if(x[a+480188>>1]<=b>>>0){b=Fb(v[j>>2]);f=Fb(v[j+4>>2]);e=kb-16|0;kb=e;v[e+8>>2]=b;while(1){q:{if(!Pb(b,f)){break q}if(WU(1380209231,v[b>>2],v[b+4>>2])){break q}b=v[Nm(e+8|0)>>2];continue}break}kb=e+16|0;if(Pb(b,Fb(v[j+4>>2]))){break p}break h}f=(b<<5)+a|0;h=f+480280|0;ef(h);v[23588]=0;e=S(206,d+704|0)|0;n=v[23588];v[23588]=0;r:{s:{if((n|0)!=1){if(l){break r}if(e>>>0<129){break s}break o}a=P()|0;O()|0;break b}u[f+480284>>1]=e<<1;break n}if(e<<24>>24<0){break o}v[d+136>>2]=e<<2;v[d+496>>2]=256;p=f+480284|0,q=v[td(d+136|0,d+496|0)>>2],u[p>>1]=q;break n}v[23588]=0;U(853,d+136|0,j|0,1380209231);b=v[23588];v[23588]=0;t:{if((b|0)!=1){v[23588]=0;b=S(206,d+136|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break t}e=w[a+484376|0];f=v[a+484360>>2];v[23588]=0;da(340,Wb(f,e)|0,d+136|0,b+1&255,255,254);b=v[23588];v[23588]=0;if((b|0)==1){break t}Bb(d+136|0);break h}a=P()|0;O()|0;break b}a=P()|0;O()|0;Bb(d+136|0);break b}v[h>>2]=1024}b=b+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}u:{if(!(c&1)){break u}u[d+56>>1]=0;v[23588]=0;U(855,d+560|0,j|0,1414807888);b=v[23588];v[23588]=0;if((b|0)==1){break c}b=v[d+564>>2];e=v[d+560>>2];v[23588]=0;f=a+484344|0;R(225,f|0,Cf(e,b)&65535);b=v[23588];v[23588]=0;v:{if((b|0)!=1){p=d,q=Fb(v[d+560>>2]),v[p+88>>2]=q;l=Fb(v[d+564>>2]);w:{x:{y:{z:{A:{while(1){b=v[d+88>>2];if(!Pb(b,l)){k=a+484348|0;b=0;break w}b=ke(d+136|0,b);v[23588]=0;e=S(206,b|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;u[d+480>>1]=e;e=S(157,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break A}v[23588]=0;U(190,d+496|0,b|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break z}e=kc(d+584|0,d+496|0);v[23588]=0;h=v[e+12>>2];v[d+8>>2]=v[e+8>>2];v[d+12>>2]=h;v[d+16>>2]=v[e+16>>2];h=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=h;X(856,d|0,x[d+480>>1],k|0,a|0);e=v[23588];v[23588]=0;if((e|0)==1){break y}Bb(d+496|0);p=d,q=x[le(d+56|0,d+480|0)>>1],u[p+56>>1]=q;Bb(b);Nf(d+88|0);continue}break}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;Bb(d+496|0)}Bb(b);break v}while(1){e=b&65535;if(e>>>0>=x[d+56>>1]){Vc(d+560|0);break u}B:{if(!ye(v[a+484344>>2],v[k>>2],e)){v[23588]=0;W(226,f|0,e|0,64)|0;e=v[23588];v[23588]=0;if((e|0)==1){break B}}b=b+1|0;continue}break}a=P()|0;O()|0;break v}a=P()|0;O()|0}Vc(d+560|0);break b}C:{if((g|0)==1179012417){v[23588]=0;U(855,d+88|0,j|0,1414745673);b=v[23588];v[23588]=0;if((b|0)==1){break d}p=d,q=Fb(v[d+88>>2]),v[p+120>>2]=q;f=c&2;k=d+504|0;l=Fb(v[d+92>>2]);g=a+480190|0;while(1){b=v[d+120>>2];if(!Pb(b,l)){Vc(d+88|0);break C}c=ke(d+560|0,b);v[23588]=0;b=Q(857,c|0,d+136|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){D:{if(!b){break D}b=w[d+137|0];if((b|0)==255){break D}v[23588]=0;e=W(251,a|0,b+1|0,0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}if(!e){break D}h=x[g>>1];b=0;v[23588]=0;U(858,d+136|0,e|0,h|0);e=v[23588];v[23588]=0;if((e|0)==1){break e}while(1){if(w[d+166|0]<=b>>>0){break D}E:{if(!Yh(x[g>>1])){break E}v[23588]=0;e=Q(859,c|0,d+496|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break e}if(!e){break E}e=x[g>>1]+1|0;u[g>>1]=e;if(v[d+496>>2]!=1347240275){break E}h=d+480|0;Ii(h,2,k);v[23588]=0;R(222,d+56|0,h|0);h=v[23588];v[23588]=0;F:{if((h|0)!=1){e=e&65535;h=d+56|0;Dc(((e<<5)+a|0)+946304|0,h);zb(h);v[23588]=0;e=(B(e,104)+a|0)+484380|0;U(860,d+496|0,d+136|0,e|0);h=v[23588];v[23588]=0;if((h|0)==1){break e}if(!f){break F}h=d+56|0;bM(h,x[d+534>>1]);v[23588]=0;W(219,h|0,e|0,c|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break E}break e}break e}h=x[e+34>>1];e=v[e>>2];v[23588]=0;Q(188,c|0,Ij(e,h)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break e}}b=b+1|0;continue}}Bb(c);Nf(d+120|0);continue}break}break e}v[23588]=0;U(855,d+480|0,j|0,1179011410);b=v[23588];v[23588]=0;if((b|0)!=1){p=d,q=Fb(v[d+480>>2]),v[p+472>>2]=q;k=c&2;l=d+496|4;h=Fb(v[d+484>>2]);e=a+480190|0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{while(1){b=v[d+472>>2];if(!Pb(b,h)){Vc(d+480|0);break C}c=ke(d+560|0,b);v[23588]=0;b=S(157,c|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break P}Q:{R:{if((b|0)!=538986817){break R}v[23588]=0;b=Q(861,c|0,d+464|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break O}if(!(b&v[d+464>>2]==1414745673)){break R}v[23588]=0;b=Q(862,c|0,d+136|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break N}if(!b){break R}b=w[d+141|0];if((b|0)==255){break R}v[23588]=0;b=W(251,a|0,b+1|0,0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break M}if(!b){break R}g=x[e>>1];v[23588]=0;U(863,d+136|0,b|0,g|0);b=v[23588];v[23588]=0;if((b|0)==1){break M}v[23588]=0;U(852,d+496|0,c|0,2);b=v[23588];v[23588]=0;if((b|0)==1){break Q}v[23588]=0;U(855,d+120|0,d+496|0,1179011410);b=v[23588];v[23588]=0;if((b|0)==1){break L}Zd(d+496|0);p=d,q=Fb(v[d+120>>2]),v[p+112>>2]=q;n=Fb(v[d+124>>2]);S:{T:{while(1){b=v[d+112>>2];if(!Pb(b,n)){break S}b=ke(d+88|0,b);v[23588]=0;g=S(157,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break K}U:{V:{if((g|0)!=538989377){break V}g=x[e>>1];if(!Yh(g)){break V}f=x[d+460>>1];u[d+460>>1]=f-1;if(!f){Bb(b);break S}i=g+1|0;u[e>>1]=i;v[23588]=0;g=Q(861,b|0,d+80|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break J}if(!(g&v[d+80>>2]==1347240275)){break T}v[23588]=0;U(190,d+496|0,b|0,v[d+84>>2]);g=v[23588];v[23588]=0;W:{if((g|0)!=1){f=d+496|0;g=kc(d+56|0,f);Bb(f);v[23588]=0;f=Q(864,g|0,f|0)|0;o=v[23588];v[23588]=0;if((o|0)==1){break U}if(f){break W}Bb(g);Bb(b);break S}a=P()|0;O()|0;break H}f=d+24|0;Ne(f,2,l);v[23588]=0;R(222,d+40|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break I}f=i&65535;i=d+40|0;Dc(((f<<5)+a|0)+946304|0,i);zb(i);v[23588]=0;f=(B(f,104)+a|0)+484380|0;U(865,d+496|0,d+136|0,f|0);i=v[23588];v[23588]=0;if((i|0)==1){break U}X:{if(!k){break X}v[23588]=0;Q(155,g|0,v[d+496>>2]+4|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break U}i=d+40|0;bM(i,x[d+536>>1]);v[23588]=0;W(219,i|0,f|0,g|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break X}break I}Bb(g)}Bb(b);Nf(d+112|0);continue}break}break I}Bb(b)}Vc(d+120|0)}Bb(c);Nf(d+472|0);continue}break}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;Zd(d+496|0);break G}a=P()|0;O()|0;break H}a=P()|0;O()|0;break H}a=P()|0;O()|0;Bb(g)}Bb(b);Vc(d+120|0)}Bb(c);Vc(d+480|0);break b}a=P()|0;O()|0;break b}e=1}Bb(d+704|0);Zd(j);Bb(m)}kb=d+784|0;return e|0}a=P()|0;O()|0;Bb(c);Vc(d+88|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}Bb(d+704|0)}Zd(j);Bb(m);T(a|0);L()}function ot(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=kb-32|0;kb=h;v[h+28>>2]=c;a:{if((c|0)<=0){break a}k=v[b+656>>2];if(!(!k|v[a+480180>>2]!=16777216)){m=v[k+44>>2]!=0}i=v[b+104>>2];b:{c:{d:{if(!k){j=c;break d}if((c|0)>128){break c}j=c-1|0;l=x[dc(k+236|0,j)>>1];e:{if((l-1&65535)>>>0<=3998){i=(B(l,104)+a|0)+484380|0;break e}Db(h+16|0,a+1074312|0,43);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break e}if(!qj(v[b+656>>2])){break a}}j=w[Lb(k+108|0,j)|0];v[h+28>>2]=j}if(j>>>0<121){break b}c=j}f:{if(!(v[a+480180>>2]&16777248?(c|0)!=255:0)){Vn(a,b);if(d){break f}Db(h+16|0,a+1074312|0,100);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])|!(w[a+480208|0]&4)|!w[b+789|0]){break f}v[b+88>>2]=v[b+88>>2]&-6145;break f}if(!x[a+480192>>1]){break f}v[b+88>>2]=v[b+88>>2]|4096}g:{if((c|0)!=254){break g}d=v[b+88>>2];c=a+480180|0;if(!(!(d&512)|v[c>>2]!=2)){v[b+88>>2]=d|2048;break g}v[b+88>>2]=d|2101248;h:{if(v[c>>2]&16777248){if(!x[a+480192>>1]){break h}Db(h+16|0,a+1074312|0,50);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break h}}v[b+688>>2]=0}Db(h+16|0,a+1074312|0,50);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}Db(h+16|0,a+1074312|0,20);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break a}t[b+797|0]=0;t[b+802|0]=0;break a}i:{j:{k:{if(m){if(d){l=w[b+797|0];if(l){break k}}v[b+708>>2]=0}if(d){break j}if(!(!(v[a+480180>>2]&1048588)|!i)){u[b+770>>1]=t[i+36|0];u[b+772>>1]=t[i+37|0]}if(i){Db(h+16|0,a+1074312|0,24);l=0;o=1;if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break i}v[b+704>>2]=v[i+24>>2];break i}l=0;break i}l=B((v[v[k+44>>2]+36>>2]<<16>>16)+1|0,(j<<16>>16)-(l<<16>>16)|0)-v[b+852>>2]|0;v[b+708>>2]=l;v[b+852>>2]=0-l}o=(i|0)!=0;l=1;if(yi(v[b+8>>2],v[b+12>>2])){break i}l=a+1074312|0;Db(h+16|0,l,54);l:{if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break l}if(qj(v[b+656>>2])){Db(h+8|0,l,117);if(!Cb(v[v[h+8>>2]>>2],v[h+12>>2])){break l}}v[b+700>>2]=0;break a}Db(h+16|0,l,39);l=(Cb(v[v[h+16>>2]>>2],v[h+20>>2])^-1)&d}m:{if(Km(v[a+480180>>2])){v[h+28>>2]=u[b+770>>1]+j;pe(h+28|0,12,131);break m}MR(h+28|0)}j=a+1074312|0;Db(h+16|0,j,34);n:{if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){d=Cl(c);break n}d=v[h+28>>2]}t[b+797|0]=d;t[b+851|0]=w[b+851|0]&183|64;if(!(v[a+480180>>2]&16777250?0:l)){t[b+803|0]=0}d=fh(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;Db(h+16|0,j,48);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){HN(a,b,k,i)}Db(h+16|0,j,115);if(!(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])|!k|!w[k+26|0])){if(!x[b+784>>1]){u[b+784>>1]=x[b+692>>1]+1}GN(b+692|0,c,w[k+26|0],w[k+27|0])}o:{if(e^1|l){break o}v[b+776>>2]=0;v[b+780>>2]=0;if(!k){break o}Db(h+16|0,j,29);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+798|0]=w[k+16|0]}if(!(w[k+60|0]&8)){pj(b+724|0)}if(!(w[k+80|0]&8)){pj(b+732|0)}if(!(w[k+100|0]&8)){pj(b+740|0)}if(w[k+20|0]){c=mt(Un(a));n=w[k+20|0];Db(h+16|0,j,28);n=((B(c,n)<<16>>16)/64<<16)+65536>>16;p:{if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){c=v[b+752>>2];break p}c=(v[b+688>>2]+1|0)/2|0}u[b+776>>1]=(B(c,n)|0)/199}q:{if(!w[k+19|0]){break q}q=b,r=(B(mt(Un(a)),w[k+19|0])<<16>>16)/32|0,u[q+778>>1]=r;Db(h+16|0,j,28);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])|x[b+784>>1]){break q}u[b+784>>1]=x[b+692>>1]+1}c=w[k+23|0];if(c){n=mt(Un(a));p=w[b+837|0];t[b+796|0]=p+1;u[b+780>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[k+24|0];if(!c){break o}n=mt(Un(a));p=w[b+838|0];t[b+795|0]=p+1;u[b+782>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!o){break a}c=0;r:{s:{if(!d){break s}if(!(v[b+700>>2]?l:0)){v[b+700>>2]=d}t:{u:{if(!m){if(!l){Db(h+16|0,j,69);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break u}Db(h+8|0,j,46);if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])|v[a+480180>>2]==1){break u}}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&239}if(!l){break u}if(v[b+76>>2]|w[a+480180|0]&2){break t}}v[b+104>>2]=i;d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;v:{w:{if(!(v[a+480208>>2]&2097152)){Db(h+16|0,j,96);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break w}}if(w[b+789|0]){break w}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Kb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break v}v[b+660>>2]=0}m=x[i+34>>1];d=m&1023;o=d|v[b+88>>2]&-525056;v[b+88>>2]=o;x:{y:{if(m&8){v[b+80>>2]=v[i+12>>2];m=v[i+16>>2];v[b+88>>2]=(d&16?o|4:o&-524295)|2;v[b+84>>2]=m;if(y[b+76>>2]>m>>>0){break y}break x}if(!(d&2)){break x}v[b+80>>2]=v[i+4>>2];m=v[i+8>>2];v[b+84>>2]=m;if(y[b+76>>2]<=m>>>0){break x}}v[b+76>>2]=m}Db(h+16|0,j,83);if(!(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])|v[b+80>>2])){d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d}d=v[b+88>>2];z:{if(!(d&128)){break z}i=v[b+76>>2];if(!i){break z}v[b+4>>2]=i-1;v[b+88>>2]=d|128}A:{if(w[b+822|0]>3){break A}Db(h+16|0,j,21);B:{C:{D:{if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){i=v[a+480180>>2];if(!(i&16777248)){break D}m=16;if(v[a+480208>>2]&4){break C}break B}i=v[a+480180>>2]}m=32;if((i|0)==16){break B}}if(i&67633152){break A}m=0}t[b+819|0]=m}Db(h+16|0,j,21);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])|w[b+825|0]>3){break t}t[b+820|0]=0}i=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){d=v[b+80>>2];v[b>>2]=i;v[b+4>>2]=d}if(!l){break s}c=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break s}d=1;if(!(w[a+480208|0]&8)){break r}d=1;if(!w[b+789|0]){break r}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){um(b);Db(h+16|0,j,21);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}E:{if(!c){i=w[b+789|0];break E}i=w[b+789|0];if(!(w[a+480208|0]&8)){break E}d=1;if(!(i&255)){break r}}if(!(i&255?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}d=c}Db(h+16|0,j,40);F:{G:{if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){if(d){if(!(!(w[a+480208|0]&8)|!w[b+789|0])){v[b+88>>2]=v[b+88>>2]&-4196353;i=1;break F}v[b+88>>2]=v[b+88>>2]&-4194305;i=1;break F}c=v[b+88>>2]&-4196353;break G}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;i=1;if(d){break F}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;Db(h+16|0,j,23);H:{if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break H}Db(h+8|0,j,22);if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])){break H}Db(h+16|0,j,52);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break H}Db(h+8|0,j,71);if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])){break H}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;I:{J:{if(k){i=1;d=w[k+22|0];K:{if(!gf(d)){i=!(c>>>13|0);break K}q=b,r=$q(d),t[q+838|0]=r}c=w[k+21|0];if(gf(c)){q=b,r=$q(c),t[q+837|0]=r;break J}if(i){break J}c=(i|0)!=0;break I}v[b+776>>2]=0;v[b+780>>2]=0;c=!c;break I}c=1;d=w[k+25|0];if((d|0)==255){break I}t[b+845|0]=d}L:{if(w[b+837|0]>=127){Db(h+16|0,j,36);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break L}}if(!c){break L}if((Wp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break L}c=v[a+1298300>>2];if(!Fd(c)|(g|0)==65535){break L}$p(c,g,w[b+837|0]>>>1|0,1)}i=0;if(!(w[b+89|0]&2)){break F}if(!Fd(v[a+1298300>>2])|(g|0)==65535){break F}Db(h+16|0,j,111);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){ik(v[a+1298300>>2],g);break F}Db(h+16|0,j,110);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break F}rz(v[a+1298300>>2],g,0,1,0)}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}M:{N:{if(w[a+24618|0]&16?c&1024:0){break N}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break N}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break M}}if(f){break M}v[b+700>>2]=0}if(i){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}kb=h+32|0}function yX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0;e=kb-1456|0;kb=e;zc(b);Xo(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!ur(b,e+1432|0)){break n}if(!YD(e+1432|0)){break n}if(!c){j=1;break n}if(!tr(v[b>>2],x[e+1450>>1]|x[e+1452>>1]<<16)){break n}if(!tr(v[b>>2],(x[e+1450>>1]|x[e+1452>>1]<<16)+(x[e+1444>>1]<<2)|0)){break n}Mv(a);z=e,A=Lv(),v[z+56>>2]=A;c=e+56|0;Kv(Uj(v[a+4>>2])+32|0,c);sr(c);l=v[Uj(v[a+4>>2])+32>>2];v[e+1428>>2]=x[e+1446>>1]|x[e+1448>>1]<<16;z=e,A=Wg(v[b>>2]),v[z+1168>>2]=A;v[e+1128>>2]=214748364;d=e+1168|0;z=e,A=B(v[Kb(d,e+1128|0)>>2],20),v[z+56>>2]=A;rn(l,v[Kb(e+1428|0,c)>>2]);Ub(d,0,256);r=Tb(e+1152|0);o:{while(1){j=x[e+1444>>1]<=s>>>0;if(!j){v[23588]=0;c=Q(155,b|0,(x[e+1450>>1]|x[e+1452>>1]<<16)+(s<<2)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}if(!c){break o}c=v[b+8>>2];d=v[b>>2];v[23588]=0;c=W(156,d|0,c|0,4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}if(!c){break o}v[23588]=0;c=S(157,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}v[23588]=0;d=Q(155,b|0,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break l}if(!d){break o}v[23588]=0;d=Q(158,b|0,e+1128|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}if(!d){break o}v[23588]=0;d=W(159,b|0,r|0,x[e+1140>>1])|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}if(!d){break o}f=v[r>>2];g=v[b>>2];v[23588]=0;d=x[e+1140>>1];g=S(160,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break j}h=c+20|0;if(g>>>0<=h+(d<<3)>>>0){break o}c=d?f:0;f=x[e+1140>>1];g=h+(f<<3)|0;d=0;h=x[e+1142>>1];p:{if(!(h&1)){while(1){if(d>>>0>=f>>>0){break p}if(!c){break o}f=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23588]=0;f=fa(161,h|0,f|0,l|0,v[e+1428>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break i}if(!f){break o}v[23588]=0;f=Q(155,b|0,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break i}if(!f){break o}f=hc(e+1120|0,Lb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24));h=v[f+4>>2];f=v[f>>2];v[23588]=0;Ok(162,e+56|0,b,f,h);f=v[23588];v[23588]=0;if((f|0)==1){break h}if(v[e+60>>2]!=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){break o}d=d+1|0;c=c+8|0;f=x[e+1140>>1];continue}}q:{r:{s:{t:{u:{if(h&4){if(!c){break o}d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23588]=0;d=fa(161,f|0,d|0,l|0,v[e+1428>>2])|0;f=v[23588];v[23588]=0;if((f|0)==1){break g}if(!d){break o}m=Lb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));k=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!k){break o}v[23588]=0;f=x[e+1146>>1];d=Q(155,b|0,g+x[e+1144>>1]|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break f}if(!d){break o}d=v[b+8>>2];g=v[b>>2];v[23588]=0;d=W(156,g|0,d|0,v[e+1132>>2]-x[e+1144>>1]|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break f}if(!d){break o}v[23588]=0;U(163,e+32|0,b|0,v[e+1132>>2]-x[e+1144>>1]|0);d=v[23588];v[23588]=0;if((d|0)==1){break b}d=e+32|0;g=rr(e+56|0,d);Bb(d);q=0;n=0;v:{w:{x:{while(1){h=0;y:{while(1){if(x[e+1140>>1]<=(n&65535)>>>0){break x}v[23588]=0;d=Q(164,g|0,f+1|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break y}i=f&15;o=x[(i<<1)+25968>>1];z:{A:{if(o>>>0<=d>>>0){v[23588]=0;i=w[i+26016|0];p=Q(164,g|0,i|0)|0;u=v[23588];v[23588]=0;if((u|0)==1){break y}d=p+(d-o<<i)|0;if((d|0)!=(f|0)){f=d&15;break z}v[23588]=0;d=Q(164,g|0,4)|0;i=v[23588];v[23588]=0;if((i|0)==1){break y}if((d|0)==15){v[23588]=0;i=Q(164,g|0,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break y}d=65535;if(!i){break A}Bb(g);break p}d=d+65520|0}if(d>>>0>65535){break z}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;p=h+m|0;i=x[e+1142>>1];B:{if(i&2){q=d+q|0;d=q;break B}d=i&512?d:d^32768}o=d>>>8|0;i=i&1024;t[p+1|0]=i?d:o;t[p|0]=i?o:d;h=h+2|0}if(h>>>0<k>>>0){continue}break}n=n+1|0;if(n>>>0>=x[e+1140>>1]){break r}d=(n<<3)+c|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);k=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[23588]=0;h=fa(161,h|0,k|0,l|0,v[e+1428>>2])|0;k=v[23588];v[23588]=0;if((k|0)==1){break y}if(!h){break t}k=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!k){break u}m=Lb(v[l>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}j=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break v}_(j|0)|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)==1){break w}}Bb(g);break p}j=P()|0;O()|0}Bb(g);break a}if(!c){break o}d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23588]=0;d=fa(161,f|0,d|0,l|0,v[e+1428>>2])|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}if(!d){break o}q=Lb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));if(x[e+1144>>1]>256){break o}m=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=x[e+1146>>1];v[23588]=0;d=Q(155,b|0,g|0)|0;g=v[23588];v[23588]=0;C:{D:{if((g|0)!=1){if(!d){break o}d=hc(e+24|0,e+1168|0,x[e+1144>>1]);g=v[d+4>>2];d=v[d>>2];v[23588]=0;Ok(165,e+56|0,b,d,g);d=v[23588];v[23588]=0;if((d|0)==1){break D}d=x[e+1144>>1];if(d>>>0>y[e+60>>2]){break o}g=v[b+8>>2];h=v[b>>2];v[23588]=0;d=W(156,h|0,g|0,v[e+1132>>2]-d|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){break C}}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}if(!d){break o}v[23588]=0;U(163,e+32|0,b|0,v[e+1132>>2]-x[e+1144>>1]|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=e+32|0;g=rr(e+56|0,d);Bb(d);k=0;n=0;E:{F:{G:{while(1){h=0;H:{while(1){if(x[e+1140>>1]<=(k&65535)>>>0){break G}v[23588]=0;d=Q(164,g|0,f+1|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break H}i=f&7;o=w[i+26e3|0];I:{J:{if(o>>>0<=d>>>0){v[23588]=0;i=w[i+26008|0];p=Q(164,g|0,i|0)|0;u=v[23588];v[23588]=0;if((u|0)==1){break H}d=p+(d-o<<i)|0;if((d|0)!=(f|0)){f=d&7;break I}v[23588]=0;d=Q(164,g|0,3)|0;i=v[23588];v[23588]=0;if((i|0)==1){break H}if((d|0)==7){v[23588]=0;i=Q(164,g|0,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break H}d=255;if(!i){break J}Bb(g);break p}d=d+248|0}if(d>>>0>255){break I}}d=w[(e+1168|0)+d|0];i=d+n|0;p=d;d=x[e+1142>>1]&2;t[h+q|0]=d?i:p;n=d?i:n;h=h+1|0}if(h>>>0<m>>>0){continue}break}k=k+1|0;if(k>>>0>=x[e+1140>>1]){break q}d=(k<<3)+c|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[23588]=0;h=fa(161,h|0,m|0,l|0,v[e+1428>>2])|0;m=v[23588];v[23588]=0;if((m|0)==1){break H}if(!h){break s}m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);q=Lb(v[l>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}j=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break E}_(j|0)|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)==1){break F}}Bb(g);break p}j=P()|0;O()|0}Bb(g);break a}Bb(g);break o}Bb(g);break o}Bb(g);break o}Bb(g);break p}Bb(g)}s=s+1|0;continue}break}se(e+8|0,v[l>>2],v[l+4>>2]);$g(e+16|0,v[e+8>>2],v[e+12>>2]);b=fe(e);c=v[b+4>>2];b=v[b>>2];v[23588]=0;b=Fg(166,e+56|0,v[e+16>>2],v[e+20>>2],b,c);c=v[23588];v[23588]=0;if((c|0)==1){break d}hd(Uj(v[a+4>>2])+12|0,b);Bb(b)}re(r)}kb=e+1456|0;return j|0}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0}re(r);T(j|0);L()}function HP(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;l=kb-336|0;kb=l;m=i&65535;p=d;q=e&65535;s=(e^i)&-2147483648;k=h;z=i>>>16&32767;A=e>>>16&32767;a:{b:{if(z-32767>>>0>4294934529&A-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){o=d;s=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;s=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;s=2147450880;break a}s=s|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));o=b?0:o;s=b?2147450880:s;b=0;c=0;break a}if(!(f|h|(e|g))){s=s|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(p|q);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:q);b=h+((b|0)==32?j:b)|0;Lf(l+320|0,i,c,p,q,b-15|0);n=16-b|0;p=v[l+328>>2];q=v[l+332>>2];c=v[l+324>>2];b=v[l+320>>2]}if(e>>>0>65535){break b}d=!(k|m);e=d<<6;h=E(d?f:k)+32|0;d=E(d?g:m);d=e+((d|0)==32?h:d)|0;Lf(l+304|0,f,g,k,m,d-15|0);n=(d+n|0)-16|0;k=v[l+312>>2];m=v[l+316>>2];f=v[l+304>>2];g=v[l+308>>2]}e=m|65536;B=e;C=k;d=k;k=e<<15|d>>>17;d=d<<15|g>>>17;h=0-d|0;e=k;i=1963258675-(e+((d|0)!=0)|0)|0;vf(l+288|0,d,e,0,0,h,i,0,0);j=v[l+296>>2];vf(l+272|0,0-j|0,0-(v[l+300>>2]+((j|0)!=0)|0)|0,0,0,h,i,0,0);h=v[l+280>>2];i=h<<1|v[l+276>>2]>>>31;h=v[l+284>>2]<<1|h>>>31;vf(l+256|0,i,h,0,0,d,e,0,0);j=h;h=v[l+264>>2];vf(l+240|0,i,j,0,0,0-h|0,0-(v[l+268>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+248>>2];i=h<<1|v[l+244>>2]>>>31;h=v[l+252>>2]<<1|h>>>31;vf(l+224|0,i,h,0,0,d,e,0,0);j=h;h=v[l+232>>2];vf(l+208|0,i,j,0,0,0-h|0,0-(v[l+236>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+216>>2];i=h<<1|v[l+212>>2]>>>31;h=v[l+220>>2]<<1|h>>>31;vf(l+192|0,i,h,0,0,d,e,0,0);e=h;h=v[l+200>>2];vf(l+176|0,i,e,0,0,0-h|0,0-(v[l+204>>2]+((h|0)!=0)|0)|0,0,0);i=d;h=v[l+184>>2];d=h<<1|v[l+180>>2]>>>31;e=d-1|0;h=(v[l+188>>2]<<1|h>>>31)-!d|0;vf(l+160|0,i,k,0,0,e,h,0,0);d=f;j=g<<15|d>>>17;vf(l+144|0,d<<15,j,0,0,e,h,0,0);k=v[l+172>>2];m=v[l+160>>2];D=v[l+152>>2];d=m+D|0;i=v[l+164>>2];j=i+v[l+156>>2]|0;j=d>>>0<D>>>0?j+1|0:j;m=(i|0)==(j|0)&d>>>0<m>>>0|i>>>0>j>>>0;i=m+v[l+168>>2]|0;k=i>>>0<m>>>0?k+1|0:k;m=!j&d>>>0>1|(j|0)!=0;i=m+i|0;k=i>>>0<m>>>0?k+1|0:k;vf(l+112|0,e,h,0,0,0-i|0,0-(((i|0)!=0)+k|0)|0,0,0);vf(l+128|0,1-d|0,0-((d>>>0>1)+j|0)|0,0,0,e,h,0,0);J=(A-z|0)+n|0;e=v[l+116>>2];x=e;d=v[l+112>>2];j=e<<1|d>>>31;m=d<<1;n=j;d=j;h=v[l+140>>2];u=h;e=v[l+136>>2];j=h<<1|e>>>31;i=e<<1|v[l+132>>2]>>>31;h=i+m|0;j=d+j|0;j=h>>>0<i>>>0?j+1|0:j;i=h;e=j;j=j-(h>>>0<13927)|0;r=j;k=q|65536;M=k;D=p;j=p;k=k<<1|j>>>31;p=j<<1|c>>>31;d=0;j=d|k;q=j;w=Oka(r,d,j,0);d=nb;t=d;j=b;d=c<<1|j>>>31;z=j<<1;A=d;h=h-13927|0;j=(e|0)==(r|0)&h>>>0<i>>>0|e>>>0>r>>>0;e=(e|0)==(n|0)&i>>>0<m>>>0|e>>>0<n>>>0;d=v[l+120>>2];k=v[l+124>>2]<<1|d>>>31;i=d<<1;m=j;n=e;e=u>>>31|0;d=e+(x>>>31|i)|0;j=k;j=d>>>0<e>>>0?j+1|0:j;e=d;d=n+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;k=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;F=k-!e|0;G=0;i=Oka(A,o,F,G);e=i+w|0;k=nb+t|0;k=e>>>0<i>>>0?k+1|0:k;m=(k|0)==(t|0)&e>>>0<w>>>0|k>>>0<t>>>0;w=d;i=Oka(d,0,p,0);d=i+e|0;j=nb+k|0;j=d>>>0<i>>>0?j+1|0:j;n=d;i=j;e=(j|0)==(k|0)&d>>>0<e>>>0|j>>>0<k>>>0;d=m+e|0;k=0;k=d>>>0<e>>>0?1:k;e=Oka(q,o,F,G);d=e+d|0;j=nb+k|0;u=d;d=d>>>0<e>>>0?j+1|0:j;m=Oka(q,o,w,o);k=nb;x=Oka(F,G,p,o);e=x+m|0;j=nb+k|0;j=e>>>0<x>>>0?j+1|0:j;x=e;e=j;j=(k|0)==(j|0)&m>>>0>x>>>0|j>>>0<k>>>0;m=u+e|0;d=d+j|0;j=m;m=j>>>0<e>>>0?d+1|0:d;u=j;e=0;d=e+n|0;j=i+x|0;j=d>>>0<e>>>0?j+1|0:j;e=j;k=(j|0)==(i|0)&d>>>0<n>>>0|i>>>0>j>>>0;i=u+k|0;j=m;u=i;i=i>>>0<k>>>0?j+1|0:j;n=d;m=e;x=h;h=Oka(h,0,p,o);e=nb;t=Oka(r,o,A,o);d=t+h|0;j=nb+e|0;j=d>>>0<t>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;H=u;t=e;I=z&-2;k=Oka(w,o,I,0);e=k+d|0;j=nb+j|0;j=e>>>0<k>>>0?j+1|0:j;u=e;k=e;e=j;h=(j|0)==(h|0)&d>>>0>k>>>0|h>>>0>j>>>0;d=t+h|0;k=0;k=d>>>0<h>>>0?1:k;j=d;h=n+d|0;d=k+m|0;d=h>>>0<j>>>0?d+1|0:d;t=h;j=h;h=d;k=(d|0)==(m|0)&j>>>0<n>>>0|d>>>0<m>>>0;d=H+k|0;j=i;N=d;n=d>>>0<k>>>0?j+1|0:j;K=Oka(q,o,x,o);H=nb;i=Oka(F,G,I,o);d=i+K|0;j=nb+H|0;j=d>>>0<i>>>0?j+1|0:j;F=d;k=Oka(r,o,p,o);i=d+k|0;m=j;d=j+nb|0;d=i>>>0<k>>>0?d+1|0:d;L=i;j=Oka(A,o,w,o);i=i+j|0;k=nb+d|0;G=i;k=i>>>0<j>>>0?k+1|0:k;i=k;w=0;O=(d|0)==(k|0)&G>>>0<L>>>0|d>>>0>k>>>0;j=(d|0)==(m|0)&F>>>0>L>>>0|d>>>0<m>>>0;d=j+((m|0)==(H|0)&F>>>0<K>>>0|m>>>0<H>>>0)|0;k=0;d=O+d|0;m=i|0;k=m+t|0;j=(d|w)+h|0;w=k;d=k;j=d>>>0<m>>>0?j+1|0:j;m=j;h=(h|0)==(j|0)&d>>>0<t>>>0|h>>>0>j>>>0;d=h+N|0;j=n;H=d;h=d>>>0<h>>>0?j+1|0:j;t=Oka(r,o,I,o);r=nb;k=Oka(A,o,x,o);d=k+t|0;j=nb+r|0;j=d>>>0<k>>>0?j+1|0:j;n=0;k=(j|0)==(r|0)&d>>>0<t>>>0|j>>>0<r>>>0;r=j;d=j+u|0;j=(k|n)+e|0;n=d;j=d>>>0<r>>>0?j+1|0:j;u=(e|0)==(j|0)&d>>>0<u>>>0|e>>>0>j>>>0;i=0;e=i+d|0;d=j;k=G+d|0;k=e>>>0<i>>>0?k+1|0:k;e=(d|0)==(k|0)&e>>>0<n>>>0|d>>>0>k>>>0;d=u+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+w|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<w>>>0|j>>>0<m>>>0;i=j+H|0;k=h;h=i;k=h>>>0<j>>>0?k+1|0:k;i=k;c:{if((k|0)==131071|k>>>0<131071){vf(l+80|0,d,e,h,i,f,g,C,B);j=b<<17;b=0;c=v[l+88>>2];n=b-c|0;k=v[l+80>>2];m=v[l+84>>2];D=(k|m)!=0;r=n-D|0;n=(j-(v[l+92>>2]+(b>>>0<c>>>0)|0)|0)-(n>>>0<D>>>0)|0;b=k;k=0-k|0;m=0-(((b|0)!=0)+m|0)|0;b=J+16382|0;break c}k=h<<31;d=(e&1)<<31|d>>>1;e=e>>>1|k;h=(i&1)<<31|h>>>1;i=i>>>1|0;vf(l+96|0,d,e,h,i,f,g,C,B);q=0;m=v[l+104>>2];n=q-m|0;k=v[l+96>>2];p=v[l+100>>2];z=(k|p)!=0;r=n-z|0;n=((b<<16)-(v[l+108>>2]+(m>>>0>q>>>0)|0)|0)-(n>>>0<z>>>0)|0;j=k;k=0-j|0;m=0-(((j|0)!=0)+p|0)|0;z=b;A=c;p=D;q=M;b=J+16383|0}if((b|0)>=32767){s=s|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=r;j=n<<1|c>>>31;r=c<<1|m>>>31;n=j;p=h;q=i&65535|b<<16;j=m<<1|k>>>31;b=k<<1;break d}if((b|0)<=-113){b=0;c=0;break a}Fm(l- -64|0,d,e,h,i,1-b|0);Lf(l+48|0,z,A,p,q,b+112|0);d=v[l+64>>2];e=v[l+68>>2];p=v[l+72>>2];q=v[l+76>>2];vf(l+32|0,f,g,C,B,d,e,p,q);c=v[l+40>>2];i=c<<1;c=v[l+44>>2]<<1|c>>>31;b=v[l+56>>2];h=v[l+36>>2];n=h>>>31|i;i=b-n|0;n=v[l+60>>2]-((b>>>0<n>>>0)+c|0)|0;c=v[l+32>>2];k=h<<1|c>>>31;c=c<<1;j=v[l+52>>2];b=v[l+48>>2];h=(k|0)==(j|0)&c>>>0>b>>>0|j>>>0<k>>>0;r=i-h|0;n=n-(h>>>0>i>>>0)|0;h=b;b=h-c|0;j=j-((c>>>0>h>>>0)+k|0)|0}vf(l+16|0,f,g,C,B,3,0,0,0);vf(l,f,g,C,B,5,0,0,0);h=d;m=p;p=d&1;c=b+p|0;d=0;k=j+d|0;k=b>>>0>c>>>0?k+1|0:k;i=c;c=k;g=(k|0)==(g|0)&i>>>0>f>>>0|g>>>0<k>>>0;d=(d|0)==(k|0)&i>>>0<p>>>0|d>>>0>k>>>0;b=d+r|0;j=n;j=b>>>0<d>>>0?j+1|0:j;f=b;d=b;b=j;g=(d|0)==(C|0)&(j|0)==(B|0)?g:(B|0)==(j|0)&d>>>0>C>>>0|j>>>0>B>>>0;d=h+g|0;k=e;k=d>>>0<g>>>0?k+1|0:k;g=(e|0)==(k|0)&d>>>0<h>>>0|e>>>0>k>>>0;e=m+g|0;j=q;j=e>>>0<g>>>0?j+1|0:j;g=e;e=d;m=g;d=v[l+20>>2];h=(d|0)==(c|0)&y[l+16>>2]<i>>>0|c>>>0>d>>>0;d=v[l+28>>2];g=v[l+24>>2];h=j>>>0<2147418112&((f|0)==(g|0)&(b|0)==(d|0)?h:(d|0)==(b|0)&g>>>0<f>>>0|b>>>0>d>>>0);g=e+h|0;d=k;d=g>>>0<h>>>0?d+1|0:d;h=(d|0)==(k|0)&e>>>0>g>>>0|d>>>0<k>>>0;e=m+h|0;k=e>>>0<h>>>0?j+1|0:j;h=e;e=v[l+4>>2];i=(e|0)==(c|0)&y[l>>2]<i>>>0|c>>>0>e>>>0;c=v[l+12>>2];e=v[l+8>>2];c=k>>>0<2147418112&((e|0)==(f|0)&(b|0)==(c|0)?i:(c|0)==(b|0)&e>>>0<f>>>0|b>>>0>c>>>0);b=c+g|0;j=b>>>0<c>>>0?d+1|0:d;c=j;f=(d|0)==(j|0)&b>>>0<g>>>0|d>>>0>j>>>0;e=h+f|0;d=k;o=e|o;s=s|(e>>>0<f>>>0?d+1|0:d)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=s;kb=l+336|0}function ika(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=kb+-64|0;kb=e;zc(a);a:{b:{if(b>>>0<=2){G=e,H=Me(a),t[G+56|0]=H;_b(a,2);G=e,H=Sg(a),u[G+58>>1]=H;G=e,H=Cg(a),v[G+60>>2]=H;break b}xo(a,e+56|0);if(b>>>0>5){break a}}t[e+57|0]=0}c:{q=d+484344|0;E=Dd(x[e+58>>1],1,1024);o=AB(q,E);if((o|0)==65535){break c}b=Zb(v[d+484344>>2],o);A=Df(v[b>>2],v[v[b+48>>2]+12>>2],0);f=x[d+480188>>1];u[e>>1]=f-1;u[e+40>>1]=w[e+56|0];F=x[Wc(e,e+40|0)>>1];p=F+1|0;b=p&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){t[c+13|0]=w[e+57|0]>>>4;b=w[c+12|0];t[e|0]=0;b=(b|0)!=0;y=Pm(e+40|0,p,e);A=d+480188|0;d:while(1){if((m|0)==(E|0)){ic(y);break c}e:{f=Lb(v[y>>2],0);d=w[f|0];f:{g:{if(!d){v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}p=f<<24>>24;if((p|0)<0){v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}G=Lb(v[y>>2],0),H=f,t[G|0]=H}t[e|0]=0;h:{i:{f=p&63;if(!f){break i}v[23588]=0;j=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break h}t[e|0]=j;j:{k:{switch(f-1|0){case 0:t[c+12|0]=0;t[e+36|0]=1;G=c,H=w[kf(e+36|0,e)|0],t[G+14|0]=H;t[c+15|0]=0;break j;case 1:if(!j){break i}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break j}t[c+14|0]=B(B(b,j),15);break j;case 2:t[c+13|0]=j>>>4;if(j>>>0>=16){b=w[c+12|0];j=0;v[e+36>>2]=0;v[e+32>>2]=0;r=0;if(!b){break f}break g}j=0;t[c+12|0]=0;v[e+36>>2]=0;v[e+32>>2]=0;r=0;if(!(b&1)){break f}break g;case 3:r=0;v[e+36>>2]=0;v[e+32>>2]=0;if(b&1){break g}break f;case 5:if(!j){break i}b=(w[c+12|0]?15:14)+c|0;d=w[b|0];t[b|0]=d>>>0<256-j>>>0?d+j|0:-1;break j;case 6:break k;default:break i}}if(!j){break i}b=(w[c+12|0]?15:14)+c|0;d=w[b|0];t[b|0]=d>>>0>j+1>>>0?d-j|0:1}j=0;v[e+36>>2]=0;v[e+32>>2]=0;break g}j=0;v[e+36>>2]=0;v[e+32>>2]=0;r=0;if(!(b&1)){break f}break g}break e}t[f|0]=d-1;j=0;v[e+36>>2]=0;v[e+32>>2]=0;r=0;if(!(b&1)){break f}}d=w[c+13|0];b=w[c+12|0];if(b){r=0;if(!d){break f}}l:{if(b){v[e>>2]=1;v[e+24>>2]=B(d,w[c+15|0])<<1;d=v[Pe(e,e+24|0)>>2];break l}d=B(w[c+14|0],30)+30|0}b=255;k=0;while(1){m:{if(!b){b=0;break m}f=B(b,d);k=(f|0)/48|0;if(f-1536>>>0<10752){break m}b=b-1|0;continue}break}v[e+36>>2]=b;v[e+32>>2]=k;pe(e+32|0,32,255);r=1;v[e>>2]=1;G=c,H=v[Pe(e,e+36|0)>>2],t[G+16|0]=H}C=m-1|0;D=1;b=Zb(v[q>>2],o);b=jd(v[b>>2],v[v[b+48>>2]+12>>2],m,1);while(1){h=D&65535;if(h>>>0>F>>>0){if(r){Ae(Zb(v[q>>2],o),Fh(wo(Ue(Oe(e,17,w[e+32|0]),m),0)));Ae(Zb(v[q>>2],o),Fh(Ue(Oe(e,16,w[e+36|0]),m)))}if(j&240){Ae(Zb(v[q>>2],o),bV(Ue(Oe(e,20,j>>>4|224),m)))}b=j&15;if(b){Ae(Zb(v[q>>2],o),bV(Ue(Oe(e,20,Dd((B(b,w[c+16|0])>>>0)/15&255,1,15)|96),m)))}m=m+1|0;b=0;continue d}n:{o:{p:{q:{r:{f=Lb(v[y>>2],h);d=w[f|0];if(!d){v[23588]=0;l=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}if(l&128){v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}G=Lb(v[y>>2],h),H=f,t[G|0]=H}p=1;if(l&64){v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t[b+1|0]=f;p=!f}if(!(l&32)){g=w[b|0];break r}v[23588]=0;g=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t[b|0]=g;if((g-1&255)>>>0<=107){d=Cl(g+24|0);t[b|0]=d;G=Id(v[c>>2],h),H=d,t[G+1|0]=H;g=w[b|0];break o}if((g+127&255)>>>0<=107){d=Cl((g&127)+24|0);G=Id(v[c>>2],h),H=d,t[G|0]=H;t[b|0]=0;break q}if((g|0)!=255){break r}g=254;break p}t[f|0]=d-1;break n}if(g&255){break o}}if(!w[b+1|0]){g=0;break o}g=w[Id(v[c>>2],h)+1|0];t[b+1|0]=0}t[b|0]=g}if($c(g)){G=Id(v[c>>2],h),H=0,t[G+5|0]=H}t[e+23|0]=0;t[e+22|0]=0;if(l&16){t[b+2|0]=1;v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t[b+4|0]=f+2>>>2}g=0;z=0;s=0;s:{if(!(l&8)){break s}v[23588]=0;f=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;s=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t:{switch(f-1|0){case 0:t[b|0]=254;break s;case 1:t[b|0]=255;break s;case 2:d=Id(v[c>>2],h);t[b|0]=w[d+1|0];t[d+5|0]=0;break s;case 3:d=Fu(s,w[c+16|0]);s=d?d|-48:0;z=d?20:0;if(w[b|0]){break s}d=Id(v[c>>2],h);t[b|0]=w[d+1|0];t[d+5|0]=0;break s;case 4:t[e|0]=1;G=e,H=Fu(s,w[c+16|0]),t[G+24|0]=H;s=w[kf(e,e+24|0)|0];G=Id(v[c>>2],h),H=0,t[G+5|0]=H;z=15;break s;case 5:case 6:case 7:case 8:u:{if(!m){break u}if((f|0)==w[Id(v[c>>2],h)+4|0]){break u}if(!Ae(Zb(v[q>>2],o),Mm(wo(Ue(Oe(e,20,(f+122|160)&255),C),h)))){break u}G=Id(v[c>>2],h),H=f,t[G+4|0]=H}d=Id(v[c>>2],h);if(!w[b|0]){t[b|0]=w[d+1|0]}t[d+5|0]=0;z=10;break s;case 9:break t;default:break s}}d=Id(v[c>>2],h);f=w[d+5|0];t[d+5|0]=f^1;s=f?-98:-97;z=20}v:{w:{x:{if(!(l&4)){break x}v[23588]=0;n=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;i=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t[e+23|0]=i;f=1;g=1;y:{switch(n-1|0){case 0:yB(e,i<<24>>24<<3,128);d=w[b|0];if($c(d)){G=b,H=Cl(d+v[e>>2]|0),t[G|0]=H}t[e+23|0]=w[e+4|0]^128;g=35;break x;case 1:d=Fu(i,w[c+16|0]);t[e+23|0]=d;if(!d){break w}t[e+23|0]=d|208;g=20;break v;case 3:case 4:G=e,H=aV(i,w[c+16|0],1),t[G+23|0]=H;g=(n|0)==4?2:3;break v;case 5:if(!w[b|0]){G=b,H=w[Id(v[c>>2],h)|0],t[G|0]=H}G=e,H=aV(i,w[c+16|0],0),t[G+23|0]=H;g=4;break v;case 6:G=b,H=Cl(i+25|0),t[G|0]=H;t[e+23|0]=255;g=4;break v;case 7:case 8:case 9:z:{if(!m){break z}if((n|0)==w[Id(v[c>>2],h)+2|0]){break z}if(!Ae(Zb(v[q>>2],o),Mm(wo(Ue(Oe(e,20,(n-8|48)&255),C),h)))){break z}G=Id(v[c>>2],h),H=n,t[G+2|0]=H}G=e,H=xB(i,w[c+16|0]),t[G+23|0]=H;g=5;break v;case 10:G=e,H=$U(i,w[c+16|0]),t[G+23|0]=H;g=18;break v;case 11:d=Fu(i,w[c+16|0]);t[e+23|0]=d;if(d){t[e+23|0]=d|192;g=20;break v}t[b|0]=254;break w;case 2:break v;default:break y}}g=0}f=0;break v}g=0}i=0;d=1;A:{if(l&2){v[23588]=0;l=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;n=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}t[e+22|0]=n;i=9;d=0;k=0;B:{switch(l-1|0){case 0:case 1:k=1;G=e,H=_U(n,w[c+16|0],(l|0)==1),t[G+22|0]=H;i=11;break A;case 2:G=e,H=$U(n,w[c+16|0]),t[G+22|0]=H;k=1;i=18;break A;case 3:case 4:case 5:C:{if(!m){break C}if((l|0)==w[Id(v[c>>2],h)+3|0]){break C}if(!Ae(Zb(v[q>>2],o),Mm(wo(Ue(Oe(e,20,(l-4|64)&255),C),h)))){break C}G=Id(v[c>>2],h),H=l,t[G+3|0]=H}G=e,H=xB(n,w[c+16|0]),t[G+22|0]=H;k=1;i=8;break A;case 7:case 8:G=e,H=_U(n,w[c+16|0],(l|0)==8),t[G+22|0]=H;k=1;i=29;break A;case 9:G=e,H=xB(n,w[c+16|0]),t[G+22|0]=H;k=1;i=27;break A;case 6:break A;default:break B}}i=0;d=1}k=0}if(f){ZU(b,m,x[A>>1],g,e+23|0)}if(k){ZU(b,m,x[A>>1],i,e+22|0)}D:{E:{F:{G:{H:{if(!p){break H}if(!$c(w[b|0])){break H}if(!g){break G}if(!d|(g|0)==4){break H}t[e+22|0]=255;i=4}d=b+2|0;if(w[b+2|0]!=1){break D}if(g){break F}t[e+23|0]=w[b+4|0];g=13;break E}t[e+23|0]=255;d=b+2|0;g=4;if(w[b+2|0]!=1){break D}}if(i){break D}t[e+22|0]=w[b+4|0];i=13}t[d|0]=0}p=ug(e);Bo(e+24|0,p,g,w[e+23|0],i,w[e+22|0]);I:{if(w[d|0]){break I}f=w[e+2|0];if(!f){break I}t[b+2|0]=f;t[b+4|0]=w[e+4|0]}k=w[e+3|0];J:{if(z){Bo(e+24|0,p,k&255,w[e+5|0],z,s&255);K:{if(w[d|0]){break K}d=w[e+2|0];if(!d){break K}t[b+2|0]=d;t[b+4|0]=w[e+4|0]}k=w[e+3|0];break J}if(!(k&255)){break n}}t[b+3|0]=k;t[b+5|0]=w[e+5|0]}b=b+6|0;D=D+1|0;continue}}break}a=P()|0;O()|0;ic(y);T(a|0);L()}else{t[A+B(b,6)|0]=254;b=b+1|0;continue}}kb=e- -64|0;return o|0}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=kb-288|0;kb=e;zc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!eV(b,e+216|0)){break p}if(!fV(e+216|0)){break p}if(!c){d=1;break p}Bd(a,131072);d=kb-16|0;kb=d;i=e+128|0;f=yc(d,3913);ad(i,f);Ab(f);kb=d+16|0;v[23588]=0;U(305,e+176|0,i|0,e+216|4);d=v[23588];v[23588]=0;q:{if((d|0)!=1){d=e+176|0;Jb(a+1298344|0,d);Ab(d);i=e+128|0;bc(i);f=yc(d,11066);Jb(a+1298356|0,f);Ab(f);v[a+1298404>>2]=5;LB(i,3,e+229|0);Fc(d,i);Bc(a+1298308|0,d);zb(d);f=e+104|0;Dj(f,3,e+259|0);Fc(i,f);v[23588]=0;U(11,d|0,5,i|0);d=v[23588];v[23588]=0;if((d|0)==1){break b}d=e+176|0;Jb(a+1298320|0,d);Ab(d);zb(e+128|0);d=yo(d);o=d,p=Dd(w[e+279|0],1,31),v[o+8>>2]=p;o=d,p=Dd(w[e+280|0],1,12),v[o+4>>2]=p;v[d>>2]=w[e+281|0]+1900;i=a+1298408|0;Lc(i);DB(i,d);g=e+136|0;i=Tb(e+160|0);r:{s:{t:{while(1){d=v[b+8>>2];f=v[b>>2];v[23588]=0;d=W(156,f|0,d|0,8)|0;f=v[23588];v[23588]=0;u:{v:{w:{x:{y:{if((f|0)!=1){if(!d){break r}v[23588]=0;R(306,b|0,e- -64|0);d=v[23588];v[23588]=0;if((d|0)==1){break y}d=v[e+68>>2];z:{l=w[e+220|0];switch(l-3|0){case 1:break x;case 0:break z;default:break w}}f=2;if(v[e+64>>2]!=1431389523){break v}break u}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}f=4;if(v[e+64>>2]!=1431389523){break v}break u}f=0;if(l>>>0>7){break u}}d=v[e+64>>2]==1146113363?-1:d;f=0}l=v[e+68>>2];v[e+128>>2]=v[e+64>>2];v[e+132>>2]=l;v[23588]=0;U(190,e+104|0,b|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break t}kc(g,e+104|0);v[23588]=0;R(307,i|0,e+128|0);d=v[23588];v[23588]=0;if((d|0)==1){break s}Ad(e+128|0);Bb(e+104|0);v[23588]=0;Q(188,b|0,f|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;Ad(e+128|0);Bb(e+104|0);break c}v[23588]=0;l=S(174,e+128|0)|0;b=v[23588];v[23588]=0;A:{B:{C:{if((b|0)!=1){v[23588]=0;U(308,e+104|0,i|0,1431389523);b=v[23588];v[23588]=0;if((b|0)==1){break C}d=e+104|0;b=hd(l,d);Bb(d);u[e+102>>1]=0;u[e+100>>1]=65534;if(w[e+220|0]<3){break A}v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break B}break e}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}u[e+102>>1]=d;if(w[e+220|0]<4){break A}v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}u[e+100>>1]=w[e+220|0]==4?d?d:-2:d}d=w[a+484376|0];f=v[a+484360>>2];v[23588]=0;g=S(202,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break e}v[23588]=0;U(238,Wb(f,d)|0,b|0,g>>>1|0);d=v[23588];v[23588]=0;if((d|0)==1){break e}d=Wb(v[a+484360>>2],w[a+484376|0]);d=CB(v[d>>2],v[d+4>>2]);Ff(e+102|0,d);Ff(e+100|0,d);v[23588]=0;U(308,e+104|0,i|0,1414807888);d=v[23588];v[23588]=0;if((d|0)==1){break h}d=e+104|0;b=hd(b,d);Bb(d);d=v[b>>2];v[23588]=0;d=S(178,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}if(!(c&1)|d^1){break q}v[23588]=0;R(309,b|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}o=a+480188|0,p=Dd(w[e+2|0],1,32)+1|0,u[o>>1]=p;v[23588]=0;d=Q(218,e+88|0,x[e>>1])|0;f=v[23588];v[23588]=0;if((f|0)==1){break j}o=e,p=Fb(v[d>>2]),v[o+40>>2]=p;g=Fb(v[d+4>>2]);D:{E:{while(1){h=v[e+40>>2];if(!Pb(h,g)){f=x[a+480188>>1];v[23588]=0;f=Q(310,e+104|0,f|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){g=a+484376|0;h=Wb(v[a+484360>>2],w[g|0]);h=El(v[h>>2],v[h+4>>2]);v[23588]=0;k=a+484344|0;R(225,k|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break g}g=Wb(v[a+484360>>2],w[g|0]);o=e,p=Fb(v[g>>2]),v[o+64>>2]=p;h=Fb(v[g+4>>2]);F:{while(1){G:{g=v[e+64>>2];if(!Pb(g,h)){g=w[a+484376|0];h=v[a+484360>>2];v[23588]=0;j=Wb(h,g);h=x[e+100>>1];g=Q(311,j|0,h|0)|0;j=v[23588];v[23588]=0;if((j|0)!=1){break G}break g}j=v[d>>2];n=Cf(j,v[d+4>>2]);m=x[g>>1];if(n>>>0>m>>>0){v[23588]=0;j=fa(312,Pg(j,m)|0,w[e+220|0],f|0,a|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break F}u[g>>1]=j}Se(e- -64|0);continue}break}H:{if(!g){break H}g=Wb(v[a+484360>>2],w[a+484376|0]);j=x[e+102>>1];if(!j){if(CB(v[g>>2],v[g+4>>2])>>>0<=h>>>0){break H}}g=Zb(v[k>>2],x[dc(v[g>>2],h)>>1]);Ae(g,Mm(Ue(Oe(e- -64|0,12,j&255),v[g+12>>2]-1|0)))}vk(f);Vc(d);break q}break g}b=P()|0;O()|0;break f}v[23588]=0;f=w[e+220|0]<3?9:8;Q(188,b|0,f-4|0)|0;k=v[23588];v[23588]=0;if((k|0)!=1){v[23588]=0;k=S(157,b|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break E}zg(b,f);v[23588]=0;U(190,e- -64|0,b|0,f+k|0);f=v[23588];v[23588]=0;if((f|0)==1){break D}j=h;f=e- -64|0;h=kc(e+104|0,f);hd(j,h);Bb(h);Bb(f);Nf(e+40|0);continue}break}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;bc(e+128|0);break a}v[23588]=0;U(308,e- -64|0,i|0,1196641603);d=v[23588];v[23588]=0;if((d|0)==1){break n}d=e- -64|0;b=hd(b,d);Bb(d);d=v[b>>2];v[23588]=0;d=S(178,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}if(d){v[23588]=0;Q(188,b|0,1)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;d=S(202,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}v[23588]=0;da(313,a+1298332|0,b|0,d|0,40,0);d=v[23588];v[23588]=0;if((d|0)==1){break e}}v[23588]=0;U(308,e- -64|0,i|0,1146113363);d=v[23588];v[23588]=0;if((d|0)==1){break k}v[23588]=0;U(308,e+40|0,i|0,1229999443);d=v[23588];v[23588]=0;if((d|0)==1){break o}d=e+40|0;b=hd(b,d);Bb(d);v[23588]=0;d=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break m}h=a+480190|0;u[h>>1]=d;k=!(c&2);f=1;I:{while(1){J:{c=f&65535;if(c>>>0>(d&65535)>>>0){break I}d=30;K:{L:{M:{if(w[e+220|0]>=2){v[23588]=0;d=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break M}}v[23588]=0;U(314,b|0,((c<<5)+a|0)+946304|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break M}v[23588]=0;R(315,b|0,e+24|0);d=v[23588];v[23588]=0;if((d|0)==1){break L}v[23588]=0;g=B(c,104)+a|0;j=g+484380|0;R(316,e+24|0,j|0);c=v[23588];v[23588]=0;if((c|0)==1){break L}d=w[e+220|0];if(d>>>0>=8){v[23588]=0;R(317,b|0,g+484423|0);c=v[23588];v[23588]=0;if((c|0)==1){break L}d=w[e+220|0]}v[23588]=0;Q(188,b|0,((d&255)>>>0>1?6:2)|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break L}v[23588]=0;c=S(157,e- -64|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;U(190,e|0,e- -64|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){break K}}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}c=kc(e+40|0,e);Bb(e);d=v[c>>2];v[23588]=0;d=S(178,d|0)|0;m=v[23588];v[23588]=0;if((m|0)!=1){N:{if(k|d^1){break N}d=_c(e,u[g+484414>>1]&1?16:8,1,0,(w[e+39|0]&12)==4?7:0);v[23588]=0;W(219,d|0,j|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break N}break J}Bb(c);f=f+1|0;d=x[h>>1];continue}}break}b=P()|0;O()|0;Bb(c);break l}ag(a);v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;v[23588]=0;d=1;W(264,a+1074312|0,114,1)|0;a=v[23588];v[23588]=0;if((a|0)==1){break m}Bb(e- -64|0);Bb(b);Zd(i)}kb=e+288|0;return d|0}b=P()|0;O()|0;break l}b=P()|0;O()|0;break d}b=P()|0;O()|0}Bb(e- -64|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;vk(f)}Vc(d);break d}b=P()|0;O()|0}Bb(l)}Zd(i);break a}b=P()|0;O()|0;zb(e+128|0)}T(b|0);L()}function gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0;d=kb-1344|0;kb=d;zc(b);f=kb-16|0;kb=f;GR(f+8|0,d+232|0);e=v[f+12>>2];nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);j=v[f+4>>2];if((j|0)==(e|0)){_b(b,v[f+12>>2])}kb=f+16|0;a:{if((e|0)!=(j|0)){break a}if(!IR(d+232|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(HR(v[d+1336>>2]),nb))){break a}if(!c){m=1;break a}zc(b);b=ke(d+232|0,b);v[23588]=0;R(618,d+216|0,b|0);f=v[23588];v[23588]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((f|0)!=1){Bb(b);v[23588]=0;U(619,d+200|0,d+216|0,1196314451);b=v[23588];v[23588]=0;if((b|0)==1){break i}v[23588]=0;U(619,d+184|0,d+216|0,1280331091);b=v[23588];v[23588]=0;if((b|0)==1){break h}if(pc(v[d+200>>2],v[d+204>>2])){break b}if(!pc(v[d+184>>2],v[d+188>>2])){break g}break b}c=P()|0;O()|0;Bb(b);break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}v[23588]=0;R(246,a|0,1);b=v[23588];v[23588]=0;j:{k:{l:{m:{n:{if((b|0)!=1){ag(a);v[a+480188>>2]=4;v[a+480208>>2]=25231360;D=d,E=Fb(v[d+184>>2]),v[D+48>>2]=E;g=c&2;m=Fb(v[d+188>>2]);f=a+480190|0;o:{p:{while(1){e=v[d+48>>2];if(!Pb(e,m)){break p}b=x[f>>1];if(!Yh(b)){break p}b=b+1|0;u[f>>1]=b;v[23588]=0;b=B(b&65535,104)+a|0;j=b+484380|0;R(277,j|0,1);i=v[23588];v[23588]=0;q:{r:{if((i|0)!=1){v[23588]=0;i=Q(620,e|0,d+232|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break r}if(!i){break c}if(Xt(d+232|0)){break q}break c}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[23588]=0;i=Q(55,d+168|0,d+232|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break o}Dc(((x[f>>1]<<5)+a|0)+946304|0,i);zb(i);i=v[d+268>>2];v[j>>2]=i;v[b+484388>>2]=i;v[b+484384>>2]=v[d+264>>2];i=b+484414|0;u[i>>1]=x[i>>1]|2;u[b+484410>>1]=255;s:{if(g){b=_c(d+16|0,8,1,0,0);v[23588]=0;W(219,b|0,j|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break s}}Nf(d+48|0);continue}break}c=P()|0;O()|0;break j}D=d,E=Fb(v[d+200>>2]),v[D+160>>2]=E;q=a+484344|0;A=c&1;s=a+484360|0;C=Fb(v[d+204>>2]);l=a+484376|0;p=a+480190|0;y=a+484380|0;z=a+946304|0;c=1;m=1;while(1){t:{u:{v:{w:{x:{y:{b=v[d+160>>2];if(!Pb(b,C)){break y}if(!(c&1)){v[23588]=0;c=S(272,s|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break x}if(!c){break y}}Lc(Wb(v[a+484360>>2],w[l|0]));v[23588]=0;c=Q(621,b|0,d+232|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break w}if(!(c&!x[d+1318>>1])|v[d+1320>>2]-5>>>0<4294967292){break c}c=w[l|0];f=v[a+484360>>2];v[23588]=0;U(5,d+48|0,5,d+232|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}v[23588]=0;R(273,Wb(f,c)|0,d+48|0);c=v[23588];v[23588]=0;if((c|0)==1){break l}Ab(d+48|0);z:{if(A){v[23588]=0;U(190,d+48|0,b|0,v[d+1328>>2]);b=v[23588];v[23588]=0;if((b|0)==1){break m}b=d+48|0;kc(d+136|0,b);break z}v[23588]=0;b=S(174,d+112|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break n}c=JD(d+48|0,b);kc(d+136|0,c);Bb(c)}Bb(b);Ub(d+48|0,0,64);c=1;A:{B:{C:{while(1){if((c|0)==32){break C}b=(B(c,34)+d|0)+198|0;f=b+32|0;Vm(d,f);D:{E:{if(xj(w[v[d>>2]])){break E}e=w[b- -64|0];if(e>>>0>15){break B}b=w[b+65|0];if(b>>>0>64){break B}if(!Xt(f)){break B}j=b<<2;i=e<<4;f=0;b=1;F:{while(1){g=b&65535;e=x[p>>1];if(g>>>0>e>>>0){break F}v[23588]=0;U(524,d+16|0,v[d>>2],v[d+4>>2]);e=v[23588];v[23588]=0;if((e|0)==1){break D}e=kb-16|0;kb=e;k=d+16|0;Ge(e+8|0,k);ER(e,((g<<5)+a|0)+946304|0);h=v[e+8>>2];r=v[e>>2];n=v[e+12>>2];o=v[e+4>>2];if((n|0)==(o|0)){h=(kT(h,n,r,o)|0)!=0}else{h=1}kb=e+16|0;zb(k);G:{H:{if(h){break H}D=dc(d+48|0,c),E=b,u[D>>1]=E;e=B(g,104)+a|0;g=e+484410|0;h=x[g>>1];if((h|0)==255){break G}f=b;if(w[e+484417|0]!=(i&255)){break H}if((h|0)==(j|0)){break G}}b=b+1|0;continue}break}t[e+484417|0]=i;u[g>>1]=j;break E}f=f&65535;if(!f){break E}if(!Yh(e)){break E}b=e+1|0;u[p>>1]=b;D=dc(d+48|0,c),E=b,u[D>>1]=E;b=B(x[p>>1],104)+y|0;Em(b);e=B(f,104)+y|0;g=ko(b,e);u[b+30>>1]=j;t[b+37|0]=i;yS(g,e);f=(f<<5)+z|0;e=v[f+4>>2];b=(x[p>>1]<<5)+z|0;v[b>>2]=v[f>>2];v[b+4>>2]=e;e=v[f+28>>2];v[b+24>>2]=v[f+24>>2];v[b+28>>2]=e;e=v[f+20>>2];v[b+16>>2]=v[f+16>>2];v[b+20>>2]=e;e=v[f+12>>2];v[b+8>>2]=v[f+8>>2];v[b+12>>2]=e}c=c+1|0;continue}break}break v}i=0;v[d+40>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;e=64;j=65535;r=x[d+1320>>1];f=0;I:while(1){J:{if(f){break J}v[23588]=0;b=W(156,v[d+136>>2],v[d+144>>2],1)|0;c=v[23588];v[23588]=0;if((c|0)==1){break A}if(b){break J}b=j;break u}e=e+1|0;if(e>>>0>=64){v[23588]=0;j=Q(359,q|0,64)|0;b=v[23588];v[23588]=0;if((b|0)==1){break A}b=65535;if((j|0)==65535){break u}b=w[l|0];c=v[a+484360>>2];e=0;v[23588]=0;R(522,Wb(c,b)|0,j|0);b=v[23588];v[23588]=0;if((b|0)==1){break A}}b=0;c=Zb(v[q>>2],j&65535);c=jd(v[c>>2],v[v[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(r|0)){continue I}g=(d+16|0)+B(b,7)|0;h=w[g+6|0];K:{if(h){t[g+6|0]=h-1;h=w[g+4|0]|w[g+5|0]<<8;t[c+4|0]=h;t[c+5|0]=h>>>8;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c|0]=g;t[c+1|0]=g>>>8;t[c+2|0]=g>>>16;t[c+3|0]=g>>>24;f=f-1|0;break K}v[23588]=0;h=W(156,v[d+136>>2],v[d+144>>2],1)|0;k=v[23588];v[23588]=0;if((k|0)==1){break v}if(!h){break K}if(v[d+144>>2]==v[d+1324>>2]){i=Wb(v[a+484360>>2],w[l|0]);Ve(i,CB(v[i>>2],v[i+4>>2]));i=e}v[23588]=0;h=S(206,d+136|0)|0;k=v[23588];v[23588]=0;L:{if((k|0)!=1){h=h<<24>>24;if((h|0)>=0){break L}h=h&127;t[g+6|0]=h;k=w[g+4|0]|w[g+5|0]<<8;t[c+4|0]=k;t[c+5|0]=k>>>8;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c|0]=g;t[c+1|0]=g>>>8;t[c+2|0]=g>>>16;t[c+3|0]=g>>>24;f=f+h|0;break K}break v}if((h-1&255)>>>0<=35){t[c|0]=h+48}v[23588]=0;h=S(206,d+136|0)|0;k=v[23588];v[23588]=0;M:{N:{if((k|0)!=1){D=c,E=w[dc(d+48|0,h&31)|0],t[D+1|0]=E;if(!(h&128)){break N}t[c+3|0]=w[g+3|0];t[c+5|0]=w[g+5|0];break M}break v}v[23588]=0;R(260,d|0,d+136|0);h=v[23588];v[23588]=0;O:{if((h|0)!=1){h=w[d|0];if(h>>>0>19){break M}n=h<<1;o=w[n+26944|0];t[c+3|0]=o;k=w[Oc(d)|0];t[c+5|0]=k;if((o|0)!=16|k>>>0<32){break O}t[c+3|0]=17;break M}break v}if(819137>>>h&1){break M}t[c+5|0]=w[n+26945|0]|k&15}h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[g|0]=h;t[g+1|0]=h>>>8;t[g+2|0]=h>>>16;t[g+3|0]=h>>>24;h=w[c+4|0]|w[c+5|0]<<8;t[g+4|0]=h;t[g+5|0]=h>>>8}c=c+6|0;b=b+1|0;continue}}}m=0;break t}break v}Gj(s,0);v[23588]=0;b=Q(1,d+232|0,6470)|0;c=v[23588];v[23588]=0;P:{if((c|0)!=1){Jb(a+1298344|0,b);Ab(b);v[23588]=0;b=Q(1,d+48|0,6772)|0;c=v[23588];v[23588]=0;if((c|0)==1){break P}Jb(a+1298356|0,b);Ab(b);v[a+1298404>>2]=5;m=1;break b}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;Bb(d+136|0);break j}Q:{if(!i&e>>>0>62){break Q}b=b&65535;if((b|0)==65535){break Q}Ae(Zb(v[q>>2],b),Fh(Ue(Oe(d,14,i&255),e)))}c=32}Bb(d+136|0);if(c>>>0<32){break b}Nf(d+160|0);c=0;continue}}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;Ab(d+48|0);break j}c=P()|0;O()|0}Vc(d+184|0)}Vc(d+200|0)}Zd(d+216|0)}T(c|0);L()}m=0}Vc(d+184|0);Vc(d+200|0);Zd(d+216|0)}kb=d+1344|0;return m|0}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,S=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=kb-336|0;kb=d;a:{if(!dd(b,1080)){break a}if(!oo(b,d+332|0)){break a}Bd(a,1);m=lS(d+312|0);if(!kS(d+332|0,m)){break a}f=x[m+10>>1];if(!f|f>>>0>127){break a}if(!c){g=1;break a}r=a+480188|0;u[r>>1]=f;p=w[m+14|0];E=w[m+13|0];h=w[m+12|0];F=1;if(!oe(d+332|0,26874)){F=oe(d+332|0,26879)}if(w[m+15|0]){Ob(a+1074312|0,5,1);f=x[a+480188>>1]}g=d+332|0;s=oe(g,16692);e=1;if(!oe(g,17456)){e=oe(d+332|0,13500)}z=(f&65535)==8&(E|0)!=0;dd(b,0);OA(b,a+1298308|0,20);u[a+480190>>1]=31;l=(h|0)!=0;q=a+480188|0;g=1;f=s;while(1)if((g|0)==32){b:{c:{d:{e:{f:{g:{N=v[m+4>>2];if(N>>>0>=G>>>0){h=d+176|0;fS(b,h);dd(b,x[m+8>>1]);g=w[d+177|0];e=128;j=a+484376|0;Iq(Wb(v[a+484360>>2],w[j|0]),h|2,128);h=!g&f;k=h?k:0;f=w[d+176|0];h:{if(f>>>0>128){break h}e=f;if(f){break h}f=v[Wb(v[a+484360>>2],w[a+484376|0])>>2];g=128;while(1){e=g;if(e>>>0<2){e=1;break h}g=e-1|0;if(!x[dc(f,g)>>1]){continue}break}}o=eS(b,Wb(v[a+484360>>2],w[j|0]),e&65535,i,r,k,0);H=1;i:{if(!(h&x[a+480188>>1]==8)){H=(p|0)!=0;break i}v[m>>2]=11183}j:{if(!z){break j}f=Wb(v[a+484360>>2],w[a+484376|0]);aa=d,ba=Fb(v[f>>2]),v[aa+160>>2]=ba;h=Fb(v[f+4>>2]);while(1){f=v[d+160>>2];if(!Pb(f,h)){break j}u[f>>1]=x[f>>1]>>>1;Se(d+160|0);continue}}f=a+484376|0;Ve(Wb(v[a+484360>>2],w[f|0]),w[d+177|0]);Q=e-1|0;e=w[d+177|0];k:{if((Q&65535)>>>0>=e>>>0){g=x[r>>1];if((e|0)!=120|(g|0)!=4){break k}}Ve(Wb(v[a+484360>>2],w[f|0]),0);g=x[a+480188>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;k=0;v[a+480208>>2]=0;aa=a,ba=Yb(256/((g&65535)>>>0)|0,32,128),v[aa+480228>>2]=ba;oh(a,0);t[d+175|0]=0;l:{if(l&1){p=1;e=1;break l}p=1;e=0;l=0;h=s;m:while(1){n:{q=0;if(o>>>0<=(l&65535)>>>0){break n}g=0;while(1)if((g|0)==256){l=l+1|0;continue m}else{f=d+144|0;j=ug(d+160|0);Iu(f,b,j);i=Oc(f);n=gB(w[j|0]);o:{p:{q:{r:{j=w[d+144|0];if((j-7&255)>>>0<3){h=0;break r}f=w[i|0];if(!((j|0)!=14|f>>>0<=1)){h=0;break q}if(!((j|0)==15&(f&255)>>>0>31)){h=n?h:0;if((j|0)!=13){break r}q=q+1|0;if((q&65535)>>>0<2){break o}}h=0;break o}if((j|0)==8){break p}if((j|0)!=14){break o}f=w[i|0]}if((f&240)!=128){break o}t[d+80|0]=f<<4;aa=d,ba=w[kf(d+175|0,d+80|0)|0],t[aa+175|0]=ba;break o}aa=d,ba=w[kf(d+175|0,i)|0],t[aa+175|0]=ba;f=t[i|0];if((f|0)>=0){k=1;break o}e=(f|0)!=-92&f>>>0>4294967183|e}p=n&p;g=g+1|0;continue}}break}f=k^-1;k=0;k=(e|f)&1?k:w[d+175|0]>47;e=h&1}j=e;dd(b,x[m+8>>1]);e=x[a+480188>>1];n=a+484344|0;I=o+z&65535;xg(n,I);R=z?4:e;o=a+1074312|0;_=k^1;$=c&1;l=0;k=0;s:{t:{u:{while(1){if((l|0)==(I|0)){break t}v:{if(z){e=(l&65534)>>>1|0;f=l&1;if(!f){if(!ph(n,e,64)){break t}}g=Zb(v[n>>2],e);e=f<<2;break v}if(!ph(n,l&65535,64)){break t}g=Zb(v[n>>2],l);e=0}h=0;q=jd(v[g>>2],v[v[g+48>>2]+12>>2],0,e);if(!$){J=0;K=0;break s}e=x[r>>1];t[d+80|0]=0;f=e;e=d+80|0;C=Pm(d+160|0,f,e);f=x[r>>1];v[23588]=0;t[d+80|0]=0;D=W(577,d+144|0,f|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){M=0;w:{x:while(1){y:{if((M|0)==64){break w}g=0;f=0;S=0;while(1){if((g|0)==(R|0)){M=M+1|0;J=f&S|J;q=B(x[r>>1],6)+q|0;continue x}v[23588]=0;h=B(g,6)+q|0;U(578,d+80|0,b|0,h|0);e=v[23588];v[23588]=0;if((e|0)!=1){e=w[d+80|0];y=Oc(d+80|0);i=w[y|0];if(e|i){z:{if(!(!E|(e&255)!=14)){e=0;t[y|0]=0;t[d+80|0]=0;i=w[y|0];break z}if(!E|(e&255)!=15|(i&255)>>>0<32){break z}i=31;t[y|0]=31;e=w[d+80|0]}Pf(h,e&255,i&255)}e=1;A:{B:{C:{D:{E:{i=w[h+3|0];switch(i-14|0){case 2:break A;case 0:break D;case 3:break E;default:break C}}k=w[h+5|0]<100|k;S=1;break B}if(!j){break B}t[h+5|0]=0;break B}if(!((i|0)!=9|_)){e=w[h+5|0];if((e|0)==164){t[h+3|0]=20;t[h+5|0]=145;break B}aa=h,ba=tg(e<<1),t[aa+5|0]=ba;break B}if((i|0)!=19){break B}e=w[h+5|0];if(e>>>0>15){break B}i=e&1;e=!i;y=!i;i=V&1;V=(i|0)==(e|0)?V:y;K=((e|0)!=(i|0))+K|0}e=f}F:{if(!w[h|0]){f=w[h+1|0];if(!f|z){break F}i=w[Lb(v[C>>2],g)|0];if(!i|(f|0)==(i|0)){break F}i=Lb(v[D>>2],g);f=w[i|0]+1|0;t[i|0]=f;if((f&255)>>>0<4){break F}v[23588]=0;W(264,o|0,85,1)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break F}break y}aa=Lb(v[D>>2],g),ba=0,t[aa|0]=ba}f=w[h+1|0];if(f){aa=Lb(v[C>>2],g),ba=f,t[aa|0]=ba}g=g+1|0;f=e;continue}break}}break}f=P()|0;O()|0;ic(D);break u}ic(D);ic(C);l=l+1|0;continue}break}f=P()|0;O()|0}ic(C);break b}h=k}G:{H:{I:{if((p^-1|X)&1){break I}J:{if(oe(d+332|0,16692)){break J}if(oe(d+332|0,17461)){break J}if(!oe(d+332|0,13490)){break I}}v[a+480208>>2]=v[a+480208>>2]|2162688;e=Ob(Ob(Ob(o,85,1),91,1),92,1);K:{if(w[d+175|0]>47){break K}e=Ob(e,84,1);if(w[d+177|0]==127){break K}Ob(e,83,1)}if(!(p&1)){break G}break H}if(p&1){break H}if(s^1|w[d+177|0]!=127|(Q&65535)>>>0>128){break G}v[m>>2]=8454;break G}if((K|0)>6|H){break G}v[a+480208>>2]=v[a+480208>>2]|8388608}if((s|H)==1){Ob(o,89,1)}if(F){Ob(o,84,1)}L:{if(!(c&2)){break L}dd(b,x[m+8>>1]+(B(I,R)<<8)|0);f=(p&s^1|Y)&1;g=1;while(1){if((g|0)==32){break L}k=B(g,104)+a|0;c=k+484380|0;e=v[c>>2];if(e){i=2;if(!F){i=dS(b,13799)?10:0;e=v[c>>2]}j=_c(d+160|0,8,1,0,i);e=QA(j,e)+v[b+8>>2]|0;if(!f){aa=c,ba=v[Zc(c,k+484388|0)>>2],v[aa>>2]=ba}wg(j,c,b);dd(b,e)}g=g+1|0;continue}}M:{if((h&s^-1|J)&1){break M}b=cS(d+120|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;b=d+160|0;_t(b,a,0,d+24|0);Z=A[v[d+160>>2]>>3];Ei(b);if(!(Z>=480)){break M}c=Ob(o,5,1);b=bS(d+96|0,Z);e=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=e;e=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=d+160|0;_t(b,a,0,d);e=w[v[d+160>>2]+26|0];Ei(b);if(e){_f(c,5);break M}v[m>>2]=17044}b=d+332|0;e=b;f=jc(b);c=b;while(1){if((e|0)!=(f|0)){h=w[e|0];t[c|0]=h>>>0>32?h:32;c=c+1|0;e=e+1|0;continue}break}Sf(d+80|0,16797);v[23588]=0;b=W(579,d+48|0,b|0,f|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break g}v[23588]=0;U(11,d- -64|0,1,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}v[23588]=0;U(145,d+160|0,d+80|0,d- -64|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}c=d+160|0;Jb(a+1298344|0,c);Ab(c);Ab(d- -64|0);zb(b);bc(d+80|0);b=yc(c,12238);Jb(a+1298356|0,b);Ab(b);b=v[m>>2];if(b){Rl(a+1298368|0,b)}v[a+1298404>>2]=14}g=G>>>0<=N>>>0;break a}f=P()|0;O()|0;break c}f=P()|0;O()|0;break d}f=P()|0;O()|0;Ab(d- -64|0)}zb(b)}bc(d+80|0)}T(f|0);L()}else{j=B(g,104)+a|0;h=j+484380|0;o=jA(b,d+176|0,h,((g<<5)+a|0)+946304|0,x[q>>1]==4);h=v[h>>2];N:{if(e){t[j+484417|0]=0-(w[d+200|0]<<3);break N}l=h>>>0<65536&l}j=Ib(x[d+198>>1]);O:{if(j){X=!Ib(x[d+204>>1])|X;break O}Y=w[d+201|0]==64|Y}n=f&1;f=0;P:{if(!n){break P}k=(j<<1)+k|0;n=w[d+200|0];f=!n;if(n|!j){break P}f=w[d+201|0]==64}G=o+G|0;i=h+i|0;g=g+1|0;continue}}kb=d+336|0;return g|0}function u7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=0,u=0,x=C(0),y=C(0),A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=C(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=C(0),Z=0,_=0,$=C(0);a:{if(!w[a+5046|0]){break a}g=z[a+4268>>2];IK(a);if(g==z[a+4268>>2]){break a}Ex(a)}b:{if(!w[a+5045|0]){break b}if(!ai(a+44|0)){break b}i=v[a+44>>2];p=Kc(i,0);q=Kc(i,1);i=v[a+56>>2];l=Kc(i,0);m=Kc(i,1);c:{if(!(!w[a+5044|0]|(!d|w[a+4264|0]&2))){z[l>>2]=z[a+5036>>2];z[m>>2]=z[a+5040>>2];t[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;u=a+4864|0;U=a+4504|0;V=a+4960|0;W=a+4868|0;X=a+4892|0;D=a+4628|0;E=a+4604|0;Q=a+4916|0;F=a+4532|0;G=a+4508|0;H=a+4772|0;I=a+4748|0;R=a+4940|0;J=a+4676|0;K=a+4652|0;L=a+4724|0;M=a+4700|0;S=a+4844|0;N=a+4580|0;O=a+4556|0;T=a+4820|0;d:{while(1){if(!r){break d}g=z[p>>2];g=C(C(C(z[a+5008>>2]-g)*z[a+4276>>2])+g);z[a+5008>>2]=g;_=Pc(v[a+4864>>2],v[W>>2],v[a+4880>>2]),$=g,z[_>>2]=$;g=z[q>>2];g=C(C(C(z[a+5012>>2]-g)*z[a+4276>>2])+g);z[a+5012>>2]=g;_=Pc(v[a+4888>>2],v[X>>2],v[a+4904>>2]),$=g,z[_>>2]=$;g=C(C(C(C(C(Qh(u,v[a+4356>>2])*C(.6800000071525574))+C(Qh(u,v[a+4360>>2])*C(-.5)))-C(Qh(u,v[a+4364>>2])*C(.6200000047683716)))+C(Qh(u,v[a+4368>>2])*C(-.5)))-C(Qh(u,v[a+4372>>2])*C(.6200000047683716)));if(t[a+4264|0]&1){e=g;g=C(z[Pc(v[a+4816>>2],v[T>>2],v[a+4836>>2])>>2]+C(e*C(.6180340051651001)));_=Pc(v[a+4816>>2],v[T>>2],v[a+4832>>2]),$=C(e-C(g*C(.6180340051651001))),z[_>>2]=$}x=z[a+4280>>2];_=a,$=C(Qh(u,v[a+4352>>2])+z[a+5020>>2]),z[_+5020>>2]=$;e=C(Qh(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=e;f=z[a+5020>>2];h=C(C(C(z[a+4980>>2]-z[Pc(v[a+4624>>2],v[D>>2],v[a+4644>>2])>>2])*z[a+4444>>2])+z[Pc(v[a+4624>>2],v[D>>2],v[a+4644>>2])>>2]);z[a+4980>>2]=h;P=C(h*z[a+4440>>2]);k=C(e*C(.7070000171661377));j=C(f*C(-.7070000171661377));f=C(k+j);h=z[a+4272>>2];e=C(P+C(f*h));_=Pc(v[a+4624>>2],v[D>>2],v[a+4640>>2]),$=C(f-C(h*e)),z[_>>2]=$;f=C(C(C(z[a+4976>>2]-z[Pc(v[a+4600>>2],v[E>>2],v[a+4620>>2])>>2])*z[a+4436>>2])+z[Pc(v[a+4600>>2],v[E>>2],v[a+4620>>2])>>2]);z[a+4976>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4432>>2])+C(e*h));_=Pc(v[a+4600>>2],v[E>>2],v[a+4616>>2]),$=C(e-C(h*f)),z[_>>2]=$;y=C(C(e*C(-.15000000596046448))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){e=C(C(C(z[a+4972>>2]-z[Pc(v[a+4576>>2],v[N>>2],v[a+4596>>2])>>2])*z[a+4428>>2])+z[Pc(v[a+4576>>2],v[N>>2],v[a+4596>>2])>>2]);z[a+4972>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4424>>2])+C(f*h));_=Pc(v[a+4576>>2],v[N>>2],v[a+4592>>2]),$=C(f-C(h*e)),z[_>>2]=$;f=C(C(C(z[a+4968>>2]-z[Pc(v[a+4552>>2],v[O>>2],v[a+4572>>2])>>2])*z[a+4420>>2])+z[Pc(v[a+4552>>2],v[O>>2],v[a+4572>>2])>>2]);z[a+4968>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4416>>2])+C(e*h));_=Pc(v[a+4552>>2],v[O>>2],v[a+4568>>2]),$=C(e-C(h*f)),z[_>>2]=$;y=C(C(C(e*C(.3499999940395355))+y)+C(f*C(-.3799999952316284)))}_=Pc(v[a+4912>>2],v[Q>>2],v[a+4928>>2]),$=f,z[_>>2]=$;e=C(z[Pc(v[a+4912>>2],v[Q>>2],v[a+4932>>2])>>2]*z[a+4496>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-e)*z[a+4500>>2])+e;e=C(C(C(z[a+4964>>2]-z[Pc(v[a+4528>>2],v[F>>2],v[a+4548>>2])>>2])*z[a+4412>>2])+z[Pc(v[a+4528>>2],v[F>>2],v[a+4548>>2])>>2]);z[a+4964>>2]=e;f=z[a+5028>>2];o=z[a+4272>>2];h=C(C(f*o)+C(e*z[a+4408>>2]));_=Pc(v[a+4528>>2],v[F>>2],v[a+4544>>2]),$=C(f-C(o*h)),z[_>>2]=$;e=C(C(C(z[a+4960>>2]-z[Pc(v[a+4504>>2],v[G>>2],v[a+4524>>2])>>2])*z[a+4404>>2])+z[Pc(v[a+4504>>2],v[G>>2],v[a+4524>>2])>>2]);z[a+4960>>2]=e;f=C(e*z[a+4400>>2]);e=z[a+4272>>2];o=C(f+C(h*e));_=Pc(v[a+4504>>2],v[G>>2],v[a+4520>>2]),$=C(h-C(e*o)),z[_>>2]=$;z[a+5020>>2]=o;e=C(C(C(C(C(Qh(s,v[a+4380>>2])*C(.7070000171661377))+C(Qh(s,v[a+4384>>2])*C(-.6000000238418579)))-C(Qh(s,v[a+4388>>2])*C(.5)))+C(Qh(s,v[a+4392>>2])*C(-.6000000238418579)))-C(Qh(s,v[a+4396>>2])*C(.5)));if(t[a+4264|0]&1){f=e;e=C(z[Pc(v[a+4840>>2],v[S>>2],v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));_=Pc(v[a+4840>>2],v[S>>2],v[a+4856>>2]),$=C(f-C(e*C(.6180340051651001))),z[_>>2]=$}Y=z[a+4280>>2];f=C(C(C(z[a+5004>>2]-z[Pc(v[a+4768>>2],v[H>>2],v[a+4788>>2])>>2])*z[a+4492>>2])+z[Pc(v[a+4768>>2],v[H>>2],v[a+4788>>2])>>2]);z[a+5004>>2]=f;P=C(f*z[a+4488>>2]);f=C(j-k);j=z[a+4272>>2];k=C(P+C(f*j));_=Pc(v[a+4768>>2],v[H>>2],v[a+4784>>2]),$=C(f-C(j*k)),z[_>>2]=$;f=C(C(C(z[a+5e3>>2]-z[Pc(v[a+4744>>2],v[I>>2],v[a+4764>>2])>>2])*z[a+4484>>2])+z[Pc(v[a+4744>>2],v[I>>2],v[a+4764>>2])>>2]);z[a+5e3>>2]=f;j=z[a+4272>>2];f=C(C(f*z[a+4480>>2])+C(k*j));_=Pc(v[a+4744>>2],v[I>>2],v[a+4760>>2]),$=C(k-C(j*f)),z[_>>2]=$;k=C(C(C(h*C(.3799999952316284))+C(k*C(-.15000000596046448)))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){h=C(C(C(z[a+4996>>2]-z[Pc(v[a+4720>>2],v[L>>2],v[a+4740>>2])>>2])*z[a+4476>>2])+z[Pc(v[a+4720>>2],v[L>>2],v[a+4740>>2])>>2]);z[a+4996>>2]=h;j=z[a+4272>>2];h=C(C(h*z[a+4472>>2])+C(f*j));_=Pc(v[a+4720>>2],v[L>>2],v[a+4736>>2]),$=C(f-C(j*h)),z[_>>2]=$;f=C(C(C(z[a+4992>>2]-z[Pc(v[a+4696>>2],v[M>>2],v[a+4716>>2])>>2])*z[a+4468>>2])+z[Pc(v[a+4696>>2],v[M>>2],v[a+4716>>2])>>2]);z[a+4992>>2]=f;j=z[a+4272>>2];f=C(C(f*z[a+4464>>2])+C(h*j));_=Pc(v[a+4696>>2],v[M>>2],v[a+4712>>2]),$=C(h-C(j*f)),z[_>>2]=$;k=C(C(C(h*C(.3499999940395355))+k)+C(f*C(-.3799999952316284)))}Z=q+4|0;n=p+4|0;h=C(g*x);y=C(y-C(o*C(.3799999952316284)));o=C(e*Y);_=Pc(v[a+4936>>2],v[R>>2],v[a+4952>>2]),$=f,z[_>>2]=$;g=C(z[Pc(v[a+4936>>2],v[R>>2],v[a+4956>>2])>>2]*z[a+4496>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-g)*z[a+4500>>2])+g;g=C(C(C(z[a+4988>>2]-z[Pc(v[a+4672>>2],v[J>>2],v[a+4692>>2])>>2])*z[a+4460>>2])+z[Pc(v[a+4672>>2],v[J>>2],v[a+4692>>2])>>2]);z[a+4988>>2]=g;e=z[a+5032>>2];f=z[a+4272>>2];g=C(C(e*f)+C(g*z[a+4456>>2]));_=Pc(v[a+4672>>2],v[J>>2],v[a+4688>>2]),$=C(e-C(f*g)),z[_>>2]=$;f=z[a+4284>>2];e=C(C(C(z[a+4984>>2]-z[Pc(v[a+4648>>2],v[K>>2],v[a+4668>>2])>>2])*z[a+4452>>2])+z[Pc(v[a+4648>>2],v[K>>2],v[a+4668>>2])>>2]);z[a+4984>>2]=e;x=z[a+4272>>2];e=C(C(e*z[a+4448>>2])+C(g*x));_=Pc(v[a+4648>>2],v[K>>2],v[a+4664>>2]),$=C(g-C(x*e)),z[_>>2]=$;z[a+5024>>2]=e;e=C(-e);x=z[a+4288>>2];i=U;e:{f:{while(1){if((i|0)==(V|0)){g:{e=C(o+C(C(C(e*C(.3799999952316284))+k)*x));g=C(h+C(C(C(g*C(.3799999952316284))+y)*f));if(!(w[a+4264|0]&2)){break g}p=n;n=Z;break f}}else{A=v[i+16>>2];B=A-1|0;v[i+16>>2]=B;if((A|0)<=0){v[i+16>>2]=B+v[i+12>>2]}A=v[i+20>>2];B=A-1|0;v[i+20>>2]=B;if((A|0)<=0){v[i+20>>2]=B+v[i+12>>2]}i=i+24|0;continue}break}z[l>>2]=C(g+z[a+5036>>2])*C(.5);z[m>>2]=C(e+z[a+5040>>2])*C(.5);z[a+5040>>2]=e;z[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;z[l>>2]=g;z[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}t[a+5044|0]=1}n=a;a=v[a+56>>2];si(n,b,c,Kc(a,0),Kc(a,1),d)}}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=kb-288|0;kb=g;e=kb-128|0;kb=e;f=ke(g+104|0,c);v[23588]=0;n=S(174,f+20|0)|0;c=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){v[23588]=0;p=S(174,f+40|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break B}v[23588]=0;q=S(174,f+60|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break A}v[23588]=0;i=S(174,f+80|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break z}v[23588]=0;o=S(174,f+100|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break y}v[23588]=0;k=S(174,f+120|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break x}j=Tb(f+140|0);zc(f);v[f+172>>2]=1873739776;u[f+176>>1]=0;v[23588]=0;d=Q(769,f|0,e+112|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break w}if(!d){break n}d=v[e+112>>2];if((d|0)!=1414744396&(d|0)!=1179011410){break n}c=v[e+120>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}t[f+176|0]=(d|0)==1414744396;v[23588]=0;U(770,e+96|0,f|0,2);c=v[23588];v[23588]=0;if((c|0)==1){break v}h=v[e+96>>2];C:{if(Kq(h,v[e+100>>2])>>>0<4){break C}c=by(h,1);d=v[c+4>>2];c=v[c>>2];Zh(e+40|0,c,d);if(v[e+40>>2]!=1635017060){break C}Zh(e- -64|0,c,d);if(!(t[e+68|0]&1)){break C}c=by(h,2);Zh(e+24|0,v[c>>2],v[c+4>>2]);if(v[e+28>>2]){break C}c=by(h,3);Zh(e+88|0,v[c>>2],v[c+4>>2]);if(v[e+88>>2]){break C}v[23588]=0;Q(155,f|0,12)|0;c=v[23588];v[23588]=0;if((c|0)==1){break u}v[23588]=0;U(770,e+40|0,f|0,1);c=v[23588];v[23588]=0;if((c|0)==1){break t}c=e+40|0;Ut(e+96|0,c);Zd(c)}v[23588]=0;U(771,e- -64|0,e+96|0,544501094);c=v[23588];v[23588]=0;if((c|0)==1){break s}v[23588]=0;d=Q(772,e- -64|0,f+156|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}if(!d){break o}d=x[f+156>>1];if((d|0)!=1){break q}v[23588]=0;d=S(202,e- -64|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break r}break k}d=P()|0;O()|0;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}if((d|0)==4){v[23588]=0;h=S(197,e- -64|0)|0;c=v[23588];v[23588]=0;D:{if((c|0)!=1){v[23588]=0;d=S(197,e- -64|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break D}if((h|0)!=2|(d|0)!=1){break p}t[f+177|0]=1;break p}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=x[f+156>>1]}if((d&65535)!=65534){break p}v[23588]=0;d=Q(773,e- -64|0,e+40|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break l}if(!d){break o}c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=e+24|0;v[c>>2]=w[e+8|0]|w[e+9|0]<<8|(w[e+10|0]<<16|w[e+11|0]<<24);u[c+4>>1]=w[e+12|0]|w[e+13|0]<<8;u[c+6>>1]=w[e+14|0]|w[e+15|0]<<8;r=c,s=pA(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24),w[e+20|0]|w[e+21|0]<<8|(w[e+22|0]<<16|w[e+23|0]<<24)),v[r+8>>2]=s;v[c+12>>2]=nb;u[f+172>>1]=v[c>>2]}v[23588]=0;U(771,e+40|0,e+96|0,1635017060);c=v[23588];v[23588]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=e+40|0;m=hd(n,c);Bb(c);c=v[m>>2];v[23588]=0;d=S(178,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}if(!d){v[23588]=0;U(771,e+40|0,e+96|0,544039792);c=v[23588];v[23588]=0;if((c|0)==1){break J}c=e+40|0;hd(m,c);Bb(c)}v[23588]=0;U(771,e+40|0,e+96|0,1952670054);c=v[23588];v[23588]=0;if((c|0)==1){break I}v[23588]=0;d=S(157,e+40|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break H}v[f+152>>2]=d;Bb(e+40|0);if(v[f+152>>2]?x[f+156>>1]==17:0){break E}h=x[f+158>>1];d=gM(h,x[f+170>>1]);if(!d){break E}c=x[f+168>>1];if((c>>>0)/(h>>>0)>>>0<d<<1>>>0?c:0){break G}c=v[m>>2];v[23588]=0;d=S(160,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}c=gM(x[f+158>>1],x[f+170>>1]);break F}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;Bb(e+40|0);break j}c=v[m>>2];v[23588]=0;d=S(160,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}c=x[f+168>>1]}v[f+152>>2]=(d>>>0)/((c&65535)>>>0)}v[23588]=0;d=Q(774,f|0,e+96|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}u[f+174>>1]=d;v[23588]=0;R(775,f|0,e+96|0);c=v[23588];v[23588]=0;if((c|0)==1){break k}v[23588]=0;U(771,e+40|0,e+96|0,1886221175);c=v[23588];v[23588]=0;if((c|0)==1){break m}c=e+40|0;hd(o,c);Bb(c)}Bb(e- -64|0);Zd(e+96|0)}kb=e+128|0;break a}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0}Bb(e- -64|0)}Zd(e+96|0)}Zd(j);Bb(k)}Bb(o)}Bb(i)}Bb(q)}Bb(p)}Bb(n)}Bb(f);T(d|0);L()}c=v[f+20>>2];v[23588]=0;d=S(714,c|0)|0;c=v[23588];v[23588]=0;K:{L:{if((c|0)!=1){M:{if(!d|(x[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=x[f+170>>1];P:{if(!c){if((lk(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((lk(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}d=lk(f);c=30240;while(1){Q:{R:{if((c|0)!=30264){if((d|0)!=v[c>>2]){break R}}else{c=30264}break Q}c=c+4|0;continue}break}if((c|0)==30264){break M}st(a,b);v[23588]=0;d=Q(55,g+88|0,21619)|0;c=v[23588];v[23588]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=Dc(((b<<5)+a|0)+946304|0,d);zb(d);v[23588]=0;d=B(b,104)+a|0;i=d+484380|0;R(277,i|0,0);c=v[23588];v[23588]=0;if((c|0)==1){break W}v[i>>2]=v[f+152>>2];v[d+484404>>2]=v[f+160>>2];c=v[a+1298404>>2];v[23588]=0;X(715,f|0,i|0,c|0,h|0);c=v[23588];v[23588]=0;if((c|0)==1){break W}ke(g- -64|0,f+20|0);d=x[f+158>>1];j=_c(g+56|0,8,d>>>0>1?2:1,0,0);c=lk(f);if((c|0)!=17|d>>>0>2){break U}xc(i,268435456);c=B(b,104)+a|0;b=c+484414|0;u[b>>1]=x[b>>1]&65470|((d|0)==2)<<6|1;if(Og(i)){break V}break S}l=P()|0;O()|0;break K}l=P()|0;O()|0;break K}j=v[c+484400>>2];h=v[i>>2];k=ke(g+32|0,g- -64|0);d=x[f+158>>1];c=x[f+168>>1];v[23588]=0;b=v[k+12>>2];v[g+16>>2]=v[k+8>>2];v[g+20>>2]=b;v[g+24>>2]=v[k+16>>2];b=v[k+4>>2];v[g+8>>2]=v[k>>2];v[g+12>>2]=b;da(716,j|0,h|0,g+8|0,c|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break L}uj(i,a);break T}if((c|0)==85){v[23588]=0;c=W(559,a|0,b|0,g- -64|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(WP(x[f+156>>1])){break Z}_:{if(!Qd(w[f+177|0])){break _}if((lk(f)|0)!=1|x[f+170>>1]!=32|x[f+168>>1]!=d<<2){break _}xd(j,32);b=12;break Y}if((lk(f)|0)!=1|x[f+170>>1]!=24|x[f+168>>1]!=d<<2){break Z}xd(j,32);b=13;break Y}if((lk(f)&65534)!=6){break X}xd(j,16);b=(lk(f)|0)==6?17:16}dg(j,b);v[23588]=0;W(219,j|0,i|0,g- -64|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break T}break L}d=x[f+170>>1];c=(d-1>>>3|0)-1|0;b=c<<3;h=b&31;xd(j,(c>>>0<7?(b&63)>>>0>=32?4196360>>>h|0:((1<<h)-1&4196360)<<32-h|136321040>>>h:8)&255);if(d>>>0<9){dg(j,1)}if((lk(f)|0)==3){dg(j,3)}v[23588]=0;W(219,j|0,i|0,g- -64|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break L}}Dz(i,v[a+480180>>2]);uj(i,a);l=1}Bb(g- -64|0)}VP(f);kb=g+288|0;return l|0}l=P()|0;O()|0;break K}l=P()|0;O()|0;Bb(g- -64|0)}VP(f);T(l|0);L()}
function ZI(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=kb-272|0;kb=h;a:{b:{if(g){pf(h+256|0,f,32);v[23588]=0;W(527,h+240|0,f|0,32)|0;k=v[23588];v[23588]=0;if((k|0)!=1){break b}f=P()|0;O()|0;break a}Mb(h+256|0);Mb(h+240|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(ts(c)){k=v[b+24>>2];i=v[k+484344>>2];if(ye(i,v[k+484348>>2],c&65535)){break j}}v[23588]=0;U(1085,a|0,h+256|0,h+240|0);a=v[23588];v[23588]=0;if((a|0)!=1){break i}f=P()|0;O()|0;break c}c=Zb(i,c);if(!(!((e|0)<0|v[c+12>>2]<=(d|0)|(d|0)<0)&x[k+480188>>1]>e>>>0)){v[23588]=0;U(1085,a|0,h+256|0,h+240|0);a=v[23588];v[23588]=0;if((a|0)!=1){break i}f=P()|0;O()|0;break c}c=jd(v[c>>2],v[v[c+48>>2]+12>>2],d,e&65535);$f(h+256|0);$f(h+240|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=w[c|0];if(!$c(d)){if(!Lp(d)){break A}}e=w[c+1|0];k=v[b+24>>2];v[23588]=0;X(1086,h+208|0,k|0,d|0,e|0);d=v[23588];v[23588]=0;e=1;if((d|0)==1){break y}v[23588]=0;R(1015,h+224|0,h+208|0);d=v[23588];v[23588]=0;if((d|0)!=1){break z}f=P()|0;O()|0;break v}e=0;v[23588]=0;Q(55,h+224|0,16730)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}}v[23588]=0;k=Q(800,h+256|0,h+224|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break w}zb(h+224|0);if(e){Ab(h+208|0)}e=9918;d=w[c|0];if(!$c(d)){e=Lp(d)?10228:16730}v[23588]=0;d=Q(55,h+224|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break u}v[23588]=0;e=Q(800,h+240|0,d|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break t}zb(d);if(f-6>>>0>4294967290){break l}v[23588]=0;d=Q(55,h+192|0,17790)|0;i=v[23588];v[23588]=0;if((i|0)==1){break s}v[23588]=0;i=Q(800,k|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break r}zb(d);v[23588]=0;d=Q(55,h+176|0,17790)|0;l=v[23588];v[23588]=0;if((l|0)==1){break q}v[23588]=0;l=Q(800,e|0,d|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break p}zb(d);d=c+1|0;B:{if(w[c+1|0]){v[23588]=0;R(544,h+160|0,d|0);j=v[23588];v[23588]=0;if((j|0)!=1){break B}break d}v[23588]=0;Q(55,h+160|0,16735)|0;j=v[23588];v[23588]=0;if((j|0)==1){break d}}v[23588]=0;j=Q(800,i|0,h+160|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break o}i=h+160|0;zb(i);d=w[d|0];v[23588]=0;d=Q(55,i|0,(d?10722:16735)|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break n}v[23588]=0;l=Q(800,l|0,d|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){break m}f=P()|0;O()|0;zb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(h+224|0);if(!e){break c}}Ab(h+208|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(d);break c}f=P()|0;O()|0;zb(h+160|0);break c}f=P()|0;O()|0;break c}zb(d);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{i=gh(w[c|0]);O:{if(i){v[23588]=0;m=Q(55,h+128|0,17790)|0;d=v[23588];v[23588]=0;if((d|0)==1){break N}d=w[c+4|0];n=w[c+2|0];v[23588]=0;o=h,p=hk(n,d)&255,v[o+96>>2]=p;R(543,h+112|0,h+96|0);d=v[23588];v[23588]=0;if((d|0)==1){break M}d=0;v[23588]=0;U(971,h+144|0,m|0,h+112|0);m=v[23588];v[23588]=0;if((m|0)!=1){break O}f=P()|0;O()|0;break G}d=w[c+2|0];if(d){d=_L(v[v[v[b+24>>2]+8>>2]+88>>2],d);v[23588]=0;d=W(527,h+128|0,1,d|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break E}v[23588]=0;R(544,h+112|0,c+4|0);m=v[23588];v[23588]=0;if((m|0)==1){break L}v[23588]=0;U(971,h+144|0,d|0,h+112|0);m=v[23588];v[23588]=0;d=1;if((m|0)!=1){break O}f=P()|0;O()|0;break J}d=0;v[23588]=0;Q(55,h+144|0,16734)|0;m=v[23588];v[23588]=0;if((m|0)==1){break e}}v[23588]=0;j=Q(800,j|0,h+144|0)|0;m=v[23588];v[23588]=0;if((m|0)==1){break K}zb(h+144|0);if(d){zb(h+112|0);zb(h+128|0)}if(i){zb(h+112|0);zb(h+128|0)}d=5491;if(!gh(w[c|0])){d=w[c+2|0]?5487:16734}v[23588]=0;d=Q(55,h+144|0,d|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break D}v[23588]=0;i=Q(800,l|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)!=1){break C}f=P()|0;O()|0;zb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break F}f=P()|0;O()|0;break I}f=P()|0;O()|0;zb(h+144|0);if(!d){break H}}zb(h+112|0)}zb(h+128|0)}if(!i){break c}}zb(h+112|0)}zb(h+128|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}zb(d);if(f-13>>>0>4294967283){break l}v[23588]=0;d=Q(55,h+96|0,17790)|0;l=v[23588];v[23588]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){v[23588]=0;l=Q(800,j|0,d|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break Z}zb(d);v[23588]=0;d=Q(55,h+80|0,17790)|0;j=v[23588];v[23588]=0;if((j|0)==1){break Y}v[23588]=0;i=Q(800,i|0,d|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break X}zb(d);_:{if(gh(w[c|0])){d=w[c+5|0];j=w[c+3|0];b=0;v[23588]=0;o=h,p=hk(j,d)&4095,v[o+16>>2]=p;R(1087,h- -64|0,h+16|0);d=v[23588];v[23588]=0;if((d|0)!=1){break _}f=P()|0;O()|0;break c}d=w[c+3|0];if(d){b=ZL(v[v[v[b+24>>2]+8>>2]+84>>2],d);v[23588]=0;b=W(527,h+48|0,1,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break W}v[23588]=0;R(544,h+32|0,c+5|0);d=v[23588];v[23588]=0;if((d|0)==1){break V}v[23588]=0;U(971,h- -64|0,b|0,h+32|0);d=v[23588];v[23588]=0;b=1;if((d|0)!=1){break _}f=P()|0;O()|0;break S}b=0;v[23588]=0;Q(55,h- -64|0,16730)|0;d=v[23588];v[23588]=0;if((d|0)==1){break U}}v[23588]=0;Q(800,l|0,h- -64|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break T}zb(h- -64|0);if(b){zb(h+32|0);zb(h+48|0)}b=11086;if(!gh(w[c|0])){b=w[c+3|0]?11086:16730}v[23588]=0;b=Q(55,h- -64|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break Q}v[23588]=0;Q(800,i|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break P}f=P()|0;O()|0;zb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break R}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(h- -64|0);if(!b){break c}}zb(h+32|0)}zb(h+48|0);break c}f=P()|0;O()|0;break c}zb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Hb(k);da:{if(b>>>0>f>>>0){v[23588]=0;X(130,h+16|0,k|0,0,f|0);b=v[23588];v[23588]=0;if((b|0)!=1){b=h+16|0;Bc(k,b);zb(b);break da}f=P()|0;O()|0;break c}if(!g){break da}v[23588]=0;b=W(527,h+16|0,f-b|0,32)|0;c=v[23588];v[23588]=0;if((c|0)==1){break ca}v[23588]=0;Q(800,k|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break ba}zb(b)}b=Hb(e);if(b>>>0<=f>>>0){break $}v[23588]=0;X(130,h|0,e|0,0,f|0);b=v[23588];v[23588]=0;if((b|0)==1){break aa}Bc(e,h);zb(h);break k}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(b);break c}f=P()|0;O()|0;break c}if(!g){break k}v[23588]=0;b=W(527,h|0,f-b|0,32)|0;c=v[23588];v[23588]=0;if((c|0)==1){break h}v[23588]=0;Q(800,e|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break g}zb(b)}v[23588]=0;U(1085,a|0,k|0,e|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}}zb(h+240|0);zb(h+256|0);kb=h+272|0;return}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}zb(h+240|0)}zb(h+256|0);T(f|0);L()}function Wfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=kb-304|0;kb=d;zc(b);a:{b:{c:{d:{if(!Wt(b,d+208|0)){break d}if(!zR(d+208|0)){break d}if(!Qb(v[b>>2],v[b+8>>2],Ec(yR(d+208|0),nb))){break d}if(!c){g=1;break d}if(!dd(b,w[d+212|0])){break d}Bd(a,268435456);ag(a);v[a+480208>>2]=4;Ob(a+1074312|0,114,1);f=d+88|0;i=yc(f,15284);Jb(a+1298344|0,i);Ab(i);i=yc(f,10232);Jb(a+1298356|0,i);Ab(i);v[a+1298404>>2]=5;i=d+16|0;qf(i,d+208|6,48,3);Fc(f,i);Bc(a+1298308|0,f);zb(f);f=w[d+262|0];u[a+480188>>1]=f+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];while(1){if((e|0)==(f|0)){e:{u[a+480190>>1]=w[d+300|0];f=x[d+302>>1];i=d+192|0;v[i>>2]=0;v[i+4>>2]=0;Hc(i+8|0);if(f){Bk(i,f);DA(i,f)}v[23588]=0;U(631,b|0,i|0,x[d+302>>1]);f=v[23588];v[23588]=0;if((f|0)==1){break b}z=Tb(d+176|0);r=Tb(d+160|0);v[23588]=0;W(409,b|0,z|0,w[d+301|0])|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}v[23588]=0;W(409,b|0,r|0,w[d+300|0])|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}p=c&2;s=d+126|0;n=d+88|6;f=0;f:{while(1){e=f;if(e>>>0>=w[d+300|0]){g=1;if(!(c&1)){break e}v[d+68>>2]=0;q=a+484376|0;Lc(Wb(v[a+484360>>2],w[q|0]));F=d,G=Fb(v[i>>2]),v[F+64>>2]=G;y=a+484344|0;C=Fb(v[i+4>>2]);D=a+484348|0;break f}v[23588]=0;f=e+1|0;h=B(f,104)+a|0;k=h+484380|0;R(277,k|0,0);g=v[23588];v[23588]=0;g:{if((g|0)!=1){g=Eb(v[r>>2],e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if(!g){continue}v[23588]=0;g=Q(155,b|0,g|0)|0;j=v[23588];v[23588]=0;h:{if((j|0)==1){break h}if(!g){continue}v[23588]=0;g=Q(632,b|0,d+88|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break h}if(!g){continue}g=d+72|0;Ne(g,2,n);v[23588]=0;R(222,d+16|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break c}g=d+16|0;Dc(((f<<5)+a|0)+946304|0,g);zb(g);j=d+72|0;uk(j,2,s);v[23588]=0;R(222,g|0,j|0);g=v[23588];v[23588]=0;if((g|0)==1){break c}g=d+16|0;Ce(h+484423|0,g);zb(g);g=w[d+138|0];if(g>>>0<=15){u[h+484408>>1]=B(g,17);g=h+484414|0;u[g>>1]=x[g>>1]|32}t[d+16|0]=w[d+139|0];t[d+72|0]=64;F=h+484412|0,G=w[Xb(d+16|0,d+72|0)|0],u[F>>1]=G;v[h+484404>>2]=w[d+141|0]|w[d+142|0]<<8;m=h+484384|0;g=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);v[m>>2]=g;q=h+484388|0;j=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[q>>2]=j;y=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);v[k>>2]=y;l=w[d+140|0];if(l&1){g=g>>>1|0;v[m>>2]=g;j=j>>>1|0;v[q>>2]=j;v[k>>2]=y>>>1}i:{if(g>>>0>=j>>>0){break i}h=h+484414|0;g=x[h>>1];u[h>>1]=g|2;if(!(l&2)){break i}u[h>>1]=g|6}Dk(k);if(!p){continue}e=Eb(v[r>>2],e);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[23588]=0;Q(155,b|0,e+w[d+92|0]|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break g}}break c}break c}e=_c(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[23588]=0;W(219,e|0,k|0,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){continue}break}break c}while(1){j:{k:{k=v[d+64>>2];if(!Pb(k,C)){b=v[d+68>>2];c=b&63;if(!c){break k}f=w[a+484376|0];e=v[a+484360>>2];v[23588]=0;b=b>>>6|0;f=Q(311,Wb(e,f)|0,b&65535)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if(!f){break k}b=x[dc(v[Wb(v[a+484360>>2],w[a+484376|0])>>2],b&65535)>>1];f=v[a+484344>>2];v[23588]=0;R(633,Zb(f,b)|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break k}}break c}c=w[k+3|0];if(w[k+2|0]>w[d+262|0]|c>>>0>=w[d+301|0]){break j}c=Eb(v[z>>2],c);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23588]=0;c=Q(155,b|0,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}if(!c){break j}v[23588]=0;R(634,b|0,d+88|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}e=w[d+92|0];if(!e){break j}f=w[k|0]|w[k+1|0]<<8;t[d+16|0]=w[d+93|0];t[d+72|0]=w[d+262|0]-w[k+2|0];j=w[Xb(d+16|0,d+72|0)|0];v[d+60>>2]=e+f;F=d,G=v[Zc(d+68|0,d+60|0)>>2],v[F+68>>2]=G;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;c=f&63;p=f>>>6|0;s=0;while(1){if((e&255)>>>0<=s>>>0){break j}e=Wb(v[a+484360>>2],w[q|0]);h=c>>>0>63;p=h+p|0;f=p&65535;if(Rc(v[e>>2],v[e+4>>2])>>>0<=f>>>0){v[23588]=0;R(324,e|0,p+1&65535);e=v[23588];v[23588]=0;if((e|0)==1){break c}v[23588]=0;n=Q(359,y|0,64)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}e=Wb(v[a+484360>>2],w[q|0]);F=dc(v[e>>2],f),G=n,u[F>>1]=G}m=v[a+484344>>2];o=v[D>>2];n=x[dc(v[e>>2],f)>>1];if(!ye(m,o,n)){break j}f=0;e=Zb(m,n);m=h?0:c;e=jd(v[e>>2],v[v[e+48>>2]+12>>2],m,w[k+2|0]);l:{while(1){if((f|0)==(j|0)){c=w[d+93|0];if(c>>>0<=j>>>0){break l}v[23588]=0;Q(188,b|0,B(c-j|0,5)|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break l}break c}v[23588]=0;R(635,d+72|0,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){c=d+72|0;h=Oc(c);E=Te(c);l=Mi(c);o=jc(c);c=w[d+72|0];A=c-1&255;m:{if(A>>>0<=142){c=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[e|0]=c;t[(d+16|0)+f|0]=c;break m}t[e|0]=0}c=w[h|0];t[e+2|0]=1;t[e+1|0]=c;c=w[E|0];n:{if((c|0)!=255){t[e+4|0]=c;break n}t[e+2|0]=0}c=w[l|0];o:{if(c>>>0>22){break o}t[e+3|0]=w[c+26992|0];h=w[o|0];t[e+5|0]=h;c=e+5|0;p:{switch(w[l|0]-4|0){case 3:t[c|0]=h&3|64;break o;case 4:t[c|0]=h&3|48;break o;case 7:l=v[i>>2];if(vc(l,v[i+4>>2])>>>0<=h>>>0){break o}o=c;c=Eb(l,h);c=w[c|0]|w[c+1|0]<<8;t[o|0]=c>>>6;h=Zb(v[a+484344>>2],n);h=jd(v[h>>2],v[v[h+48>>2]+12>>2],m,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break o;case 8:o=c;c=v[d+60>>2];t[o|0]=c>>>6;h=Zb(v[a+484344>>2],n);h=jd(v[h>>2],v[v[h+48>>2]+12>>2],m,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break o;case 10:t[c|0]=h&15|128;break o;case 12:t[d+15|0]=15;F=c,G=w[Xb(c,d+15|0)|0]|208,t[F|0]=G;break o;case 13:t[d+15|0]=15;F=c,G=w[Xb(c,d+15|0)|0]|192,t[F|0]=G;break o;case 14:t[d+15|0]=15;F=c,G=w[Xb(c,d+15|0)|0]|224,t[F|0]=G;break o;case 0:case 16:case 17:if(!(h&15)){break o}l=h&240;if(!l|(l|0)==240){break o}t[c|0]=h|15;break o;case 9:case 18:break p;default:break o}}if(A>>>0<143){break o}t[e|0]=w[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}c=m+1|0;s=s+1|0;e=w[d+92|0];continue}}a=Wb(v[a+484360>>2],w[a+484376|0]);F=d,G=Fb(v[a>>2]),v[F+88>>2]=G;b=Fb(v[a+4>>2]);c=65535;while(1){a=v[d+88>>2];if(!Pb(a,b)){break e}if(x[a>>1]==65535){q:{if((c&65535)!=65535){break q}v[23588]=0;c=Q(359,y|0,64)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break q}break c}u[a>>1]=c}Se(d+88|0);continue}}Le(d- -64|0);continue}}}else{u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;continue}break}wc(r);wc(z);wc(i)}kb=d+304|0;return g|0}a=P()|0;O()|0;wc(r);wc(z);break a}a=P()|0;O()|0}wc(i);T(a|0);L()}function MN(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=C(0),T=0,U=0,V=0,W=C(0),X=0;m=kb-48|0;kb=m;t[m+40|0]=0;h=b+223848|0;j=m+40|0;Si(h,Sh(e,xi(e,go(e),j))+1|0);se(j,v[h>>2],v[b+223852>>2]);h=kb-16|0;kb=h;t[h+15|0]=0;hc(m+32|0,e,Sh(e,xi(e,go(e),h+15|0)));kb=h+16|0;G=v[m+32>>2];H=v[m+36>>2];i=kb-16|0;kb=i;I=a+906300|0;r=a+1074312|0;n=B(c,872)+b|0;J=n+1415|0;K=n+1304|0;L=n+1392|0;D=n+1368|0;E=n+1364|0;M=n+1336|0;N=n+1308|0;O=n+1300|0;P=n+1280|0;Q=n+1402|0;p=n+1466|0;R=C(w[p|0]);S=C(f>>>0);F=n+616|0;l=v[n+1272>>2];T=a+480188|0;k=1;o=255;while(1){if((s|0)!=(H|0)&y[j+4>>2]>g>>>0){e=w[Lb(G,s)|0];h=e-48|0;a:{b:{c:{if((h&255)>>>0<=9){break c}if((e-65&255)>>>0<=5){h=e-55|0;break c}d:{e:{f:{switch(e-97|0){case 2:g:{e=Pl(a,b,c,3,0)-1|0;if((e&255)>>>0>249){break g}e=v[Md(I,e)>>2];if(!e){break g}e=Ky(e,47496,44552);if(!e){break g}h=ob[v[v[e>>2]+192>>2]](e,F,c)|0;e=(h|0)!=255;h=e?h:0;if(e|!l){break c}break d}if(l){break d}h=0;break c;case 21:Db(i+8|0,r,28);h:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){Db(i,r,1);e=0;if(!Cb(v[v[i>>2]>>2],v[i+4>>2])){break h}}e=u[L>>1]}h=B(v[D>>2],v[E>>2]);e=B(v[a+1074456>>2],e+v[K>>2]|0);e=Yb((Ic(Pka(Oka(h,h>>31,e,e>>31),nb,1048576,0),nb)|0)/2|0,1,127);break e;case 20:e=B(v[D>>2],v[E>>2]);h=e;A=e>>31;e=B(v[a+1074456>>2],v[M>>2]);e=Yb((Ic(Pka(Oka(h,A,e,e>>31),nb,67108864,0),nb)|0)/2|0,1,127);break e;case 23:v[i+8>>2]=v[N>>2]/2;v[i>>2]=127;e=v[td(i+8|0,i)>>2];break e;case 24:v[i+8>>2]=v[O>>2]/2;v[i>>2]=127;e=v[td(i+8|0,i)>>2];break e;case 0:e=0;if(!l){break e}h=x[l+28>>1];if(!h){break e}e=h-1>>>7&127;break e;case 1:e=0;if(!l){break e}h=x[l+28>>1];if(!h){break e}e=h-1&127;break e;case 14:e=v[P>>2]>>>8|0;break e;case 7:e=(x[T>>1]<=c>>>0?w[Q|0]-1|0:c)&127;break e;case 12:e=w[n+704|0]>>>7|0;break e;case 15:e=0;if(!l){break e}h=w[l+30|0];if(!h){break e}e=h-1&127;break e;case 25:i:{if(!d|t[p|0]<0){break i}j:{if(g>>>0<3){break j}e=v[j>>2];if(w[Lb(e,g-3|0)|0]!=240){break j}if(w[Lb(e,g-2|0)|0]>239){break i}}q=Rp(b,R,S);k:{if(q<C(4294967296)&q>=C(0)){e=~~q>>>0;break k}e=0}t[p|0]=e;o=128;break e}o=(o&255)==255?f:o;e=f;break e;case 18:l:{if(!g){h=0;break l}e=v[j>>2];h=g;while(1){h=h-1|0;A=Lb(e,h);if(!h){break l}if(w[A|0]!=240){continue}break}}if(g-h>>>0<5){break a}A=v[j>>2];if(w[Lb(A,h)|0]!=240){break a}h=h+5|0;e=0;while(1){if((g|0)!=(h|0)){e=w[Lb(A,h)|0]+e|0;h=h+1|0;continue}break};e=0-e&127;break e;case 13:break f;default:break a}}e=w[J|0];e=$c(e)?e-1|0:0}h=((k^-1)&1)+g|0;U=Lb(v[j>>2],h),V=e,t[U|0]=V;g=h+1|0;k=1;break b}e=x[F+786>>1];h=(e?e-1|0:c)&15;e=w[l+31|0];if((e|0)!=17){h=vj(e)?e-1&15:0}}e=Lb(v[j>>2],g);m:{if(k){t[e|0]=h;break m}t[e|0]=w[e|0]<<4|h;g=g+1|0}k=(k^-1)&1}}s=s+1|0;continue}else{if(o<<24>>24>=0){t[p|0]=o}gc(i+8|0,v[j>>2],((k^-1)&1)+g|0);e=v[i+12>>2];v[j>>2]=v[i+8>>2];v[j+4>>2]=e;kb=i+16|0}break}p=v[m+44>>2];h=0;n:while(1){n=0;while(1){e=h;o:{p:{q:{r:{while(1){if(y[m+44>>2]<=e>>>0){break o}f=v[m+40>>2];k=Lb(f,e);g=t[k|0];if((g|0)==-16){g=e;if(p-g>>>0>=4){h=4;if((w[Lb(f,e+1|0)|0]&254)==240){break p}}s:{while(1){g=g+1|0;if(p>>>0<=g>>>0){break s}if(w[Lb(f,g)|0]!=247){continue}break}h=(g-e|0)+1|0;if(h){break p}}U=Lb(f,p),V=247,t[U|0]=V;p=p+1|0;h=p-e|0;break q}if((g|0)<0){break r}if(n&255){e=e-1|0;U=Lb(f,e),V=n,t[U|0]=V;continue}break}h=h+1|0;continue n}U=m,V=MP(g&255),v[U+16>>2]=V;v[m+28>>2]=p-e;h=v[Kb(m+16|0,m+28|0)>>2]}if(!h){break o}f=v[m+40>>2];k=Lb(f,e)}s=w[k|0];Cq(m+16|0,f,v[m+44>>2],e,h);i=v[hc(m+8|0,v[m+16>>2],v[m+20>>2])>>2];k=kb-32|0;kb=k;f=v[m+12>>2];t:{if(!f){break t}j=Qd(w[b+223884|0]);u:{l=Lb(i,0);g=w[l|0]-250|0;if(g>>>0>5|!(1<<g&37)){break u}o=x[a+480188>>1];g=0;while(1){if((g|0)==(o|0)){break u}r=(B(g,872)+b|0)+1453|0;t[r|0]=127;t[r+1|0]=0;g=g+1|0;continue}}v:{if((f|0)!=4|w[l|0]!=240){break v}g=w[Lb(i,1)|0];if((g&254)!=240){break v}l=(B(c,872)+b|0)+616|0;o=Lb(i,2);i=w[Lb(i,3)|0];f=i<<24>>24;w:{x:{y:{z:{A:{B:{o=w[o|0];switch(o|0){case 3:break y;case 2:break z;case 1:break A;case 0:break B;default:break x}}if((g|0)==241|(f|0)<0){break x}g=B(c,872)+b|0;i=g+1453|0;if(d){f=kh(Rp(b,C(w[i|0]),C((f&255)>>>0)))}t[i|0]=f;t[g+1412|0]=0;f=Wp(a,l,!(v[g+704>>2]&32768),256);if((f|0)<0|!(w[g+705|0]&2)){break t}g=v[a+1298300>>2];if(j|Fd(g)^1){break t}$p(g,c,f>>>2&255,1);break t}if((g|0)==241|(f|0)<0){break x}g=B(c,872)+b|0;i=g+1454|0;if(d){f=kh(Rp(b,C(w[i|0]),C((f&255)>>>0)))}t[i|0]=f;t[g+1411|0]=0;Wp(a,l,!(v[g+704>>2]&32768),256);break t}if((g|0)==241){break w}if(f>>>0>31){break t}g=B(c,872)+b|0;t[g+1461|0]=(f&240)>>>4;Wp(a,l,!(v[g+704>>2]&32768),256);break t}if((g|0)==241){break w}g=(f|0)<0;f=Pl(a,b,c,3,0)-1|0;if(g|(f&255)>>>0>249){break t}t[k+24|0]=f;g=Md(a+906300|0,f&255);f=v[g>>2];if(!f){break t}q=C(C(127-i|0)/C(127));if(j){j=0;i=kb-16|0;kb=i;U=i,V=Aj(k+24|0),v[U>>2]=V;f=kb-16|0;kb=f;l=b+223860|0;o=Jy(l,f+12|0,w[k+24|0]);g=v[o>>2];if(!g){g=kb-16|0;kb=g;j=jc(l);r=mh(f,tc(24),nh(g+8|0,j));j=v[r>>2];D=w[v[i>>2]];v[j+20>>2]=0;t[j+16|0]=D;U=jc(r),V=1,t[U+4|0]=V;kb=g+16|0;Kg(l,v[f+12>>2],o,v[f>>2]);g=ce(f);rk(f);j=1}Jg(i+8|0,v[fc(f,g)>>2],j);kb=f+16|0;f=wd(v[i+8>>2]);kb=i+16|0;z[f+4>>2]=q;break t}if(!d){ft(v[f+20>>2],q);break t}ft(v[f+20>>2],Rp(b,z[g+144>>2],q));break t}if(o&128){break w}if((g|0)!=241){break t}}l=Pl(a,b,c,3,0)-1|0;if((f|0)<0|(l&255)>>>0>249){break t}i=v[Md(a+906300|0,l&255)>>2];if(!i){break t}g=(g|0)==241?o+128|0:o&127;q=C(C((f&255)>>>0)/C(127));if(j){U=aO(b+223872|0,qN(k+24|0,l,g)),W=q,z[U>>2]=W;break t}f=v[i>>2];if(!d){ob[v[f+44>>2]](i,g,q);break t}V=i,X=g,W=Rp(b,C(ob[v[f+48>>2]](i,g)),q),U=v[v[i>>2]+44>>2],ob[U](V|0,X|0,C(W));break t}if(j){break t}j=x[a+480188>>1];C:{if(j>>>0>c>>>0){g=c+1|0;break C}g=x[(B(c,872)+b|0)+1402>>1];if(!g){break t}}if(w[(B(c,872)+b|0)+707|0]&4|j>>>0<(g&65535)>>>0){break t}g=Pl(a,b,c,3,0)-1|0;if((g&255)>>>0>249){break t}g=v[Md(a+906300|0,g)>>2];if(!g){break t}j=w[l|0];if((j|0)==240){$g(k+16|0,i,f);f=v[v[g>>2]+72>>2];i=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=i;ob[f|0](g,k)|0;break t}U=k,X=MP(j),v[U+24>>2]=X;v[k+12>>2]=f;f=k+24|0;j=v[Kb(f,k+12|0)>>2];v[k+24>>2]=0;uc(f,i,j);ob[v[v[g>>2]+68>>2]](g,v[k+24>>2])|0}kb=k+32|0;n=s>>>0<240?s:n;h=e+h|0;continue}break}break}kb=m+48|0}function e$(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=kb-560|0;kb=l;v[l+548>>2]=k;v[l+552>>2]=b;a:{b:{c:{d:{if($j(a,l+552|0)){v[f>>2]=v[f>>2]|4;a=0;break d}v[l+96>>2]=1158;b=l+96|0;s=te(l+136|0,l+144|0,b);m=v[s>>2];v[l+132>>2]=m;v[l+128>>2]=m+400;y=Mb(b);o=Mb(l+80|0);q=Mb(l- -64|0);p=Mb(l+48|0);u=Mb(l+32|0);v[23588]=0;na(1167,c|0,d|0,l+120|0,l+116|0,l+112|0,y|0,o|0,q|0,p|0,l+28|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[j>>2]=v[i>>2];z=e&512;A=z>>>9|0;k=v[l+28>>2];e=0;while(1){e:{f:{g:{h:{i:{j:{k:{l:{if((e|0)==4){break l}v[23588]=0;b=Q(1141,a|0,l+552|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(!b){break l}m:{n:{o:{p:{q:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break e}b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}v[23588]=0;b=W(1168,h|0,1,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(b){v[23588]=0;R(1169,l+16|0,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;R(49,u|0,v[l+16>>2]);b=v[23588];v[23588]=0;if((b|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break i;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break e}}if((e|0)==3){break e}}while(1){v[23588]=0;b=Q(1141,a|0,l+552|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}if(!b){break e}b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}v[23588]=0;b=W(1168,h|0,1,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}if(!b){break e}v[23588]=0;R(1169,l+16|0,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;R(49,u|0,v[l+16>>2]);b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}r:{if(!Hb(q)){break r}b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if((b|0)!=v[Ac(q)>>2]){break r}v[23588]=0;S(1145,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}t[g|0]=0;r=Hb(q)>>>0>1?q:r;break e}s:{if(!Hb(p)){break s}b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if((b|0)!=v[Ac(p)>>2]){break s}v[23588]=0;S(1145,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}t[g|0]=1;r=Hb(p)>>>0>1?p:r;break e}c=Hb(q);b=Hb(p);t:{if(c){if(!b){break t}v[l+28>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break i}if(!b){break e}}B=g,C=!Hb(p),t[B|0]=C;break e}if(!(e>>>0<2|r|((e|0)==2&w[l+123|0]!=0|A))){r=0;break e}c=fc(l+16|0,ie(o));u:{v:{if(!e|w[(e+l|0)+119|0]>1){break v}while(1){w:{b=Uk(o);d=v[c>>2];if(!Pb(d,b)){break w}b=v[d>>2];v[23588]=0;b=W(1168,h|0,1,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break u}if(!b){break w}Le(c);continue}break}b=ie(o);b=cu(v[c>>2],b);if(Hb(u)>>>0>=b>>>0){d=zm(Uk(u),0-b|0);n=Uk(u);x=ie(o);b=kb-16|0;kb=b;v[b>>2]=x;v[b+8>>2]=d;while(1){x:{x=Pb(d,n);if(!x){break x}if(!pc(v[d>>2],v[v[b>>2]>>2])){break x}d=Le(b+8|0);Le(b);d=v[d>>2];continue}break}kb=b+16|0;if(x^1){break v}}B=c,C=v[fc(l+8|0,ie(o))>>2],v[B>>2]=C}v[l+8>>2]=v[c>>2];y:{while(1){b=Uk(o);if(!Pb(v[l+8>>2],b)){break y}v[23588]=0;b=Q(1141,a|0,l+552|0)|0;c=v[23588];v[23588]=0;z:{if((c|0)==1){break z}if(!b){break y}b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break z}if((b|0)!=v[v[l+8>>2]>>2]){break y}v[23588]=0;S(1145,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}Le(l+8|0);continue}break}break f}if(!z){break e}b=Uk(o);if(!Pb(v[l+8>>2],b)){break e}v[l+28>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break i}break f}b=0;n=v[l+112>>2];A:{while(1){B:{v[23588]=0;c=Q(1141,a|0,l+552|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break B}if(!c){break A}c=v[a>>2];v[23588]=0;c=S(1143,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break h}v[23588]=0;d=W(1168,h|0,64,c|0)|0;x=v[23588];v[23588]=0;if((x|0)==1){break h}C:{if(d){d=v[j>>2];if((d|0)==v[l+548>>2]){v[23588]=0;U(1170,i|0,j|0,l+548|0);d=v[23588];v[23588]=0;if((d|0)==1){break h}d=v[j>>2]}v[j>>2]=d+4;v[d>>2]=c;b=b+1|0;break C}if(!Hb(y)|!b|(c|0)!=(n|0)){break A}if(v[l+128>>2]==(m|0)){v[23588]=0;U(1164,s|0,l+132|0,l+128|0);c=v[23588];v[23588]=0;if((c|0)==1){break h}m=v[l+132>>2]}c=m+4|0;v[l+132>>2]=c;v[m>>2]=b;m=c;b=0}v[23588]=0;S(1145,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!b|v[s>>2]==(m|0)){break k}if(v[l+128>>2]==(m|0)){v[23588]=0;U(1164,s|0,l+132|0,l+128|0);c=v[23588];v[23588]=0;if((c|0)==1){break g}m=v[l+132>>2]}c=m+4|0;v[l+132>>2]=c;v[m>>2]=b;break j}v[l+28>>2]=k;D:{if(!r){break D}k=1;while(1){if(Hb(r)>>>0<=k>>>0){break D}v[23588]=0;b=Q(1142,a|0,l+552|0)|0;c=v[23588];v[23588]=0;E:{if((c|0)==1){break E}F:{if(!b){b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break E}if((b|0)==v[Ai(r,k)>>2]){break F}}v[f>>2]=v[f>>2]|4;a=0;break i}v[23588]=0;S(1145,a|0)|0;b=v[23588];v[23588]=0;k=k+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;b=v[s>>2];if((b|0)==(m|0)){break i}a=0;v[l+16>>2]=0;Gf(y,b,m,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break i}a=1;break i}c=m}G:{if((k|0)<=0){break G}v[23588]=0;b=Q(1142,a|0,l+552|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}H:{if(!b){b=v[a>>2];v[23588]=0;b=S(1143,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}if((b|0)==v[l+116>>2]){break H}}v[l+28>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break i}v[23588]=0;d=S(1145,a|0)|0;m=v[23588];v[23588]=0;b=k;if((m|0)==1){break g}while(1){if((b|0)<=0){k=0;break G}v[23588]=0;m=Q(1142,d|0,l+552|0)|0;n=v[23588];v[23588]=0;I:{if((n|0)==1){break I}J:{if(!m){m=v[d>>2];v[23588]=0;m=S(1143,m|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break I}v[23588]=0;m=W(1168,h|0,64,m|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break I}if(m){break J}}v[l+28>>2]=b;v[f>>2]=v[f>>2]|4;a=0;break i}if(v[j>>2]==v[l+548>>2]){v[23588]=0;U(1170,i|0,j|0,l+548|0);m=v[23588];v[23588]=0;if((m|0)==1){break I}}m=v[d>>2];v[23588]=0;m=S(1143,m|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break I}n=v[j>>2];v[j>>2]=n+4;v[n>>2]=m;v[23588]=0;S(1145,d|0)|0;m=v[23588];v[23588]=0;b=b-1|0;if((m|0)!=1){continue}}break}break f}if(v[j>>2]!=v[i>>2]){m=c;break e}v[l+28>>2]=k;v[f>>2]=v[f>>2]|4;a=0}Gc(u);Gc(p);Gc(q);Gc(o);zb(y);Xc(s);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;v[l+28>>2]=k;break a}e=e+1|0;continue}}a=P()|0;O()|0;break a}kb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Gc(u);Gc(p);Gc(q);Gc(o);zb(y);Xc(s);T(a|0);L()}function tW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=kb-224|0;kb=e;zc(b);a:{b:{c:{d:{if(!BC(b,e+176|0)){break d}if(!EC(e+176|0)){break d}if(!c){n=1;break d}Bd(a,2048);ag(a);d=kb-16|0;kb=d;f=e+8|0;h=yc(d,3947);ad(f,h);Ab(h);kb=d+16|0;v[23588]=0;U(213,e+80|0,f|0,w[e+179|0]);d=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{k:{if((d|0)!=1){d=e+80|0;Jb(a+1298344|0,d);Ab(d);f=e+8|0;bc(f);h=yc(d,11070);Jb(a+1298356|0,h);Ab(h);v[a+1298404>>2]=5;h=a+480188|0;u[h>>1]=w[e+216|0];u[a+480190>>1]=w[e+212|0];Ne(f,2,e+176|4);Fc(d,f);Bc(a+1298308|0,d);zb(d);d=w[e+179|0];l:{if(d>>>0>=9){if(d>>>0>=11){f=(d|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break l}h=lv(b);m:{if((h|0)==100){v[((d<<5)+a|0)+480280>>2]=256;break m}v[e+80>>2]=(h<<1)+128;v[e+8>>2]=0;v[e+160>>2]=256;s=((d<<5)+a|0)+480284|0,y=v[Jj(e+80|0,e+8|0,e+160|0)>>2],u[s>>1]=y}d=d+1|0;continue}}f=e+80|0;d=kb-16|0;kb=d;n:{if(!Qb(v[b>>2],v[b+8>>2],16)){pC(f);break n}bv(d+8|0,f);ud(d,b,v[d+8>>2],v[d+12>>2])}kb=d+16|0;d=0;while(1){if((d|0)==16){break l}u[((d<<5)+a|0)+480284>>1]=t[(e+80|0)+d|0]&1?64:192;d=d+1|0;continue}}u[h>>1]=4;zg(b,1);oh(a,1)}o:{if(w[e+179|0]>=13){d=e+80|0;ev(d,b);f=Oc(d);d=w[e+80|0];if(d>>>0<=31){t[e+80|0]=125;d=125}v[a+480204>>2]=B(d,1e4);v[a+480196>>2]=w[f|0];break o}v[a+480196>>2]=6;v[a+480204>>2]=125e4}vg(Wb(v[a+484360>>2],w[a+484376|0]),w[e+213|0]);l=Tb(e+160|0);f=w[e+179|0];q=v[b+8>>2]+((f>>>0>13)<<1)|0;d=0;p:{if(f>>>0<14){break p}v[23588]=0;R(214,l|0,w[e+213|0]);f=v[23588];v[23588]=0;if((f|0)!=1){break p}d=P()|0;O()|0;break b}q:{r:{s:{while(1){t:{if(w[e+213|0]<=d>>>0){d=0;if(w[e+179|0]!=10){break s}m=v[b+8>>2];k=a+480190|0;d=1;while(1){j=x[k>>1];if(j>>>0<(d&65535)>>>0){break t}v[23588]=0;f=Q(215,b|0,e+80|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break r}if(f){f=0;u:{if(w[e+212|0]<(w[e+126|0]|w[e+127|0]<<8|(w[e+128|0]<<16|w[e+129|0]<<24))>>>0|w[e+80|0]>1){break u}h=w[e+130|0]|w[e+131|0]<<8|(w[e+132|0]<<16|w[e+133|0]<<24);if(h>>>0>1048576|w[e+136|0]>64|h>>>0<(w[e+137|0]|w[e+138|0]<<8|(w[e+139|0]<<16|w[e+140|0]<<24))>>>0){break u}f=h>>>0>=(w[e+141|0]|w[e+142|0]<<8|(w[e+143|0]<<16|w[e+144|0]<<24))>>>0}if(!f){break t}}d=d+1|0;continue}}s=dc(v[Wb(v[a+484360>>2],w[a+484376|0])>>2],d),y=d,u[s>>1]=y;if(w[e+179|0]>=14){v[23588]=0;f=S(194,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break q}s=dc(v[l>>2],d),y=f,u[s>>1]=y}f=x[a+480188>>1];v[23588]=0;Q(188,b|0,f<<1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}d=d+1|0;continue}break}v[23588]=0;Q(155,b|0,m|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}d=j>>>0>=(d&65535)>>>0}j=a+480190|0;f=x[j>>1];v[23588]=0;v[e+80>>2]=0;m=W(216,e- -64|0,f|0,e+80|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}n=d?59:65;k=e+80|1;f=1;v:{while(1){h=f&65535;if(h>>>0>x[j>>1]){h=Tb(e+48|0);v[23588]=0;n=W(217,b|0,h|0,x[e+214>>1])|0;d=v[23588];v[23588]=0;w:{if((d|0)!=1){if(!n){break e}d=0;k=0;f=v[h>>2];if(!pc(f,v[h+4>>2])){f=Fb(f);g=Fb(v[h+4>>2]);k=kb-16|0;kb=k;x:{if(!Pb(f,g)){break x}v[k+8>>2]=f;while(1){j=v[Se(k+8|0)>>2];if(!Pb(j,g)){break x}f=Ek(w[f|0]|w[f+1|0]<<8,w[j|0]|w[j+1|0]<<8)?j:f;continue}}kb=k+16|0;k=w[f|0]|w[f+1|0]<<8}v[23588]=0;j=Q(218,e+32|0,k|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break w}y:{while(1){if((d|0)==(k|0)){if(!(c&2)){break j}i=_c(e+80|0,8,1,0,1);o=a+480190|0;f=x[o>>1];g=1;z:{A:while(1){p=g&65535;if(p>>>0>(f&65535)>>>0){break j}d=v[b+8>>2];f=v[b>>2];v[23588]=0;d=W(156,f|0,d|0,1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break z}if(!d){break j}r=v[b+8>>2];d=0;while(1){f=x[o>>1];if(f>>>0<=d>>>0){g=g+1|0;continue A}if((p|0)!=v[Eb(v[m>>2],d)>>2]){d=d+1|0;continue}v[23588]=0;Q(155,b|0,r|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;d=d+1|0;W(219,i|0,(B(d,104)+a|0)+484380|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){continue}}break}break}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}v[23588]=0;f=S(194,b|0)|0;g=v[23588];v[23588]=0;B:{if((g|0)==1){break B}v[23588]=0;Q(188,b|0,1)|0;g=v[23588];v[23588]=0;if((g|0)==1){break B}if(f){v[23588]=0;U(190,e+8|0,b|0,B(f,3)+(w[e+179|0]==1?3:0)|0);f=v[23588];v[23588]=0;if((f|0)==1){break y}g=e+8|0;f=kc(e+80|0,g);hd(Pg(v[j>>2],d),f);Bb(f);Bb(g)}d=d+1|0;continue}break}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}C:{D:{if(w[e+179|0]<=9){v[23588]=0;R(220,b|0,e+80|0);g=v[23588];v[23588]=0;E:{F:{if((g|0)==1){break F}v[23588]=0;R(221,e+80|0,(B(h,104)+a|0)+484380|0);g=v[23588];v[23588]=0;if((g|0)==1){break F}g=e+48|0;Ne(g,2,k);v[23588]=0;R(222,e+8|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break E}break D}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}v[23588]=0;U(223,b|0,e+80|0,n|0);g=v[23588];v[23588]=0;if((g|0)==1){break C}v[23588]=0;U(224,e+80|0,(B(h,104)+a|0)+484380|0,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break C}g=e+48|0;Ne(g,2,k);v[23588]=0;R(222,e+8|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break v}}g=e+8|0;Dc(((h<<5)+a|0)+946304|0,g);zb(g);s=Eb(v[m>>2],h-1|0),y=x[e+126>>1]|x[e+128>>1]<<16,v[s>>2]=y;f=f+1|0;continue}break}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;bc(e+8|0);break a}d=P()|0;O()|0;break b}if(!(c&1)){break f}v[23588]=0;g=a+484344|0;R(225,g|0,w[e+213|0]);c=v[23588];v[23588]=0;G:{if((c|0)!=1){f=a+480188|0;a=0;while(1){H:{if(w[e+213|0]<=a>>>0){break f}d=64;c=v[l>>2];if(Rc(c,v[l+4>>2])>>>0>a>>>0){d=x[dc(c,a)>>1]}v[23588]=0;c=W(226,g|0,a&65535,d&65535)|0;d=v[23588];v[23588]=0;if((d|0)==1){break G}I:{if(c){c=x[f>>1];v[23588]=0;Q(155,b|0,B(((w[e+179|0]>13)<<1)+(c<<1)|0,a)+q|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break G}c=Tb(e+80|0);d=x[f>>1];v[23588]=0;i=W(217,b|0,c|0,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break I}d=0;J:{if(!i){break J}while(1){if(x[f>>1]<=d>>>0){break J}K:{i=dc(v[c>>2],d);i=w[i|0]|w[i+1|0]<<8;if(!i|i>>>0>x[e+214>>1]){break K}i=dc(v[h>>2],i-1|0);i=(w[i|0]|w[i+1|0]<<8)-1&65535;if(i>>>0>=k>>>0){break K}o=v[g>>2];p=v[j>>2];v[23588]=0;U(227,Zb(o,a)|0,d&65535,Pg(p,i)|0);i=v[23588];v[23588]=0;if((i|0)!=1){break K}break H}d=d+1|0;continue}}od(c)}a=a+1|0;continue}}break}d=P()|0;O()|0;od(c);break i}d=P()|0;O()|0;break i}d=P()|0;O()|0}Vc(j)}od(h)}wc(m);break b}Vc(j)}od(h);wc(m);od(l)}kb=e+224|0;return n|0}d=P()|0;O()|0}od(l)}T(d|0);L()}function l$(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=kb-560|0;kb=l;v[l+548>>2]=k;v[l+552>>2]=b;a:{b:{c:{d:{if(dj(a,l+552|0)){v[f>>2]=v[f>>2]|4;a=0;break d}v[l+104>>2]=1158;b=l+104|0;s=te(l+136|0,l+144|0,b);m=v[s>>2];v[l+132>>2]=m;v[l+128>>2]=m+400;x=Mb(b);o=Mb(l+88|0);q=Mb(l+72|0);p=Mb(l+56|0);u=Mb(l+40|0);v[23588]=0;na(1161,c|0,d|0,l+120|0,l+119|0,l+118|0,x|0,o|0,q|0,p|0,l+36|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;d=v[l+36>>2];k=h;h=0;while(1){e:{f:{g:{h:{i:{j:{k:{if((h|0)==4){break k}v[23588]=0;b=Q(1125,a|0,l+552|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(!b){break k}l:{m:{n:{o:{p:{switch(t[(l+120|0)+h|0]){case 1:if((h|0)==3){break e}b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(vh(v[k+8>>2],1,b)){v[23588]=0;R(1162,l+24|0,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;R(47,u|0,t[l+24|0]);b=v[23588];v[23588]=0;if((b|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break h;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break e}}if((h|0)==3){break e}}while(1){v[23588]=0;b=Q(1125,a|0,l+552|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}if(!b){break e}b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}if(!vh(v[k+8>>2],1,b)){break e}v[23588]=0;R(1162,l+24|0,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;R(47,u|0,t[l+24|0]);b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}q:{if(!Hb(q)){break q}b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(w[Tc(q,0)|0]!=(b&255)){break q}v[23588]=0;S(1129,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}t[g|0]=0;r=Hb(q)>>>0>1?q:r;break e}r:{if(!Hb(p)){break r}b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}if(w[Tc(p,0)|0]!=(b&255)){break r}v[23588]=0;S(1129,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}t[g|0]=1;r=Hb(p)>>>0>1?p:r;break e}c=Hb(q);b=Hb(p);s:{if(c){if(!b){break s}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break h}if(!b){break e}}B=g,C=!Hb(p),t[B|0]=C;break e}if(!(h>>>0<2|r|((h|0)==2&w[l+123|0]!=0|z))){r=0;break e}B=l,C=ie(o),v[B+16>>2]=C;c=mj(l+24|0,l+16|0);t:{if(!h|w[(h+l|0)+119|0]>1){break t}while(1){u:{B=l,C=zh(o),v[B+16>>2]=C;if(!zi(c,l+16|0)){break u}if(!vh(v[k+8>>2],1,t[v[c>>2]])){break u}He(c);continue}break}B=l,C=ie(o),v[B+16>>2]=C;b=On(c,l+16|0);if(Hb(u)>>>0>=b>>>0){B=l,C=zh(u),v[B+16>>2]=C;e=Gp(l+16|0,0-b|0);n=zh(u);A=ie(o);b=kb-32|0;kb=b;v[b+16>>2]=n;v[b+24>>2]=e;v[b+8>>2]=A;while(1){e=zi(b+24|0,b+16|0);if(!(!e|w[v[b+24>>2]]!=w[v[b+8>>2]])){He(b+24|0);He(b+8|0);continue}break}kb=b+32|0;if(e^1){break t}}B=l,C=ie(o),v[B+8>>2]=C;B=c,C=v[mj(l+16|0,l+8|0)>>2],v[B>>2]=C}v[l+16>>2]=v[c>>2];v:{w:{while(1){B=l,C=zh(o),v[B+8>>2]=C;if(!zi(l+16|0,l+8|0)){break v}v[23588]=0;b=Q(1125,a|0,l+552|0)|0;c=v[23588];v[23588]=0;x:{if((c|0)==1){break x}if(!b){break v}b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break x}if(w[v[l+16>>2]]!=(b&255)){break v}v[23588]=0;S(1129,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break w}He(l+16|0);continue}break}a=P()|0;O()|0;v[l+36>>2]=d;break a}a=P()|0;O()|0;v[l+36>>2]=d;break a}if(!y){break e}B=l,C=zh(o),v[B+8>>2]=C;if(!zi(l+16|0,l+8|0)){break e}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break h}b=0;n=w[l+118|0];y:{while(1){z:{v[23588]=0;c=Q(1125,a|0,l+552|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break z}if(!c){break y}c=v[a>>2];v[23588]=0;e=S(1127,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break g}A:{if(vh(v[k+8>>2],64,e)){c=v[j>>2];if((c|0)==v[l+548>>2]){v[23588]=0;U(1163,i|0,j|0,l+548|0);c=v[23588];v[23588]=0;if((c|0)==1){break g}c=v[j>>2]}v[j>>2]=c+1;t[c|0]=e;b=b+1|0;break A}if(!Hb(x)|!b|(n|0)!=(e&255)){break y}if(v[l+128>>2]==(m|0)){v[23588]=0;U(1164,s|0,l+132|0,l+128|0);c=v[23588];v[23588]=0;if((c|0)==1){break g}m=v[l+132>>2]}c=m+4|0;v[l+132>>2]=c;v[m>>2]=b;m=c;b=0}v[23588]=0;S(1129,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!b|v[s>>2]==(m|0)){break j}if(v[l+128>>2]==(m|0)){v[23588]=0;U(1164,s|0,l+132|0,l+128|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}m=v[l+132>>2]}e=m+4|0;v[l+132>>2]=e;v[m>>2]=b;break i}v[l+36>>2]=d;B:{if(!r){break B}k=1;while(1){if(Hb(r)>>>0<=k>>>0){break B}v[23588]=0;b=Q(1126,a|0,l+552|0)|0;c=v[23588];v[23588]=0;C:{if((c|0)==1){break C}D:{if(!b){b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break C}if(w[hg(r,k)|0]==(b&255)){break D}}v[f>>2]=v[f>>2]|4;a=0;break h}v[23588]=0;S(1129,a|0)|0;b=v[23588];v[23588]=0;k=k+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;b=v[s>>2];if((b|0)==(m|0)){break h}a=0;v[l+24>>2]=0;Gf(x,b,m,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break h}a=1;break h}e=m}E:{if((d|0)<=0){break E}v[23588]=0;b=Q(1126,a|0,l+552|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}F:{if(!b){b=v[a>>2];v[23588]=0;b=S(1127,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}if(w[l+119|0]==(b&255)){break F}}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break h}v[23588]=0;c=S(1129,a|0)|0;m=v[23588];v[23588]=0;b=d;if((m|0)==1){break f}while(1){if((b|0)<=0){d=0;break E}v[23588]=0;m=Q(1126,c|0,l+552|0)|0;n=v[23588];v[23588]=0;G:{if((n|0)==1){break G}H:{if(!m){m=v[c>>2];v[23588]=0;m=S(1127,m|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break G}if(vh(v[k+8>>2],64,m)){break H}}v[l+36>>2]=b;v[f>>2]=v[f>>2]|4;a=0;break h}if(v[j>>2]==v[l+548>>2]){v[23588]=0;U(1163,i|0,j|0,l+548|0);m=v[23588];v[23588]=0;if((m|0)==1){break G}}m=v[c>>2];v[23588]=0;m=S(1127,m|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break G}n=v[j>>2];v[j>>2]=n+1;t[n|0]=m;v[23588]=0;S(1129,c|0)|0;m=v[23588];v[23588]=0;b=b-1|0;if((m|0)!=1){continue}}break}a=P()|0;O()|0;v[l+36>>2]=d;break a}if(v[j>>2]!=v[i>>2]){m=e;break e}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0}zb(u);zb(p);zb(q);zb(o);zb(x);Xc(s);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}h=h+1|0;continue}}a=P()|0;O()|0;break a}kb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}zb(u);zb(p);zb(q);zb(o);zb(x);Xc(s);T(a|0);L()}function Up(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;g=kb-16|0;kb=g;i=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:i;s=v[b+752>>2];k=w[b+802|0];a:{if(!k){Db(g+8|0,a+1074312|0,11);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}}b:{c:{if(!i){break c}if(!$c(k)){break c}d:{l=k-1|0;k=dc(i+236|0,l);if(x[k>>1]){break d}Db(g+8|0,a+1074312|0,43);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break d}if(vj(w[i+31|0])){break d}v[b+656>>2]=i;break a}if(w[Lb(i+108|0,l)|0]>120){break a}k=x[k>>1];l=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}l=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(k>>>0>250){break a}Db(g+8|0,a+1074312|0,43);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){if(i){l=0;if(vj(w[i+31|0])){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}l=0}k=v[b+104>>2];n=(k|0)!=0&(k|0)!=(l|0);j=v[b+656>>2];p=!i|v[a+480180>>2]!=16777216?p:v[i+44>>2]!=0;q=d^1;h=(j|0)!=(i|0);if((q|h|n)==1){u[b+774>>1]=0}r=!n;if(!(r|(h|!(d&p)))){break a}e:{if(!(d&n)){break e}k=a+1074312|0;Db(g+8|0,k,32);if(!(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])|!(w[a+480208|0]&8))){l=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:l}m=v[a+480180>>2];f:{if(!(i?h|!(m&1048580):1)|(m|0)==268435456){break f}if((m|0)==1){if(yi(v[b+8>>2],v[b+12>>2])){break f}}Db(g+8|0,k,79);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break e}if(!yi(v[b+8>>2],v[b+12>>2])){break e}}o=1}g:{if(!v[b+16>>2]|(!n|(h|!x[a+480192>>1]))){break g}Db(g+8|0,a+1074312|0,87);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}o=$c(w[b+788|0])^1|o}h:{i:{j:{k:{l:{if(yi(v[b+8>>2],v[b+12>>2])|!(v[a+480180>>2]&16777248)){break l}if(i){if(vj(w[i+31|0])){break l}}k=1;break k}if(!(h|n)){break j}k=(j|0)!=(i|0)}if(!d){break i}Db(g+8|0,a+1074312|0,61);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break i}j=v[b+656>>2];if(!j){j=0;m=0;h=v[b+104>>2];if(!h){break i}break h}h=v[b+104>>2];m=0;break h}k=0}v[b+656>>2]=i;j=i;m=k;h=l}m:{n:{o:{if(!e){break o}p:{if(w[a+480180|0]&3){if(h){if(_d(v[h>>2],v[h+20>>2])){break p}}if(!qj(j)){break o}}if(!h){break n}}if(u[h+34>>1]<0){break o}v[b+688>>2]=x[h+30>>1]}i=(h|0)!=0;if(!(n&o)|!h){break m}Db(g+8|0,a+1074312|0,85);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){u[b+772>>1]=t[h+37|0]}i=1;if(v[a+480180>>2]!=2){break m}if(!_d(v[h>>2],v[h+20>>2])){break m}v[b+704>>2]=v[h+24>>2];break m}if(!(!j|!w[j+34|0])){k=v[b+688>>2];if(j){k=v[j+4>>2]<<2}v[b+688>>2]=k;i=0;break m}i=0;v[b+688>>2]=0}if(o){break a}t[b+803|0]=0;q:{if(!j){break q}Db(g+8|0,a+1074312|0,29);if(!(z=1,A=(Cb(v[v[g+8>>2]>>2],v[g+12>>2])^-1)&i,C=w[j+34|0]|m,C?z:A)){break q}t[b+798|0]=w[j+16|0]}l=64;v[b+752>>2]=64;if(h){l=x[h+32>>1];v[b+752>>2]=l}if(j){v[b+752>>2]=B(v[j+4>>2],l)>>>6}r:{if(!(v[a+480180>>2]&1048580?e:1)){break r}Db(g+8|0,a+1074312|0,48);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break r}HN(a,b,j,h)}s:{t:{u:{if(!f){break u}f=a+1074312|0;Db(g+8|0,f,19);v:{w:{x:{y:{z:{A:{B:{C:{if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){if(!v[b+76>>2]){e=1;break B}if(!(!c|q)){e=(w[a+480208|0]&8)>>>3|0;if(e){break B}break C}e=0;if(c){break C}break B}c=v[a+480180>>2]&17301536;e=1;D:{if(!d|!c){break D}c=1;e=1;if(w[a+480208|0]&8){break D}e=1;if(!v[b+76>>2]){break D}e=0;if(!(w[b+89|0]&16)){break D}e=!v[b+696>>2]}if(!j|(!c|m)){break z}if(!e){break y}c=v[b+88>>2];e=c&6144;break A}if(d){break B}if(!(w[b+89|0]&24)){e=0;break B}e=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|m){break z}if(!e){break y}c=v[b+88>>2];e=c&2048}v[b+88>>2]=c|2097152;if(!j){break v}if(e){break w}if(!(w[j+60|0]&8)){pj(b+724|0)}if(!(w[j+80|0]&8)){pj(b+732|0)}if(w[j+100|0]&8){break v}pj(b+740|0);break v}if(e){break x}}if(j){if(t[j+60|0]&1){break u}Db(g+8|0,f,32);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){pj(b+724|0);break u}um(b);break u}c=0;if(!h){break t}break s}v[b+88>>2]=v[b+88>>2]|2097152;if(!j){break v}}um(b)}Db(g+8|0,f,21);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break u}t[b+818|0]=0;v[b+756>>2]=0}c=0;if(h){break s}if(!j){break t}c=1;if(vj(w[j+31|0])){break s}}v[b+752>>2]=0;v[b+104>>2]=0;break a}E:{F:{G:{H:{I:{if(!(!d|(i^1|v[b+104>>2]!=(h|0)))){d=v[a+480180>>2];if(v[b+76>>2]?d&16777250:0){break a}if((d|0)!=4){break I}Db(g+8|0,a+1074312|0,40);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+789|0]){break I}d=v[b+88>>2];break H}v[b+88>>2]=v[b+88>>2]&-6145;e=a+1074312|0;Db(g+8|0,e,18);J:{if(z=Cb(v[v[g+8>>2]>>2],v[g+12>>2]),A=1,C=v[a+480180>>2]&16777248,C?z:A){f=-640;if(!(v[b+104>>2]!=(h|0)|m)){break J}}f=-768}v[b+88>>2]=f&v[b+88>>2];K:{if(!j){break K}t[b+730|0]=w[j+60|0];t[b+738|0]=w[j+80|0];t[b+746|0]=w[j+100|0];L:{if((w[j+100|0]&17)!=17){break L}Db(g+8|0,e,36);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+837|0]){break L}t[b+837|0]=127}e=w[j+21|0];if(gf(e)){z=b,A=$q(e),t[z+837|0]=A}e=w[j+22|0];if(!gf(e)){break K}z=b,A=$q(e),t[z+838|0]=A}if(c){break G}if(!d){break E}break F}d=v[b+88>>2]&-6145}v[b+88>>2]=d&-640;if(!c){break F}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break E}c=a+1074312|0;Db(g+8|0,c,54);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){Db(g,c,39);if(!Cb(v[v[g>>2]>>2],v[g+4>>2])){break E}}v[b+8>>2]=0;v[b+12>>2]=0}M:{if(w[b+788|0]!=255){break M}Db(g+8|0,a+1074312|0,100);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])|(!(v[a+480208>>2]&4)|r)){break M}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}bq(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];e=a+1074312|0;Db(g+8|0,e,83);if(!(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;Db(g+8|0,e,21);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){t[b+818|0]=0;v[b+756>>2]=0}N:{O:{if(p){v[b+704>>2]=v[h+24>>2];t[b+851|0]=w[b+851|0]|64;c=0;break O}if(!(n|q)){d=v[a+480180>>2];if(d&5){break N}}v[b+704>>2]=v[h+24>>2];c=t[h+37|0]}u[b+772>>1]=c;d=v[a+480180>>2]}if(Km(d)){c=t[h+36|0]}else{c=0}u[b+770>>1]=c;Db(g+8|0,e,69);if(!(Cb(v[v[g+8>>2]>>2],v[g+12>>2])|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;i=v[b+88>>2];if(i&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];i=i>>>2&4|i|2;v[b+88>>2]=i}P:{if(!(i&2)){i=v[b+76>>2];break P}i=v[b+76>>2];c=v[b+84>>2];if(i>>>0<=c>>>0){break P}v[b+76>>2]=c;i=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<i>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}kb=g+16|0}function yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;e=kb-272|0;kb=e;zc(b);d=kb-16|0;kb=d;i=e+112|0;jU(d+8|0,i);g=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);h=v[d+4>>2];if((h|0)==(g|0)){_b(b,v[d+12>>2])}kb=d+16|0;d=(g|0)==(h|0);if(!d){iU(i)}a:{if(!d){break a}if(!kU(e+112|0)){break a}if(!c){f=1;break a}Bd(a,v[(x[e+228>>1]<<2)+26384>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+48|0;f=yc(d,13023);Jb(a+1298344|0,f);Ab(f);f=yc(d,10263);Jb(a+1298356|0,f);Ab(f);f=kb-16|0;kb=f;g=e+8|0;i=yc(f,4392);ad(g,i);Ab(i);kb=f+16|0;v[23588]=0;X(229,d|0,g|0,w[e+191|0],e+188|0);d=v[23588];v[23588]=0;b:{if((d|0)!=1){d=e+48|0;Jb(a+1298368|0,d);Ab(d);f=e+8|0;bc(f);Rl(a+1298392|0,(x[e+228>>1]<<2)+26432|0);Rl(a+1298380|0,v[(x[e+228>>1]<<2)+26480>>2]);v[a+1298404>>2]=5;Ne(f,2,e+112|4);Fc(d,f);Bc(a+1298308|0,d);zb(d);Ne(f,2,e+148|0);Fc(d,f);c:{if(yq(d,9700)){v[23588]=0;U(11,e+8|0,5,e+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=e+8|0;Jb(a+1298320|0,d);Ab(d)}zb(e+48|0);u[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;ef(i);f=w[(d+e|0)+193|0];e:{if(f>>>0<=15){v[e+48>>2]=f<<4|8;v[e+8>>2]=256;y=g+480284|0,z=v[td(e+48|0,e+8|0)>>2],u[y>>1]=z;break e}if((f|0)!=16){if((f|0)!=255){break e}u[a+480188>>1]=d;break d}u[g+480284>>1]=128;v[i>>2]=256}d=d+1|0;continue}break}d=x[a+480188>>1]}f=0;if(!(d&65535)){break a}v[e+48>>2]=w[e+225|0]<<2;v[e+8>>2]=256;y=a,z=v[Kb(e+48|0,e+8|0)>>2],v[y+480200>>2]=z;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(dd(b,x[e+230>>1]|x[e+232>>1]<<16)){to(Wb(v[a+484360>>2],w[a+484376|0]),b,w[e+234|0]+1|0,255,254)}if(!dd(b,v[e+240>>2])){break a}l=a+480190|0;d=w[e+248|0]+1|0;u[l>>1]=d;m=e+80|0;n=a+480180|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(d&65535)>>>0){break g}d=kb-16|0;kb=d;g=e+48|0;gc(d+8|0,g,62);f=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);h=v[d+4>>2];if((h|0)==(f|0)){_b(b,v[d+12>>2])}kb=d+16|0;d=(f|0)==(h|0);if(!d){Ub(g,0,62)}if(!d){break g}d=0;f=B(j,104)+a|0;k=f+484380|0;nd(k,0);h=e+32|0;Ne(h,2,e+48|0);g=e+8|0;Fc(g,h);Dc(((j<<5)+a|0)+946304|0,g);zb(g);uk(h,2,m);Fc(g,h);Ce(f+484423|0,g);zb(g);g=x[e+106>>1];v[f+484404>>2]=g;if(!Km(v[n>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==x[(d<<1)+26528>>1]){t[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!dd(b,v[e+244>>2])){break h}d=1;f=a+480190|0;while(1){g=d&65535;if(g>>>0>x[f>>1]){break h}g=B(g,104)+a|0;wg(_c(e+48|0,u[g+484414>>1]&1?16:8,1,0,1),g+484380|0,b);d=d+1|0;continue}}n=a+484344|0;xg(n,w[e+239|0]+1|0);f=xq(a);d=kb-16|0;kb=d;v[d+12>>2]=0;ct(d+12|0,f);k=v[d+12>>2];kb=d+16|0;dd(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));p=c&1;q=a+480188|0;r=a+480180|0;j=0;m=1;i:{j:{k:{while(1){if(w[e+239|0]<j>>>0){if(v[a+480180>>2]==1){break k}c=v[a+480208>>2]&-8454145;break j}l:{d=Sg(b);if(d>>>0>=3){c=e+8|0;ae(c,b,d-2|0);h=kc(e+48|0,c);Bb(c);m:{if(!p){break m}c=v[h>>2];v[23588]=0;c=S(178,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}if(!c){break m}v[23588]=0;c=W(226,n|0,j&65535,64)|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}l=0;if(!c){break m}while(1){if((l|0)==64){break m}c=Zb(v[n>>2],j);s=Df(v[c>>2],v[v[c+48>>2]+12>>2],l);n:{o:while(1){v[23588]=0;c=S(206,h|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=x[q>>1]){break n}f=B(d,6)+s|0;if(c&32){v[23588]=0;R(260,e+8|0,h|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}g=Oc(e+8|0);d=w[e+8|0];if(d){d=(d&127)-1|0;t[e+8|0]=d;d=(B((d&240)>>>4|0,12)+(d&15)|0)+13|0;t[f|0]=d;m=gB(d)&m}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){c=v[h>>2];v[23588]=0;c=W(156,c|0,v[e+56>>2],2)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}if(!c){continue o}o=w[f+5|0];c=w[f+3|0];v[23588]=0;R(260,e+8|0,h|0);d=v[23588];v[23588]=0;if((d|0)!=1){i=w[Oc(e+8|0)|0];t[g|0]=i;d=w[(w[e+8|0]&31)+26560|0];t[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(i>>>0<224){break r}d=223;if(v[r>>2]!=1){break s}break r;case 11:t[e+32|0]=64;y=g,z=w[Xb(g,e+32|0)|0],t[y|0]=z;if(!hU(v[k+88>>2])){break r}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=o;d=c;break q;case 17:u:{switch(((i&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[g|0]=i&15|224;break p;case 1:t[f+3|0]=3;t[g|0]=i&15|224;break p;default:break u}}if(uu(v[k+84>>2],19)){break r}Wu(f);break r;case 13:d=v[k+84>>2];if(uu(d,15)){break r}if(!uu(d,19)){break r}t[f+3|0]=19;t[g|0]=i&15|144;break p;case 18:d=145;if((i|0)==1){break s}if((i&240)==128){if(uu(v[k+84>>2],20)){break r}t[f+3|0]=19;break p}t[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=i&240;if(!d){break r}}t[g|0]=d}d=w[f+3|0]}if((d&255)!=20){break p}d=w[g|0];if(w[f+2|0]|(d&240)!=128){break p}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=o}if(!(w[e+8|0]&32)){continue o}continue}break}break}break i}l=l+1|0;continue}}Bb(h)}j=j+1|0;continue}break}break i}c=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?m&1?8454144:0:0)}v[a+480208>>2]=c;f=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break a}if(!dd(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break a}uB(a+1298332|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4);break a}d=P()|0;O()|0;Bb(h);break b}u[f+484412>>1]=64;g=w[e+93|0]|w[e+94|0]<<8|(w[e+95|0]<<16|w[e+96|0]<<24);v[k>>2]=g;d=w[e+105|0];if(d&2){h=f+484414|0;u[h>>1]=x[h>>1]|1;v[k>>2]=g>>>1}v[f+484384>>2]=w[e+97|0]|w[e+98|0]<<8|(w[e+99|0]<<16|w[e+100|0]<<24);v[f+484388>>2]=(w[e+101|0]|w[e+102|0]<<8|(w[e+103|0]<<16|w[e+104|0]<<24))-1;if(d&1){g=f+484414|0;u[g>>1]=x[g>>1]|2}v:{w:{if(!(d&4)){break w}g=w[e+108|0];if((g|0)==255){break w}t[e+8|0]=g;t[e+32|0]=64;y=f+484410|0,z=w[Xb(e+8|0,e+32|0)|0]<<2,u[y>>1]=z;break v}g=f+484414|0;u[g>>1]=x[g>>1]|32768}x:{if(d&8){d=f+484414|0;g=x[d>>1]|32;u[d>>1]=g;j=f+484408|0;f=w[e+109|0];if(f>>>0<=15){v[e+32>>2]=256;v[e+8>>2]=f<<4|8;h=v[td(e+8|0,e+32|0)>>2]}else{h=128}u[j>>1]=h;u[d>>1]=g&65279|((f|0)==16)<<8;break x}u[f+484408>>1]=128}i=i+1|0;d=x[l>>1];continue}}d=P()|0;O()|0;zb(e+48|0);break b}d=P()|0;O()|0;bc(e+8|0)}T(d|0);L()}kb=e+272|0;return f|0}function bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=kb+-64|0;kb=g;d=v[b>>2];v[23588]=0;f=S(178,d|0)|0;d=v[23588];v[23588]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(f){l=Tb(g+48|0);v[23588]=0;e=(c|0)!=0;f=W(822,l|0,b|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}d=4;g:{h:{i:{j:{if(f){break j}v[23588]=0;f=W(823,l|0,b|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}d=5;if(f){break j}v[23588]=0;f=W(824,l|0,b|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}d=6;if(f){break j}f=0;v[23588]=0;e=W(825,l|0,b|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}d=3;if(!e){break i}}if(!c){d=1;f=0;break h}f=v[l>>2];if(!pc(f,v[l+4>>2])){vv(b,f+12|0)}f=d}d=31552;k:{while(1){e=d;if((e|0)!=32092){h=v[e+8>>2];i=(h>>1)+a|0;d=v[e+4>>2];d=h&1?v[v[i>>2]+d>>2]:d;v[23588]=0;h=W(d|0,i|0,b|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}d=e+12|0;if(!h){continue}break k}break}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){d=(e|0)!=32092;f=0;break h}if(!(v[a+480184>>2]|!f)){v[a+480184>>2]=f}v[23588]=0;f=1;R(765,a+1298264|0,1);e=v[23588];v[23588]=0;d=1;if((e|0)==1){break g}}KM(l);if(f){break f}break a}break c}v[23588]=0;R(246,a|0,0);d=v[23588];v[23588]=0;if((d|0)==1){break d}v[23588]=0;R(765,a+1298264|0,1);d=v[23588];v[23588]=0;if((d|0)==1){break d}v[a+1074304>>2]=19988498}d=0;while(1){if((d|0)==127){d=1;while(1){f=d&65535;if(f>>>0>x[a+480190>>1]){f=0;i=a+480180|0;d=0;l:{while(1){e=d&65535;if(e>>>0>x[a+480192>>1]){m:{u[a+480192>>1]=f;d=a+480204|0;if(y[a+480204>>2]>=1e4){break m}v[d>>2]=125e4;break l}}else{e=v[((e<<2)+a|0)+900380>>2];if(e){h=v[i>>2];xc(e,65536);xc(e+4|0,64);xc(e+8|0,256);Ff(e+28|0,16384);wf(e+30|0,128);wf(e+31|0,17);if(w[e+16|0]>=4){t[e+16|0]=0}if(w[e+17|0]>=5){t[e+17|0]=0}if(w[e+18|0]>=3){t[e+18|0]=0}wf(e+19|0,64);wf(e+20|0,100);j=224;f=t[e+26|0];n:{if((f|0)>=-32){j=32;if((f|0)<33){break n}}t[e+26|0]=j}wf(e+23|0,64);wf(e+24|0,64);Fz(e+48|0,64);Fz(e+68|0,64);Fz(e+88|0,(h|0)==4096?255:64);h=e+108|0;j=0;while(1){o:{if((j|0)==128){if(!Io(w[e+14|0])){t[e+14|0]=5}if(w[e+34|0]>=251){t[e+34|0]=0}break o}f=Lb(h,j);if((w[f|0]-121&255)>>>0<=135){t[f|0]=j+1}j=j+1|0;continue}break}f=d}d=d+1|0;continue}break}xc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}e=a+480216|0;f=a+480220|0;d=v[a+480216>>2];if(!(d|w[a+480224|0]!=2)){v[e>>2]=1;d=1}if(y[a+480220>>2]<d>>>0){v[f>>2]=d}xc(e,65536);xc(f,65536);xc(a+480200|0,256);p:{f=a+480248|0;if(!pc(v[f>>2],v[a+480252>>2])){d=v[e>>2];v[23588]=0;R(826,f|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break p}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];d=v[a+480220>>2];f=a+1074408|0;v[f>>2]=v[a+480216>>2];v[f+4>>2]=d;v[a+1074456>>2]=v[a+480200>>2];Wy(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;if(Km(v[a+480180>>2])){v[23588]=0;Q(265,a+1074312|0,7)|0;d=v[23588];v[23588]=0;if((d|0)==1){break p}}u[a+480276>>1]=0;Np(a);o=g,p=Fb(v[a+484360>>2]),v[o+48>>2]=p;f=Fb(v[a+484364>>2]);while(1){e=v[g+48>>2];if(!Pb(e,f)){q:{r:{l=v[a+480180>>2];if(l){ct(a+8|0,xq(a));if(v[a+1074308>>2]){v[23588]=0;Y(827,a|0);d=v[23588];v[23588]=0;if((d|0)==1){break p}}n=Tb(g+48|0);s:{if((c&12)!=12){break s}i=a+906300|0;h=a+1298464|0;d=0;t:{u:{v:{w:{x:{y:{while(1){if((d|0)==250){break s}z:{k=Md(i,d);e=k+16|0;A:{if(!yi(v[e>>2],v[k+20>>2])){break A}v[23588]=0;R(828,k|0,a|0);c=v[23588];v[23588]=0;B:{if((c|0)!=1){m=v[k>>2];if(!m){break B}f=v[k+148>>2];c=v[v[m>>2]+56>>2];v[23588]=0;R(c|0,m|0,f|0);c=v[23588];v[23588]=0;if((c|0)!=1){break A}}a=P()|0;O()|0;break q}j=Fb(v[n>>2]);f=Fb(v[n+4>>2]);m=kb-16|0;kb=m;v[m+8>>2]=j;while(1){C:{if(!Pb(j,f)){break C}c=v[j>>2];if((w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))==(w[k+20|0]|w[k+21|0]<<8|(w[k+22|0]<<16|w[k+23|0]<<24))){c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==(w[k+16|0]|w[k+17|0]<<8|(w[k+18|0]<<16|w[k+19|0]<<24))}else{c=0}if(c){break C}j=v[Le(m+8|0)>>2];continue}break}kb=m+16|0;if(Pb(j,Fb(v[n+4>>2]))){break A}v[23588]=0;v[g+32>>2]=e;R(829,n|0,g+32|0);c=v[23588];v[23588]=0;if((c|0)==1){break z}v[23588]=0;f=Q(1,g+16|0,17666)|0;c=v[23588];v[23588]=0;if((c|0)==1){break y}v[23588]=0;R(830,g|0,k|0);c=v[23588];v[23588]=0;if((c|0)==1){break x}v[23588]=0;U(2,g+32|0,f|0,g|0);c=v[23588];v[23588]=0;if((c|0)==1){break w}c=v[h>>2];v[23588]=0;U(376,c|0,2,g+32|0);c=v[23588];v[23588]=0;if((c|0)==1){break v}Ab(g+32|0);Ab(g);Ab(f)}d=d+1|0;continue}break}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;break u}a=P()|0;O()|0;Ab(g+32|0)}Ab(g)}Ab(f);break q}c=w[a+1074368|0];v[23588]=0;R(831,a|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}wc(n)}d=(l|0)!=0;break a}a=P()|0;O()|0}wc(n);break b}v[23588]=0;Y(832,e|0);d=v[23588];v[23588]=0;if((d|0)!=1){if(Rc(v[e>>2],v[e+4>>2])>>>0<=x[e+28>>1]){Ve(e,0)}Az(g+48|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}h=B(f,104)+a|0;i=h+484380|0;D:{if(_d(v[i>>2],v[h+484400>>2])){uj(i,a);break D}e=h+484414|0;f=x[e>>1];if(f&16384){break D}v[i>>2]=0;v[i+4>>2]=0;v[i+16>>2]=0;v[i+8>>2]=0;v[i+12>>2]=0;u[e>>1]=f&65505}f=h+484412|0;if(x[f>>1]>=65){u[f>>1]=64}E:{F:{if(!(w[h+484415|0]&2)){break F}if(!jk(v[a+1298300>>2])){break F}v[23588]=0;Y(833,a|0);f=v[23588];v[23588]=0;if((f|0)==1){break E}}d=d+1|0;continue}break}a=P()|0;O()|0;break b}e=(d<<5)+a|0;Ff(e+480286|0,64);f=e+480284|0;if(x[f>>1]>=257){u[f>>1]=128}f=e+480288|0;if(w[f|0]>=251){t[f|0]=0}fo((B(d,872)+a|0)+1074992|0,a,d&65535,134217728);d=d+1|0;continue}}break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;KM(l)}Bb(b);T(a|0);L()}Bb(b);kb=g- -64|0;return d|0}function E1(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0;n=kb-560|0;kb=n;v[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){x=1;A=5299;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){x=1;A=5302;break a}x=e&1;A=x?5305:5300;F=!x}b:{if((g&2146435072)==2146435072){d=x+3|0;Hf(a,32,c,d,e&-65537);tf(a,A,x);f=f&32;tf(a,b!=b?f?9928:13743:f?11058:14109,3);Hf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c;break b}z=n+16|0;c:{d:{e:{b=SH(b,n+44|0);b=b+b;if(b!=0){g=v[n+44>>2];v[n+44>>2]=g-1;u=f|32;if((u|0)!=97){break e}break c}u=f|32;if((u|0)==97){break c}l=v[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;v[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}r=(n+48|0)+((l|0)<0?0:288)|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}v[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=(d|0)<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=v[g>>2];p=d&31;C=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=C+q|0;i=i+E|0;i=p>>>0<q>>>0?i+1|0:i;i=Rka(p,i,1e9,0);q=Oka(i,nb,-1e9,0)+p|0;v[g>>2]=q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[n+44>>2]-d|0;v[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){y=((m+25>>>0)/9|0)+1|0;p=(u|0)==102;while(1){d=0-d|0;i=(d|0)<9?d:9;h:{if(g>>>0<=k>>>0){h=v[k>>2];break h}q=1e9>>>i|0;E=-1<<i^-1;d=0;h=k;while(1){C=d;d=v[h>>2];v[h>>2]=C+(d>>>i|0);d=B(q,d&E);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0}d=i+v[n+44>>2]|0;v[n+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(y|0)?h+(y<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=(m-((u|0)==102?0:d)|0)-((u|0)==103&(m|0)!=0)|0;if((h|0)<(B(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(p<<2)|0)-4048|0;h=10;i=i+B(p,-9)|0;if((i|0)<=7){while(1){h=B(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=v[l>>2];y=(p>>>0)/(h>>>0)|0;i=B(y,h);q=l+4|0;j:{if((i|0)==(p|0)&(q|0)==(g|0)){break j}p=p-i|0;k:{if(!(y&1)){b=9007199254740992;if(!(t[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=p>>>0<q>>>0?.5:(q|0)==(p|0)?s:1.5;if(!(w[A|0]!=45|F)){s=-s;b=-b}v[l>>2]=i;if(b+s==b){break j}d=h+i|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!v[g>>2]){continue}}break}l:{if((u|0)!=103){l=e&8;break l}g=m?m:1;l=(g|0)>(d|0)&(d|0)>-5;m=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=v[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=B(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=B(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}i=-1;u=l|m;if(((u?2147483645:2147483646)|0)<(m|0)){break b}p=(((u|0)!=0)+m|0)+1|0;q=f&-33;n:{if((q|0)==70){if((2147483647-p|0)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=En((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((z-g|0)<2){continue}break}}y=g-2|0;t[y|0]=f;t[g-1|0]=(d|0)<0?45:43;g=z-y|0;if((g|0)>(2147483647-p|0)){break b}}d=g+p|0;if((d|0)>(x^2147483647)){break b}f=d+x|0;Hf(a,32,c,f,e);tf(a,A,x);Hf(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=n+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=En(v[k>>2],0,l);r:{if((i|0)!=(k|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}t[n+24|0]=48;g=d}tf(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(u){tf(a,16736,1)}if((m|0)<=0|h>>>0<=k>>>0){break q}while(1){g=En(v[k>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}tf(a,g,(m|0)<9?m:9);g=m-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;g=n+16|0;d=g|8;r=g|9;h=k;while(1){g=En(v[h>>2],0,r);if((r|0)==(g|0)){t[n+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}tf(a,g,1);g=g+1|0;if(!(l|m)){break t}tf(a,16736,1)}C=g;g=r-g|0;tf(a,C,(g|0)>(m|0)?m:g);m=m-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}Hf(a,48,m+18|0,18,0);tf(a,y,z-y|0);break o}g=m}Hf(a,48,g+9|0,9,0)}Hf(a,32,c,f,e^8192);i=(c|0)<(f|0)?f:c;break b}m=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(w[m|0]==45){b=-(s+(-b-s));break u}b=b+s-s}l=x|2;k=f&32;h=v[n+44>>2];g=h>>31;g=En((g^h)-g|0,0,z);if((z|0)==(g|0)){t[n+15|0]=48;g=n+15|0}r=g-2|0;t[r|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=n+16|0;while(1){f=h;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=k|w[g+77088|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(n+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(n+16|0)|0;g=k}d=g+f|0;Hf(a,32,c,d,e);tf(a,m,l);Hf(a,48,c,d,e^65536);tf(a,n+16|0,k);Hf(a,48,g-k|0,0,0);tf(a,r,p);Hf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c}kb=n+560|0;return i|0}function Efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-272|0;kb=e;zc(b);d=kb-16|0;kb=d;f=e+120|0;lR(d+8|0,f);g=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);h=v[d+4>>2];if((h|0)==(g|0)){_b(b,v[d+12>>2])}kb=d+16|0;d=(g|0)==(h|0);if(!d){kR(f)}a:{b:{if(!d){break b}if(!mR(e+120|0)){break b}if(!c){i=1;break b}Bd(a,4194304);d=e+32|0;g=yc(d,17003);Jb(a+1298344|0,g);Ab(g);g=yc(d,10087);Jb(a+1298356|0,g);Ab(g);v[a+1298404>>2]=5;n=a,o=Dd(x[e+198>>1],x[e+200>>1],127),u[n+480188>>1]=o;g=w[e+189|0];v[a+480228>>2]=(g|0)==255?48:g;v[a+480196>>2]=w[e+187|0];v[a+480204>>2]=B(w[e+188|0],1e4);g=e+96|0;qf(g,e+120|4,59,3);Fc(d,g);Bc(a+1298308|0,d);zb(d);d=x[e+202>>1]|x[e+204>>1]<<16;c:{if(d>>>0<5){break c}if(!dd(b,d-4|0)){break c}if(!Gh(b,14209)){break c}to(Wb(v[a+484360>>2],w[a+484376|0]),b,x[e+192>>1],65535,65535)}d:{d=x[e+206>>1]|x[e+208>>1]<<16;if(d>>>0<5){break d}if(!dd(b,d-4|0)){break d}if(!Gh(b,13738)){break d}d=0;while(1){if((d|0)==32){break d}g=(d<<5)+a|0;ef(g+480280|0);n=g+480284|0,o=((((Me(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;d=d+1|0;continue}}d=x[e+214>>1]|x[e+216>>1]<<16;e:{if(d>>>0<5){break e}if(!dd(b,d-4|0)){break e}if(!Gh(b,14066)){break e}d=e+32|0;ae(d,b,x[e+196>>1]<<6);k=c&2;h=a+480190|0;g=kc(e+96|0,d);Bb(d);j=e+45|0;d=0;f:{while(1){if(x[e+196>>1]<=(d&65535)>>>0){break f}v[23588]=0;f=Q(661,g|0,e+32|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}if(!f){break f}f=w[e+77|0]|w[e+78|0]<<8;u[e+30>>1]=f;g:{h:{if((f-1&65535)>>>0>3998){break h}f=B(f,104)+a|0;i=f+484380|0;if(_d(v[i>>2],v[f+484400>>2])){break h}n=h,o=x[le(h,e+30|0)>>1],u[n>>1]=o;v[23588]=0;R(662,e+32|0,i|0);f=v[23588];v[23588]=0;if((f|0)==1){break g}YT(e,1,j);v[23588]=0;R(222,e+16|0,e|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}f=e+16|0;Dc(((x[e+30>>1]<<5)+a|0)+946304|0,f);zb(f);if(!k){break h}v[23588]=0;Q(155,b|0,w[e+69|0]|w[e+70|0]<<8|(w[e+71|0]<<16|w[e+72|0]<<24))|0;f=v[23588];v[23588]=0;if((f|0)==1){break g}i=1;l=e+16|0;f=w[e+79|0];m=_c(l,f&4?16:8,1,0,0);i:{j:{if(f&8){break j}i=2;if(f&16){break j}if(f&127){break i}}dg(m,i)}v[23588]=0;W(219,l|0,(B(x[e+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){break h}break a}d=d+1|0;continue}break}break a}Bb(g)}i=1;if(!(c&1)){break b}k:{c=x[e+210>>1]|x[e+212>>1]<<16;if(c>>>0<5){break k}if(!dd(b,c-4|0)){break k}if(!Gh(b,13588)){break k}k=a+484344|0;xg(k,x[e+194>>1]);f=0;while(1){if(x[e+194>>1]<=f>>>0){break k}if(!wA(b,e+16|0)){break k}l:{d=x[e+16>>1];if(d>>>0>3){c=e+96|0;ae(c,b,(d+15&131056)-4|0);g=kc(e+32|0,c);Bb(c);v[23588]=0;c=W(226,k|0,f&65535,w[e+18|0])|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}h=0;m:{if(!c){break m}while(1){n:{c=v[g>>2];v[23588]=0;d=W(156,c|0,v[e+40>>2],1)|0;c=v[23588];v[23588]=0;o:{if((c|0)!=1){c=w[e+18|0];if(!(d&c>>>0>(h&255)>>>0)){break n}v[23588]=0;d=S(206,g|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}if(d){break o}h=h+1|0;continue}break a}c=v[a+484344>>2];u[e+96>>1]=d&31;u[e>>1]=x[a+480188>>1]-1;c=Zb(c,f);c=jd(v[c>>2],v[v[c+48>>2]+12>>2],h,x[Wc(e+96|0,e)>>1]);if(d&128){v[23588]=0;R(260,e+96|0,g|0);j=v[23588];v[23588]=0;if((j|0)==1){break a}t[c|0]=w[e+96|0]+36;n=c,o=w[Oc(e+96|0)|0],t[n+1|0]=o}if(d&64){t[c+2|0]=1;v[23588]=0;j=S(206,g|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break a}t[e+96|0]=j;t[e|0]=64;n=c,o=w[Xb(e+96|0,e)|0],t[n+4|0]=o}if(!(d&32)){continue}v[23588]=0;R(260,e+96|0,g|0);d=v[23588];v[23588]=0;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{if((d|0)!=1){d=w[Oc(e+96|0)|0];t[c+5|0]=d;switch(w[e+96|0]-1|0){case 71:break q;case 70:break r;case 69:break s;case 60:break t;case 59:break u;case 52:break v;case 51:break w;case 50:break x;case 49:break y;case 42:break z;case 41:break A;case 40:break B;case 39:break C;case 30:break D;case 29:break E;case 22:break F;case 21:break G;case 20:break H;case 19:break I;case 16:break J;case 15:break K;case 14:break L;case 13:break M;case 12:break N;case 11:break O;case 10:break P;case 9:break Q;case 3:break R;case 2:break S;case 1:break T;case 0:break U;default:break p}}break a}t[c+3|0]=11;t[c+5|0]=d<<4|15;continue}t[c+3|0]=11;t[c+5|0]=d<<4;continue}t[c+3|0]=11;t[c+5|0]=d|240;continue}t[c+3|0]=11;t[c+5|0]=d&15;continue}t[c+3|0]=2;t[c+5|0]=d|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=d|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=d|16;continue}t[c+3|0]=6;t[c+5|0]=d<<4;continue}t[c+3|0]=6;t[c+5|0]=d&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=d|48;continue}t[c+3|0]=7;t[c+5|0]=d<<4;continue}t[c+3|0]=7;t[c+5|0]=d&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=d|64;continue}t[c+3|0]=10;v[23588]=0;d=S(206,g|0)|0;j=v[23588];v[23588]=0;if((j|0)!=1){t[c+5|0]=d;v[23588]=0;Q(188,g|0,1)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}break a}t[c+3|0]=15;t[c+5|0]=d&15;continue}t[c+3|0]=20;t[c+5|0]=d|192;continue}t[c+3|0]=20;t[c+5|0]=d|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=d|176;continue}t[c+3|0]=20;t[c+5|0]=d|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=d&15|32;continue}t[c+3|0]=20;t[c+5|0]=d&15|128;continue}t[c+3|0]=0;continue}break}if((c|0)==64){break m}Ae(Zb(v[k>>2],f),Fh(Ue(Oe(e+96|0,14,0),c-1|0)))}Bb(g)}f=f+1|0;continue}break}break a}c=x[e+218>>1]|x[e+220>>1]<<16;if(!c){break b}dd(b,c);uB(a+1298332|0,b,Sg(b),4)}kb=e+272|0;return i|0}a=P()|0;O()|0;Bb(g);T(a|0);L()}function rja(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;k=kb-128|0;kb=k;t[k+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}t[b+5|0]=d;t[k+8|0]=15;l=k+127|0;p=k+8|0;j=p;o=w[Xb(l,j)|0];t[k+8|0]=14;l=w[Xb(l,j)|0];v[k+8>>2]=d+31>>>5;v[k+120>>2]=14;r=k+120|0;n=v[td(j,r)>>2];v[k+8>>2]=d+127>>>7;v[k+120>>2]=14;q=c&15;j=q<<8|d;p=td(p,r);b:{switch((c>>>4|0)-2|0){case 0:t[b+2|0]=1;t[b+4|0]=j>>>2;break a;case 1:t[b+2|0]=1;if(!j){t[b+4|0]=0;break a}s=b,y=tg(dB(j)>>>2|0),t[s+4|0]=y;break a;case 2:t[b+3|0]=9;t[b+5|0]=j>>>4;break a;case 3:t[b+3|0]=23;t[b+5|0]=j+1>>>5;break a;case 4:t[b+3|0]=23;if(j){a=tg(dB(j)>>>5|0)}else{a=0}t[b+5|0]=a;break a;case 5:t[b+5|0]=q;t[b+3|0]=15;break a;case 6:t[b+3|0]=15;if((e|0)>=0){if(w[b+2|0]){break a}t[b+2|0]=2;s=b,y=Ic(((q<<6|7)>>>0)/15|0,0),t[s+4|0]=y;break a}t[b+2|0]=1;t[b+5|0]=q;t[b+4|0]=d+3>>>2;break a;case 7:t[b+3|0]=10;c:{if((e|0)>5){break c}if(!j){t[b+5|0]=1;break a}c=vq(a,f,g);if(!c){break c}a=Hi(a,c);c=x[a+34>>1];if(c&1){j=j>>>1|0;v[k+120>>2]=j}if(!(c&2)){break c}c=v[a>>2];if(c>>>0>=j<<8>>>0){break c}v[k+120>>2]=v[a+4>>2]+8>>>8;xc(k+120|0,c-1>>>8|0);j=v[k+120>>2]}t[b+5|0]=j;if(w[b+2|0]|j>>>0<256){break a}t[b+2|0]=15;v[k+116>>2]=j>>>8;cB(k+8|0);v[k+112>>2]=9;s=b,y=v[Kb(k+116|0,k+112|0)>>2],t[s+4|0]=y;break a;default:break b}}j=v[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:Pf(b,c,d);f:{switch(w[b+3|0]-16|0){case 1:v[h>>2]=B(w[b+5|0],1e4);break a;case 0:break f;default:break a}}a=w[b+5|0];if(!a){break a}v[i>>2]=a;break a;case 4:t[b+3|0]=4;if(w[b+2|0]){break a}t[b+4|0]=0;t[b+2|0]=8;break a;case 5:t[b+3|0]=5;if(w[b+2|0]){break a}t[b+4|0]=0;t[b+2|0]=11;break a;case 7:if(!$c(w[b|0])|!d){break a}t[b+3|0]=35;t[b+5|0]=(d>>>1&120|128)-(d<<3&120);e=a+480192|0;if(x[e>>1]){break a}u[k+8>>1]=255;c=x[Wc(a+480190|0,k+8|0)>>1];u[e>>1]=c;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=Qu(a,d,d);if(c){t[c+33|0]=2;d=(d<<5)+a|0;f=d+946304|0;g=v[f+4>>2];v[c+492>>2]=v[f>>2];v[c+496>>2]=g;f=d+946312|0;g=v[f+4>>2];v[c+500>>2]=v[f>>2];v[c+504>>2]=g;f=d+946320|0;g=v[f+4>>2];v[c+508>>2]=v[f>>2];v[c+512>>2]=g;d=d+946328|0;f=v[d+4>>2];v[c+516>>2]=v[d>>2];v[c+520>>2]=f;Mj(c,127,1);Lj(c,0,1)}b=b+1|0;c=x[e>>1];continue};case 8:t[b+3|0]=19;t[b+5|0]=o|208;break a;case 9:t[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}t[b+3|0]=19;t[b+5|0]=d|64;break a;case 12:t[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}t[b+3|0]=19;t[b+5|0]=d|112;break a;case 15:t[b+3|0]=1;break a;case 16:case 17:t[b+3|0]=19;t[b+5|0]=l|c<<4;break a;case 18:t[b+3|0]=15;break a;case 19:t[b+3|0]=11;t[b+5|0]=l<<4;break a;case 20:t[b+5|0]=l;t[b+3|0]=11;break a;case 23:t[b+3|0]=6;t[b+5|0]=l<<4;break a;case 24:t[b+5|0]=l;t[b+3|0]=6;break a;case 27:t[b+3|0]=7;t[b+5|0]=l<<4;break a;case 28:break e;default:break a}}t[b+5|0]=l;t[b+3|0]=7;break a;case 0:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n<<4;break a;case 1:if(!d){break a}t[b+5|0]=n;t[b+3|0]=24;break a;case 4:t[b+3|0]=11;t[b+5|0]=l<<4|15;break a;case 5:t[b+3|0]=11;t[b+5|0]=l|240;break a;case 6:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n|240;break a;case 8:if(!d){break a}t[b+3|0]=16;v[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=v[h>>2];if(a>>>0<1e4){break a}t[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,y=tk(245850/(m+m)),t[s+5|0]=y;break a;case 10:t[b+3|0]=19;t[b+5|0]=o|224;break a;case 12:t[b+3|0]=28;t[b+5|0]=o|16;break a;case 13:t[b+3|0]=28;t[b+5|0]=o|32;break a;case 14:t[b+3|0]=29;t[b+5|0]=l<<3&240;break a;case 15:t[b+3|0]=29;t[b+5|0]=(l&254)>>>1;break a;case 16:t[b+3|0]=18;break a;case 17:t[b+3|0]=19;t[b+5|0]=o|176;break a;case 18:case 19:t[b+3|0]=20;t[b+5|0]=d?120:119;break a;case 20:t[b+3|0]=20;t[b+5|0]=d?125:123;break a;case 21:t[b+3|0]=20;t[b+5|0]=d?122:121;break a;case 22:t[b+3|0]=20;t[b+5|0]=d?126:123;break a;case 26:t[b+3|0]=10;t[b+5|0]=d+15>>>4;break a;case 27:t[b+5|0]=1;t[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=v[h>>2];if(o>>>0<1e4){break a}l=v[i>>2];if(!l){break a}i=vq(a,f,g);if(!i){break a}j=Hi(a,i);n=x[j+34>>1];g:{if(!(n&2)){i=v[j>>2];break g}i=v[j+8>>2]-((e|0)<6?v[j+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=v[j+24>>2];if(!n){break a}h:{if(x[a+480192>>1]<g>>>0){break h}a=v[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(w[Lb(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=ni(m/12+(a?(e|0)<6?+t[j+37|0]/-1536:-0:-0))*+(n>>>0);if(a){t[b+3|0]=17;a=tk(m*.5*(+(B(d,l)>>>0)*2.5)/+(i>>>0));t[b+5|0]=a;v[h>>2]=B(a,1e4);break a}m=tu(mK(+(i>>>0)/m/(+(B(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=$c(w[b|0]);t[b|0]=a;m=(m-H(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}t[b+5|0]=a;if((a|0)!=128){t[b+3|0]=35}if(c){break a}if(!w[b+2|0]){t[b+4|0]=9;t[b+2|0]=11;break a}t[b+5|0]=255;t[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}t[b+3|0]=20;t[b+5|0]=a-99;break a;case 34:t[b+3|0]=21;t[b+5|0]=d<<2;break a;case 35:t[b+3|0]=21;s=b,y=tg(dB(d<<4)>>>6|0),t[s+5|0]=y;break a;case 36:case 38:t[b+3|0]=22;t[b+5|0]=j<<4;break a;case 37:case 39:t[b+5|0]=j;t[b+3|0]=22;break a;case 40:t[b+3|0]=22;t[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}t[b+3|0]=22;t[b+5|0]=l|240}kb=k+128|0}function Pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=kb-208|0;kb=d;zc(c);a:{if(!vo(c,d+192|0)){break a}if(Sb(d+192|0,13769,4)){break a}f=d+200|0;if(Sb(f,14142,4)){if(Sb(f,14246,4)){break a}}e=kb-32|0;kb=e;i=d+176|0;g=Tb(i);b:{c:{d:{e:{f:{while(1){h=v[c+8>>2];j=v[c>>2];v[23588]=0;h=W(156,j|0,h|0,8)|0;j=v[23588];v[23588]=0;if((j|0)==1){break d}if(!h){break e}v[23588]=0;R(787,e|0,c|0);h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;R(788,g|0,e|0);h=v[23588];v[23588]=0;if((h|0)==1){break f}Ad(e);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ad(e);break c}kb=e+32|0;break b}a=P()|0;O()|0}Zd(g);T(a|0);L()}v[23588]=0;U(717,d+152|0,i|0,1129270605);c=v[23588];v[23588]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){v[23588]=0;c=Q(718,d+152|0,d+128|0)|0;e=v[23588];v[23588]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!cc(x[d+130>>1]|x[d+132>>1]<<16)){break g}if((Ib(x[d+128>>1])-3&65535)>>>0<65534){break g}if((Ib(x[d+134>>1])-65&65535)>>>0<65472){break g}v[d+124>>2]=1162760014;c=1;if(!Sb(f,14246,4)){v[23588]=0;c=Q(606,d+152|0,d+124|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break o}if(!c){break g}c=v[d+124>>2]!=1936684916}v[23588]=0;U(717,d+104|0,d+176|0,1397968452);e=v[23588];v[23588]=0;p:{q:{if((e|0)!=1){v[23588]=0;k=Q(719,d+104|0,d+96|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break p}if(k){break q}break h}c=P()|0;O()|0;break j}f=((Ib(x[d+134>>1])-1|0)/8|0)-1|0;g=f<<3;e=g&31;g=_c(d+88|0,(f>>>0<7?(g&63)>>>0>=32?4196360>>>e|0:((1<<e)-1&4196360)<<32-e|136321040>>>e:8)&255,(Ib(x[d+128>>1])|0)==2?2:1,c,0);c=v[d+124>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}dg(g,3);break r}dg(g,17);xd(g,16);break r}dg(g,16);xd(g,16);break r}dg(g,1)}c=v[d+96>>2];v[23588]=0;c=W(156,v[d+104>>2],v[d+112>>2],cc(c)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}if(c){c=v[d+96>>2];v[23588]=0;Q(188,d+104|0,cc(c)|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break l}}st(a,b);v[23588]=0;c=B(b,104)+a|0;i=c+484380|0;R(277,i|0,0);e=v[23588];v[23588]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}r=i,s=cc(x[d+130>>1]|x[d+132>>1]<<16),v[r>>2]=s;j=c+484404|0;c=w[d+138|0]|w[d+139|0]<<8|(w[d+140|0]<<16|w[d+141|0]<<24);f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);h=30-w[d+137|0]|0;e=0;while(1){c=f;if(h&255){f=c>>>1|0;h=h-1|0;e=c;continue}break}v[j>>2]=c+(e&1);v[23588]=0;W(219,g|0,i|0,d+104|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break D}v[23588]=0;U(717,d- -64|0,d+176|0,1296126539);c=v[23588];v[23588]=0;if((c|0)==1){break C}v[23588]=0;c=S(178,v[d+64>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break B}if(!c){break u}v[23588]=0;U(717,d+16|0,d+176|0,1229869908);c=v[23588];v[23588]=0;if((c|0)==1){break A}v[23588]=0;c=Q(720,d+16|0,d+40|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break z}Bb(d+16|0);if(!c){break u}v[23588]=0;f=S(271,d- -64|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break y}e=Tb(d+16|0);v[23588]=0;R(721,e|0,f|0);c=v[23588];v[23588]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}v[23588]=0;g=Q(722,d- -64|0,d|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break w}if(!g){break x}v[23588]=0;R(723,e|0,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break w}v[23588]=0;Q(188,d- -64|0,w[d+6|0]|1)|0;g=v[23588];v[23588]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break m}c=P()|0;O()|0;break m}c=P()|0;O()|0;Bb(d+16|0);break m}c=P()|0;O()|0;break m}c=Ib(x[d+48>>1]);if(c){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]&65511|((c|0)==2)<<4|8}c=Ib(x[d+54>>1]);if(c){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]&65529|((c|0)==2?4:2)|2}r=d,s=Fb(v[e>>2]),v[r>>2]=s;c=B(b,104)+a|0;g=c+484388|0;h=c+484384|0;j=c+484396|0;l=c+484392|0;m=Fb(v[e+4>>2]);n=x[d+50>>1];o=x[d+52>>1];p=x[d+56>>1];q=x[d+58>>1];while(1){c=v[d>>2];if(!Pb(c,m)){break v}f=Ib(w[c|0]|w[c+1|0]<<8);if((f|0)==(Ib(n)|0)){r=l,s=cc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Ib(w[c|0]|w[c+1|0]<<8)}if((Ib(o)|0)==(f|0)){r=j,s=cc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Ib(w[c|0]|w[c+1|0]<<8)}if((Ib(p)|0)==(f|0)){r=h,s=cc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Ib(w[c|0]|w[c+1|0]<<8)}if((f|0)==(Ib(q)|0)){r=g,s=cc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s}v[d>>2]=v[d>>2]+7;continue}}c=P()|0;O()|0;nO(e);break m}Dk(i);nO(e)}v[23588]=0;U(717,d+16|0,d+176|0,1312902469);c=v[23588];v[23588]=0;if((c|0)==1){break n}v[23588]=0;c=S(178,v[d+16>>2])|0;e=v[23588];v[23588]=0;E:{if((e|0)==1){break E}F:{if(c){v[23588]=0;c=S(160,v[d+16>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break E}v[23588]=0;U(314,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break F}break E}v[23588]=0;c=Q(55,d|0,21619)|0;e=v[23588];v[23588]=0;if((e|0)==1){break E}Dc(((b<<5)+a|0)+946304|0,c);zb(c)}Dz(i,v[a+480180>>2]);uj(i,a);Bb(d+16|0);Bb(d- -64|0);break h}c=P()|0;O()|0;Bb(d+16|0);break m}c=P()|0;O()|0;break k}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break m}c=P()|0;O()|0;break i}Bb(d- -64|0);break k}c=P()|0;O()|0}Bb(d+104|0)}Bb(d+152|0)}Zd(d+176|0);T(c|0);L()}Bb(d+104|0)}Bb(d+152|0);Zd(d+176|0)}kb=d+208|0;return k|0}function ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=kb-224|0;kb=e;zc(b);a:{if(!Zt(b,e+160|0)){break a}if(!PQ(e+160|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(OQ(e+160|0),nb))){break a}if(!c){d=1;break a}Bd(a,256);f=e+144|0;Dj(f,2,e+160|0);d=e+48|0;Fc(d,f);Bc(a+1298308|0,d);zb(d);f=x[e+210>>1];v[a+480260>>2]=64;v[a+480264>>2]=32767;u[a+480188>>1]=4;u[a+480190>>1]=f;Ob(a+1074312|0,107,1);f=w[e+203|0];f=f?f:96;k=Vz(f);v[a+480196>>2]=f>>>4;v[a+480204>>2]=k;t[e+48|0]=64;A=a,C=w[Xb(e+202|0,d)|0]<<2,v[A+480200>>2]=C;d=0;b:{c:{d:{e:{f:{g:{while(1){if((d|0)==4){h:{k=Tb(e+144|0);m=Tb(e+128|0);v[23588]=0;Q(155,b|0,x[e+192>>1]<<4)|0;d=v[23588];v[23588]=0;i:{if((d|0)==1){break i}v[23588]=0;W(217,b|0,k|0,x[e+208>>1])|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}v[23588]=0;Q(155,b|0,x[e+194>>1]<<4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}v[23588]=0;W(217,b|0,m|0,x[e+210>>1])|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}v[23588]=0;Q(155,b|0,(x[e+196>>1]<<4)+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}d=a+484376|0;f=w[d|0];i=v[a+484360>>2];v[23588]=0;R(324,Wb(i,f)|0,x[e+212>>1]);f=v[23588];v[23588]=0;if((f|0)==1){break i}d=Wb(v[a+484360>>2],w[d|0]);A=e,C=Fb(v[d>>2]),v[A+48>>2]=C;d=Fb(v[d+4>>2]);j:{while(1){f=v[e+48>>2];if(!Pb(f,d)){d=0;if(!RQ(Wb(v[a+484360>>2],w[a+484376|0]))){break b}i=c&2;j=e+48|1;d=1;break j}v[23588]=0;i=S(206,b|0)|0;j=v[23588];v[23588]=0;k:{if((j|0)==1){break k}u[f>>1]=i;v[23588]=0;Q(188,b|0,4)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}Se(e+48|0);continue}break}d=P()|0;O()|0;break c}l:{m:{n:{o:{while(1){f=d&65535;if(f>>>0>x[e+210>>1]){break l}g=dc(v[m>>2],f-1|0);g=w[g|0]|w[g+1|0]<<8;v[23588]=0;g=Q(155,b|0,g<<4)|0;h=v[23588];v[23588]=0;p:{if((h|0)!=1){if(g){break p}d=0;break b}d=P()|0;O()|0;break c}v[23588]=0;Q(670,b|0,e+48|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break o}v[23588]=0;g=(B(f,104)+a|0)+484380|0;U(671,e+48|0,g|0,0);h=v[23588];v[23588]=0;if((h|0)==1){break o}h=e+16|0;uk(h,2,j);v[23588]=0;R(222,e+32|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break n}h=((f<<5)+a|0)+946304|0;f=e+32|0;Dc(h,f);zb(f);q:{r:{if(!i|!v[e+64>>2]){break r}f=cR(e+48|0);v[23588]=0;f=Q(155,b|0,f|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break m}if(!f){break r}f=e+32|0;bR(f,w[e+78|0],w[e+79|0],1);v[23588]=0;W(219,f|0,g|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break q}}d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}t[e+15|0]=1;d=v[k>>2];s:{if(pc(d,v[k+4>>2])|x[e+188>>1]==26){break s}f=w[d|0]|w[d+1|0]<<8;d=0;v[23588]=0;f=Q(155,b|0,f<<4)|0;i=v[23588];v[23588]=0;if((i|0)==1){break h}if(!f){break b}v[23588]=0;d=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break h}if((d|0)!=x[e+188>>1]){break s}t[e+15|0]=0}n=c&1;if(n){v[23588]=0;R(225,a+484344|0,x[e+208>>1]);c=v[23588];v[23588]=0;if((c|0)==1){break h}}h=a+484344|0;c=e+48|0;p=c|5;q=c|4;r=c|2;s=c|1;y=a+480188|0;f=0;while(1){t:{if(!n|x[e+208>>1]<=f>>>0){break t}v[23588]=0;c=W(226,h|0,f&65535,64)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}if(!c){break t}c=dc(v[k>>2],f);c=w[c|0]|w[c+1|0]<<8;v[23588]=0;c=Q(155,b|0,c<<4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}d=0;if(!c){break b}if(!w[e+15|0]){v[23588]=0;c=S(194,b|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break g}if(c>>>0>2112){break b}}u[e+16>>1]=65535;v[e+32>>2]=63;u:while(1){c=Zb(v[h>>2],f);z=Df(v[c>>2],v[v[c+48>>2]+12>>2],d);v:while(1){c=d;while(1){if(c>>>0<=63){v[23588]=0;i=S(206,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}if(!i){d=64;if(c>>>0>62){continue v}d=c+1|0;continue u}d=i&31;j=B(d,6)+z|0;l=ug(e+48|0);g=d>>>0<x[y>>1];o=g?j:l;if(i&32){v[23588]=0;R(260,e|0,b|0);d=v[23588];v[23588]=0;w:{x:{y:{if((d|0)!=1){l=Oc(e);d=w[e|0];if(d>>>0>239){break y}d=aR((B(d>>>4|0,12)+(d&15)|0)+37|0);break x}d=P()|0;O()|0;break c}z:{switch(d-254|0){case 0:break x;case 1:break z;default:break w}}d=0}t[o|0]=d}t[(g?j+1|0:s)|0]=w[l|0]}if(i&64){v[23588]=0;d=S(206,b|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break e}t[e|0]=d;t[(g?j+2|0:r)|0]=1;t[e+14|0]=64;A=g?j+4|0:q,C=w[Xb(e,e+14|0)|0],t[A|0]=C}if(!(i&128)){continue}v[23588]=0;R(260,e|0,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}A=g?j+5|0:p,C=w[Oc(e)|0],t[A|0]=C;QQ(o,w[e|0],c,255,e+16|0,e+32|0);continue}break}break}break}c=x[e+16>>1];if((c|0)!=65535){Ae(Zb(v[h>>2],f),Mm(Ue(Oe(e+48|0,12,c&255),v[e+32>>2])))}f=f+1|0;continue}break}v[23588]=0;b=Q(1,e+48|0,6091)|0;c=v[23588];v[23588]=0;A:{B:{C:{if((c|0)!=1){Jb(a+1298344|0,b);Ab(b);v[23588]=0;b=Q(1,e+32|0,5277)|0;c=v[23588];v[23588]=0;if((c|0)==1){break C}Jb(a+1298356|0,b);Ab(b);v[a+1298404>>2]=5;v[23588]=0;R(673,e|0,4408);b=v[23588];v[23588]=0;if((b|0)==1){break B}v[23588]=0;U(305,e+16|0,e|0,e+15|0);b=v[23588];v[23588]=0;if((b|0)==1){break A}b=a+1298368|0;a=e+16|0;Jb(b,a);Ab(a);bc(e);d=1;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;bc(e);break c}d=P()|0;O()|0;break c}}else{f=(d<<5)+a|0;ef(f+480280|0);u[f+480284>>1]=d&1?64:192;d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0}od(m);od(k);T(d|0);L()}od(m);od(k)}kb=e+224|0;return d|0}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=kb-224|0;kb=f;if(Gh(b,13784)){if(d){t[d|0]=1}k=a+480204|0;n=a+480216|0;o=a+480220|0;p=a+480224|0;l=a+1074368|0;s=a+480228|0;z=a+480232|0;q=a+480200|0;m=a+480268|0;A=a+1298320|0;C=a+480248|0;D=nu(a+1074312|0);E=a+480180|0;F=a+484376|0;G=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Qb(v[b>>2],v[b+8>>2],7)){break a}e=Cg(b);g=Sg(b);if((e|0)==(w[21595]|w[21596]<<8|(w[21597]<<16|w[21598]<<24))){zg(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Qb(v[b>>2],v[b+8>>2],g)){break a}d=f+176|0;ae(d,b,g);h=kc(f+200|0,d);Bb(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=z;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=n;if((e|0)==1380991534){break s}d=o;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=s;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}v[23588]=0;U(440,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}v[k>>2]=B(v[f+176>>2],1e4)+(y[k>>2]%1e4|0);break j}v[23588]=0;U(440,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=v[k>>2];v[k>>2]=d-((d>>>0)%1e4|0)+y[f+176>>2]%1e4;break j}e=P()|0;O()|0;break b}if(c){break j}v[23588]=0;u[f+176>>1]=0;U(441,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)!=1){H=a,I=Dd(x[f+176>>1],x[a+480188>>1],127),u[H+480188>>1]=I;break j}e=P()|0;O()|0;break b}v[23588]=0;U(442,h|0,g|0,l|0);d=v[23588];v[23588]=0;if((d|0)!=1){break j}break c}v[23588]=0;v[f+176>>2]=0;U(440,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[a+1074304>>2]=v[f+176>>2];break j}e=P()|0;O()|0;break b}v[23588]=0;v[f+176>>2]=0;U(440,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)==1){break h}d=v[f+176>>2];if(!d){break j}v[a+1074308>>2]=d;break j}d=q}v[23588]=0;U(440,h|0,g|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}break j}if(v[E>>2]==4){break j}v[23588]=0;U(441,h|0,g|0,f+176|0);d=v[23588];v[23588]=0;if((d|0)!=1){Ve(Wb(v[a+484360>>2],w[F|0]),x[f+176>>1]);break j}e=P()|0;O()|0;break b}v[23588]=0;U(443,h|0,g|0,m|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}if(Io(w[m|0])){break j}t[m|0]=5;break j}d=Mb(f+176|0);e=v[h>>2];v[23588]=0;e=S(160,e|0)|0;g=v[23588];v[23588]=0;x:{if((g|0)==1){break x}v[23588]=0;U(444,h|0,d|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break x}v[23588]=0;U(11,f+160|0,0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break x}e=f+160|0;Jb(A,e);Ab(e);zb(d);break j}e=P()|0;O()|0;zb(d);break b}if(g&1|g>>>0>126){break j}d=64;u[f+176>>1]=(g>>>1|0)- -64;u[f+160>>1]=127;e=x[Wc(f+176|0,f+160|0)>>1];i=e>>>0>64?e:64;while(1){if((d|0)==(i|0)){break j}v[23588]=0;R(260,f+176|0,h|0);e=v[23588];v[23588]=0;if((e|0)==1){break g}e=w[f+176|0];y:{if((e|0)==255){break y}j=w[Oc(f+176|0)|0];g=(d<<5)+a|0;r=g+480284|0;u[r>>1]=128;u[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;v[g>>2]=j;e=e&127;if(e>>>0<65){u[r>>1]=e<<2;break y}if((e|0)!=100){break y}v[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}v[23588]=0;d=S(194,h|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break f}if(!d|d>>>0>x[G>>1]){break j}d=(B(d,104)+a|0)+484448|0;g=xT(d);while(1){if((d|0)==(g|0)){break j}e=v[h>>2];v[23588]=0;i=W(156,e|0,v[f+208>>2],4)|0;e=v[23588];v[23588]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}v[23588]=0;e=S(157,h|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){break z}}e=P()|0;O()|0;break b}v[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}v[23588]=0;R(445,f|0,h|0);d=v[23588];v[23588]=0;A:{B:{C:{D:{if((d|0)!=1){v[23588]=0;U(446,f+176|0,v[f>>2],v[f+4>>2]);d=v[23588];v[23588]=0;if((d|0)==1){break D}v[23588]=0;d=Q(89,f+16|0,f+176|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break C}zb(f+176|0);ic(f);e=v[h>>2];v[23588]=0;S(160,e|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break A}v[23588]=0;U(447,d|0,C|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break A}sf(d);break j}e=P()|0;O()|0;break b}e=P()|0;O()|0;break B}e=P()|0;O()|0;zb(f+176|0)}ic(f);break b}e=P()|0;O()|0;sf(d);break b}e=0;g=nu(D);E:while(1){d=v[h>>2];v[23588]=0;d=W(156,d|0,v[f+208>>2],1)|0;i=v[23588];v[23588]=0;if((i|0)==1){break d}if(!(d&e>>>0<118)){break j}v[23588]=0;i=S(206,h|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>117){break F}v[23588]=0;W(264,g|0,e|0,1)|0;j=v[23588];v[23588]=0;if((j|0)!=1){break F}e=P()|0;O()|0;break b}e=e+1|0;d=d+1|0;continue}}}v[23588]=0;U(448,h|0,g|0,p|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}}Bb(h);continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}Bb(h);T(e|0);L()}b=v[a+8>>2];Qo(k,B(v[b+20>>2],1e4),B(v[b+24>>2],1e4));if(w[a+480224|0]>=3){t[p|0]=0}if(w[l|0]>=6){t[l|0]=0}xc(q,256);xc(n,65536);xc(o,65536)}kb=f+224|0}function QH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0;j=kb-80|0;kb=j;v[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((2147483647-p|0)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=w[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(w[i+1|0]!=37){b=i;break j}h=h+1|0;m=w[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;D=2147483647-p|0;if((h|0)>(D|0)){break d}if(a){tf(a,k,h)}if(h){continue e}v[j+76>>2]=b;h=b+1|0;q=-1;i=t[b+1|0];if(!(!ak(i)|w[b+2|0]!=36)){q=i-48|0;x=1;h=b+3|0}v[j+76>>2]=h;n=0;i=t[h|0];b=i-32|0;k:{if(b>>>0>31){m=h;break k}m=h;b=1<<b;if(!(b&75913)){break k}while(1){m=h+1|0;v[j+76>>2]=m;n=b|n;i=t[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=m;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){b=t[m+1|0];m:{if(!(!ak(b)|w[m+2|0]!=36)){v[((b<<2)+e|0)-192>>2]=10;i=m+3|0;x=1;b=v[((t[m+1|0]<<3)+d|0)-384>>2];break m}if(x){break h}i=m+1|0;if(!a){v[j+76>>2]=i;x=0;r=0;break l}b=v[c>>2];v[c>>2]=b+4;x=0;b=v[b>>2]}r=b;v[j+76>>2]=i;if((r|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=PH(j+76|0);if((r|0)<0){break d}i=v[j+76>>2]}h=0;l=-1;n:{if(w[i|0]!=46){b=i;C=0;break n}if(w[i+1|0]==42){b=t[i+2|0];o:{if(!(!ak(b)|w[i+3|0]!=36)){v[((b<<2)+e|0)-192>>2]=10;b=i+4|0;l=v[((t[i+2|0]<<3)+d|0)-384>>2];break o}if(x){break h}b=i+2|0;l=0;if(!a){break o}i=v[c>>2];v[c>>2]=i+4;l=v[i>>2]}v[j+76>>2]=b;C=(l^-1)>>>31|0;break n}v[j+76>>2]=i+1;l=PH(j+76|0);b=v[j+76>>2];C=1}while(1){o=h;m=28;y=b;h=t[b|0];if(h-123>>>0<4294967238){break c}b=y+1|0;h=w[(h+B(o,58)|0)+76559|0];if(h-1>>>0<8){continue}break}v[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){v[(q<<2)+e>>2]=h;h=(q<<3)+d|0;i=v[h+4>>2];v[j+64>>2]=v[h>>2];v[j+68>>2]=i;break q}if(!a){break f}OH(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=5289;m=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=t[y|0];h=o?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}o=v[j+64>>2];i=v[j+68>>2];z=5289;break z}h=0;I:{switch(o&255){case 0:v[v[j+64>>2]>>2]=p;continue e;case 1:v[v[j+64>>2]>>2]=p;continue e;case 2:k=v[j+64>>2];v[k>>2]=p;v[k+4>>2]=p>>31;continue e;case 3:u[v[j+64>>2]>>1]=p;continue e;case 4:t[v[j+64>>2]]=p;continue e;case 6:v[v[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=v[j+64>>2];v[k>>2]=p;v[k+4>>2]=p>>31;continue e}l=l>>>0>8?l:8;n=n|8;h=120}k=s;F=h&32;o=v[j+64>>2];i=v[j+68>>2];if(o|i){while(1){k=k-1|0;t[k|0]=F|w[(o&15)+77088|0];G=!i&o>>>0>15|(i|0)!=0;y=i;i=i>>>4|0;o=(y&15)<<28|o>>>4;if(G){continue}break}}if(!(n&8)|!(v[j+64>>2]|v[j+68>>2])){break y}z=(h>>>4|0)+5289|0;q=2;break y}h=s;k=v[j+68>>2];i=k;o=v[j+64>>2];if(i|o){while(1){h=h-1|0;t[h|0]=o&7|48;y=!i&o>>>0>7|(i|0)!=0;k=i;i=i>>>3|0;o=(k&7)<<29|o>>>3;if(y){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}h=v[j+68>>2];i=h;o=v[j+64>>2];if((h|0)<0){i=0-(i+((o|0)!=0)|0)|0;o=0-o|0;v[j+64>>2]=o;v[j+68>>2]=i;q=1;z=5289;break z}if(n&2048){q=1;z=5290;break z}q=n&1;z=q?5291:5289}k=En(o,i,s)}if((l|0)<0?C:0){break d}n=C?n&-65537:n;i=v[j+64>>2];h=v[j+68>>2];if(!((i|h)!=0|l)){k=s;m=k;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=v[j+64>>2];k=h?h:17037;h=l>>>0<2147483647?l:2147483647;m=Ws(k,0,h);h=m?m-k|0:h;m=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(w[m|0]){break d}break g}if(l){i=v[j+64>>2];break u}h=0;Hf(a,32,r,0,n);break t}v[j+12>>2]=0;v[j+8>>2]=v[j+64>>2];i=j+8|0;v[j+64>>2]=i;l=-1}h=0;J:{while(1){k=v[i>>2];if(!k){break J}k=NH(j+4|0,k);m=(k|0)<0;if(!(m|k>>>0>l-h>>>0)){i=i+4|0;h=h+k|0;if(l>>>0>h>>>0){continue}break J}break}if(m){break b}}m=61;if((h|0)<0){break c}Hf(a,32,r,h,n);if(!h){h=0;break t}m=0;i=v[j+64>>2];while(1){k=v[i>>2];if(!k){break t}k=NH(j+4|0,k);m=k+m|0;if(m>>>0>h>>>0){break t}tf(a,j+4|0,k);i=i+4|0;if(h>>>0>m>>>0){continue}break}}Hf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?C:0){break d}m=61;h=ob[f|0](a,A[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}t[j+55|0]=v[j+64>>2];l=1;k=E;n=i;break g}i=w[h+1|0];h=h+1|0;continue}}if(a){break a}if(!x){break f}h=1;while(1){a=v[(h<<2)+e>>2];if(a){OH((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(v[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}m=28;break c}o=m-k|0;l=(l|0)>(o|0)?l:o;if((l|0)>(2147483647-q|0)){break d}m=61;i=l+q|0;h=(i|0)<(r|0)?r:i;if((D|0)<(h|0)){break c}Hf(a,32,h,i,n);tf(a,z,q);Hf(a,48,h,i,n^65536);Hf(a,48,l,o,0);tf(a,k,o);Hf(a,32,h,i,n^8192);continue}break}p=0;break a}m=61}v[116064]=m}p=-1}kb=j+80|0;return p}function Uia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;e=kb-1360|0;kb=e;zc(b);g=kb-16|0;kb=g;j=e+784|0;FT(g+8|0,j);i=v[g+12>>2];nc(g,v[b>>2],v[b+8>>2],v[g+8>>2],v[g+12>>2]);l=v[g+4>>2];if((l|0)==(i|0)){_b(b,v[g+12>>2])}kb=g+16|0;g=(i|0)==(l|0);if(!g){ET(j)}a:{if(!g){break a}if(!HT(e+784|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(GT(x[e+818>>1],x[e+820>>1]),nb))){break a}if(!c){d=1;break a}q=Hc(e+776|0);b:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;ef(i);j=(e+784|0)+(d<<4)|0;u[g+480284>>1]=((w[j+78|0]<<8&65280)>>>0)/255;m=e+512|0;uk(m,1,j- -64|0);l=e+112|0;Fc(l,m);Hl(g+480289|0,l);zb(l);c:{d:{switch(w[j+79|0]){case 0:k=f+1|0;break c;case 1:v[i>>2]=1024;k=d+1|0;break c;case 2:break d;default:break b}}v[i>>2]=1024;g=e+112|0;Sc(g,q,d);po(g)}f=f+1|0;d=d+1|0;continue}break}Bd(a,33554432);u[a+480188>>1]=k&255;d=e+112|0;f=yc(d,6776);Jb(a+1298344|0,f);Ab(f);d=yc(d,11062);Jb(a+1298356|0,d);Ab(d);v[a+1298404>>2]=5;e:{if(w[e+863|0]){break e}d=1;f=1;while(1){if((d|0)==16){while(1){if((f|0)==16){break e}d=((f<<5)+a|0)+480280|0;v[d>>2]=v[d>>2]&-1025;f=f+1|0;continue}}g=d<<4;d=d+1|0;if(w[(e+g|0)+863|0]==1){continue}break}}d=e+512|0;Ne(d,1,e+784|0);f=e+112|0;Fc(f,d);Bc(a+1298308|0,f);zb(f);v[a+480208>>2]=v[a+480208>>2]&-17|x[e+822>>1]<<4&16;v[a+480196>>2]=w[e+832|0];v[a+480204>>2]=B(w[e+833|0],1e4);v[a+480200>>2]=w[e+834|0]<<2;v[a+480228>>2]=w[e+835|0];f=x[e+820>>1];u[a+480190>>1]=0;u[a+480192>>1]=f;fv(b,d);Wq(Wb(v[a+484360>>2],w[a+484376|0]),d,x[e+816>>1],65535,255);o=c&1;if(o){xg(a+484344|0,x[e+818>>1])}m=a+484344|0;s=a+480188|0;f:{while(1){g:{if(x[e+818>>1]<=h>>>0){l=c&2;q=e+108|0;m=a+480192|0;g=1;c=0;h:while(1){if(x[m>>1]<=(c&65535)>>>0){d=32;break b}c=c+1|0;f=Qu(a,c&65535,0);i=!f;d=kb-16|0;kb=d;k=e+112|0;gc(d+8|0,k,384);h=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);j=v[d+4>>2];if((j|0)==(h|0)){_b(b,v[d+12>>2])}kb=d+16|0;d=(h|0)==(j|0);if(!d){Ub(k,0,384)}if(!d|i){continue}k=g&65535;h=kb-32|0;kb=h;i=e+112|0;Ne(h,1,i);d=h+16|0;Fc(d,h);Dc(f+492|0,d);zb(d);i:{if(!(w[i+378|0]|w[i+379|0]<<8)){break i}j=f+236|0;d=0;while(1){v[h+16>>2]=120;v[h>>2]=116;if(y[Kb(h+16|0,h)>>2]<=d>>>0){break i}z=dc(j,d+12|0),A=k+w[(d+i|0)+32|0]|0,u[z>>1]=A;d=d+1|0;continue}}d=w[i+376|0]|w[i+377|0]<<8;t[f+33|0]=1;v[f>>2]=d;XA(i,f+48|0,0);XA(i,f+68|0,1);XA(i,f+88|0,2);d=w[f+100|0];if(d&1){t[f+100|0]=d|16}if(!(v[f>>2]|t[f+60|0]&1)){v[f>>2]=32767}kb=h+32|0;d=0;while(1){f=x[e+490>>1];if(f>>>0<=d>>>0){g=f+g|0;continue h}KU(b,e+48|0);j:{k:{if(Sb(q,15502,4)){break k}f=d+g|0;k=f&65535;if(k>>>0>3999){break k}u[a+480190>>1]=f;i=kb-32|0;kb=i;j=B(k,104)+a|0;f=j+484380|0;nd(f,0);_h(i,1,e+48|0);h=i+16|0;Fc(h,i);Ce(f+43|0,h);zb(h);p=w[e+64|0]|w[e+65|0]<<8|(w[e+66|0]<<16|w[e+67|0]<<24);v[f>>2]=p;n=w[e+68|0]|w[e+69|0]<<8|(w[e+70|0]<<16|w[e+71|0]<<24);v[f+4>>2]=n;o=w[e+72|0]|w[e+73|0]<<8|(w[e+74|0]<<16|w[e+75|0]<<24);v[f+8>>2]=o;v[f+24>>2]=w[e+76|0]|w[e+77|0]<<8|(w[e+78|0]<<16|w[e+79|0]<<24);u[f+30>>1]=w[e+80|0]<<2;u[f+28>>1]=w[e+81|0];h=w[e+96|0];if(h&1){u[f+34>>1]=x[f+34>>1]|2;h=w[e+96|0]}if(h&2){u[f+34>>1]=x[f+34>>1]|4;h=w[e+96|0]}if(h&4){v[f+8>>2]=o>>>1;v[f+4>>2]=n>>>1;v[f>>2]=p>>>1;u[f+34>>1]=x[f+34>>1]|1;h=w[e+96|0]}if(h&8){u[f+34>>1]=x[f+34>>1]|32}kb=i+32|0;h=kb-16|0;kb=h;pv(h+8|0,j+484423|0);i=e+24|0;br(i,v[h+8>>2],v[h+12>>2]);kb=h+16|0;Dc(((k<<5)+a|0)+946304|0,i);zb(i);h=v[e+64>>2];if(!h){break k}ae(e,b,h);h=kc(e+24|0,e);Bb(e);if(l){i=_c(e,u[j+484414>>1]&1?16:8,1,0,0);v[23588]=0;W(219,i|0,f|0,h|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break j}}Bb(h)}d=d+1|0;continue}break}break}a=P()|0;O()|0;Bb(h);break f}f=Sg(b);p=Sg(b);d=e+48|0;ae(d,b,f-4|0);j=kc(e+112|0,d);Bb(d);l:{m:{if(!o){break m}v[23588]=0;d=W(226,m|0,h&65535,p|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break l}if(!d){break m}k=0;i=ug(e+24|0);while(1){if(k>>>0>=p>>>0){break m}v[23588]=0;l=S(206,j|0)|0;d=v[23588];v[23588]=0;n:{if((d|0)!=1){if(l){break n}k=k+1|0;continue}break g}f=i;n=l&31;if(n>>>0<x[s>>1]){d=Zb(v[m>>2],h);f=jd(v[d>>2],v[v[d+48>>2]+12>>2],k,n)}if(l&32){v[23588]=0;R(260,e+48|0,j|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}g=w[e+48|0];t[f|0]=g;z=f,A=w[Oc(e+48|0)|0],t[z+1|0]=A;o:{p:{if((g|0)==160){d=255;break p}if((g|0)==255){d=0;break p}d=0;g=(B(g>>>4|0,12)+(g&15)|0)+13|0;if(DT(g)){break o}}g=d}t[f|0]=g}d=l&192;q:{if(!d){break q}if((d|0)==192){v[23588]=0;R(349,e+48|0,j|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=e+48|0;g=Oc(d);l=Te(d);d=Mi(d);YA(e,w[e+48|0],w[g|0]);g=Oc(e);r=e+504|0;YA(r,w[l|0],w[d|0]);Bo(e+496|0,f,w[e|0],w[g|0],w[e+504|0],w[Oc(r)|0]);break q}break g}v[23588]=0;R(260,e+48|0,j|0);d=v[23588];v[23588]=0;r:{s:{if((d|0)!=1){YA(e,w[e+48|0],w[Oc(e+48|0)|0]);g=w[Oc(e)|0];d=w[e|0];if((d|0)!=13){break s}t[f+2|0]=1;d=f+4|0;break r}break g}t[f+3|0]=d;d=f+5|0}t[d|0]=g}Sc(e+48|0,q,n);if(!Cb(v[v[e+48>>2]>>2],v[e+52>>2])){continue}if(!AV(w[f+3|0],w[f+5|0])){continue}t[f+3|0]=0;continue}}Bb(j);h=h+1|0;continue}}break}a=P()|0;O()|0;Bb(j)}T(a|0);L()}d=d>>>0>31}kb=e+1360|0;return d|0}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;e=kb-1824|0;kb=e;zc(b);d=kb-16|0;kb=d;j=e+1224|0;YR(d+8|0,j);f=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);i=v[d+4>>2];if((i|0)==(f|0)){_b(b,v[d+12>>2])}kb=d+16|0;d=(f|0)==(i|0);if(!d){XR(j)}a:{if(!d){break a}if(!ZR(e+1224|0)){break a}if(!iA(b,16,0)){break a}v[e+1216>>2]=v[e+1240>>2];d=v[e+1228>>2];v[e+1200>>2]=v[e+1224>>2];v[e+1204>>2]=d;d=e+1232|0;f=v[d+4>>2];v[e+1208>>2]=v[d>>2];v[e+1212>>2]=f;Bd(a,1);Ob(Ob(_f(a+1074312|0,83),84,1),85,1);u[a+480188>>1]=4;v[e+1196>>2]=0;u[a+480190>>1]=15;dd(b,20);i=a+480188|0;g=1;n=1;while(1){b:{if((g|0)==16){d=e+1064|0;fS(b,d);f=a+484360|0;j=a+484376|0;Iq(Wb(v[f>>2],w[j|0]),d|2,128);g=0;m=eS(b,Wb(v[f>>2],w[j|0]),w[e+1064|0],k,i,0,1);if(!(w[e+1064|0]?1:w[e+1065|0]|m>>>0>1)){break a}if(df(b)+65536>>>0<(m<<10)+k>>>0){break a}if(c){break b}g=1;break a}f=B(g,104)+a|0;j=f+484380|0;d=((g<<5)+a|0)+946304|0;jA(b,e+24|0,j,d,1);m=v[j>>2];c:{if(!w[Lb(d,0)|0]){break c}d:{if(Sb(d,16738,3)){if(Sb(d,16742,3)){break d}}if(w[Lb(d,5)|0]==58){break c}}n=0}d=Ib(x[e+52>>1]);if(d>>>0>=2){l=d<<1;d=Ib(x[e+50>>1]);v[f+484388>>2]=l+d;v[f+484384>>2]=d;Dk(j)}e:{if(Ib(x[e+46>>1])>>>0<=4999){if(Ib(x[e+50>>1])>>>0<1e4){break e}}v[e+1064>>2]=5;z=e,A=v[Pe(e+1196|0,e+1064|0)>>2],v[z+1196>>2]=A}k=k+m|0;g=g+1|0;continue}break}g=w[e+1065|0];if(!g){t[e+1065|0]=120;g=120}f:{if(!Sb(e+1200|0,14890,6)){t[e+1065|0]=120;v[a+480204>>2]=125e4;break f}v[a+480204>>2]=125e4;if((g|0)==120){break f}z=a,A=Qe(1773447.5/(+(240-g|0)*122)*1e4),v[z+480204>>2]=A;if(v[e+1196>>2]>=2){v[e+24>>2]=n?4:5;z=e,A=v[Pe(e+1196|0,e+24|0)>>2],v[z+1196>>2]=A;break f}v[e+24>>2]=n?1:2;z=e,A=v[Pe(e+1196|0,e+24|0)>>2],v[z+1196>>2]=A}v[a+480228>>2]=64;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480208>>2]=v[a+480208>>2]|2097152;f=e+1048|0;Dj(f,3,e+1200|0);d=e+24|0;Fc(d,f);Bc(a+1298308|0,d);zb(d);oh(a,0);r=v[b+8>>2];s=a+484376|0;while(1){g:{h:{if((p&65535)>>>0<m>>>0){d=Wb(v[a+484360>>2],w[s|0]);d=Pb(cA(Fb(v[d>>2]),Fb(v[d+4>>2]),p),Fb(v[d+4>>2]));WR(b,e+24|0);if(d){h=gA(e+24|0,0)+h|0;if(h>>>0>512){break h}}k=0;d=0;j=0;i:while(1){if((j|0)==64){break g}g=0;y=Kd(e+24|0,j);while(1){f=d;if((g|0)==4){j=j+1|0;continue i}else{o=Eb(y,g);l=w[Lb(o,2)|0]&15;i=w[Lb(o,3)|0];d=0;j:{if(!(f&255)){break j}if(Sb(o,26884,4)){break j}d=f+1|0;if((d&255)>>>0<33){break j}v[e+1196>>2]=6}k:{l:{m:{switch(l-1|0){case 0:case 1:f=v[e+1196>>2];if((f|0)==1&i>>>0>=32){break l}l=(l|0)!=1;if(!(l|!i|i>>>0>2)){v[e+1048>>2]=2;z=e,A=v[Pe(e+1196|0,e+1048|0)>>2],v[z+1196>>2]=A;break k}if(l|(i|0)!=55&(i|0)!=71){break k}if((f|0)<=2){break l}break k;case 10:v[e+1196>>2]=6;break k;case 11:case 12:case 13:v[e+1048>>2]=2;z=e,A=v[Pe(e+1196|0,e+1048|0)>>2],v[z+1196>>2]=A;if((l|0)!=13){break k}k=((i|j)!=0)+k|0;d=1;break k;case 14:break m;default:break k}}v[e+1048>>2]=3;z=e,A=v[Pe(e+1196|0,e+1048|0)>>2],v[z+1196>>2]=A;break k}v[e+1196>>2]=n}g=g+1|0;continue}}}}if(!(v[e+1196>>2]!=6|m+32>>>0>=q>>>0)){v[e+1196>>2]=5}dd(b,r);o=c&1;if(o){xg(a+484344|0,m)}l=a+484344|0;k=0;while(1){if((k|0)==(m|0)){g=21619;d=v[e+1196>>2];if(d>>>0<7){g=v[(d<<2)+26896>>2]}d=e+24|0;f=yc(d,8264);Jb(a+1298344|0,f);Ab(f);d=yc(d,10706);Jb(a+1298356|0,d);Ab(d);Rl(a+1298368|0,g);v[a+1298404>>2]=14;if(!(c&2)){break h}g=1;while(1){if((g|0)==16){break h}c=B(g,104)+a|0;d=c+484384|0;_b(b,v[d>>2]);f=v[d>>2];v[d>>2]=0;d=c+484380|0;v[d>>2]=v[d>>2]-f;c=c+484388|0;v[c>>2]=v[c>>2]-f;c=e+24|0;_c(c,8,1,1,0);wg(c,d,b);g=g+1|0;continue}}WR(b,e+24|0);n:{if(!o){break n}if(!ph(l,k&65535,64)){break n}j=0;v[e+1048>>2]=0;o:while(1){if((j|0)==64){break n}g=0;d=Zb(v[l>>2],k);q=jd(v[d>>2],v[v[d+48>>2]+12>>2],j,0);r=Kd(e+24|0,j);while(1)if((g|0)==4){j=j+1|0;continue o}else{d=Eb(r,g);d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+4>>2]=d;v[e+8>>2]=d;h=e+16|0;d=q+B(g,6)|0;yu(h,e+4|0,d);f=w[e+16|0];i=Oc(h);h=w[i|0];if(!((f|0)!=14?h:0)){t[(e+1048|0)+g|0]=0}n=(e+1048|0)+g|0;p:{if(f|h){q:{h=w[n|0];if(h){r:{if(h>>>0>=16){t[d+2|0]=3;h=h>>>4|0;break r}t[d+2|0]=4}t[d+4|0]=h;f=w[e+16|0]}s:{t:{u:{v:{switch((f&255)-12|0){case 1:h=v[e+1196>>2];if((h|0)!=6){t[e+16|0]=10;break t}t[i|0]=0;break u;case 0:t[i|0]=w[i|0]&127;break u;case 2:h=w[i|0];if(h>>>0<=1){f=14;if(v[e+1196>>2]>3){break s}}t[e+16|0]=10;t[n|0]=w[i|0];break u;case 3:break v;default:break u}}t[i|0]=w[i|0]&15}h=v[e+1196>>2]}if((h|0)<2){break q}h=w[i|0];f=w[e+16|0]}Pf(d,f,h&255);break p}f=w[i|0];t[d+5|0]=f;w:{switch(w[e+16|0]){case 0:if(w[i|0]<=2){t[d+3|0]=0;break p}t[d+3|0]=1;break p;case 1:t[d+3|0]=1;break p;case 2:h=f&15;if(h){t[d+3|0]=2;t[d+5|0]=h;break p}if(f>>>0<16){break p}t[d+3|0]=3;t[d+5|0]=(f&240)>>>4;break p;default:break w}}t[d+3|0]=0;break p}t[n|0]=0}g=g+1|0;continue}}}k=k+1|0;continue}}g=(p&65535)>>>0>=m>>>0;break a}if((k-1&255)>>>0<2){v[e+1196>>2]=6}p=p+1|0;q=(k&255)+q|0;continue}}kb=e+1824|0;return g|0}function sfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=kb-352|0;kb=d;dd(b,60);f=15;a:{if(!Gh(b,14094)){dd(b,124);f=31;if(!Gh(b,15357)){break a}}Bd(a,536870912);u[a+480190>>1]=f;zc(b);b:{while(1){if(x[a+480190>>1]>g>>>0){e=Co(b);v[(d+224|0)+(g<<2)>>2]=e;g=g+1|0;if(e>>>0<=131072){continue}break b}break}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;g=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;oh(a,1);_b(b,4);e=Hj(b);if(e>>>0<178){break a}p=a,q=Qe(1776930/+(e>>>0)*1e4),v[p+480204>>2]=q;_b(b,14);f=0;n=1;c:while(1){m=n&65535;if(m>>>0<=x[a+480190>>1]){aS(b,d+56|0);g=v[((m<<2)+d|0)+220>>2];l=kb-16|0;kb=l;h=(B(m,104)+a|0)+484380|0;nd(h,1);v[h>>2]=g;t[h+37|0]=w[d+80|0]<<4;t[l+15|0]=w[d+81|0];t[l+14|0]=64;p=h,q=w[Xb(l+15|0,l+14|0)|0]<<2,u[p+30>>1]=q;d:{if(!g){break d}e=Ib(w[d+84|0]|w[d+85|0]<<8);j=Ib(w[d+82|0]|w[d+83|0]<<8);v[h+4>>2]=j;e=(e<<1)+j|0;v[h+8>>2]=e;if(g>>>0<=j>>>0){j=g-1|0;v[h+4>>2]=j}if(e>>>0>g>>>0){v[h+8>>2]=g;e=g}if(!(!(e>>>0<4|e>>>0<j>>>0)&e-j>>>0>3)){v[h+4>>2]=0;v[h+8>>2]=0;break d}if(e>>>0<=j>>>0){break d}u[h+34>>1]=x[h+34>>1]|2}kb=l+16|0;g=0;while(1)if((g|0)==22){if(f>>>0>127){break b}e=d+192|0;Il(e,3,d+56|0);g=d+208|0;Fc(g,e);Dc(((m<<5)+a|0)+946304|0,g);n=n+1|0;zb(g);continue c}else{e=(d+56|0)+g|0;if((w[e|0]-1&255)>>>0<=30){t[e|0]=32;f=f+1|0}g=g+1|0;continue}}break}l=1;e:{f:{g:{f=a+946336|0;g=Nc(d+56|0,13961);if(!XQ(f,g)){v[23588]=0;e=Q(55,d+208|0,13972)|0;h=v[23588];v[23588]=0;if((h|0)==1){break g}l=XQ(f,e);zb(e)}zb(g);g=0;e=d+56|0;f=$R(b,e);if(!f){eA(e)}if(!f){break a}e=w[d+56|0];if(!_Q(e)){break a}if(!c){break e}u[d+54>>1]=0;while(1)if((e|0)==(g|0)){g=a+484360|0;f=a+484376|0;i=Wb(v[g>>2],w[f|0]);h=w[d+57|0];Ve(i,e>>>0>h>>>0?h:0);Iq(Wb(v[g>>2],w[f|0]),d+56|2,w[d+56|0]);if(x[a+480190>>1]==31){_b(b,4)}v[d+48>>2]=0;v[d+44>>2]=0;v[d+40>>2]=0;t[d+39|0]=0;m=c&1;if(m){xg(a+484344|0,x[d+54>>1])}n=a+484344|0;h=0;while(1){h:{i:{j:{if(x[d+54>>1]<=h>>>0){if(!(c&2)){break j}g=1;while(1){f=x[a+480190>>1];c=g&65535;if(f>>>0<c>>>0){break i}c=(B(c,104)+a|0)+484380|0;if(v[c>>2]){wg(_c(d+192|0,8,1,0,0),c,b)}g=g+1|0;continue}}k:{if(m){j=0;if(ph(n,h&65535,64)){break k}}_b(b,1024);break h}l:while(1){if((j|0)==64){break h}g=0;e=Zb(v[n>>2],h);o=jd(v[e>>2],v[v[e+48>>2]+12>>2],j,0);while(1)if((g|0)==4){j=j+1|0;continue l}else{f=d+192|0;Tm(f,b);e=B(g,6)+o|0;m:{n:{o:{p:{if(w[Lb(f,0)|0]!=255){break p}t[(d+48|0)+g|0]=0;t[(d+40|0)+g|0]=0;f=Lb(d+192|0,1);i=w[f|0];if((i|0)==252&l){t[f|0]=254;break n}switch(i-252|0){case 1:break m;case 2:break n;case 0:break o;default:break p}}f=v[d+192>>2];v[d+32>>2]=f;v[d+12>>2]=f;f=d+16|0;yu(f,d+12|0,e);i=Oc(f);f=w[e|0];q:{if(!f){break q}t[(d+40|0)+g|0]=0;t[(d+48|0)+g|0]=f;if(f>>>0>48){break q}t[d+31|0]=8;p=d,q=w[kf(d+39|0,d+31|0)|0],t[p+39|0]=q}f=w[i|0];r:{if(!(f|w[d+16|0])){break r}t[e+5|0]=f;s:{t:{switch(w[d+16|0]-1|0){case 0:t[e+3|0]=1;break r;case 1:if(f&240){t[e+3|0]=3;t[e+5|0]=f>>>4;break r}f=f&15;if(f){t[e+3|0]=2;t[e+5|0]=f;break r}t[e+3|0]=0;break r;case 2:if(w[(d+40|0)+g|0]){t[e+3|0]=0;break r}t[e+3|0]=19;t[e+5|0]=0;break r;case 3:if(w[(d+40|0)+g|0]){t[e+3|0]=0;break r}t[e+3|0]=19;t[e+5|0]=1;break r;case 4:if(!w[e+1|0]){break s}t[d+31|0]=63;t[d+30|0]=w[e+5|0]+(x[(B(w[e+1|0],104)+a|0)+484410>>1]>>>2|0);f=w[Xb(d+31|0,d+30|0)|0];t[e+3|0]=13;t[e+5|0]=f;if(!w[(d+40|0)+g|0]){break r}t[e+4|0]=w[e+5|0];t[e+2|0]=1;t[e+3|0]=0;break r;case 5:i=w[e+1|0];if(i){t[e+3|0]=13;i=x[(B(i,104)+a|0)+484410>>1]>>>2|0;f=f>>>0>i>>>0?0:i-f|0;t[e+5|0]=f;if(!w[(d+40|0)+g|0]){break r}t[e+4|0]=f;t[e+2|0]=1}t[e+3|0]=0;break r;case 6:i=f&15;t[(d+40|0)+g|0]=i;k=w[(d+48|0)+g|0];f=k-(f>>>4|0)|0;t[(d+44|0)+g|0]=f;f=WQ(i,f&255,k);t[e+3|0]=3;t[e+5|0]=f;break r;case 7:i=f&15;t[(d+40|0)+g|0]=i;k=f>>>4|0;f=w[(d+48|0)+g|0];k=k+f|0;t[(d+44|0)+g|0]=k;f=WQ(i,f,k&255);t[e+3|0]=2;t[e+5|0]=f;break r;case 8:break t;default:break s}}t[d+31|0]=8;p=d,q=w[kf(d+39|0,d+31|0)|0],t[p+39|0]=q}t[e+3|0]=0}if(w[e+3|0]){break m}i=w[(d+40|0)+g|0];if(!i){break m}k=(d+44|0)+g|0;f=w[k|0];if(f){t[(d+48|0)+g|0]=f;t[e|0]=f;t[e+5|0]=i;t[k|0]=0}t[e+3|0]=4;break m}t[e+3|0]=14;t[d+39|0]=9;break m}t[e+3|0]=13}g=g+1|0;continue}}}f=x[a+480190>>1]}u:{v:{w:{if((f&65535)==15){b=d+16|0;Sf(b,4421);v[23588]=0;U(305,d+192|0,b|0,d+39|0);b=v[23588];v[23588]=0;if((b|0)==1){break u}b=d+192|0;Jb(a+1298344|0,b);Ab(b);bc(d+16|0);break w}v[23588]=0;b=Q(1,d+192|0,12242)|0;c=v[23588];v[23588]=0;if((c|0)==1){break v}Jb(a+1298344|0,b);Ab(b)}Rl(a+1298356|0,x[a+480190>>1]==15?5285:15091);v[a+1298404>>2]=14;break e}f=P()|0;O()|0;break f}f=P()|0;O()|0;bc(d+16|0);break f}h=h+1|0;continue}}else{u[d+192>>1]=w[(d+g|0)+58|0]+1;p=d,q=x[le(d+54|0,d+192|0)>>1],u[p+54>>1]=q;g=g+1|0;continue}}f=P()|0;O()|0;zb(g)}T(f|0);L()}g=1;break a}g=0}kb=d+352|0;return g|0}function uI(a,b,c,d,e,f){var g=0,h=C(0),i=0,j=0,k=C(0),l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,A=C(0),D=C(0),E=0,F=0,G=0,H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=B(s,2304)+b|0;v=0;q=(c|0)>0?c:0;n=kb-128|0;x=n+96|0;y=n- -64|0;E=n+32|0;while(1){if((q|0)!=(v|0)){o=G+(v<<2)|0;w=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=z[B(15-j|0,72)+o>>2];g=B(j,72)+o|0;h=z[g+1152>>2];l=C(k+h);m=z[g>>2];A=z[B(31-j|0,72)+o>>2];D=C(m+A);z[p>>2]=l+D;g=B(j,12);k=C(C(k-h)*z[g+71280>>2]);h=C(C(m-A)*z[g+71284>>2]);z[p+64>>2]=k+h;m=C(D-l);l=z[g+71288>>2];z[p+32>>2]=m*l;z[p+96>>2]=C(h-k)*l;p=p+4|0;j=j+1|0;continue}break}while(1){if((w|0)!=4){l=z[i+8>>2];m=z[i+20>>2];h=C(l+m);A=z[i+4>>2];D=z[i+24>>2];H=C(A+D);k=C(h+H);I=z[i+12>>2];J=z[i+16>>2];K=C(I+J);L=z[i>>2];M=z[i+28>>2];N=C(L+M);O=C(K+N);z[i>>2]=k+O;z[i+16>>2]=C(O-k)*C(.7071067690849304);k=C(N-K);h=C(C(k+C(H-h))*C(.7071067690849304));z[i+24>>2]=C(k-h)*C(1.3065630197525024);z[i+8>>2]=C(k+h)*C(.5411961078643799);k=C(L-M);h=C(l-m);l=C(A-D);m=C(C(h+l)*C(.7071067690849304));A=C(k+m);D=C(C(I-J)+h);h=C(l+k);l=C(D-C(h*C(.1989123672246933)));h=C(C(l*C(.3826834261417389))+h);z[i+28>>2]=C(A-h)*C(2.562915563583374);z[i+4>>2]=C(A+h)*C(.509795606136322);k=C(k-m);h=C(l-C(h*C(.1989123672246933)));z[i+20>>2]=C(k+h)*C(.8999761939048767);z[i+12>>2]=C(k-h)*C(.601344883441925);i=i+32|0;w=w+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;z[o>>2]=z[p+n>>2];k=z[p+x>>2];i=i+1|0;j=i<<2;h=z[j+x>>2];z[o+72>>2]=C(z[p+y>>2]+k)+h;z[o+144>>2]=z[p+E>>2]+z[j+E>>2];z[o+216>>2]=h+C(k+z[j+y>>2]);o=o+288|0;continue}break}z[o>>2]=z[n+28>>2];k=z[n+124>>2];z[o+72>>2]=z[n+92>>2]+k;h=z[n+60>>2];z[o+216>>2]=k;z[o+144>>2]=h;v=v+1|0;continue}break}s=s+1|0;continue}break}E=uc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=kb-32|0;kb=i;o=E+(s<<8)|0;v=(s<<2)+b|0;z[o+4080>>2]=z[v+1152>>2];f=d-1|0;w=v+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[v>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[v+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[v+4>>2];z[o+4348>>2]=z[w+4>>2];x=(B(s,G)<<1)+e|0;y=x+(f<<1)|0;rs(y,d,o+244|0);f=d<<6;rs(f+y|0,d,o+500|0);rs(x,d,o+240|0);rs(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=71376;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=B(31-p|0,72);z[j>>2]=z[f+v>>2];z[j+4>>2]=z[f+w>>2];f=f|4;z[j+8>>2]=z[f+v>>2];z[j+12>>2]=z[f+w>>2];f=B(p,72);q=f+76|0;z[j+256>>2]=z[q+v>>2];z[j+260>>2]=z[q+w>>2];f=f+72|0;z[j-248>>2]=z[f+v>>2];z[j-244>>2]=z[f+w>>2];q=p<<2;t=g+o|0;k=z[n+4>>2];h=z[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=z[g+j>>2];m=z[g+t>>2];z[g+(i+16|0)>>2]=C(l*h)-C(k*m);z[i+g>>2]=C(l*k)+C(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=z[n+12>>2];h=z[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=z[n+20>>2];h=z[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=z[n+28>>2];h=z[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=z[n+36>>2];h=z[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=z[n+44>>2];h=z[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=z[n+52>>2];h=z[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=z[n+60>>2];h=z[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=z[j+q>>2];m=z[g+j>>2];z[t>>2]=z[t>>2]+C(C(l*k)+C(h*m));j=j+(i+16|0)|0;z[j>>2]=C(C(m*k)-C(h*l))+z[j>>2];f=f+1|0;continue}break}f=B(15-p|0,d)<<1;P=f+y|0,Q=ij(z[i+20>>2]),u[P>>1]=Q;j=B(p+17|0,d)<<1;P=j+y|0,Q=ij(z[i+4>>2]),u[P>>1]=Q;P=f+x|0,Q=ij(z[i+16>>2]),u[P>>1]=Q;P=j+x|0,Q=ij(z[i>>2]),u[P>>1]=Q;f=B(47-p|0,d)<<1;P=f+y|0,Q=ij(z[i+28>>2]),u[P>>1]=Q;j=B(p+49|0,d)<<1;P=j+y|0,Q=ij(z[i+12>>2]),u[P>>1]=Q;P=f+x|0,Q=ij(z[i+24>>2]),u[P>>1]=Q;P=j+x|0,Q=ij(z[i+8>>2]),u[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}kb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}z[(s<<2)+a>>2]=z[E+(b+s<<2)>>2];s=s+2|0;continue}}uc(a,E+(b<<2)|0,3840)}}function vja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;g=kb-288|0;kb=g;zc(b);e=kb-16|0;kb=e;h=g+80|0;eU(e+8|0,h);f=v[e+12>>2];nc(e,v[b>>2],v[b+8>>2],v[e+8>>2],v[e+12>>2]);i=v[e+4>>2];if((i|0)==(f|0)){_b(b,v[e+12>>2])}kb=e+16|0;e=(f|0)==(i|0);if(!e){dU(h)}a:{if(!e){break a}if(!gU(g+80|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(fU(g+80|0),nb))){break a}b:{if(!c){break b}Bd(a,16777216);ag(a);v[a+480208>>2]=v[a+480208>>2]|16777216;d=g+56|0;wq(d,32);f=g- -64|0;h=v[f+4>>2];e=a+1074320|0;v[e>>2]=v[f>>2];v[e+4>>2]=h;e=v[g+60>>2];v[a+1074312>>2]=v[g+56>>2];v[a+1074316>>2]=e;Ob(a+1074312|0,114,1);s=a+480188|0,y=Ib(x[g+280>>1]),u[s>>1]=y;oh(a,1);e=yc(d,8501);Jb(a+1298368|0,e);Ab(e);e=g+32|0;Sf(e,3927);v[23588]=0;U(362,d|0,e|0,w[g+83|0]);d=v[23588];v[23588]=0;c:{if((d|0)!=1){d=g+56|0;Jb(a+1298344|0,d);Ab(d);e=g+32|0;bc(e);f=yc(d,10710);Jb(a+1298356|0,f);Ab(f);v[a+1298404>>2]=12;Ne(e,3,g+80|4);Fc(d,e);Bc(a+1298308|0,d);zb(d);f=160;while(1){d:{d=f;if(!d){d=0;break d}f=d-1|0;if(w[(g+f|0)+116|0]==32){continue}}break}cU(a+1298332|0,g+116|0,d,4);o=a+480190|0;d=Ib(x[g+276>>1]);u[o>>1]=d;l=1;while(1){e:{f:{g:{h:{i:{e=d&65535;d=l&65535;if(e>>>0<d>>>0){f=a+484360|0;e=a+484376|0;Ve(Wb(v[f>>2],w[e|0]),Ib(x[g+284>>1]));d=g+32|0;ae(d,b,512);j=kc(g+56|0,d);Bb(d);d=w[e|0];f=v[f>>2];h=x[g+282>>1];v[23588]=0;U(274,Wb(f,d)|0,j|0,Ib(h)|0);d=v[23588];v[23588]=0;if((d|0)!=1){break i}d=P()|0;O()|0;break h}h=B(d,104)+a|0;i=h+484380|0;nd(i,1);uo(i);cV(b,((d<<5)+a|0)+946304|0,w[g+83|0]==1?32:28);n=1;d=w[g+83|0];if(d>>>0>=3){_b(b,14);d=eB(b);if((d|0)>=0){e=h+484414|0;u[e>>1]=x[e>>1]|32;s=h+484408|0,y=Ec((((d&65535)<<8)+2047>>>0)/4095|0,0),u[s>>1]=y}d=w[g+83|0]}if((d&255)>>>0>=2){n=Hj(b);s=h+484404|0,y=Hj(b),v[s>>2]=y}d=g+56|0;f=kb-16|0;kb=f;j:{if(!Qb(v[b>>2],v[b+8>>2],12)){v[f>>2]=0;e=d;j=3;while(1){if(j){k=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[e|0]=k;t[e+1|0]=k>>>8;t[e+2|0]=k>>>16;t[e+3|0]=k>>>24;j=j-1|0;e=e+4|0;continue}break}break j}Dq(f+8|0,d);ud(f,b,v[f+8>>2],v[f+12>>2])}kb=f+16|0;e=jc(d);d=Gb(d);k=cc(v[g+56>>2]);v[i>>2]=k;m=h+484384|0;j=cc(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[m>>2]=j;p=h+484388|0;q=cc(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+j|0;v[p>>2]=q;f=h+484414|0;if(j){e=x[f>>1];break f}e=x[f>>1];if(cc(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>=3){break f}d=e&-3;break e}d=Fb(v[Wb(v[a+484360>>2],w[e|0])>>2]);f=Fb(v[Wb(v[a+484360>>2],w[e|0])+4>>2]);e=kb-16|0;kb=e;k:{if(!Pb(d,f)){break k}v[e+8>>2]=d;while(1){h=v[Se(e+8|0)>>2];if(!Pb(h,f)){break k}d=Ek(x[d>>1],x[h>>1])?h:d;continue}}kb=e+16|0;d=x[d>>1];v[23588]=0;n=a+484344|0;p=d+1&65535;R(225,n|0,p|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=w[g+83|0];v[g+24>>2]=v[a+480204>>2];v[g+20>>2]=v[a+480196>>2];o=d>>>0<4?4:5;q=c&1;k=a+480188|0;h=0;while(1){if((h|0)==(p|0)){if(!(c&2)){break g}d=1;c=a+480190|0;while(1){e=d&65535;if(e>>>0>x[c>>1]){break g}e=B(e,104)+a|0;f=_c(g+8|0,u[e+484414>>1]&1?16:8,1,1,0);v[23588]=0;W(219,f|0,e+484380|0,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){d=d+1|0;continue}break}d=P()|0;O()|0;break h}l:{if(!q){break l}d=x[g+278>>1];e=v[b+8>>2];f=x[k>>1];i=v[b>>2];v[23588]=0;d=W(156,i|0,e|0,B(f,B(Ib(d),o))|0)|0;e=v[23588];v[23588]=0;m:{n:{if((e|0)==1){break n}if(!d){break l}d=x[g+278>>1];v[23588]=0;d=W(226,n|0,h&65535,Ib(d)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}if(!d){break l}d=x[k>>1];t[g+19|0]=0;e=ee(g+8|0,0,g+19|0);v[23588]=0;i=W(363,g+32|0,d|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}e=0;o:while(1){if(Ib(x[g+278>>1])>>>0<=e>>>0){od(i);break l}d=0;f=Zb(v[n>>2],h);r=Df(v[f>>2],v[v[f+48>>2]+12>>2],e);while(1){if(x[k>>1]<=d>>>0){e=e+1|0;continue o}t[g+12|0]=0;v[g+8>>2]=0;v[23588]=0;U(364,b|0,g+8|0,o|0);f=v[23588];v[23588]=0;p:{if((f|0)==1){break p}l=B(d,6)+r|0;f=w[g+8|0];if((f-24&255)>>>0<=59){f=f+13|0;t[l|0]=f;s=dc(v[i>>2],d),y=f,t[s|0]=y}m=w[g+9|0];q:{if(!m){f=dc(v[i>>2],d);break q}t[l+1|0]=m;f=dc(v[i>>2],d);t[f+1|0]=m}m=w[f+1|0];f=w[f|0];v[23588]=0;Da(365,a|0,l|0,w[g+10|0],w[g+11|0],0-w[g+83|0]|0,f|0,m|0,g+24|0,g+20|0);f=v[23588];v[23588]=0;if((f|0)==1){break p}if(w[g+12|0]){t[l+2|0]=1;t[l+4|0]=w[g+12|0]+1>>>2}d=d+1|0;continue}break}break}d=P()|0;O()|0;od(i);break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}h=h+1|0;continue}}d=P()|0;O()|0}Bb(j);break c}Bb(j);break b}d=e|2}u[f>>1]=d;if((n|0)==2){u[f>>1]=d|1;v[i>>2]=k>>>1;v[m>>2]=j>>>1;v[p>>2]=q>>>1}s=h+484410|0,y=Hj(b),u[s>>1]=y;d=eB(b);if(d){Bl(i,+(d|0)/96)}t[h+484417|0]=d<<4;l=l+1|0;d=x[o>>1];continue}}d=P()|0;O()|0;bc(g+32|0)}T(d|0);L()}d=1}kb=g+288|0;return d|0}function Fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;i=kb-208|0;kb=i;zc(b);a:{if(!jB(b,i+160|0)){break a}if(!$P(i+160|0)){break a}b:{if(!c){break b}if(!Qb(v[b>>2],v[b+8>>2],Ec(_P(w[i+207|0]),nb))){break a}Bd(a,128);d=i+144|0;Ne(d,2,i+175|0);h=i+72|0;Fc(h,d);Bc(a+1298308|0,h);zb(h);e=yc(h,8413);Jb(a+1298344|0,e);Ab(e);e=yc(h,6059);Jb(a+1298356|0,e);Ab(e);e=yc(d,17505);v[23588]=0;U(724,h|0,e|0,v[(w[i+174|0]<<2)+26860>>2]);h=v[23588];v[23588]=0;c:{if((h|0)!=1){h=i+72|0;Jb(a+1298368|0,h);Ab(h);Ab(e);v[a+480208>>2]=12;v[a+1298404>>2]=5;BB(a+1298332|0,b,w[i+207|0]<<5,32,0);l=a+480190|0;d=Me(b);u[l>>1]=d;h=1;while(1){j=h&65535;if(j>>>0>(d&65535)>>>0){to(Wb(v[a+484360>>2],w[a+484376|0]),b,256,255,254);h=0;d=Me(b);if(d>>>0>=127){break a}g=a+480188|0;u[g>>1]=d+1;e=Me(b);while(1)if(x[g>>1]<=h>>>0){o=a+484344|0;q=e+1|0;xg(o,q);d=0;while(1){d:{g=d&65535;if(g>>>0>e>>>0){r=a+480188|0;e:while(1){y=s&65535;h=x[r>>1];if(y>>>0>=h>>>0){e=ho(i+8|0);t[e+16|0]=0;u[e+14>>1]=0;u[e+12>>1]=h;v[23588]=0;R(726,e|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){a=P()|0;O()|0;We(e);T(a|0);L()}v[23588]=0;U(725,i+32|0,o|0,e|0);d=v[23588];v[23588]=0;h=1;if((d|0)==1){break d}We(i+32|0);We(e);if(!(c&2)){break a}c=a+480190|0;while(1){d=h&65535;if(d>>>0>x[c>>1]){break b}d=B(d,104)+a|0;wg(_c(i+72|0,u[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);h=h+1|0;continue}}n=0;e=ug(i+72|0);f:while(1){g:{if((n|0)!=(q|0)){if(Qb(v[b>>2],v[b+8>>2],5)){break g}}s=s+1|0;continue e}d=0;h=Zb(v[o>>2],n);h=jd(v[h>>2],v[v[h+48>>2]+12>>2],0,y);while(1){h:{i:{if(d>>>0>63){break i}l=w[i+174|0];g=kb-32|0;kb=g;p=1;f=Me(b);if((f|0)==252){p=Me(b);f=Me(b)}t[e|0]=(f-1&255)>>>0<60?f+36|0:0;f=g+24|0;Tm(f,b);k=Oc(f);j=Te(f);f=Mi(f);t[e+1|0]=w[g+24|0];m=g+16|0;YP(m,w[k|0]&15,w[j|0],l);j=Oc(m);m=g+8|0;YP(m,w[k|0]>>>4|0,w[f|0],l);l=Oc(m);f=w[g+16|0];m=(f|0)!=10;k=w[g+8|0];j:{if(!(m|(k|0)!=10)){j=w[j|0];f=w[l|0];t[e+3|0]=10;j=j|f<<8;t[e+5|0]=j>>>6;if(j>>>0<16384){break j}t[e+2|0]=15;t[e+4|0]=f>>>6;break j}k:{l:{m:{n:{o:{if(!m){k=w[j|0];m=k<<2;z=j,A=Ml(m),t[z|0]=A;if(k>>>0<64){break o}f=w[g+8|0];if(Ki(f)>>>0>=Jz(10)>>>0){break n}t[e+5|0]=m;t[e+2|0]=15;t[e+3|0]=10;t[e+4|0]=k>>>6;break j}if((k|0)==10){f=w[l|0];k=f<<2;z=l,A=Ml(k),t[z|0]=A;if(f>>>0<64){break o}if(Ki(w[g+16|0])>>>0>=Jz(10)>>>0){break o}t[e+5|0]=k;t[e+2|0]=15;t[e+3|0]=10;t[e+4|0]=f>>>6;break j}if((f|0)!=(k|0)){break o}t[g+8|0]=0;break m}f=w[g+8|0]}if((f|0)==13){break l}if(f){break k}f=w[g+16|0]}if((f|0)==13){break k}}Ji(g+16|0,g+8|0);Ji(j,l)}Vu(g+8|0,l,g+16|0,j);Bo(g,e,w[g+16|0],w[j|0],w[g+8|0],w[l|0])}kb=g+32|0;f=d+p|0;d=f>>>0>64?64-d|0:p;if(!d){break i}while(1){if(!d){break h}g=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[h|0]=g;t[h+1|0]=g>>>8;t[h+2|0]=g>>>16;t[h+3|0]=g>>>24;g=w[e+4|0]|w[e+5|0]<<8;t[h+4|0]=g;t[h+5|0]=g>>>8;d=d-1|0;h=B(x[r>>1],6)+h|0;continue}}n=n+1|0;continue f}d=f>>>0<64?f:64;continue}}}}d=d+1|0;h=0;if(ph(o,g,64)){continue}break a}break}d=P()|0;O()|0;We(e);break c}else{d=(h<<5)+a|0;ef(d+480280|0);d=d+480284|0;p:{if(w[i+174|0]>=51){f=(Me(b)<<4|8)&248;break p}f=h&1?192:64}u[d>>1]=f;h=h+1|0;continue}}else{q:{if(w[i+174|0]>=52){d=i+72|0;if(!OU(b,d)){EB(d)}break q}e=kb-32|0;kb=e;v[e+28>>2]=64;v[e+8>>2]=66;f=v[b>>2];g=v[b+8>>2];d=v[Kb(e+28|0,e+8|0)>>2];if(!Qb(f,g,d)){d=df(b)}f=e+8|0;n=i+72|0;Gu(f,n);g=hc(e+16|0,v[e+8>>2],d);nc(e,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);Gu(f,n);Ub(v[e+8>>2]+d|0,0,66-d|0);_b(b,v[e+28>>2]);kb=e+32|0;u[i+136>>1]=x[i+134>>1];u[i+134>>1]=8363}g=kb-32|0;kb=g;e=(B(j,104)+a|0)+484380|0;nd(e,0);uo(e);d=i+72|0;uk(g,2,d+32|0);f=g+16|0;Fc(f,g);Ce(e+43|0,f);zb(f);f=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);n=w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24);r:{if(f>>>0<=n>>>0){break r}v[e>>2]=f-n;v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[g+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);z=e,A=v[Kb(g+16|0,e)>>2],v[z+16>>2]=A;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=w[d+64|0]|w[d+65|0]<<8;if(f){Bl(e,+(f<<16>>16)/393216)}f=w[d+61|0];if(f&8){u[e+34>>1]=x[e+34>>1]|8;f=w[d+61|0]}if(f&16){u[e+34>>1]=x[e+34>>1]|16;f=w[d+61|0]}if(!(f&4)){break r}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}kb=g+32|0;e=i+56|0;Ne(e,2,d);d=i+144|0;Fc(d,e);Dc(((j<<5)+a|0)+946304|0,d);h=h+1|0;zb(d);d=x[l>>1];continue}}}d=P()|0;O()|0;Ab(e)}T(d|0);L()}h=1}kb=i+208|0;return h|0}function Rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=kb-144|0;kb=d;zc(c);a:{b:{c:{d:{if(!vo(c,d+128|0)){break d}if(Sb(d+128|0,13769,4)){break d}g=d+136|0;e:{if(!Sb(g,13422,4)){break e}if(!Sb(g,13480,4)){break e}if(Sb(g,14204,4)){break d}}e=kb-32|0;kb=e;l=Tb(d+112|0);f:{g:{h:{i:{j:{while(1){k=v[c+8>>2];h=v[c>>2];v[23588]=0;k=W(156,h|0,k|0,8)|0;h=v[23588];v[23588]=0;if((h|0)==1){break h}if(!k){break i}v[23588]=0;R(791,e|0,c|0);k=v[23588];v[23588]=0;if((k|0)!=1){v[23588]=0;R(792,l|0,e|0);k=v[23588];v[23588]=0;if((k|0)==1){break j}Ad(e);continue}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;Ad(e);break g}kb=e+32|0;break f}a=P()|0;O()|0}Zd(l);T(a|0);L()}v[23588]=0;k=S(174,d+88|0)|0;c=v[23588];v[23588]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c|0)!=1){l=_c(d+80|0,8,1,1,0);if(Sb(g,14204,4)){break t}v[23588]=0;U(711,d+56|0,d+112|0,1296581714);c=v[23588];v[23588]=0;if((c|0)==1){break q}v[23588]=0;U(711,d+32|0,d+112|0,1296318804);c=v[23588];v[23588]=0;if((c|0)==1){break c}c=d+32|0;e=hd(k,c);Bb(c);c=0;v[23588]=0;g=S(712,d+56|0)|0;i=v[23588];v[23588]=0;f=1;if((i|0)==1){break c}i=0;if(!g){break u}e=v[e>>2];v[23588]=0;e=S(178,e|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break c}i=0;if(!e){break u}v[23588]=0;i=S(279,d+56|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}v[23588]=0;g=S(271,d+56|0)|0;c=v[23588];v[23588]=0;w:{if((c|0)==1){break w}v[23588]=0;Q(188,d+56|0,2)|0;c=v[23588];v[23588]=0;if((c|0)==1){break w}v[23588]=0;c=S(279,d+56|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break v}}break c}f=P()|0;O()|0;break a}v[23588]=0;R(627,d+32|0,d+56|0);e=v[23588];v[23588]=0;if((e|0)==1){break c}e=XT(d+32|0);j=Ib(x[d+32>>1]);if(!j){break u}c=(c>>>0)/(j>>>0)|0;f=d+32|0;j=jc(f);h=Te(f);f=1;j=Ib(w[j|0]|w[j+1|0]<<8);if((j|0)!=(Ib(w[h|0]|w[h+1|0]<<8)+1|0)){break u}if((j|0)==2){Ko(l,2)}x:{if((g|0)!=16){if((g|0)!=8){break u}y:{switch(Ib(w[e|0]|w[e+1|0]<<8)|0){case 0:dg(l,1);break x;case 2:dg(l,17);break x;case 3:break y;default:break u}}dg(l,16);break x}if(Ib(w[e|0]|w[e+1|0]<<8)){break u}xd(l,16)}f=0}Bb(d+56|0);j=0;if(!f){break s}f=0;break k}v[23588]=0;U(711,d+56|0,d+112|0,1447576658);c=v[23588];v[23588]=0;z:{A:{if((c|0)!=1){v[23588]=0;U(711,d+32|0,d+112|0,1128808782);c=v[23588];v[23588]=0;if((c|0)==1){break A}v[23588]=0;U(711,d+8|0,d+112|0,1112491097);c=v[23588];v[23588]=0;if((c|0)==1){break m}c=d+8|0;h=hd(k,c);Bb(c);c=v[h>>2];v[23588]=0;m=S(178,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break z}c=0;e=0;B:{if(!m){break B}v[23588]=0;m=S(178,v[d+56>>2])|0;c=v[23588];v[23588]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}v[23588]=0;m=Q(713,d+56|0,d+8|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}c=Sb(g,13422,4);v[23588]=0;e=S(279,d+32|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break m}if(c){p=l,q=v[_c(d,16,1,0,0)>>2],v[p>>2]=q}if((e|0)==6){Ko(l,3)}i=v[h>>2];v[23588]=0;g=v[d+24>>2];h=x[d+20>>1];n=v[d+12>>2];m=v[d+8>>2];i=S(160,i|0)|0;j=v[23588];v[23588]=0;o=1;if((j|0)==1){break m}e=B((e|0)==6?2:1,c?2:1);i=(i>>>0)/(e>>>0)|0;j=cc(g);c=Ib(h);n=(cc(n)>>>0)/(e>>>0)|0;e=(cc(m)>>>0)/(e>>>0)|0}Bb(d+32|0);Bb(d+56|0);if(o){break r}break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;break l}break m}e=0}st(a,b);v[23588]=0;f=B(b,104)+a|0;g=f+484380|0;R(277,g|0,0);h=v[23588];v[23588]=0;if((h|0)==1){break p}v[g>>2]=i;h=e+n|0;v[f+484388>>2]=h;v[f+484384>>2]=e;if(!(h>>>0<=e+4>>>0|h>>>0>i>>>0)){e=(B(b,104)+a|0)+484414|0;u[e>>1]=x[e>>1]|2}e=B(b,104)+a|0;v[e+484404>>2]=c?c:22050;c=j>>>8|0;u[e+484410>>1]=(j&16776960)>>>0>65536?256:c&65535?c:256;Dz(g,v[a+480180>>2]);v[23588]=0;U(711,d+56|0,d+112|0,1312902469);c=v[23588];v[23588]=0;if((c|0)==1){break o}v[23588]=0;c=S(178,v[d+56>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}C:{D:{if(c){v[23588]=0;c=S(160,v[d+56>>2])|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}v[23588]=0;U(325,d+56|0,((b<<5)+a|0)+946304|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break D}break n}v[23588]=0;c=Q(55,d+32|0,21619)|0;e=v[23588];v[23588]=0;if((e|0)==1){break C}Dc(((b<<5)+a|0)+946304|0,c);zb(c)}v[23588]=0;W(219,l|0,g|0,k|0)|0;b=v[23588];v[23588]=0;f=1;if((b|0)==1){break n}uj(g,a);Bb(d+56|0);break k}break n}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;Bb(d+56|0);break b}f=P()|0;O()|0;Bb(d+32|0)}Bb(d+56|0);break b}Bb(k);Zd(d+112|0)}kb=d+144|0;return f|0}f=P()|0;O()|0;Bb(d+56|0)}Bb(k)}Zd(d+112|0);T(f|0);L()}function Jd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=kb-96|0;kb=k;t=h;u=i&65535;m=(e^i)&-2147483648;l=e&65535;p=l;A=l;K=i>>>16&32767;L=e>>>16&32767;a:{b:{if(K-32767>>>0>4294934529&L-32767>>>0>=4294934530){break b}l=e&2147483647;j=d;if(!(!d&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){o=d;m=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;m=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(f|h|(e|g))){m=2147450880;b=0;c=0;break a}m=m|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|l;b=0;c=0;if(!(d|e)){m=2147450880;break a}m=m|2147418112;break a}if(!(b|j|(c|l))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){j=b;h=!(d|p);i=h<<6;l=E(h?b:d)+32|0;b=E(h?c:p);b=i+((b|0)==32?l:b)|0;Lf(k+80|0,j,c,d,p,b-15|0);s=16-b|0;d=v[k+88>>2];A=v[k+92>>2];c=v[k+84>>2];b=v[k+80>>2]}if(e>>>0>65535){break b}e=!(t|u);h=e<<6;i=E(e?f:t)+32|0;e=E(e?g:u);e=h+((e|0)==32?i:e)|0;Lf(k- -64|0,f,g,t,u,e-15|0);s=(s-e|0)+16|0;t=v[k+72>>2];u=v[k+76>>2];f=v[k+64>>2];g=v[k+68>>2]}e=f;j=g<<15|e>>>17;h=e<<15;e=j;p=h&-32768;q=c;B=Oka(p,0,c,0);c=nb;x=c;C=e;i=0;j=Oka(e,0,b,i);e=j+B|0;h=nb+c|0;h=e>>>0<j>>>0?h+1|0:h;c=e;j=e;n=Oka(b,i,p,i);l=0+n|0;e=nb+e|0;e=l>>>0<n>>>0?e+1|0:e;y=l;n=l;l=e;D=(j|0)==(e|0)&r>>>0>n>>>0|e>>>0<j>>>0;r=d;M=Oka(p,i,d,0);H=nb;e=Oka(q,i,C,i);d=e+M|0;j=nb+H|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=t;j=u<<15|e>>>17;z=e<<15|g>>>17;g=j;j=Oka(z,0,b,i);e=j+n|0;f=nb+d|0;I=e;f=e>>>0<j>>>0?f+1|0:f;u=f;e=f;f=(h|0)==(x|0)&c>>>0<B>>>0|h>>>0<x>>>0;c=h+I|0;f=e+f|0;B=c;f=c>>>0<h>>>0?f+1|0:f;t=f;c=f;F=A|65536;A=w;N=Oka(p,i,F,w);J=nb;h=Oka(r,o,C,i);f=h+N|0;e=nb+J|0;O=f;e=f>>>0<h>>>0?e+1|0:e;w=e;G=g|-2147483648;x=0;g=Oka(G,x,b,i);b=g+f|0;f=nb+e|0;f=b>>>0<g>>>0?f+1|0:f;P=b;e=Oka(z,o,q,i);b=b+e|0;p=f;j=f+nb|0;Q=b;g=b>>>0<e>>>0?j+1|0:j;f=0;b=f+B|0;e=c+Q|0;e=b>>>0<f>>>0?e+1|0:e;R=b;c=b;b=b+D|0;D=e;f=b>>>0<c>>>0?e+1|0:e;c=f;s=((L+K|0)+s|0)-16383|0;j=Oka(G,x,q,i);h=nb;i=Oka(F,A,C,i);e=i+j|0;f=nb+h|0;f=e>>>0<i>>>0?f+1|0:f;i=(f|0)==(h|0)&e>>>0<j>>>0|f>>>0<h>>>0;h=e;q=i;i=Oka(z,o,r,o);e=i+e|0;j=nb+f|0;j=e>>>0<i>>>0?j+1|0:j;i=(f|0)==(j|0)&e>>>0<h>>>0|f>>>0>j>>>0;f=q+i|0;h=0;h=f>>>0<i>>>0?1:h;q=Oka(G,x,F,A);i=q+f|0;f=nb+h|0;f=i>>>0<q>>>0?f+1|0:f;q=e;h=j;C=i;e=(d|0)==(u|0)&n>>>0>I>>>0|d>>>0>u>>>0;d=e+((d|0)==(H|0)&n>>>0<M>>>0|d>>>0<H>>>0)|0;j=0;j=d>>>0<e>>>0?1:j;i=d;d=q+d|0;e=h+j|0;e=d>>>0<i>>>0?e+1|0:e;n=d;i=e;e=(e|0)==(h|0)&d>>>0<q>>>0|e>>>0<h>>>0;d=C+e|0;h=d>>>0<e>>>0?f+1|0:f;q=d;j=Oka(z,o,F,A);e=nb;r=Oka(G,x,r,o);d=r+j|0;f=nb+e|0;f=d>>>0<r>>>0?f+1|0:f;r=d;d=f;f=(e|0)==(f|0)&j>>>0>r>>>0|e>>>0>f>>>0;z=d+q|0;e=f+h|0;e=d>>>0>z>>>0?e+1|0:e;h=0;d=h+n|0;f=i+r|0;f=d>>>0<h>>>0?f+1|0:f;h=f;j=(i|0)==(f|0)&d>>>0<n>>>0|f>>>0<i>>>0;i=j+z|0;n=i;i=i>>>0<j>>>0?e+1|0:e;r=d;e=d;d=h;j=(p|0)==(w|0)&O>>>0>P>>>0|p>>>0<w>>>0;f=j+((w|0)==(J|0)&O>>>0<N>>>0|w>>>0<J>>>0)|0;h=0;j=f+((g|0)==(p|0)&P>>>0>Q>>>0|g>>>0<p>>>0)|0;f=g+e|0;e=d+j|0;e=f>>>0<g>>>0?e+1|0:e;g=f;h=(d|0)==(e|0)&f>>>0<r>>>0|d>>>0>e>>>0;d=h+n|0;f=i;f=d>>>0<h>>>0?f+1|0:f;h=e;n=d;i=(t|0)==(D|0)&B>>>0>R>>>0|t>>>0>D>>>0;d=i+((t|0)==(u|0)&B>>>0<I>>>0|t>>>0<u>>>0)|0;j=0;j=d>>>0<i>>>0?1:j;i=d;d=d+g|0;e=e+j|0;e=d>>>0<i>>>0?e+1|0:e;h=(e|0)==(h|0)&d>>>0<g>>>0|e>>>0<h>>>0;g=n+h|0;f=g>>>0<h>>>0?f+1|0:f;h=g;i=f;c:{if(f&65536){s=s+1|0;break c}w=l>>>31|0;f=i<<1|h>>>31;h=g<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;g=y;f=l<<1|g>>>31;y=g<<1;l=f;f=c<<1|b>>>31;b=b<<1|w;c=f}if((s|0)>=32767){m=m|2147418112;b=0;c=0;break a}d:{if((s|0)<=0){f=1-s|0;if(f>>>0>=128){b=0;c=0;break a}g=s+127|0;Lf(k+48|0,y,l,b,c,g);Lf(k+32|0,d,e,h,i,g);Fm(k+16|0,y,l,b,c,f);Fm(k,d,e,h,i,f);y=v[k+32>>2]|v[k+16>>2]|(v[k+48>>2]|v[k+56>>2]|(v[k+52>>2]|v[k+60>>2]))!=0;l=v[k+36>>2]|v[k+20>>2];b=v[k+40>>2]|v[k+24>>2];c=v[k+44>>2]|v[k+28>>2];d=v[k>>2];e=v[k+4>>2];f=v[k+8>>2];g=v[k+12>>2];break d}f=h;g=i&65535|s<<16}o=f|o;m=g|m;if(!(!b&(c|0)==-2147483648?!(l|y):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;c=j;f=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=f+o|0;e=m;o=d;m=d>>>0<f>>>0?e+1|0:e;break a}if(b|y|(c^-2147483648|l)){b=d;c=e;break a}j=m;c=d&1;b=c+d|0;f=b>>>0<c>>>0?e+1|0:e;c=f;e=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;d=e+o|0;o=d;m=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=m;kb=k+96|0}function aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=kb-144|0;kb=g;zc(b);a:{b:{c:{d:{e:{if(!CR(b,14090)){break e}k=Tb(g+128|0);j=Tb(g+112|0);v[23588]=0;v[g+104>>2]=0;v[g+108>>2]=0;R(246,a|0,32768);d=v[23588];v[23588]=0;if((d|0)==1){break b}v[23588]=0;d=Q(1,g+88|0,8129)|0;i=v[23588];v[23588]=0;if((i|0)==1){break c}Jb(a+1298344|0,d);Ab(d);v[23588]=0;d=Q(1,g+72|0,6063)|0;i=v[23588];v[23588]=0;if((i|0)==1){break d}Jb(a+1298356|0,d);Ab(d);v[a+1298404>>2]=14;m=a+484376|0;i=a+480280|0;while(1){d=v[b+8>>2];f=v[b>>2];v[23588]=0;d=W(156,f|0,d|0,8)|0;f=v[23588];v[23588]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}v[23588]=0;d=Q(626,b|0,g- -64|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break m}if(!d){break n}d=v[g+68>>2];v[23588]=0;U(190,g+16|0,b|0,cc(d)|0);d=v[23588];v[23588]=0;if((d|0)==1){break l}d=g+16|0;f=kc(g+40|0,d);Bb(d);d=v[f>>2];v[23588]=0;d=S(178,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}if(d){break k}Bb(f)}if(x[a+480188>>1]){break i}i=0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=cc(v[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(x[a+480188>>1]){break f}d=v[f>>2];v[23588]=0;d=S(160,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;v[23588]=0;R(627,g+16|0,f|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{e=x[a+480188>>1];h=dc(g+16|0,d);v:{if(!Ib(w[h|0]|w[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+104|0;o=Lb(h,e),p=1,t[o|0]=p;o=Lb(h,x[a+480188>>1]+1|0),p=255,t[o|0]=p;ef(i+(x[a+480188>>1]<<5)|0);h=x[a+480188>>1];e=h+1|0;u[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;u[l+4>>1]=h>>>0<2?192:64}ef(i+((e&65535)<<5)|0);e=x[a+480188>>1];u[a+480188>>1]=e+1;u[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(x[a+480190>>1]){break f}v[23588]=0;R(628,f|0,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){break f}break j}d=v[f>>2];v[23588]=0;d=S(160,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[23588]=0;d=S(271,f|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}o=a,p=Dd(d,1,255),v[o+480196>>2]=p;break f}d=v[f>>2];v[23588]=0;d=S(160,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[23588]=0;n=S(271,f|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break f}break j}d=w[m|0];e=v[a+484360>>2];h=v[f>>2];v[23588]=0;h=S(160,h|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break j}v[23588]=0;da(340,Wb(e,d)|0,f|0,h|0,255,254);d=v[23588];v[23588]=0;if((d|0)==1){break j}break f}d=k;if(Cf(v[d>>2],v[d+4>>2])>>>0>=256){break f}break q}if(Cf(v[j>>2],v[j+4>>2])>>>0>3998){break f}d=v[f>>2];v[23588]=0;e=S(160,d|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break j}d=j;if(!e){break f}}v[23588]=0;R(629,d|0,f|0);d=v[23588];v[23588]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}Bb(f);break g}a=P()|0;O()|0;Bb(f);break a}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=w[a+484376|0];d=v[a+484360>>2];v[23588]=0;R(324,Wb(d,b)|0,n&65535);b=v[23588];v[23588]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=v[k+4>>2];i=v[k>>2];d=0;v[23588]=0;R(225,a+484344|0,Cf(i,b)&65535);b=v[23588];v[23588]=0;if((b|0)==1){break b}while(1){f=v[k>>2];b=d&65535;if(Cf(f,v[k+4>>2])>>>0<=b>>>0){break w}v[23588]=0;i=v[g+108>>2];e=v[g+104>>2];v[g+8>>2]=e;v[g+12>>2]=i;v[g>>2]=e;v[g+4>>2]=i;X(630,Pg(f,b)|0,b|0,a|0,g|0);b=v[23588];v[23588]=0;if((b|0)!=1){d=d+1|0;continue}break}a=P()|0;O()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(x[a+480190>>1]<=d>>>0){break g}if(!f|Cf(v[j>>2],v[j+4>>2])>>>0<=b>>>0){break g}c=(B(d,104)+a|0)+484380|0;Lo(c);x:{if(v[c>>2]){e=v[Pg(v[j>>2],b)>>2];v[23588]=0;e=S(160,e|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break h}xc(c,e);e=_c(g+40|0,8,1,1,0);h=v[j>>2];v[23588]=0;W(219,e|0,c|0,Pg(h,b)|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Vc(j);Vc(k);break e}Bb(f);continue}}kb=g+144|0;return i|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Vc(j);Vc(k);T(a|0);L()}function jN(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=kb-16|0;kb=h;a:{if(!$c(d&255)){break a}m=a+1074376|0;j=(m+B(b,872)|0)+616|0;b:{g=x[a+480192>>1];if(!(e?1:!(v[a+480180>>2]&17825824)|!g)){break b}if(qj(v[j+656>>2])){break b}c=B(b,872)+a|0;d=c+1075068|0;if(!v[d>>2]){break a}c=v[c+1075080>>2];if(c&1024){break a}e=B(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(v[g>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=v[a+1298300>>2];if(!Fd(c)){break c}rj(c,b,0);break a}c=Hy(a,b);if((c|0)==65535){break a}i=B(c,872);c=a+1074992|0;a=i+c|0;Sp(a,j);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;jo(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[e>>2]=0;break a}e=B(b,872)+a|0;k=v[e+1075096>>2];c=c>>>0>g>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}l=d-1|0;c=x[dc(g+236|0,l)>>1];f=a+1074312|0;Db(h+8|0,f,104);e:{if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])){Db(h,f,34);if(Cb(v[v[h>>2]>>2],v[h+4>>2])){break e}}d=w[Lb(g+108|0,l)|0]}if((c-1&65535)>>>0<=3998){k=(B(c,104)+a|0)+484380|0;break d}Db(h+8|0,f,43);if(!Cb(v[v[h+8>>2]>>2],v[h+12>>2])){break d}if(!vj(w[g+31|0])){break a}}if(w[e+1075081|0]&4){break a}o=b>>>0>256?b:256;l=a+1074312|0;p=b+1|0;q=a+480188|0;c=b;f:{while(1){if((c|0)==(o|0)){g:{e=0;c=0;if(!qj(v[j+656>>2])){break f}c=0;if(!$c(w[(B(b,872)+a|0)+1075789|0])){break f}d=Pl(a,m,b,2,1)-1|0;c=0;if((d&255)>>>0>249){break f}e=v[Md(a+906300|0,d)>>2];if(e){break g}e=0;c=0;break f}}else{h:{if((b|0)!=(c|0)&x[q>>1]>c>>>0){break h}e=B(c,872)+a|0;if(x[e+1075778>>1]!=(p|0)&(b|0)!=(c|0)){break h}n=e+1075648|0;f=v[n>>2];if(!f){break h}i:{j:{k:{l:{m:{n:{o:{switch(w[f+17|0]-1|0){case 0:if(!d){break h}i=w[e+1075789|0]==(d|0)&(f|0)==(g|0);if(!g){break n}if(i){break k}break h;case 1:if(!k|v[e+1075096>>2]!=(k|0)){break h}if((f|0)==(g|0)){break i}Db(h+8|0,l,104);if(!Cb(v[v[h+8>>2]>>2],v[h+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(g){break l}i=(f|0)==(g|0)}if(i){break i}break h}if(!g){break h}i=w[g+34|0];if(!i){break h}if((i|0)==w[f+34|0]){break j}break h}if((f|0)!=(g|0)){break h}}if(!w[g+34|0]){break i}}if(!w[e+1075789|0]|w[f+18|0]>2){break i}tm(a,c&65535,w[e+1075793|0]|256,0)}f=e+1074992|0;p:{q:{switch(w[v[n>>2]+18|0]){case 0:Vn(a,f);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break p}f=v[a+1298300>>2];if(!Fd(f)){break p}rj(f,c&65535,1);break p;case 1:Vn(a,f);if(!(w[e+1075081|0]&2)){break p}f=v[a+1298300>>2];if(!Fd(f)){break p}ik(f,c&65535);break p;case 2:break q;default:break p}}i=e+1075080|0;f=v[i>>2];v[i>>2]=f|4096;if(!(f&512)){break p}if(!Fd(v[a+1298300>>2])){break p}Db(h+8|0,l,105);if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])){break p}ik(v[a+1298300>>2],c&65535)}if(v[e+1075680>>2]){break h}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;continue}break}c=ob[v[v[e>>2]+104>>2]](e,w[(B(b,872)+a|0)+1075793|0],b)|0}if(!(yi(v[j+8>>2],v[j+12>>2])?1:c)){break a}g=Hy(a,b);if((g|0)==65535){break a}f=B(g,872)+a|0;d=f+1075080|0;k=f+1074992|0;r:{if(!(w[f+1075081|0]&2)){break r}i=v[a+1298300>>2];if(!Fd(i)){break r}rj(i,g,1)}k=Sp(k,j);v[d>>2]=v[d>>2]&-917505;t[f+1075823|0]=0;i=x[a+480188>>1];t[f+1075797|0]=0;u[f+1075778>>1]=b>>>0<i>>>0?b+1|0:0;s:{if(!(c&(e|0)!=0)){break s}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break s}tm(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}t:{u:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:Vn(a,k);if(!(w[d+1|0]&2)){break t}c=v[a+1298300>>2];if(!Fd(c)){break t}ik(c,b);Db(h+8|0,l,105);if(!Cb(v[v[h+8>>2]>>2],v[h+12>>2])){break t}sz(v[a+1298300>>2],b,g);break t;case 0:v[(B(g,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}c=v[a+1298300>>2];if(!Fd(c)){break t}rj(c,b,1);break t;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!Fd(v[a+1298300>>2])){break t}Db(h+8|0,l,105);c=v[a+1298300>>2];if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])){sz(c,b,g);break t}ik(c,b);break t;case 1:break u;default:break t}}if(!(w[d+1|0]&2)){break t}c=v[a+1298300>>2];if(!Fd(c)){break t}sz(c,b,g)}if(!v[(B(g,872)+a|0)+1075680>>2]){v[(B(g,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}kb=h+16|0}function hW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-112|0;kb=f;zc(b);a:{if(!Tq(b,11694)){break a}if(!_u(b,f+96|0)){break a}if(!mC(w[f+97|0])){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(lC(f+96|0),nb))){break a}if(!_b(b,w[f+105|0]|w[f+106|0]<<8)){break a}b:{if(!c){break b}Bd(a,4096);v[a+480208>>2]=12;u[a+480188>>1]=(w[f+98|0]&31)+1;e=a+480190|0;u[e>>1]=w[f+99|0];oh(a,1);d=f+24|0;i=yc(d,8436);Jb(a+1298344|0,i);Ab(i);i=yc(d,7053);Jb(a+1298356|0,i);Ab(i);i=kb-16|0;kb=i;g=yc(i,4250);ad(f,g);Ab(g);kb=i+16|0;v[23588]=0;X(229,d|0,f|0,w[f+97|0],f+96|0);d=v[23588];v[23588]=0;c:{if((d|0)!=1){d=f+24|0;Jb(a+1298368|0,d);Ab(d);bc(f);v[a+1298404>>2]=5;d=w[f+99|0];i=f+80|0;v[i>>2]=0;v[i+4>>2]=0;ok(i+8|0,0);if(d){_q(i,d);YC(i,d,0)}d=1;d:{while(1){g=d&65535;if(g>>>0>x[e>>1]){v[23588]=0;Q(230,b|0,a+1298308|0)|0;g=v[23588];v[23588]=0;d=1;e:{if((g|0)==1){break e}g=a+480190|0;while(1){e=d&65535;if(e>>>0>x[g>>1]){d=0;g=a+480188|0;f:{while(1){if(x[g>>1]<=d>>>0){d=0;v[23588]=0;g=a+484344|0;R(225,g|0,x[f+100>>1]);e=v[23588];v[23588]=0;if((e|0)==1){break e}break f}e=(d<<5)+a|0;ef(e+480280|0);v[23588]=0;R(231,b|0,e+480289|0);e=v[23588];v[23588]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}g:{h:{i:{j:{while(1){if(x[f+100>>1]<=d>>>0){v[23588]=0;e=S(194,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break h}if(!e){break i}d=v[b+8>>2];g=v[b>>2];v[23588]=0;d=W(156,g|0,d|0,e|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break h}if(d){break j}break i}v[23588]=0;e=Q(232,b|0,f+24|0)|0;h=v[23588];v[23588]=0;k:{if((h|0)==1){break k}v[23588]=0;h=W(226,g|0,d&65535,64)|0;j=v[23588];v[23588]=0;if((j|0)==1){break k}if((e&h)==1){e=v[g>>2];v[23588]=0;R(233,Zb(e,d)|0,f+24|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}}d=d+1|0;continue}break}b=P()|0;O()|0;break d}g=Tb(f+24|0);v[23588]=0;U(234,b|0,g|0,e|0);d=v[23588];v[23588]=0;l:{if((d|0)!=1){d=Mb(f);v[23588]=0;R(46,d|0,e|0);e=v[23588];v[23588]=0;m:{if((e|0)==1){break m}k=f,l=Fb(v[g>>2]),v[k+48>>2]=l;h=Fb(v[g+4>>2]);while(1){n:{e=v[f+48>>2];if(!Pb(e,h)){v[23588]=0;X(235,f+48|0,5,6,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break n}h=f+48|0;e=Bc(d,h);zb(h);h=Mc(e);j=Hb(e);v[23588]=0;da(236,a+1298332|0,h|0,j|0,76,0);h=v[23588];v[23588]=0;if((h|0)==1){break m}zb(e);ic(g);break i}o:{e=w[e|0];if(e&128){k=f,l=zh(d),v[k+64>>2]=l;j=v[mj(f+72|0,f- -64|0)>>2];v[23588]=0;X(237,d|0,j|0,e&127,32);e=v[23588];v[23588]=0;if((e|0)!=1){break o}break m}v[23588]=0;R(47,d|0,e<<24>>24);e=v[23588];v[23588]=0;if((e|0)!=1){break o}break m}He(f+48|0);continue}break}}b=P()|0;O()|0;zb(d);break l}b=P()|0;O()|0}ic(g);break d}d=w[a+484376|0];g=v[a+484360>>2];v[23588]=0;U(238,Wb(g,d)|0,b|0,x[f+102>>1]);d=v[23588];v[23588]=0;if((d|0)==1){break h}e=c&1;h=a+484348|0;d=0;while(1){p:{q:{if(x[f+100>>1]>d>>>0){g=v[b+8>>2];j=v[b>>2];v[23588]=0;g=W(156,j|0,g|0,4)|0;j=v[23588];v[23588]=0;if((j|0)==1){break p}if(g){break q}}if(!(c&2)){break g}g=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>x[g>>1]){break g}e=B(c,104)+a|0;h=x[e+484414>>1];Db(f+24|0,v[i>>2],c-1|0);c=_c(f,h&1?16:8,1,0,Cb(v[v[f+24>>2]>>2],v[f+28>>2])?6:0);v[23588]=0;W(219,c|0,e+484380|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}v[23588]=0;g=S(157,b|0)|0;j=v[23588];v[23588]=0;r:{s:{if((j|0)!=1){v[23588]=0;U(190,f|0,b|0,g|0);g=v[23588];v[23588]=0;if((g|0)==1){break s}g=kc(f+24|0,f);Bb(f);if(!e){break r}j=v[a+484344>>2];if(!ye(j,v[h>>2],d&65535)){break r}v[23588]=0;U(239,Zb(j,d)|0,0,g|0);j=v[23588];v[23588]=0;if((j|0)!=1){break r}b=P()|0;O()|0;Bb(g);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}Bb(g);d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}We(i);break b}v[23588]=0;Q(240,b|0,((e<<5)+a|0)+946304|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23588]=0;R(241,b|0,f+24|0);h=v[23588];v[23588]=0;t:{if((h|0)==1){break t}v[23588]=0;R(242,f+24|0,(B(g,104)+a|0)+484380|0);h=v[23588];v[23588]=0;if((h|0)==1){break t}h=w[f+40|0];Db(f,v[i>>2],g-1|0);Ze(f,(h&3)!=0);d=d+1|0;continue}break}b=P()|0;O()|0}We(i);break c}b=P()|0;O()|0;bc(f)}T(b|0);L()}d=1}kb=f+112|0;return d|0}function W9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0;e=kb-336|0;kb=e;d=-1;a:{b:{c:{if(!_k(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){b=_l(e+224|0,b);v[23588]=0;d=Q(449,e+208|0,13921)|0;f=v[23588];v[23588]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){v[23588]=0;v[e+192>>2]=83886084;v[e+196>>2]=0;U(450,b|0,d|0,e+192|0);f=v[23588];v[23588]=0;if((f|0)==1){break A}$b(d);t[e+207|0]=0;v[23588]=0;d=Q(449,e+192|0,14706)|0;f=v[23588];v[23588]=0;if((f|0)==1){break z}v[23588]=0;U(451,b|0,e+207|0,d|0);f=v[23588];v[23588]=0;if((f|0)==1){break y}$b(d);v[23588]=0;f=w[e+207|0];d=Q(449,e+176|0,15771)|0;g=v[23588];v[23588]=0;if((g|0)==1){break x}v[23588]=0;f=f?0:c;X(880,b|0,a+40|0,d|0,f|0);c=v[23588];v[23588]=0;if((c|0)==1){break w}$b(d);u[e+174>>1]=65535;v[23588]=0;c=Q(449,e+160|0,15441)|0;d=v[23588];v[23588]=0;if((d|0)==1){break v}v[23588]=0;W(479,b|0,e+174|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break u}$b(c);u[e+158>>1]=0;v[23588]=0;c=Q(449,e+144|0,15340)|0;d=v[23588];v[23588]=0;if((d|0)==1){break t}v[23588]=0;W(479,b|0,e+158|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break s}$b(c);u[a>>1]=x[e+158>>1];v[23588]=0;c=Q(449,e+128|0,15022)|0;d=v[23588];v[23588]=0;if((d|0)==1){break r}v[23588]=0;X(881,b|0,a+52|0,c|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break q}$b(c);v[23588]=0;c=Q(449,e+112|0,14952)|0;d=v[23588];v[23588]=0;if((d|0)==1){break p}v[23588]=0;U(872,b|0,a+36|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break o}$b(c);v[23588]=0;c=Q(449,e+96|0,15448)|0;d=v[23588];v[23588]=0;if((d|0)==1){break n}v[23588]=0;h=a+4|0;U(882,b|0,h|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break m}$b(c);v[23588]=0;c=Q(449,e+80|0,15342)|0;d=v[23588];v[23588]=0;if((d|0)==1){break l}v[23588]=0;f=a+28|0;U(883,b|0,f|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break k}$b(c);v[23588]=0;c=Q(449,e- -64|0,15197)|0;d=v[23588];v[23588]=0;if((d|0)==1){break j}v[23588]=0;U(883,b|0,a+30|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}$b(c);v[23588]=0;c=Q(449,e+48|0,14994)|0;d=v[23588];v[23588]=0;if((d|0)==1){break h}v[23588]=0;U(884,b|0,a+32|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}$b(c);u[e+46>>1]=0;v[23588]=0;c=Q(449,e+32|0,14925)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}v[23588]=0;W(479,b|0,e+46|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}$b(c);i=HL(z[a+32>>2]);z[a+32>>2]=i;d=-1;if(!qm(i)){break d}k=e,l=Fb(v[a+4>>2]),v[k+24>>2]=l;c=Fb(v[a+8>>2]);while(1){g=v[e+24>>2];if(!Pb(g,c)){break e}if(!qm(z[g>>2])){break d}Le(e+24|0);continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(c);break a}a=P()|0;O()|0;$b(c);break a}if(Lk(w[b|0])){break d}c=x[f>>1];if((c-301&65535)>>>0<64935){break d}g=x[a>>1];if(g>>>0>3|(g|0)==2){break d}j=u[a+30>>1];if((j|0)<0){break d}k=e,l=Fi(v[a+36>>2]),v[k+24>>2]=l;v[e+16>>2]=0;k=a,l=v[Jj(e+24|0,e+16|0,43824)>>2],v[k+36>>2]=l;if(vc(v[a+4>>2],v[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=u[e+46>>1];if((f|0)<=0){break d}u[e+14>>1]=j;z[e+24>>2]=z[a+32>>2];v[23588]=0;u[e+16>>1]=c;u[e+18>>1]=(c+f|0)-1;a=fa(885,a|0,e+14|0,e+24|0,e+16|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;case 0:g=u[e+46>>1];if((g|0)<=0){break d}z[e+24>>2]=z[a+32>>2];v[23588]=0;u[e+16>>1]=c;u[e+18>>1]=(c+g|0)-1;a=ja(886,a|0,h|0,e+24|0,e+16|0,f|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;default:break C}}v[23588]=0;Y(887,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}}d=1}lh(b)}kb=e+336|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}lh(b);T(a|0);L()}function Ax(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=kb-48|0;kb=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}Nb(k);v[j>>2]=0}v[23588]=0;Z(105);k=v[23588];v[23588]=0;b:{c:{if((k|0)==1){m=Ya(92948,48944,49e3,62688,93136,93240,93188,93080,93068,93384,93352,93320,93308,93532,0)|0;d:{e:{n=O()|0;if((n|0)==(ea(92948)|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=277;if((j|0)==1){break e}break b}if((ea(48944)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(49e3)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(62688)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(93136)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(93240)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(93188)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(93080)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(93068)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(93384)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(93352)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(93320)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}if((ea(93308)|0)==(n|0)){k=_(m|0)|0;v[23588]=0;R(1053,j|0,k|0);j=v[23588];v[23588]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break d}o=ea(93532)|0;k=257;m=_(m|0)|0;if((n|0)!=(o|0)){break b}v[23588]=0;R(1053,j|0,m|0);j=v[23588];v[23588]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Vb()}L()}T(a|0);L()}$()}m=!g;if(d){j=ob[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){v[g+16>>2]=k;m=g;g=v[l+44>>2];p=m,q=gg(g?g:21619),v[p+20>>2]=q}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];p=i,q=gg(g?g:21619),v[p>>2]=q}g=v[l+44>>2];if(g){Nb(g);v[l+44>>2]=0}f:{if(!(j&1)){break f}v[23588]=0;R(1051,l+32|0,a|0);g=v[23588];v[23588]=0;g:{h:{if((g|0)!=1){i:{if(f){g=v[f+24>>2];v[23588]=0;R(1052,g|0,l+32|0);g=v[23588];v[23588]=0;if((g|0)!=1){break i}break h}g=Mc(l+32|0);if(b){v[23588]=0;R(b|0,g|0,c|0);g=v[23588];v[23588]=0;if((g|0)==1){break h}break i}Os(g,l)}zb(l+32|0);break f}g=V(0)|0;O()|0;break g}g=V(0)|0;O()|0;zb(l+32|0)}_(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+8>>2]=a?a:21619;v[l+4>>2]=254;v[l>>2]=9134;qK(17835,l);Ms(93888);$()}kb=l+48|0}function Bja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;e=kb-352|0;kb=e;zc(b);f=kb-16|0;kb=f;mU(f+8|0,e+128|0);h=v[f+12>>2];nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);i=v[f+4>>2];if((i|0)==(h|0)){_b(b,v[f+12>>2])}kb=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((h|0)!=(i|0)){break g}if(!oU(e+128|0)){break g}if(!Qb(v[b>>2],v[b+8>>2],Ec(nU(w[e+344|0],w[e+345|0]),nb))){break g}if(!c){d=1;break g}Bd(a,2);ag(a);v[a+480188>>2]=524296;s=a,z=Qe(455e3),v[s+480204>>2]=z;Ob(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;f=e+96|0;Ne(f,2,e+159|0);d=e+112|0;Fc(d,f);Bc(a+1298308|0,d);zb(d);d=0;h:{i:{while(1){if((d|0)==8){j:{d=Wb(v[a+484360>>2],w[a+484376|0]);o=w[e+344|0];n=o+1|0;to(d,b,n,65535,65535);f=Tb(e+112|0);v[23588]=0;U(234,b|0,f|0,n|0);d=v[23588];v[23588]=0;if((d|0)==1){break j}s=e,z=Fb(v[f>>2]),v[s+96>>2]=z;d=Fb(v[f+4>>2]);while(1){h=v[e+96>>2];p=Pb(h,d);if(p){if((w[h|0]-9&255)>>>0<248){break h}He(e+96|0);continue}break}s=a,z=w[Lb(v[f>>2],0)|0],v[s+480196>>2]=z;d=w[e+343|0];i=w[e+345|0];h=Tb(e+96|0);v[23588]=0;m=i+1|0;U(234,b|0,h|0,m|0);i=v[23588];v[23588]=0;k:{if((i|0)==1){break k}v[23588]=0;i=a+484344|0;R(225,i|0,m|0);g=v[23588];v[23588]=0;if((g|0)==1){break k}q=d+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(m|0)){break i}d=w[Lb(v[h>>2],c)|0];v[23588]=0;d=W(226,i|0,d|0,q|0)|0;g=v[23588];v[23588]=0;l:{if((g|0)!=1){if(!d){break i}j=0;k=Zb(v[i>>2],w[Lb(v[h>>2],c)|0]);m:while(1){r=j&65535;if(r>>>0>7){break l}j=j+1|0;d=0;while(1){if(y[k+12>>2]<=d>>>0){continue m}v[23588]=0;g=S(206,b|0)|0;l=v[23588];v[23588]=0;n:{o:{if((l|0)!=1){if(!(g&128)){break o}d=(g&127)+d|0;break n}d=P()|0;O()|0;break b}l=jd(v[k>>2],v[v[k+48>>2]+12>>2],d,r);if((g|0)==1){t[l|0]=254;break n}if((g-1&255)>>>0>96){break n}t[l+1|0]=j;t[l|0]=g+12}d=d+1|0;continue}}}d=P()|0;O()|0;break b}c=c+1|0;continue}}d=P()|0;O()|0;break b}}else{i=e+112|0;f=(e+128|0)+B(d,19)|0;iB(i,f+63|0);h=e+96|0;Fc(h,i);Hl(((d<<5)+a|0)+480289|0,h);zb(h);d=d+1|0;g=B(d,104)+a|0;j=g+484380|0;nd(j,2);t[e+107|0]=0;h=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[e+103|0]=h;t[e+104|0]=h>>>8;t[e+105|0]=h>>>16;t[e+106|0]=h>>>24;h=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);v[e+8>>2]=v[e+104>>2];v[e+96>>2]=f;v[e+100>>2]=h;f=v[e+100>>2];v[e>>2]=v[e+96>>2];v[e+4>>2]=f;Gl(j,1,e);v[g+484404>>2]=8215;f=e+80|0;Fc(f,i);Dc(((d<<5)+a|0)+946304|0,f);zb(f);continue}break}d=P()|0;O()|0;break a}j=o+1|0;c=a+484376|0;d=0;p:{q:{while(1){if((d|0)==(j|0)){v[23588]=0;b=Q(1,e+80|0,8576)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break p}d=P()|0;O()|0;break b}b=w[c|0];g=v[a+484360>>2];v[23588]=0;k=d&65535;b=Q(311,Wb(g,b)|0,k|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){r:{s:{if(b){b=Wb(v[a+484360>>2],w[c|0]);break s}v[23588]=0;g=Q(359,i|0,q|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break q}if((g|0)==65535){break r}b=Wb(v[a+484360>>2],w[c|0]);s=dc(v[b>>2],d),z=g,u[s>>1]=z}b=hB(Fb(v[Zb(v[i>>2],x[dc(v[b>>2],d)>>1])+4>>2]),1);g=w[b+5|0];l=w[Lb(v[f>>2],(d+1>>>0)%(n>>>0)|0)|0];if((g|0)==(l|0)){break r}t:{if(w[b+3|0]!=16){break t}g=w[c|0];m=v[a+484360>>2];v[23588]=0;g=Q(360,Wb(m,g)|0,k|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break c}if((g|0)==65535){break t}b=hB(Fb(v[Zb(v[i>>2],g)+4>>2]),1)}t[b+5|0]=l;t[b+3|0]=16}d=d+1|0;continue}break}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}Jb(a+1298344|0,b);Ab(b);v[23588]=0;b=Q(1,e- -64|0,6052)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}Jb(a+1298356|0,b);Ab(b);b=e+16|0;Dj(b,2,e+139|0);v[23588]=0;R(222,e+32|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;U(11,e+48|0,5,e+32|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}b=e+48|0;Jb(a+1298368|0,b);Ab(b);zb(e+32|0);v[a+1298404>>2]=5;ic(h)}ic(f);d=p^1}kb=e+352|0;return d|0}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;zb(e+32|0);break b}d=P()|0;O()|0}ic(h)}ic(f);T(d|0);L()}function TH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,C=0;i=kb-560|0;kb=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;k=g+B(s,-24)|0;o=v[(e<<2)+73776>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){A[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+v[(c<<2)+73792>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;t=(o|0)>0?o:0;h=(d|0)<=0;while(1){a:{if(h){f=0;break a}n=g+j|0;c=0;f=0;while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(n-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;c=(g|0)==(t|0);g=g+1|0;if(!c){continue}break}z=47-k|0;u=48-k|0;C=k-25|0;g=o;b:{while(1){f=A[(g<<3)+i>>3];c=0;h=g;l=(g|0)<=0;if(!l){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(D(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(D(f)<2147483648){j=~~f;break d}j=-2147483648}v[n>>2]=j;h=h-1|0;f=A[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Vj(f,q);f=f+H(f*.125)*-8;e:{if(D(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{w=(q|0)<=0;i:{if(!w){h=(g<<2)+i|0;j=v[h+476>>2];c=j>>u;r=h;h=j-(c<<u)|0;v[r+476>>2]=h;n=c+n|0;j=h>>z;break i}if(q){break h}j=v[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;h=0;if(!l){while(1){r=(i+480|0)+(c<<2)|0;x=v[r>>2];l=16777215;j:{k:{if(h){break k}l=16777216;if(x){break k}h=0;break j}v[r>>2]=l-x;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(w){break l}c=8388607;m:{switch(C|0){case 1:c=4194303;break;case 0:break m;default:break l}}l=(g<<2)+i|0;v[l+476>>2]=v[l+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!h){break f}f=f-Vj(1,q)}if(f==0){c=1;l=0;h=g;n:{if((g|0)<=(o|0)){break n}while(1){h=h-1|0;l=v[(i+480|0)+(h<<2)>>2]|l;if((h|0)>(o|0)){continue}break}if(!l){break n}k=q;while(1){k=k-24|0;g=g-1|0;if(!v[(i+480|0)+(g<<2)>>2]){continue}break}break b}while(1){h=c;c=c+1|0;if(!v[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;A[(i+320|0)+(j<<3)>>3]=v[(s+g<<2)+73792>>2];c=0;f=0;if((d|0)>0){while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=Vj(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(D(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(D(f)<2147483648){a=~~f;break q}a=-2147483648}v[d>>2]=a;g=g+1|0;break o}if(D(f)<2147483648){c=~~f}else{c=-2147483648}k=q}v[(i+480|0)+(g<<2)>>2]=c}f=Vj(1,k);if((g|0)>=0){d=g;while(1){a=d;A[(a<<3)+i>>3]=f*+v[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}a=0;h=g;while(1){d=a>>>0>t>>>0?t:a;c=0;f=0;while(1){f=A[(c<<3)+76560>>3]*A[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}A[(i+160|0)+(g-h<<3)>>3]=f;h=h-1|0;c=(a|0)!=(g|0);a=a+1|0;if(c){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;y=A[h>>3];f=y+f;A[e+(c<<3)>>3]=m+(y-f);A[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=p+f;A[d+(c<<3)>>3]=m+(p-f);A[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[i+160>>3];if(j){break s}A[b>>3]=f;f=A[i+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;f=A[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[i+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}kb=i+560|0;return n&7}function yM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=kb-16|0;kb=k;a:{b:{c:{if(!$c(c)|!d|v[b+480180>>2]!=16777216|x[b+480192>>1]<d>>>0){break c}d=v[((d<<2)+b|0)+900380>>2];if(!d){break c}e=v[d+44>>2];if(!e){break c}u[k+14>>1]=c-61;c=kb+-64|0;kb=c;d:{e:{d=u[e+28>>1];h=k+14|0;b=u[h>>1];if((d|0)<=(b|0)){if((b|0)<=(vc(v[e+4>>2],v[e+8>>2])+d<<16)-65536>>16){break e}}Mb(a);break d}f:{d=x[e+30>>1];if(!d){b=e+52|0;d=Xx(b,h);if(!Ig(d,xf(b))){break f}Jk(a,wd(d)+4|0);break d}b=Pn(b,d<<16>>16);u[c+62>>1]=b;d=Mb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=e+52|0;f=Xx(a,c+62|0);t:{if(Ig(f,xf(a))){v[23588]=0;R(135,d|0,wd(f)+4|0);a=v[23588];v[23588]=0;if((a|0)==1){break t}a=u[e+30>>1];b=u[h>>1];v[23588]=0;l=c,m=Wx(b,a)+5|0,v[l+32>>2]=m;R(132,c+48|0,c+32|0);a=v[23588];v[23588]=0;u:{if((a|0)!=1){v[23588]=0;Q(98,d|0,c+48|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break u}Ab(c+48|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;Ab(c+48|0);break g}if(u[e+30>>1]>26){break q}v[23588]=0;b=W(527,c+32|0,1,(b<<24)+1090519040>>24)|0;a=v[23588];v[23588]=0;if((a|0)==1){break s}v[23588]=0;U(11,c+48|0,0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}a=c+48|0;f=Jb(d,a);Ab(a);zb(b);v[23588]=0;Q(133,f|0,14600)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break p}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(b);break g}v[23588]=0;a=b<<16>>16;v[c+28>>2]=(a|0)%16;R(840,c+32|0,c+28|0);f=v[23588];v[23588]=0;if((f|0)==1){break o}v[23588]=0;v[c+12>>2]=((a|0)/16<<16>>16)%16;R(840,c+16|0,c+12|0);a=v[23588];v[23588]=0;if((a|0)==1){break n}v[23588]=0;U(2,c+48|0,c+32|0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break m}a=c+48|0;f=Jb(d,a);Ab(a);Ab(c+16|0);Ab(c+32|0);if(b<<16>>16<256){break p}v[23588]=0;U(8,c|0,0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break k}b=c+32|0;g=ie(c);j=zh(c);i=ie(c);a=kb-32|0;kb=a;v[a+16>>2]=j;v[a+24>>2]=g;v[a+8>>2]=i;while(1){if(zi(a+24|0,a+16|0)){g=a+24|0;j=Qp(t[v[g>>2]]);i=a+8|0;t[v[i>>2]]=j;He(g);He(i);continue}break}kb=a+32|0;ad(b,c);v[23588]=0;U(11,c+48|0,0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}a=c+48|0;Jb(f,a);Ab(a);zb(c+32|0);zb(c)}a=u[e+30>>1];b=u[h>>1];v[23588]=0;l=c,m=Wx(b,a)+5|0,v[l+16>>2]=m;R(132,c+48|0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;Q(98,d|0,c+48|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break h}Ab(c+48|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;break l}a=P()|0;O()|0;Ab(c+16|0)}Ab(c+32|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(c+32|0);zb(c);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Ab(c+48|0)}break a}d=kb-16|0;kb=d;f=kb-32|0;kb=f;e=pf(f+16|0,1,0);v:{w:{x:{while(1){j=f+8|0;b=Ac(e);i=Hb(e)+b|0;g=u[h>>1];if(!((b|0)==(i|0)|(g|0)>=0)){t[b|0]=45;g=0-(g&65535)&65535;b=b+1|0}Bx(j,b,i,g&65535);if(!v[f+12>>2]){break x}b=dh(Hb(e));v[23588]=0;R(59,e|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){continue}break}break w}b=v[f+8>>2];h=Ac(e);v[23588]=0;R(60,e|0,b-h|0);b=v[23588];v[23588]=0;y:{if((b|0)!=1){v[23588]=0;R(72,d|0,e|0);b=v[23588];v[23588]=0;if((b|0)!=1){break y}break w}break w}zb(e);kb=f+32|0;break v}a=P()|0;O()|0;zb(e);T(a|0);L()}v[23588]=0;R(71,a|0,d|0);a=v[23588];v[23588]=0;z:{if((a|0)!=1){Ab(d);kb=d+16|0;break z}a=P()|0;O()|0;break a}}kb=c- -64|0;break b}e=v[b>>2];b=kb-32|0;kb=b;A:{if(Lp(c)){v[b+16>>2]=v[8028];d=v[8027];v[b+8>>2]=v[8026];v[b+12>>2]=d;d=v[8025];v[b>>2]=v[8024];v[b+4>>2]=d;yc(a,(b+(c<<2)|0)-1004|0);break A}if($c(c)){d=Mb(b);v[23588]=0;c=c-1|0;f=(c|0)/12|0;c=Q(841,d|0,e+(B(f,-12)+c<<16>>16<<2)|0)|0;e=v[23588];v[23588]=0;B:{if((e|0)==1){break B}v[23588]=0;c=Q(842,c|0,f+48&255)|0;e=v[23588];v[23588]=0;if((e|0)==1){break B}v[23588]=0;Q(3,a|0,c|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break B}Ab(c);break A}a=P()|0;O()|0;break a}if(!c){yc(a,16730);break A}yc(a,14571)}kb=b+32|0}kb=k+16|0;return}Ab(d);T(a|0);L()}function p$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=kb+-64|0;kb=h;v[h+56>>2]=b;v[e>>2]=0;gd(h,d);v[23588]=0;i=S(1136,h|0)|0;j=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){ac(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;ac(h);T(a|0);L()}kG(a,f+24|0,h+56|0,c,e,i);break b}jG(a,f+16|0,h+56|0,c,e,i);break b}g=a;i=b;a=ob[v[v[a+8>>2]+12>>2]](a+8|0)|0;b=Ac(a);k=h,l=Zj(g,i,c,d,e,f,b,b+(Hb(a)<<2)|0),v[k+56>>2]=l;break b}a=Xi(h+56|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}g=v[20767];v[h+24>>2]=v[20766];v[h+28>>2]=g;g=v[20765];v[h+16>>2]=v[20764];v[h+20>>2]=g;g=v[20763];v[h+8>>2]=v[20762];v[h+12>>2]=g;g=v[20761];v[h>>2]=v[20760];v[h+4>>2]=g;k=h,l=Zj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[20775];v[h+24>>2]=v[20774];v[h+28>>2]=g;g=v[20773];v[h+16>>2]=v[20772];v[h+20>>2]=g;g=v[20771];v[h+8>>2]=v[20770];v[h+12>>2]=g;g=v[20769];v[h>>2]=v[20768];v[h+4>>2]=g;k=h,l=Zj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=Xi(h+56|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Xi(h+56|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Xi(h+56|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Xi(h+56|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Xi(h+56|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+56|0;b=kb-16|0;kb=b;v[b+8>>2]=c;while(1){H:{if(!ds(a,b+8|0)){break H}if(!Xk(i,1,Yk(v[a>>2]))){break H}Cn(a);continue}break}if($j(a,b+8|0)){v[e>>2]=v[e>>2]|2}kb=b+16|0;break b}b=h+56|0;a=ob[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Hb(a)|0)==(0-Hb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=Sr(b,c,a,a+24|0,i,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=uc(h,83104,44);k=g,l=Zj(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[20792];g=v[20791];v[h+8>>2]=v[20790];v[h+12>>2]=g;g=v[20789];v[h>>2]=v[20788];v[h+4>>2]=g;k=h,l=Zj(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=Xi(h+56|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}g=v[20803];v[h+24>>2]=v[20802];v[h+28>>2]=g;g=v[20801];v[h+16>>2]=v[20800];v[h+20>>2]=g;g=v[20799];v[h+8>>2]=v[20798];v[h+12>>2]=g;g=v[20797];v[h>>2]=v[20796];v[h+4>>2]=g;k=h,l=Zj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=Xi(h+56|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=ob[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ob[v[v[a+8>>2]+24>>2]](a+8|0)|0;b=Ac(a);k=h,l=Zj(g,i,c,d,e,f,b,b+(Hb(a)<<2)|0),v[k+56>>2]=l;break b}iG(f+20|0,h+56|0,c,e,i);break b}a=Xi(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=kb-16|0;kb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if($j(c,a+8|0)){break M}b=4;if((vn(i,Yk(v[c>>2]))|0)!=37){break M}b=2;if(!$j(Cn(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}kb=a+16|0}a=v[h+56>>2]}kb=h- -64|0;return a|0}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0;d=kb-128|0;kb=d;g=-1;a:{b:{c:{d:{e:{f:{if(!Zg(v[v[b>>2]-12>>2]+b|0)){break f}e=d+112|0;ne(e,b);f=v[e+8>>2];i=v[e+12>>2];e=d+104|0;Tj(e);b=Vk(b,e,8);if(Sb(e,16706,8)){a=Yg(d+88|0,f,i);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;Yj(b,d+8|0);break f}u[d+86>>1]=0;Wf(b,d+86|0);l=u[d+86>>1];if((l-4&65535)>>>0<65534){break f}e=d+78|0;Tj(e);b=Vk(b,e,8);if(Sb(e,14251,8)){break f}u[d+76>>1]=0;Wf(b,d+76|0);i=u[d+76>>1];if((i-5&65535)>>>0<65534){break f}g:{h:{i:{if(i>>>0<=3){e=Mb(d+112|0);v[23588]=0;f=W(483,b|0,e|0,65535)|0;k=v[23588];v[23588]=0;if((k|0)==1){break b}if(!f){break h}v[23588]=0;U(11,d- -64|0,c|0,e|0);f=v[23588];v[23588]=0;if((f|0)!=1){break i}break b}e=Mb(d+112|0);v[23588]=0;f=Q(485,b|0,e|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break c}if(!f){break g}v[23588]=0;U(11,d- -64|0,c|0,e|0);f=v[23588];v[23588]=0;if((f|0)==1){break c}}f=d- -64|0;Jb(a+40|0,f);Ab(f);zb(e);u[d+62>>1]=0;Wf(b,d+62|0);u[d+60>>1]=0;Wf(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;j:{if((i|0)<=3){v[d+112>>2]=0;pk(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break f}f=Dl(e);u[d+58>>1]=f;break j}Wf(b,d+58|0);f=x[d+58>>1]}k=a+52|0;n=f&65535;i=(i|0)>3;f=0;k:{l:{m:{while(1){if((f&65535)>>>0>=n>>>0){break l}e=Mb(d+112|0);v[23588]=0;u[d+40>>1]=0;R(891,b|0,d+40|0);h=v[23588];v[23588]=0;if((h|0)==1){break e}n:{if(!i){v[23588]=0;h=W(483,b|0,e|0,65535)|0;j=v[23588];v[23588]=0;if((j|0)==1){break e}if(h){break n}zb(e);break f}v[23588]=0;h=Q(485,b|0,e|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break e}if(!h){break k}}v[23588]=0;U(11,d- -64|0,c|0,e|0);h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;h=Q(888,k|0,d+40|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break m}j=h;h=d- -64|0;Jb(j,h);Ab(h);zb(e);f=f+1|0;continue}break}g=P()|0;O()|0;break d}g=P()|0;O()|0;Ab(d- -64|0);break d}c=d- -64|0;Tj(c);b=Vk(b,c,8);if(Sb(c,14195,8)){break f}c=x[a>>1];if(c>>>0>3|(c|0)==2){break f}c=a+4|0;o:{if((l|0)<=2){if(EL(b,c)){break o}break f}if(!DL(b,c)){break f}}o=d,p=Fb(v[a+4>>2]),v[o+112>>2]=p;c=Fb(v[a+8>>2]);while(1){e=v[d+112>>2];if(Pb(e,c)){if(!qm(z[e>>2])){break f}Le(d+112|0);continue}break}c=a+16|0;p:{if((l|0)<=2){if(EL(b,c)){break p}break f}if(!DL(b,c)){break f}}o=d,p=Fb(v[a+16>>2]),v[o+112>>2]=p;c=Fb(v[a+20>>2]);while(1){e=v[d+112>>2];if(Pb(e,c)){if(!qm(z[e>>2])){break f}Le(d+112|0);continue}break}o=a,p=vc(v[a+16>>2],v[a+20>>2]),v[o+36>>2]=p;u[d+56>>1]=0;Wf(b,d+56|0);c=x[d+56>>1];u[a+28>>1]=c;if((c-201&65535)>>>0<65135){break f}u[d+54>>1]=0;Wf(b,d+54|0);c=u[d+54>>1];u[a+30>>1]=c;if((c|0)<0){break f}v[d+48>>2]=0;Ep(b,d+48|0);m=HL(z[d+48>>2]);z[a+32>>2]=m;if(!qm(m)){break f}c=d+40|0;Tj(c);Vk(b,c,8);if(Sb(c,16697,8)){break f}b=vc(v[a+4>>2],v[a+8>>2]);if(b>>>0>32767){break f}c=u[a+30>>1];e=x[a>>1];if(!(e?!(z[a+32>>2]<=C(0))&(c|0)>0:1)){break f}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break f}break;default:break q}}b=0;c=v[a+36>>2];if(c){b=c-1|0;v[a+36>>2]=b}o=d,p=Fi(b),v[o+112>>2]=p;v[d+32>>2]=0;o=a,p=v[Jj(d+112|0,d+32|0,43824)>>2],v[o+36>>2]=p;Fp(a);g=1;if(x[a>>1]!=3){break f}c=u[a+30>>1];if((c-u[a+28>>1]|0)>(PL(vc(v[a+4>>2],v[a+8>>2]))|0)){break f}g=a+32|0;e=Tb(d+112|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=x[a+28>>1];u[d+32>>1]=b;o=d,p=(vc(v[a+4>>2],v[a+8>>2])+b|0)-1|0,u[o+34>>1]=p;v[23588]=0;u[d+30>>1]=0;ja(886,a|0,e|0,g|0,d+32|0,d+30|0)|0;a=v[23588];v[23588]=0;g=1;if((a|0)==1){break r}wc(e);break f}c=u[a+28>>1];f=v[a+4>>2];v[23588]=0;R(892,e|0,Eb(f,b-c|0)|0);c=v[23588];v[23588]=0;if((c|0)!=1){b=b+1|0;c=x[a+30>>1];continue}}break}g=P()|0;O()|0;wc(e);break a}zb(e);break f}zb(e);break f}zb(e)}kb=d+128|0;return g|0}g=P()|0;O()|0}zb(e);break a}g=P()|0;O()|0;zb(e);break a}g=P()|0;O()|0;zb(e)}T(g|0);L()}function Bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=kb-752|0;kb=e;zc(b);d=kb-16|0;kb=d;h=e+144|0;hR(d+8|0,h);f=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){_b(b,v[d+12>>2])}kb=d+16|0;d=(f|0)==(g|0);if(!d){gR(h)}a:{if(!d){break a}if(!jR(e+144|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(iR(x[e+178>>1]),nb))){break a}if(!c){n=1;break a}Bd(a,262144);f=e+104|0;Ii(f,2,e+144|0);d=e+24|0;Fc(d,f);Bc(a+1298308|0,d);zb(d);h=yc(d,8277);Jb(a+1298344|0,h);Ab(h);d=yc(d,10075);Jb(a+1298356|0,d);Ab(d);d=kb-16|0;kb=d;i=f;f=yc(d,4196);ad(i,f);Ab(f);kb=d+16|0;t[e+8|0]=w[e+174|0];v[23588]=0;t[e+127|0]=w[e+173|0];R(663,e+128|0,e+127|0);d=v[23588];v[23588]=0;b:{c:{d:{if((d|0)!=1){v[23588]=0;X(250,e+24|0,e+104|0,e+8|0,e+128|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=e+24|0;Jb(a+1298368|0,d);Ab(d);Ab(e+128|0);f=e+104|0;bc(f);v[a+480208>>2]=12;v[a+1298404>>2]=5;h=a+480188|0;u[h>>1]=x[e+182>>1];u[e+24>>1]=x[e+178>>1];u[e+104>>1]=3999;A=a,C=x[Wc(d,f)>>1],u[A+480190>>1]=C;rU(Wb(v[a+484360>>2],w[a+484376|0]),e+240|0,x[e+176>>1]);d=0;while(1)if(x[h>>1]<=d>>>0){d=e+24|0;ae(d,b,B(x[e+178>>1],80));h=c&2;l=kc(e+104|0,d);Bb(d);g=e+72|0;d=0;e:{f:{while(1){if(x[a+480190>>1]<=d>>>0){n=1;if(c&1){break f}break b}v[23588]=0;R(664,l|0,e+24|0);f=v[23588];v[23588]=0;if((f|0)==1){break e}f=e+8|0;Ii(f,2,g);v[23588]=0;R(222,e+128|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break e}d=d+1|0;f=e+128|0;Dc(((d<<5)+a|0)+946304|0,f);zb(f);v[23588]=0;i=f;f=(B(d,104)+a|0)+484380|0;U(665,i|0,e+24|0,f|0);j=v[23588];v[23588]=0;g:{if((j|0)==1){break g}if(!h|!v[f>>2]){continue}v[23588]=0;j=Q(155,b|0,x[e+42>>1]|x[e+44>>1]<<16)|0;i=v[23588];v[23588]=0;if((i|0)==1){break g}if(!j){continue}v[23588]=0;W(219,e+128|0,f|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){continue}}break}break e}v[23588]=0;m=a+484344|0;R(225,m|0,x[e+180>>1]);c=v[23588];v[23588]=0;if((c|0)==1){break e}c=e+24|0;r=c|4;s=c|2;o=c|3;y=c|5;z=c|1;p=a+480188|0;a=0;while(1){if(x[e+180>>1]<=a>>>0){break b}v[23588]=0;c=W(226,m|0,a&65535,64)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}h:{if(!c){break h}c=(a<<1)+e|0;c=w[c+496|0]|w[c+497|0]<<8;if(!c){break h}v[23588]=0;c=Q(155,b|0,c<<4)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}if(!c){break h}j=0;c=Zb(v[m>>2],a);c=jd(v[c>>2],v[v[c+48>>2]+12>>2],0,0);while(1){if(j>>>0>63){break h}d=v[b+8>>2];f=v[b>>2];v[23588]=0;d=W(156,f|0,d|0,1)|0;f=v[23588];v[23588]=0;i:{if((f|0)!=1){if(!d){break h}v[23588]=0;h=S(206,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}if(h){break i}j=j+1|0;c=B(x[p>>1],6)+c|0;continue}break e}u[e+28>>1]=0;v[e+24>>2]=0;f=h&31;d=B(f,6)+c|0;i=ug(e+24|0);f=f>>>0<x[p>>1];i=f?d:i;j:{if(!(h&32)){break j}v[23588]=0;R(260,e+128|0,b|0);g=v[23588];v[23588]=0;if((g|0)==1){break e}g=w[e+128|0];t[i|0]=g;A=f?d+1|0:z,C=w[Oc(e+128|0)|0],t[A|0]=C;k:{if(g){if((g|0)==254){break k}if(g>>>0<121){break j}}g=0}t[i|0]=g}l:{if(!(h&64)){break l}v[23588]=0;R(260,e+128|0,b|0);g=v[23588];v[23588]=0;if((g|0)==1){break e}g=f?d+5|0:y;q=Oc(e+128|0);t[g|0]=w[q|0];k=w[e+128|0];m:{if(k>>>0<=15){Pf(i,k,w[q|0]);break m}t[(f?d+3|0:o)|0]=k>>>0<=23?w[k+26999|0]:0}i=f?d+3|0:o;k=w[i|0];if((k|0)!=23){if((k|0)!=9){break l}t[i|0]=20;t[e+8|0]=w[g|0]>>>3;t[e+127|0]=1;A=g,C=w[kf(e+8|0,e+127|0)|0]-1&15|128,t[A|0]=C;break l}t[e+8|0]=64;A=g,C=w[Xb(g,e+8|0)|0]<<1,t[A|0]=C}if(!(h&128)){continue}t[(f?d+2|0:s)|0]=1;v[23588]=0;h=S(206,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}t[(f?d+4|0:r)|0]=h;continue}}a=a+1|0;continue}}d=P()|0;O()|0;Bb(l);break c}else{f=(d<<5)+a|0;ef(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;d=d+1|0;continue}}d=P()|0;O()|0;Ab(e+128|0);break d}d=P()|0;O()|0}bc(e+104|0)}T(d|0);L()}Bb(l)}kb=e+752|0;return n|0}function eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=kb-48|0;kb=g;a:{b:{if(!c){break b}f=Hh(a,b);a=Fb(v[d>>2]);v[g+40>>2]=a;d=Fb(v[d+4>>2]);while(1){if(!Pb(a,d)){break b}zc(a);c:{if((Hj(a)|0)==(c|0)){_b(a,20);d=Hj(a);k=Yf(g+24|0);c=Al(g+16|0,0,b?32:64);v[23588]=0;R(393,f|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}o=(b|0)==2?4096:(b|0)==1?2048:16384;c=24;d=d+24|0;p=1;l=1;d:{while(1){h=o;while(1){e=v[a+8>>2];i=v[a>>2];v[23588]=0;e=W(156,i|0,e|0,1)|0;i=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((i|0)!=1){if(!e){break d}e=v[f+4>>2];i=v[f>>2];m=v[a+8>>2];v[23588]=0;v[g+16>>2]=m;m=Q(394,k|0,g+16|0)|0;q=v[23588];v[23588]=0;if((q|0)==1){break a}y=m,z=$d(i,e),v[y>>2]=z;v[23588]=0;e=S(206,a|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}q:{switch(e-128|0){case 3:case 4:case 7:case 8:break e;case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 3:case 4:break e;case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(w[f+12|0]&4){break e}v[23588]=0;e=S(271,a|0)|0;i=v[23588];v[23588]=0;t:{if((i|0)==1){break t}v[23588]=0;v[g+16>>2]=e;e=Q(394,k|0,g+16|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break t}t[f+15|0]=v[e>>2];y=f,z=$d(v[f>>2],v[f+4>>2])-1|0,t[y+16|0]=z;t[f+12|0]=w[f+12|0]|4;break e}break a}v[23588]=0;e=S(271,a|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}u[g+16>>1]=e;u[g+14>>1]=1;e=x[le(g+16|0,g+14|0)>>1];h=B(e,B(r<<16>>16,l))+h|0;u:{if(e>>>0<2){break u}y=g,z=Dl((e+x[Bj(v[f+4>>2])>>1]|0)-1|0),u[y+16>>1]=z;e=qu(b,h);v[23588]=0;t[g+14|0]=e;U(395,f|0,g+16|0,g+14|0);e=v[23588];v[23588]=0;if((e|0)!=1){break u}break a}y=g,z=Dl(x[Bj(v[f+4>>2])>>1]+1|0),u[y+16>>1]=z;e=qu(b,h);v[23588]=0;t[g+14|0]=e;U(395,f|0,g+16|0,g+14|0);e=v[23588];v[23588]=0;if((e|0)!=1){break e}break a}v[23588]=0;j=S(206,a|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}s=v[a+8>>2];break e}v[23588]=0;e=S(271,a|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}e=c+e|0;v[g+16>>2]=e;if(!(!(j&255)|e>>>0<s>>>0)){j=j-1|0;if(!(j&255)){break f}v[23588]=0;Q(155,a|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break e}break a}if(!(j&255)){break f}v[23588]=0;e=Q(396,k|0,g+16|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}t[f+13|0]=v[e>>2];y=f,z=$d(v[f>>2],v[f+4>>2])-1|0,t[y+14|0]=z;t[f+12|0]=w[f+12|0]|2;break e}p=0;n=1;break e}v[23588]=0;h=S(271,a|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}e=qu(b,h);y=Bj(v[f+4>>2]),z=e,t[y+2|0]=z;break e}v[23588]=0;r=S(397,a|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break e}break a}v[23588]=0;e=S(206,a|0)|0;l=v[23588];v[23588]=0;if((l|0)!=1){t[g+16|0]=e;t[g+14|0]=1;l=w[kf(g+16|0,g+14|0)|0];break e}break a}v[23588]=0;Q(188,a|0,1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}break e}n=1;if(c>>>0<d>>>0){break e}break d}j=0}if(!n|c>>>0>=d>>>0){continue}break}v[23588]=0;c=Q(155,a|0,d|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}if(!c){break d}c=v[a+8>>2];h=v[a>>2];v[23588]=0;c=W(156,h|0,c|0,2)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}if(!c){break d}h=w[f+12|0];v:{if(!(!(h&4)&p)){c=v[f+4>>2];break v}c=v[f+4>>2];e=v[f>>2];t[f+12|0]=h|4;h=$d(e,c)-1|0;t[f+15|0]=h;t[f+16|0]=h}y=g,z=Dl(x[Bj(c)>>1]+1|0),u[y+16>>1]=z;c=qu(b,o);v[23588]=0;t[g+14|0]=c;U(395,f|0,g+16|0,g+14|0);c=v[23588];v[23588]=0;if((c|0)!=1){n=1;t[f+17|0]=w[f+16|0]+1;c=d;continue}break}break a}t[f+12|0]=w[f+12|0]|1;QT(k);break b}a=v[Nf(g+40|0)>>2];continue}break}break a}kb=g+48|0;return}a=P()|0;O()|0;QT(k);T(a|0);L()}function LV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=kb-3056|0;kb=e;zc(b);f=kb-16|0;kb=f;h=e+1096|0;SB(f+8|0,h);i=v[f+12>>2];j=b;nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(i|0)){_b(j,v[f+12>>2])}kb=f+16|0;b=(b|0)==(i|0);if(!b){RB(h)}a:{if(!b){break a}if(!TB(e+1096|0)){break a}b:{if(!c){break b}if(!Qb(v[j>>2],v[j+8>>2],Ec(1024,0))){break a}QB(j,e+576|0);QB(j,e- -64|0);while(1){if((g|0)!=128){b=g<<2;f=v[b+(e+576|0)>>2];if(f>>>0>16777215){break a}b=v[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}g=g+1|0;if(tr(v[j>>2],(b+f|0)+2978|0)){continue}break a}break}Bd(a,2);ag(a);b=e+40|0;d=yc(b,13794);Jb(a+1298344|0,d);Ab(d);d=yc(b,14723);Jb(a+1298356|0,d);Ab(d);b=yc(b,15464);Jb(a+1298368|0,b);Ab(b);v[a+1298404>>2]=5;b=w[e+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=b;Ve(Wb(v[a+484360>>2],w[a+484376|0]),w[e+1097|0]);v[a+480188>>2]=4194317;Ob(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;g=0;while(1){if((g|0)==4){c:{while(1){d:{if((d|0)==32){g=0;break d}b=d+1|0;g=B(b,104)+a|0;i=g+484380|0;nd(i,2);h=e+16|0;_h(h,1,(B(d,13)+e|0)+1098|0);f=e+40|0;Fc(f,h);Dc(((b<<5)+a|0)+946304|0,f);zb(f);d=(e+1096|0)+(d<<4)|0;f=w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24);v[i>>2]=f;h=f;f=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);if(h>>>0>=f>>>0){d=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);u[g+484414>>1]=2;v[g+484388>>2]=f;v[g+484384>>2]=d}v[g+484404>>2]=8287;d=b;continue}break}while(1){if((g|0)!=32){d=g+33|0;f=(B(d,104)+a|0)+484380|0;nd(f,2);i=e+16|0;_h(i,1,(B(g,13)+e|0)+2026|0);b=e+40|0;Fc(b,i);Dc(((d<<5)+a|0)+946304|0,b);zb(b);v[e+48>>2]=0;v[e+40>>2]=0;v[e+44>>2]=0;d=(e+1096|0)+B(g,11)|0;o=Lb(b,0),p=w[d+1347|0],t[o|0]=p;o=Lb(b,1),p=w[d+1352|0],t[o|0]=p;o=Lb(b,2),p=w[d+1348|0],t[o|0]=p;o=Lb(b,3),p=w[d+1353|0],t[o|0]=p;o=Lb(b,4),p=w[d+1349|0],t[o|0]=p;o=Lb(b,5),p=w[d+1354|0],t[o|0]=p;o=Lb(b,6),p=w[d+1350|0],t[o|0]=p;o=Lb(b,7),p=w[d+1355|0],t[o|0]=p;o=Lb(b,8),p=w[d+1351|0],t[o|0]=p;o=Lb(b,9),p=w[d+1356|0],t[o|0]=p;o=Lb(b,10),p=w[d+1346|0],t[o|0]=p;v[e+8>>2]=v[e+48>>2];b=v[e+44>>2];v[e>>2]=v[e+40>>2];v[e+4>>2]=b;Gl(f,1,e);g=g+1|0;continue}break}Wq(Wb(v[a+484360>>2],w[a+484376|0]),e+2794|0,256,255,65535);l=a+484344|0;xg(l,128);m=c&1;f=0;while(1){e:{f:{if((f|0)!=128){b=f<<2;dd(j,v[b+(e+576|0)>>2]+2978|0);d=e+16|0;ae(d,j,v[b+(e- -64|0)>>2]);b=kc(e+40|0,d);Bb(d);if(!m){break e}v[23588]=0;d=W(226,l|0,f&65535,64)|0;g=v[23588];v[23588]=0;if((g|0)==1){break c}if(!d){break e}g=0;i=Zb(v[l>>2],f);while(1){if(g>>>0>63){break e}g:{while(1){h:{d=v[b>>2];v[23588]=0;d=W(156,d|0,v[e+48>>2],1)|0;h=v[23588];v[23588]=0;if((h|0)==1){break h}if(!d){break e}v[23588]=0;d=S(206,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break c}if(d>>>0>12){break g}h=jd(v[i>>2],v[v[i+48>>2]+12>>2],g,d);v[23588]=0;R(260,e+16|0,b|0);k=v[23588];v[23588]=0;if((k|0)==1){break c}k=w[e+16|0];d=d>>>0>3;t[h|0]=((k&15)+(d?13:37)|0)+B(k>>>4&7,12);k=Oc(e+16|0);t[h+1|0]=((w[k|0]>>>4|0)+(d?33:1)|0)+(w[e+16|0]>>>3&16);PB(h,w[k|0],d);continue}break}break c}h=d-32|0;if((h&255)>>>0<=12){h=jd(v[i>>2],v[v[i+48>>2]+12>>2],g,h&65535);v[23588]=0;k=S(206,b|0)|0;n=v[23588];v[23588]=0;if((n|0)==1){break c}PB(h,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!g){break e}o=jd(v[i>>2],v[v[i+48>>2]+12>>2],g-1|0,0),p=14,t[o+3|0]=p;break e}v[23588]=0;d=S(206,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break c}g=d+g|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}wg(_c(e+40|0,8,1,0,1),(B(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}Bb(b);d=0;break a}Bb(b);f=f+1|0;continue}}}else{u[((g<<5)+a|0)+480284>>1]=g&1?192:64;g=g+1|0;continue}break}a=P()|0;O()|0;Bb(b);T(a|0);L()}d=1}kb=e+3056|0;return d|0}function Aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=kb-208|0;kb=d;zc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!vo(b,d+192|0)){break l}if(!UR(d+192|0)){break l}g=Jh(d+168|0);h=Mb(d+152|0);Cu(d+88|0);v[23588]=0;f=Q(595,b|0,d+80|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=cc(cc(v[d+84>>2])-4|0),v[m+84>>2]=n;while(1){f=cc(cc(v[d+84>>2])-8|0);v[d+84>>2]=f;n:{if(c){break n}if((cc(v[d+80>>2])|0)!=1347699796){break n}j=1;break m}v[23588]=0;U(190,d+56|0,b|0,cc(f)|0);f=v[23588];v[23588]=0;if((f|0)==1){break d}e=d+56|0;f=kc(d,e);Bb(e);e=v[f>>2];v[23588]=0;i=S(178,e|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=cc(v[d+80>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}v[23588]=0;Q(188,f|0,4)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;e=S(596,f|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break b}if(!e){break o}e=cc(v[d+84>>2]);if(e>>>0<7){break o}v[23588]=0;U(597,f|0,h|0,e-6|0);e=v[23588];v[23588]=0;if((e|0)==1){break b}break o}v[23588]=0;l=Q(598,f|0,d+88|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break o}break b}vv(g,f);break o}v[23588]=0;j=W(599,a|0,f|0,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}}Bb(f);if(i){v[23588]=0;f=Q(595,b|0,d+80|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break i}if(f){continue}}break}if(sh(v[h+4>>2],w[h+11|0])){v[23588]=0;b=Q(1,d+56|0,14842)|0;c=v[23588];v[23588]=0;if((c|0)==1){break g}Jb(h,b);Ab(b)}q:{if(!(j&l&1)){break q}b=x[d+130>>1];v[23588]=0;b=Ib(b)&256;W(264,a+1074312|0,5,!b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}c=Ib(x[d+126>>1]);if(c){u[d>>1]=64;u[d+40>>1]=c;m=a,n=x[Wc(d,d+40|0)>>1],v[m+480228>>2]=n}c=!b;b=Ib(x[d+128>>1]);if(!(c|!b)){v[a+480204>>2]=B(b,1e4)}if(w[d+88|0]){b=d+40|0;Ne(b,2,d+88|0);v[23588]=0;R(222,d|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}Bc(a+1298308|0,d);zb(d)}c=x[d+134>>1];if(!jq(c,1,12)){break q}f=x[d+132>>1];if(!jq(f,1,31)){break q}e=x[d+138>>1];if(!jq(e,0,23)){break q}i=x[d+140>>1];if(!jq(i,0,59)){break q}k=x[d+142>>1];if(!jq(k,0,59)){break q}b=yo(d);m=b,n=Ib(x[d+136>>1])+1900|0,v[m>>2]=n;m=b,n=Ib(c),v[m+4>>2]=n;m=b,n=Ib(f),v[m+8>>2]=n;m=b,n=Ib(e),v[m+12>>2]=n;m=b,n=Ib(i),v[m+16>>2]=n;m=b,n=Ib(k),v[m+24>>2]=n;v[b+28>>2]=0;v[23588]=0;R(434,a+1298408|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break q}a=P()|0;O()|0;break a}if(j&1){b=v[g>>2];v[23588]=0;b=S(178,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break h}if(b){b=Mb(d);v[23588]=0;U(268,g|0,b|0,32);c=v[23588];v[23588]=0;if((c|0)==1){break c}if(yq(b,13687)){v[23588]=0;U(11,d+40|0,14,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}c=d+40|0;Jb(a+1298320|0,c);Ab(c)}c=v[g+8>>2];f=v[g>>2];v[23588]=0;c=Q(600,f|0,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}if(!c){v[23588]=0;c=S(202,g|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}v[23588]=0;da(313,a+1298332|0,g|0,c|0,40,0);c=v[23588];v[23588]=0;if((c|0)==1){break c}}zb(b)}v[23588]=0;b=Q(1,d+40|0,17493)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}v[23588]=0;U(477,d|0,b|0,h|0);c=v[23588];v[23588]=0;if((c|0)==1){break j}Jb(a+1298368|0,d);Ab(d);Ab(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[23588]=0;a=W(264,a+1074312|0,84,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break h}v[23588]=0;a=W(264,a|0,83,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break h}v[23588]=0;Q(265,a|0,85)|0;a=v[23588];v[23588]=0;if((a|0)==1){break h}}Ab(h);Bb(g)}kb=d+208|0;return j&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(b);break a}a=P()|0;O()|0;Bb(f)}Ab(h);Bb(g);T(a|0);L()}function iga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=kb-256|0;kb=e;zc(b);a:{if(!eV(b,e+184|0)){break a}if(!KR(e+184|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(JR(e+184|0),nb))){break a}b:{if(!c){break b}Bd(a,16);f=e+24|0;Dj(f,2,e+184|4);d=e+48|0;Fc(d,f);Bc(a+1298308|0,d);zb(d);l=a+480190|0;u[l>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];g=yc(d,8325);Jb(a+1298344|0,g);Ab(g);g=yc(d,10079);Jb(a+1298356|0,g);Ab(g);Sf(f,4214);g=w[e+187|0];v[e>>2]=g>>>4;v[23588]=0;v[e+180>>2]=g&15;X(302,d|0,f|0,e|0,e+180|0);d=v[23588];v[23588]=0;c:{d:{e:{if((d|0)!=1){d=e+48|0;Jb(a+1298368|0,d);Ab(d);bc(e+24|0);v[a+1298404>>2]=5;g=1;while(1){j=g&65535;if(j>>>0>x[l>>1]){g=0;d=a+480188|0;while(1)if(x[d>>1]<=g>>>0){f=e+48|0;d=kb-16|0;kb=d;h=b;f:{if(!Qb(v[b>>2],v[b+8>>2],128)){b=0;while(1){if((b|0)!=128){Dh(b+f|0);b=b+1|0;continue}break}break f}aT(d+8|0,f);ud(d,h,v[d+8>>2],v[d+12>>2])}kb=d+16|0;hv(Wb(v[a+484360>>2],w[a+484376|0]),f,w[e+211|0]+1|0);b=w[e+216|0];ae(e,h,B(x[e+208>>1],192));i=kc(e+24|0,e);Bb(e);n=c&1;if(n){v[23588]=0;R(225,a+484344|0,w[e+210|0]+1|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}}o=b?b:64;p=a+484344|0;q=a+480188|0;while(1){if(w[e+210|0]<m>>>0){b=x[e+212>>1];if(b){v[23588]=0;da(313,a+1298332|0,h|0,b|0,39,1);b=v[23588];v[23588]=0;if((b|0)==1){break d}}if(!(c&2)){break e}g=1;b=a+480190|0;while(1){c=g&65535;if(c>>>0>x[b>>1]){break e}c=B(c,104)+a|0;d=_c(e,u[c+484414>>1]&1?16:8,1,0,1);v[23588]=0;W(219,d|0,c+484380|0,h|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){g=g+1|0;continue}break}break d}g:{h:{if(n){v[23588]=0;b=W(226,p|0,m&65535,o|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break d}k=0;if(b){break h}}v[23588]=0;Q(188,h|0,64)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break g}break d}while(1){d=k&65535;if(d>>>0>31){break g}v[23588]=0;b=S(194,h|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break d}i:{if(!b|b>>>0>x[e+208>>1]|d>>>0>=x[q>>1]){break i}v[23588]=0;Q(155,i|0,B(b,192)-192|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}l=0;b=Zb(v[p>>2],m);g=jd(v[b>>2],v[v[b+48>>2]+12>>2],0,d);while(1){if((l|0)==(o|0)){break i}v[23588]=0;R(534,e|0,i|0);b=v[23588];v[23588]=0;if((b|0)!=1){j=Oc(e);d=Te(e);b=w[e|0];if(b>>>0>=4){t[g|0]=(b>>>2|0)+37;b=w[e|0]}t[g+1|0]=b<<4&48|w[j|0]>>>4;b=w[d|0];d=0;f=0;j:{k:{l:{m:{n:{o:{j=w[j|0]&15;switch(j-8|0){case 0:break l;case 6:break n;case 2:break o;default:break m}}b=(b&240?-16:15)&b;j=10;break k}j=14;r=(b+16&240)>>>4|0;if(r>>>0>8){break k}if(1<<r&435){break l}break k}d=j;f=b}j=d;b=f;if(!((d|b)&255)){break j}}Pf(g,j,b&255)}l=l+1|0;g=B(x[q>>1],6)+g|0;continue}break}break d}k=k+1|0;continue}}m=m+1|0;continue}}else{f=(g<<5)+a|0;ef(f+480280|0);u[f+480284>>1]=(w[(e+g|0)+218|0]<<4|8)&248;g=g+1|0;continue}}else{f=e+48|0;FC(b,f);h=kb-16|0;kb=h;d=(B(j,104)+a|0)+484380|0;nd(d,0);u[h+14>>1]=w[f+35|0]<<2;u[h+12>>1]=256;s=d,y=x[Wc(h+14|0,h+12|0)>>1],u[s+30>>1]=y;i=w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24);p:{if(i>>>0<3){break p}v[d>>2]=i;v[d+4>>2]=w[f+26|0]|w[f+27|0]<<8|(w[f+28|0]<<16|w[f+29|0]<<24);v[h+8>>2]=w[f+30|0]|w[f+31|0]<<8|(w[f+32|0]<<16|w[f+33|0]<<24);v[h+4>>2]=1;s=d,y=v[Zc(h+8|0,h+4|0)>>2]-1|0,v[s+8>>2]=y;xc(d+8|0,i);k=v[d+8>>2];i=v[d+4>>2];q:{if(k>>>0<=i+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;k=0;i=0;break q}u[d+34>>1]=x[d+34>>1]|2;k=k>>>1|0;i=i>>>1|0}t[d+37|0]=w[f+34|0];s=d,y=Yu(0,t[f+34|0]<<4),v[s+24>>2]=y;if(!(t[f+36|0]&1)){break p}v[d+8>>2]=k;v[d+4>>2]=i;u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1}kb=h+16|0;Il(e,2,f);d=e+24|0;Fc(d,e);Dc(((j<<5)+a|0)+946304|0,d);g=g+1|0;zb(d);continue}}}g=P()|0;O()|0;bc(e+24|0);break c}v[a+480260>>2]=64;v[a+480264>>2]=32767;Bb(i);break b}g=P()|0;O()|0;Bb(i)}T(g|0);L()}g=1}kb=e+256|0;return g|0}function bk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=1;o(+b);f=j(1)|0;d=j(0)|0;a:{b:{m=f&2147483647;g=d;c:{if(!(m|d)){break c}o(+a);d=j(1)|0;t=j(0)|0;if(!t&(d|0)==1072693248){break c}q=d&2147483647;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(t|0)!=0|m>>>0>2146435072)&(!g|(m|0)!=2146435072))){return a+b}d:{e:{f:{r=0;g:{if((d|0)>0|(d|0)>=0){break g}r=2;if(m>>>0>1128267775){break g}r=0;if(m>>>0<1072693248){break g}h=m>>>20|0;if(m>>>0<1094713344){break f}e=1075-h|0;h=g>>>e|0;r=0;if((g|0)!=h<<e){break g}r=2-(h&1)|0}e=r;if(!g){break e}break d}if(g){break d}g=1043-h|0;h=m>>>g|0;e=0;if((m|0)!=h<<g){break e}e=2-(h&1)|0}if((m|0)==2146435072){if(!(q-1072693248|t)){break c}if(q>>>0>=1072693248){return(f|0)>0|(f|0)>=0?b:0}return(f|0)>0|(f|0)>=0?0:-b}if((m|0)==1072693248){if((f|0)>0|(f|0)>=0){return a}return 1/a}if((f|0)==1073741824){return a*a}if((f|0)!=1071644672|(d|0)<0){break d}return K(a)}c=D(a);h:{if(t){break h}i:{if((d|0)<0){if((d|0)==-2147483648|(d|0)==-1074790400){break i}if((d|0)!=-1048576){break h}break i}if(!d|(d|0)==2146435072){break i}if((d|0)!=1072693248){break h}}k=(f|0)<0?1/c:c;if((d|0)>0|(d|0)>=0){break c}if(!(q-1072693248|e)){a=k-k;return a/a}return(e|0)==1?-k:k}j:{if((d|0)>0|(d|0)>=0){break j}k:{switch(e|0){case 0:a=a-a;return a/a;case 1:break k;default:break j}}k=-1}l:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(q>>>0<=1072693247){return(f|0)<0?N:0}return(f|0)>0?N:0}if(q>>>0<=1072693246){return(f|0)<0?k*1e300*1e300:k*1e-300*1e-300}if(q>>>0>=1072693249){return(f|0)>0?k*1e300*1e300:k*1e-300*1e-300}a=c+-1;c=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;i=c;c=a*1.4426950216293335;o(+(i+c));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=i-(a-c);break l}a=c*9007199254740992;g=q>>>0<1048576;c=g?a:c;o(+a);e=j(1)|0;j(0)|0;h=g?e:q;d=h&1048575;e=d|1072693248;h=(h>>20)+(g?-1076:-1023)|0;g=0;m:{if(d>>>0<235663){break m}if(d>>>0<767610){g=1;break m}e=d|1071644672;h=h+1|0}d=g<<3;w=A[d+3536>>3];o(+c);j(1)|0;q=0;l(0,j(0)|q);l(1,e|0);p=+n();s=A[d+3520>>3];i=p-s;u=1/(s+p);c=i*u;o(+c);m=j(1)|0;j(0)|0;l(0,0);l(1,m|0);a=+n();x=a;l(0,q|0);l(1,((g<<18)+(e>>>1|0)|0)+537395200|0);v=a*a;y=i;i=+n();p=u*(y-a*i-a*(p-(i-s)));i=p*(c+a);a=c*c;s=i+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();i=x*a;c=p*a+c*(s-(a+-3-v));o(+(i+c));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=w+(a*-7.028461650952758e-9+(c-(a-i))*.9617966939259756);i=c;p=A[d+3552>>3];c=a*.9617967009544373;s=+(h|0);o(+(p+(i+c)+s));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=i-(a-s-p-c)}l(0,0);l(1,f|0);p=+n();c=(b-p)*a+c*b;b=a*p;a=c+b;o(+a);d=j(1)|0;e=j(0)|0;n:{f=d;if((d|0)>=1083179008){if(e|f-1083179008){break b}if(!(c+8008566259537294e-32>a-b)){break n}break b}if((f&2147482624)>>>0<1083231232){break n}if(e|f+1064252416){break a}if(!(c<=a-b)){break n}break a}g=0;h=f&2147483647;if(h>>>0>=1071644673){e=f+(1048576>>>(h>>>20|0)-1022|0)|0;f=e>>>20&2047;g=(e&1048575|1048576)>>>1043-f|0;g=(d|0)<0?0-g|0:g;l(0,0);l(1,e&-1048576>>f-1023);b=b-+n();o(+(c+b));d=j(1)|0;j(0)|0}l(0,0);l(1,d|0);a=+n();p=a*.6931471824645996;c=(c-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=p+c;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);i=a*b/(b+-2);b=a;a=c-(a-p);a=b-(i-(b*a+a))+1;o(+a);e=j(1)|0;d=j(0)|0;e=(g<<20)+e|0;o:{if((e|0)<=1048575){a=Vj(a,g);break o}l(0,d|0);l(1,e|0);a=+n()}k=k*a}return k}return k*1e300*1e300}return k*1e-300*1e-300}function Sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=kb-736|0;kb=h;a:{b:{if(d>>>0<=511){a=kb-16|0;kb=a;e=h+56|0;gc(a+8|0,e,554);d=v[a+12>>2];nc(a,v[b>>2],v[b+8>>2],v[a+8>>2],v[a+12>>2]);f=v[a+4>>2];if((f|0)==(d|0)){_b(b,v[a+12>>2])}kb=a+16|0;a=(d|0)==(f|0);if(!a){Ub(e,0,554)}if(!a){break b}d=kb-32|0;kb=d;c:{a=h+56|0;if(Sb(a,13951,4)){break c}cr(d,a+32|0);b=d+16|0;Fc(b,d);Dc(c+492|0,b);zb(b);_h(d,1,a+4|0);Fc(b,d);Dc(c+524|0,b);zb(b);b=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];f=c+108|0;g=c+236|0;b=0;while(1)if((b|0)==120){b=w[c+60|0]&-2|t[a+17|0]&1;t[c+60|0]=b;b=b&-3|w[a+17|0]&2;t[c+60|0]=b;t[c+60|0]=b&251|w[a+17|0]&4;g=c+61|0;t[g|0]=w[a+18|0];i=c+62|0;t[i|0]=w[a+19|0];j=c+63|0;t[j|0]=w[a+20|0];k=c- -64|0;t[k|0]=w[a+21|0];f=c+48|0;Rg(f,25);e=v[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=Eb(e,b);m=b<<1;n=w[(a+m|0)+504|0];u[l>>1]=n;if((n|0)!=255){break d}Rg(f,b);e=v[f>>2]}b=kf(g,i);a=$d(e,v[c+52>>2]);if(a>>>0<=w[b|0]){t[c+60|0]=w[c+60|0]&253}if(a>>>0>w[kf(j,k)|0]){break c}t[c+60|0]=w[c+60|0]&251;break c}t[l+2|0]=w[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{i=a+(b<<1)|0;e=w[i- -64|0];o=dc(g,b),p=w[i+65|0],u[o>>1]=p;o=Lb(f,b),p=(e>>>0<120?e:b)+1|0,t[o|0]=p;b=b+1|0;continue}}kb=d+32|0;break b}i=v[b+8>>2];d=kb-32|0;kb=d;v[d+28>>2]=674;v[d+8>>2]=674;e=v[b>>2];g=v[b+8>>2];f=v[Kb(d+28|0,d+8|0)>>2];if(!Qb(e,g,f)){f=df(b)}j=d+8|0;e=h+56|0;CT(j,e);g=hc(d+16|0,v[d+8>>2],f);nc(d,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);CT(j,e);Ub(v[d+8>>2]+f|0,0,674-f|0);_b(b,v[d+28>>2]);kb=d+32|0;f=v[a+480180>>2];a=0;d=kb-32|0;kb=d;if(!Sb(e,13951,4)){cr(d,e+32|0);a=d+16|0;Fc(a,d);Dc(c+492|0,a);zb(a);_h(d,1,e+4|0);Fc(a,d);Dc(c+524|0,a);zb(a);v[c>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[c+4>>2]=w[e+24|0]>>>1;xc(c+4|0,64);g=w[e+25|0]&127;v[c+8>>2]=g>>>0>64?128:g<<2;t[c+15|0]=w[c+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[d+16|0]=w[e+26|0];t[d|0]=100;o=c,p=w[Xb(a,d)|0],t[o+20|0]=p;t[d+16|0]=w[e+27|0];t[d|0]=64;o=c,p=w[Xb(a,d)|0],t[o+19|0]=p;t[c+16|0]=w[e+17|0];t[c+17|0]=w[e+18|0];t[c+18|0]=w[e+19|0];t[c+26|0]=w[e+22|0];t[c+27|0]=w[e+23|0];a=w[e+58|0];Mj(c,a&127,a>>>7|0);a=w[e+59|0];Lj(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=w[e+28|0]|w[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=w[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){t[c+30|0]=a}a=w[e+62|0]|w[e+63|0]<<8;if(a>>>0<129){break f}break e}a=t[e+61|0];if((a|0)<0){break g}t[c+30|0]=a+1}a=w[e+62|0];a=a<<24>>24>=0?a+1|0:0;g=t[e+63|0];if((g|0)<0){break f}a=((g&255)<<7)+a|0}u[c+28>>1]=a}a=t[e+60|0];t[c+31|0]=a;if((a|0)<0){t[c+31|0]=0;t[c+34|0]=a^128}a=0;f=f&16777216?240:25;sv(e+304|0,c+48|0,0,f);sv(e+386|0,c+68|0,32,f);sv(e+468|0,c+88|0,32,f);t[c+100|0]=w[c+100|0]&239|w[e+468|0]>>>3&16;g=c+108|0;j=c+236|0;while(1){if((a|0)!=120){k=e+(a<<1)|0;f=w[k- -64|0];o=dc(j,a),p=w[k+65|0],u[o>>1]=p;o=Lb(g,a),p=(f>>>0<120?f:a)+1|0,t[o|0]=p;a=a+1|0;continue}break}a=554}kb=d+32|0;d=0;k:{if(!a){break k}d=e+550|0;l:{if(Sb(d,13427,4)){if(Sb(d,13779,4)){break l}}d=c+236|0;a=0;while(1){if((a|0)!=120){f=dc(d,a);u[f>>1]=x[f>>1]|w[(a+e|0)+554|0]<<8;a=a+1|0;continue}break}a=674}d=a}dd(b,d+i|0);if(!Gh(b,13956)){break b}d=h+8|0;ae(d,b,Cg(b));a=kc(h+32|0,d);Bb(d);b=v[a>>2];v[23588]=0;S(160,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;b=Q(402,a|0,13702)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}if(b){v[23588]=0;b=S(206,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}Bb(a)}kb=h+736|0;return}b=P()|0;O()|0;Bb(a);T(b|0);L()}function v$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=kb-32|0;kb=h;v[h+24>>2]=b;v[e>>2]=0;i=h+8|0;gd(i,d);v[23588]=0;i=S(19,i|0)|0;j=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){ac(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;ac(h+8|0);T(a|0);L()}nG(a,f+24|0,h+24|0,c,e,i);break b}mG(a,f+16|0,h+24|0,c,e,i);break b}g=a;i=b;a=ob[v[v[a+8>>2]+12>>2]](a+8|0)|0;b=Mc(a);k=h,l=_j(g,i,c,d,e,f,b,Hb(a)+b|0),v[k+24>>2]=l;break b}a=Yi(h+24|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=_j(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=_j(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=Yi(h+24|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Yi(h+24|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Yi(h+24|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Yi(h+24|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Yi(h+24|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+24|0;b=kb-16|0;kb=b;v[b+8>>2]=c;while(1){H:{if(!pp(a,b+8|0)){break H}c=Zk(v[a>>2]);if(!vh(v[i+8>>2],1,c)){break H}fm(a);continue}break}if(dj(a,b+8|0)){v[e>>2]=v[e>>2]|2}kb=b+16|0;break b}b=h+24|0;a=ob[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Hb(a)|0)==(0-Hb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=Ur(b,c,a,a+24|0,i,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[83016]|w[83017]<<8|(w[83018]<<16|w[83019]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[83013]|w[83014]<<8|(w[83015]<<16|w[83016]<<24);v[h+8>>2]=w[83009]|w[83010]<<8|(w[83011]<<16|w[83012]<<24);v[h+12>>2]=g;k=h,l=_j(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[83024];v[h+8>>2]=w[83020]|w[83021]<<8|(w[83022]<<16|w[83023]<<24);k=h,l=_j(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=Yi(h+24|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=_j(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=Yi(h+24|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=ob[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ob[v[v[a+8>>2]+24>>2]](a+8|0)|0;b=Mc(a);k=h,l=_j(g,i,c,d,e,f,b,Hb(a)+b|0),v[k+24>>2]=l;break b}lG(f+20|0,h+24|0,c,e,i);break b}a=Yi(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=kb-16|0;kb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(dj(c,a+8|0)){break M}b=4;if((xn(i,Zk(v[c>>2]))|0)!=37){break M}b=2;if(!dj(fm(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}kb=a+16|0}a=v[h+24>>2]}kb=h+32|0;return a|0}function JK(){var a=0,b=0,c=0,d=0,e=0,f=0;if(w[468304]){return v[117075]}b=Vd(469944);v[b>>2]=83224;c=b+8|0;v[c>>2]=0;v[c+4>>2]=0;e=Hc(c+8|0),f=0,t[e+128|0]=f;if(th(1073741823)>>>0<=29){cd();L()}a=RF(sw(c),30);v[c>>2]=a;v[c+4>>2]=a;e=Gb(c),f=a+120|0,v[e>>2]=f;Ct(c,30);v[23588]=0;d=Q(55,b+152|0,14249)|0;a=v[23588];v[23588]=0;a:{b:{c:{if((a|0)!=1){Lc(c);Vd(469616);v[117404]=85812;v[23588]=0;Y(1177,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469624);v[117406]=85844;v[23588]=0;Y(1178,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=Vd(469632);t[a+12|0]=0;v[a+8>>2]=0;v[a>>2]=83244;v[a+8>>2]=83296;v[23588]=0;Y(1179,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469648);v[117412]=84760;v[23588]=0;Y(1180,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469656);v[117414]=84908;v[23588]=0;Y(1181,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Z(1182);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Y(1183,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469680);v[117420]=85056;v[23588]=0;Y(1184,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469688);v[117422]=85288;v[23588]=0;Y(1185,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469696);v[117424]=85172;v[23588]=0;Y(1186,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469704);v[117426]=85404;v[23588]=0;Y(1187,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=Vd(469712);u[a+8>>1]=11310;v[a>>2]=84376;Mb(a+12|0);v[23588]=0;Y(1188,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=Vd(469736);v[a+8>>2]=46;v[a+12>>2]=44;v[a>>2]=84416;Mb(a+16|0);v[23588]=0;Y(1189,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469768);v[117442]=85876;v[23588]=0;Y(1190,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469776);v[117444]=86120;v[23588]=0;Y(1191,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469784);v[117446]=86332;v[23588]=0;Y(1192,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469792);v[117448]=86564;v[23588]=0;Y(1193,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469800);v[117450]=87548;v[23588]=0;Y(1194,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469808);v[117452]=87696;v[23588]=0;Y(1195,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469816);v[117454]=87812;v[23588]=0;Y(1196,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469824);v[117456]=87928;v[23588]=0;Y(1197,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469832);v[117458]=88044;v[23588]=0;Y(1198,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469840);v[117460]=88208;v[23588]=0;Y(1199,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469848);v[117462]=88372;v[23588]=0;Y(1200,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469856);v[117464]=88536;v[23588]=0;Y(1201,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469864);v[117468]=89792;v[117468]=86812;v[117466]=86764;v[23588]=0;Y(1202,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469880);v[117472]=89828;v[117472]=87076;v[117470]=87028;v[23588]=0;Y(1203,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Z(1204);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Y(1205,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Z(1206);a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;Y(1207,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469928);v[117482]=88700;v[23588]=0;Y(1208,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Vd(469936);v[117484]=88820;v[23588]=0;Y(1209,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;zb(d)}UF(c);T(b|0);L()}v[117074]=469944;t[468304]=1;v[117075]=468296;return 468296}function dN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-16|0;kb=f;g=a+1074376|0;h=B(b,872);e=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(wj(v[e+656>>2])){a=B(b,872)+a|0;u[a+1075764>>1]=d-8;a=a+1075843|0;t[a|0]=w[a|0]|64;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=d<<28>>24;c=x[(d<<1)+33280>>1];v[b+1075696>>2]=c;e=b+1075692|0;if(!v[e>>2]){break a}l=e,m=fh(a,w[b+1075789|0],d<<28>>24,c),v[l>>2]=m;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(d,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}Db(f+8|0,a+1074312|0,21);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}Db(f+8|0,a+1074312|0,21);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Db(f+8|0,a+1074312|0,21);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+d;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(d>>>0<=2){d=x[a+480188>>1];h=d>>>0>256?d:256;i=a+906300|0;j=b+1|0;k=(c&15)-1|0;while(1){if((d|0)==(h|0)){break a}c=B(d,872)+a|0;c:{if(x[c+1075778>>1]!=(j|0)){break c}d:{e:{switch(k|0){case 0:Vn(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}e=v[a+1298300>>2];if(!Fd(e)){break d}ik(e,d&65535);break d;case 1:g=c+1075080|0;e=v[g>>2];v[g>>2]=e|4096;if(!(e&512)){break d}e=v[a+1298300>>2];if(!Fd(e)){break d}ik(e,d&65535);break d;default:break e}}v[c+1075688>>2]=0;g=c+1075080|0;e=v[g>>2];v[g>>2]=e|4096;if(!(e&512)){break d}e=v[a+1298300>>2];if(!Fd(e)){break d}rj(e,d&65535,1)}e=v[c+1075648>>2];if(!e){break c}g=w[e+34|0];if(!g){break c}g=v[Md(i,g-1|0)>>2];if(!g){break c}ob[v[v[g>>2]+96>>2]](g,e,w[c+1075789|0]|256,0,b)}d=d+1|0;continue}}xP(e,d,v[a+480180>>2]);break a;case 7:if(!(w[a+480209|0]&16)){break a}vm(a,e,d,4);break a;case 8:b=e;c=v[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d&15){case 0:v[b+88>>2]=v[b+88>>2]&-257;break f;case 1:v[b+692>>2]=128;v[b+88>>2]=v[b+88>>2]|256;break f;case 8:v[b+88>>2]=v[b+88>>2]&-25165825|16777216;break f;case 9:v[b+88>>2]=v[b+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=c&-16385;break f;case 11:v[a+480208>>2]=c|16384;break f;case 12:v[a+480208>>2]=c&-8193;break f;case 13:v[a+480208>>2]=c|8192;break f;case 14:v[b+88>>2]=v[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(v[b>>2]|v[b+4>>2]){break h}a=v[b+76>>2];if(!a){break h}if(!(l=$c(w[b+788|0]),m=1,n=w[b+88|0]&2,n?l:m)){break h}v[b>>2]=-1;v[b+4>>2]=a-1}v[b+88>>2]=v[b+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=d;Db(f+8|0,a+1074312|0,35);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}if(!$c(w[c+1075780|0])){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}v[e+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}Yy(a,g,e,d);break a;case 11:i:{if(d){break i}d=1;c=v[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Db(f+8|0,a+1074312|0,30);Gy(a,b,d,Cb(v[v[f+8>>2]>>2],v[f+12>>2])|v[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=d}kb=f+16|0}function hK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=kb-192|0;kb=g;v[g+188>>2]=c;v[g+184>>2]=b;a:{if(!c){break a}h=w[dl(b,c)|0];if((h|0)==33){f=1}else{if((h|0)!=63){break a}f=0}kl(g+8|0,b,c,c-1|0);b=v[g+12>>2];v[g+184>>2]=v[g+8>>2];v[g+188>>2]=b}b=g+8|0;Xd(b);c=v[g+8>>2];Xd(g+160|0);h=cl(c,v[g+164>>2],g+184|0);Xd(b);b=v[g+188>>2];c=v[g+184>>2];b:{c:{d:{e:{if((h|0)==v[g+12>>2]){a=rc(g+176|0,21619);if(Qc(c,b,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23588]=0;b=Lh(g+160|0,d,e);c=v[23588];v[23588]=0;f:{g:{h:{if((c|0)!=1){v[23588]=0;U(967,g+8|0,17598,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break h}f=0;c=sc(a,g+8|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(g+8|0);break g}c=P()|0;O()|0;break f}c=P()|0;f=1;O()|0}zb(b);if(!f){break c}}ca(a|0);break c}if(!f){break e}a=ba(8)|0;v[23588]=0;b=Lh(g+128|0,v[g+184>>2],v[g+188>>2]);c=v[23588];v[23588]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((c|0)!=1){v[23588]=0;U(967,g+144|0,17634,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break q}v[23588]=0;R(969,g+160|0,g+144|0);c=v[23588];v[23588]=0;f=1;if((c|0)==1){break p}v[23588]=0;d=Lh(g+112|0,d,e);c=v[23588];v[23588]=0;if((c|0)==1){break o}v[23588]=0;U(971,g+8|0,g+160|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break n}c=sc(a,g+8|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(g+8|0);f=0;break m}c=P()|0;O()|0;break i}c=P()|0;f=1;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0;break l}c=P()|0;O()|0}zb(d)}zb(g+160|0)}zb(g+144|0)}zb(b);if(!f){break c}}ca(a|0);break c}f=rc(g+104|0,21619);if(Qc(c,b,v[f>>2],v[f+4>>2])){a=ba(8)|0;v[23588]=0;b=Lh(g+160|0,d,e);c=v[23588];v[23588]=0;r:{s:{t:{if((c|0)!=1){v[23588]=0;U(967,g+8|0,17598,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break t}f=0;c=sc(a,g+8|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(g+8|0);break s}c=P()|0;O()|0;break r}c=P()|0;f=1;O()|0}zb(b);if(!f){break c}}ca(a|0);break c}f=rc(g+96|0,12273);if(Qc(c,b,v[f>>2],v[f+4>>2])){b=d;c=e;f=rc(g+88|0,5604);if(Qc(b,c,v[f>>2],v[f+4>>2])){v[a+52>>2]=0;break e}f=rc(g+80|0,11205);if(Qc(b,c,v[f>>2],v[f+4>>2])){v[a+52>>2]=1;break e}f=b;b=rc(g+72|0,9166);if(Qc(f,c,v[b>>2],v[b+4>>2])){v[a+52>>2]=2;break e}a=ba(8)|0;v[23588]=0;b=Lh(g+160|0,d,e);c=v[23588];v[23588]=0;u:{v:{w:{if((c|0)!=1){v[23588]=0;U(967,g+8|0,14577,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break w}f=0;c=sc(a,g+8|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(g+8|0);break v}c=P()|0;O()|0;break u}c=P()|0;f=1;O()|0}zb(b);if(!f){break c}}ca(a|0);break c}f=b;b=rc(g- -64|0,11442);if(!Qc(c,f,v[b>>2],v[b+4>>2])){break e}b=0;x:{c=d;d=e;e=rc(g+56|0,15561);if(Qc(c,d,v[e>>2],v[e+4>>2])){break x}b=1;e=rc(g+48|0,15566);if(Qc(c,d,v[e>>2],v[e+4>>2])){break x}b=2;e=rc(g+40|0,12547);if(Qc(c,d,v[e>>2],v[e+4>>2])){break x}b=3;e=c;c=rc(g+32|0,9230);if(Qc(e,d,v[c>>2],v[c+4>>2])){break x}a=ba(8)|0;v[23588]=0;b=Q(55,g+8|0,11478)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}v[a+56>>2]=b;a=v[a+24>>2];if(!v[a+24668>>2]){break e}c=a+24664|0;d=v[c+4>>2];v[g+24>>2]=v[c>>2];v[g+28>>2]=d;c=a+24656|0;d=v[c+4>>2];v[g+16>>2]=v[c>>2];v[g+20>>2]=d;c=v[a+24652>>2];v[g+8>>2]=v[a+24648>>2];v[g+12>>2]=c;i=g,j=NJ(b),v[i+28>>2]=j;if(!xx(g+8|0,a+24648|0)){break e}py(a,g+8|0)}kb=g+192|0;return}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}function qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=kb-192|0;kb=e;a:{b:{if(Qb(v[c>>2],v[c+8>>2],8)){_b(c,4);while(1){if(hu(v[c>>2],v[c+8>>2])){break b}m=kb-288|0;kb=m;f=SO(m);h=kb-384|0;kb=h;i=uc(f,SO(h+96|0),282);f=0;c:{d:{e:{f:{g:{if(Gh(c,13593)){zg(c,4);l=ke(h+72|0,c);v[23588]=0;j=Q(759,l|0,i|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break g}h:{if(!j){break h}j=v[l+8>>2];g=v[l>>2];k=w[i+26|0];v[23588]=0;j=W(156,g|0,j|0,k|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break g}if(!j){break h}j=0;i:{while(1){if(w[i+26|0]<=f>>>0){g=v[l+8>>2];k=v[l>>2];f=0;v[23588]=0;j=j&65535;g=W(156,k|0,g|0,j|0)|0;k=v[23588];v[23588]=0;if((k|0)==1){break e}if(!g){break h}v[23588]=0;Q(188,l|0,j|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}zg(l,TO(i));f=Hc(h- -64|0);g=h+96|0;oz(g);v[23588]=0;R(760,l|0,g|0);g=v[23588];v[23588]=0;if((g|0)!=1){u[h+118>>1]=0;u[h+120>>1]=0;f=pz(f,h+96|0,h+123|0);g=w[i+26|0];v[23588]=0;Q(188,l|0,g|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){break i}}f=P()|0;O()|0;break d}v[23588]=0;g=S(198,l|0)|0;k=v[23588];v[23588]=0;if((k|0)!=1){t[(f+i|0)+27|0]=g;f=f+1|0;j=g+j|0;continue}break}f=P()|0;O()|0;break d}k=f;f=i+27|0;k=pz(k,f,f+w[i+26|0]|0);v[23588]=0;U(190,h+16|0,l|0,j|0);f=v[23588];v[23588]=0;if((f|0)==1){break f}g=h+16|0;j=kc(h+40|0,g);Bb(g);f=0;v[23588]=0;R(560,g|0,j|0);g=v[23588];v[23588]=0;if((g|0)==1){f=P()|0;O()|0;Bb(j);break d}g=h+16|0;hC(h+8|0,g);n=k;k=v[h+8>>2];k=pz(n,k,Lb(k,v[h+12>>2]));Uc(g);Bb(j);if(v[k>>2]!=(w[i+22|0]|w[i+23|0]<<8|(w[i+24|0]<<16|w[i+25|0]<<24))){break h}f=TO(i);v[23588]=0;Q(188,c|0,f|0)|0;i=v[23588];v[23588]=0;f=1;if((i|0)==1){break e}}Bb(l)}kb=h+384|0;break c}f=P()|0;O()|0;break d}f=P()|0;O()|0;break d}f=P()|0;O()|0}Bb(l);T(f|0);L()}kb=m+288|0;if(f){continue}break}}zc(c);wg(b,a,c);a=1;break a}t[d|0]=1;zc(c);f=Cg(c);d=e+144|0;ae(d,c,df(c));h=kc(e+168|0,d);Bb(d);b=x[a+34>>1]&-66|w[b|0]>15|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=f>>>(b&1)>>>(b>>>6&1);v[e+140>>2]=0;v[e+136>>2]=0;v[23588]=0;R(560,d|0,h|0);b=v[23588];v[23588]=0;j:{k:{l:{m:{if((b|0)!=1){c=Je(e+144|0);d=v[e+144>>2];i=qA(c,Fi(d),e+140|0,e+136|0);v[23588]=0;b=v[e+140>>2];Q(188,h|0,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){if(!i){break j}Og(a);l=b+c|0;b=d-b|0;d=v[e+136>>2];c=0;while(1){n:{if(d){if(!b|(d|0)!=1){break k}d=v[a>>2];if(d>>>0>c>>>0){break n}break k}d=v[a>>2];if(d>>>0<=c>>>0){break k}}if(!_d(d,v[a+20>>2])){break k}v[e+132>>2]=0;v[e+128>>2]=0;j=wS(i,l,Fi(b),e+132|0,e+124|0,e+128|0);v[23588]=0;Q(188,h|0,j|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}bi(e+128|0,Fi(v[a>>2]-c|0));d=v[e+128>>2];o:{if((d|0)<=0){break o}f=v[e+132>>2];k=x[a+34>>1];if((Ld(k)|0)!=(f|0)){break o}m=B(c,f);g=v[a+20>>2];if(k&1){v[e+120>>2]=d;v[e+104>>2]=d;v[e+56>>2]=d;v[e+40>>2]=d;v[e+100>>2]=f;v[e+96>>2]=v[e+124>>2];v[e+116>>2]=f;v[e+112>>2]=g+(m<<1);v[23588]=0;f=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=f;f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;R(561,e+48|0,e+32|0);f=v[23588];v[23588]=0;if((f|0)!=1){break o}break m}v[e+88>>2]=d;v[e+72>>2]=d;v[e+24>>2]=d;v[e+8>>2]=d;v[e+68>>2]=f;v[e+64>>2]=v[e+124>>2];v[e+84>>2]=f;v[e+80>>2]=g+m;v[23588]=0;f=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=f;f=v[e+84>>2];v[e+16>>2]=v[e+80>>2];v[e+20>>2]=f;R(562,e+16|0,e|0);f=v[23588];v[23588]=0;if((f|0)==1){break m}}b=b-j|0;l=j+l|0;c=c+d|0;d=vS(i);continue}}break m}c=P()|0;O()|0;break l}c=P()|0;O()|0;Uc(e+144|0)}Bb(h);T(c|0);L()}uS(i)}Uc(e+144|0);Bb(h);a=(i|0)!=0}kb=e+192|0;return a|0}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;i=kb-32|0;kb=i;s=v[a+4>>2];e=bf(v[a+8>>2],b);y=v[e>>2];a:{if(y+1>>>0<2){break a}j=(B(b,872)+s|0)+616|0;if(!(I=1,J=yi(v[j+8>>2],v[j+12>>2]),K=w[e+4|0],K?I:J)){break a}h=B(b,872)+s|0;if(!v[h+720>>2]){break a}g=v[h+704>>2]&2;e=v[(g?h+700|0:h+692|0)>>2];k=v[h+700>>2];f=v[h+696>>2];Db(i+8|0,v[a>>2]+1074312|0,31);z=Cb(v[v[i+8>>2]>>2],v[i+12>>2]);m=lf(v[h+624>>2],v[h+628>>2],c);q=m;l=w[h+704|0]&128;m=l?0-m|0:m;n=nb;l=l?0-(n+((q|0)!=0)|0)|0:n;q=e;D=g?A:0;e=f;r=g?e:0;n=k-e|0;F=n<<1;G=h+1316|0;o=h+1467|0;E=h+1362|0;A=(w[E|0]&17)!=1;b:{c:{while(1){if((p|0)!=(y|0)){d:{if(d>>>0>p>>>0){f=(w[E|0]&17)==1;break d}v[v[a+4>>2]+16>>2]=p-d;t[o|0]=w[o|0]&254|(d|0)==(p|0);f=v[a>>2];k=v[a+4>>2];e=Zb(v[f+484344>>2],x[k+70>>1]);e=jd(v[e>>2],v[v[e+48>>2]+12>>2],v[k+48>>2],b);g=w[e+3|0];e:{f:{switch(w[e+2|0]-11|0){case 0:k=i+8|0;Zy(k,f,g,w[e+4|0],0);k=Te(k);lt(v[a>>2],v[a+4>>2],b,x[i+8>>1]);f=1;if(!w[k|0]){break e}break d;case 1:u=w[e+4|0];Db(i+8|0,f+1074312|0,12);Uy(f,k,b,u<<2&252,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));break e;case 2:break f;default:break e}}u=w[e+4|0];Db(i+8|0,f+1074312|0,12);Ty(f,k,b,u<<2&252,Cb(v[v[i+8>>2]>>2],v[i+12>>2]))}f=1;g:{h:{i:{j:{k:{switch(g-2|0){default:if(g-38>>>0<4){break h}if((g|0)==19){break j}if((g|0)!=28){break g}e=w[e+5|0];f=e&240;if((f|0)==32){break i}if((f|0)!=16){break g}Sy(v[a>>2],j,e&15);break g;case 2:lt(v[a>>2],v[a+4>>2],b,w[e+5|0]);break g;case 4:lt(v[a>>2],v[a+4>>2],b,0);break g;case 0:e=w[e+5|0];g=v[a>>2];if(!e&(t[g+480180|0]&1)){break d}Uy(g,v[a+4>>2],b,e,0);break g;case 1:break k;case 3:break d}}e=w[e+5|0];g=v[a>>2];if(!e&(t[g+480180|0]&1)){break d}Ty(g,v[a+4>>2],b,e,0);break g}f=w[e+5|0];e=f&15;if(!(v[v[a>>2]+480180>>2]&1048580?1:e)){break g}f=f&240;if((f|0)!=32){if((f|0)!=16){break g}Ry(v[a>>2],j,e);break g}Qy(v[a>>2],j,e);break g}Py(v[a>>2],j,e&15);break g}EN(v[a>>2],j,w[e+5|0],(g|0)==38|(g|0)==40,(g&254)==40)}f=1}v[i+28>>2]=v[G>>2];if(z){kt(v[a>>2],j)}if(!A){DN(v[a>>2],j,i+28|0);f=1}if(!z){kt(v[a>>2],j)}v[i+24>>2]=0;CN(j,i+24|0);l:{if(w[h+705|0]&2){break l}m:{if(!f){if(!w[bf(v[a+8>>2],b)+4|0]){break m}}if(w[o|0]&96){yP(j,C(1),0,v[a>>2]);e=w[o|0];t[o|0]=(e&64?-65:-33)&e}_y(i+8|0,v[a>>2],j,v[i+28>>2],0);e=v[i+12>>2];v[h+624>>2]=v[i+8>>2];v[h+628>>2]=e;I=bf(v[a+8>>2],b),J=0,t[I+4|0]=J;e=lf(v[h+624>>2],v[h+628>>2],c);f=w[h+704|0]&128;m=f?0-e|0:e;g=nb;l=f?0-(g+((e|0)!=0)|0)|0:g}Rb(j,m,l);k=v[j>>2];e=v[j+4>>2];if((k>>>0<H>>>0&(e|0)<=(q|0)|(e|0)<(q|0))&((e|0)>=(r|0)&k>>>0>=D>>>0|(e|0)>(r|0)|((l|0)>0|(l|0)>=0))){break l}g=v[h+704>>2];if(!(g&2)){break c}if(g&4){f=v[h+696>>2];if(k>>>0<D>>>0&(e|0)<=(r|0)|(e|0)<(r|0)){I=j,J=Tg(0,f<<1,k,e),v[I>>2]=J;e=nb;v[j+4>>2]=e;v[h+704>>2]=g^128;g=m;m=0-g|0;l=0-(((g|0)!=0)+l|0)|0}Db(i+8|0,v[a>>2]+1074312|0,33);e=(e-f>>>0)%(F-Cb(v[v[i+8>>2]>>2],v[i+12>>2])>>>0)|0;n:{if(e>>>0<n>>>0){f=e+v[h+696>>2]|0;break n}f=v[h+700>>2]+(n-e|0)|0}v[j+4>>2]=f;f=v[h+704>>2];if((f&128)>>>7^e>>>0<n>>>0){break l}v[h+704>>2]=f^128;e=m;m=0-e|0;l=0-(((e|0)!=0)+l|0)|0;break l}f=e;g=v[h+700>>2];if(e>>>0>=g+n>>>0){f=g+((f-g>>>0)%(n>>>0)|0)|0}while(1){e=f;f=e-n|0;if(e>>>0>=g>>>0){continue}break}v[j>>2]=k;v[j+4>>2]=e}p=p+1|0;continue}break}v[v[a+4>>2]+16>>2]=0;break b}v[v[a+4>>2]+16>>2]=0;AP(j);v[(B(b,872)+s|0)+1324>>2]=0}I=bf(v[a+8>>2],b),J=0,v[I>>2]=J}kb=i+32|0}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=kb-976|0;kb=e;zc(b);d=kb-16|0;kb=d;h=e+872|0;uU(d+8|0,h);f=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){_b(b,v[d+12>>2])}kb=d+16|0;d=(f|0)==(g|0);if(!d){tU(h)}a:{if(!d){break a}if(!wU(e+872|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(vU(w[e+919|0]|w[e+920|0]<<8),nb))){break a}if(!c){l=1;break a}Bd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[e+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Ob(a+1074312|0,7,1);d=e+96|0;f=yc(d,8184);Jb(a+1298344|0,f);Ab(f);f=yc(d,8872);Jb(a+1298356|0,f);Ab(f);v[a+1298404>>2]=5;f=e+16|0;sU(f,e+872|4);Fc(d,f);Bc(a+1298308|0,d);zb(d);d=0;while(1){if((d|0)==16){b:{d=x[e+968>>1];if(d){BB(a+1298332|0,b,d,132,0)}d=kb-16|0;kb=d;h=e+96|0;gc(d+8|0,h,771);f=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){_b(b,v[d+12>>2])}kb=d+16|0;l=(f|0)==(g|0);if(!l){Ub(h,0,771)}if(!l){break a}d=a+484360|0;f=a+484376|0;rU(Wb(v[d>>2],w[f|0]),e+96|0,w[e+353|0]);Ve(Wb(v[d>>2],w[f|0]),w[e+354|0]);dd(b,w[e+919|0]|w[e+920|0]<<8);o=a+484344|0;p=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}zV(b,e- -64|0);d=0;while(1){if((d|0)==64){break a}if(!(w[e- -64+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!jB(b,e+16|0)){break a}d=d+1|0;u[a+480190>>1]=d;Ne(e,1,e+16|0);h=e+72|0;Fc(h,e);Dc(((x[a+480190>>1]<<5)+a|0)+946304|0,h);zb(h);c=(B(d,104)+a|0)+484380|0;nd(c,0);i=w[e+48|0]|w[e+49|0]<<8|(w[e+50|0]<<16|w[e+51|0]<<24);v[c>>2]=i;f=w[e+54|0]|w[e+55|0]<<8|(w[e+56|0]<<16|w[e+57|0]<<24);v[c+4>>2]=f;g=w[e+58|0]|w[e+59|0]<<8|(w[e+60|0]<<16|w[e+61|0]<<24);v[c+24>>2]=16726;v[c+8>>2]=g;u[c+30>>1]=w[e+53|0]<<4;if(t[e+62|0]&1){g=g>>>1|0;v[c+8>>2]=g;f=f>>>1|0;v[c+4>>2]=f;v[c>>2]=i>>>1}if(!(!(w[e+63|0]&8)|f>>>0>=g>>>0)){u[c+34>>1]=x[c+34>>1]|2}_c(h,t[e+62|0]&1?16:8,1,0,0);wg(h,c,b);continue}}d:{d=(h<<1)+e|0;g=w[d+355|0]|w[d+356|0]<<8;if(g){f=e+72|0;ae(f,b,g);i=kc(e+16|0,f);Bb(f);n=((w[d+355|0]|w[d+356|0]<<8)-2|0)/64|0;e:{if(!p){break e}v[23588]=0;d=W(226,o|0,h&65535,n|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break d}if(!d){break e}v[23588]=0;d=S(206,i|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break b}v[23588]=0;Q(188,i|0,1)|0;f=v[23588];v[23588]=0;if((f|0)==1){break b}q=d?d>>>0<n-2>>>0?d+1|0:-1:-1;f=0;f:while(1){g:{d=Zb(v[o>>2],h);if((f|0)==(n|0)){break g}m=0;r=Df(v[d>>2],v[v[d+48>>2]+12>>2],f);while(1){if((m|0)==16){f=f+1|0;continue f}v[23588]=0;R(349,e+72|0,i|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=B(m,6)+r|0;j=e+72|0;g=Te(j);j=Mi(j);k=w[e+72|0];if((k-1&255)>>>0<=71){t[d|0]=k+36;s=d,y=w[Oc(e+72|0)|0]+1|0,t[s+1|0]=y}if((w[g|0]-1&255)>>>0<=15){t[d+2|0]=1;t[d+4|0]=((w[g|0]<<6)+-64>>>0)/15}k=w[j|0];g=k&15;t[d+5|0]=g;h:{i:{switch((w[j|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=k|240;break h;case 2:t[d+5|0]=g<<2;break h;case 3:t[d+5|0]=(6/(g+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=g<<3;break h;case 9:t[d+4|0]=(g<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=g|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(g+1>>>0)|0)+1|13}t[d+3|0]=w[(w[j|0]>>>4|0)+26368|0];m=m+1|0;continue}}break}Ae(d,Fh(Ue(Oe(e+72|0,14,0),q)))}Bb(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;ef(h);g=h;h=(e+872|0)+d|0;v[g>>2]=!w[h+50|0]<<10;u[f+480284>>1]=(w[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=P()|0;O()|0;Bb(i);T(a|0);L()}kb=e+976|0;return l|0}function yW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=kb-576|0;kb=e;zc(b);d=kb-16|0;kb=d;f=e+72|0;OC(d+8|0,f);g=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);j=v[d+4>>2];if((j|0)==(g|0)){_b(b,v[d+12>>2])}kb=d+16|0;d=(g|0)==(j|0);if(!d){NC(f)}a:{if(!d){break a}if(!QC(e+72|0)){break a}b:{if(!c){break b}if(!Qb(v[b>>2],v[b+8>>2],Ec(PC(w[e+182|0],w[e+183|0]),nb))){break a}Bd(a,64);v[a+480204>>2]=78e4;v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480196>>2]=4;u[a+480188>>1]=8;Ob(a+1074312|0,7,1);d=e+40|0;g=yc(d,14613);Jb(a+1298344|0,g);Ab(g);d=yc(d,14646);Jb(a+1298356|0,d);Ab(d);Rl(a+1298368|0,Sb(e+72|0,11074,2)?14641:14613);v[a+1298404>>2]=5;f=w[e+182|0];u[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=kb-16|0;kb=f;d=e+40|0;gc(f+8|0,d,25);l=v[f+12>>2];nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);i=v[f+4>>2];if((i|0)==(l|0)){_b(b,v[f+12>>2])}kb=f+16|0;if((i|0)!=(l|0)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;t[d+24|0]=0;t[d+16|0]=0;t[d+17|0]=0;t[d+18|0]=0;t[d+19|0]=0;t[d+20|0]=0;t[d+21|0]=0;t[d+22|0]=0;t[d+23|0]=0;t[d+8|0]=0;t[d+9|0]=0;t[d+10|0]=0;t[d+11|0]=0;t[d+12|0]=0;t[d+13|0]=0;t[d+14|0]=0;t[d+15|0]=0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}f=(B(j,104)+a|0)+484380|0;nd(f,0);v[f+24>>2]=8363;l=e+40|0;d=l;i=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[f>>2]=i;k=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);v[f+4>>2]=k;d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>i>>>0?k?d:0:d;v[f+8>>2]=d;if(d){u[f+34>>1]=2;Dk(f)}f=e+8|0;_h(f,2,l);d=e+24|0;Fc(d,f);Dc(((j<<5)+a|0)+946304|0,d);g=g+1|0;zb(d);f=x[a+480190>>1];continue}break}g=e+24|0;h=e+72|2;cg(g,3,h,36);d=e+40|0;Fc(d,g);Bc(a+1298308|0,d);zb(d);g=0;MC(a+1298332|0,h,108,36,0);d=a+484360|0;h=a+484376|0;hv(Wb(v[d>>2],w[h|0]),e+185|0,128);d=Wb(v[d>>2],w[h|0]);h=w[e+184|0];if(x[dc(v[d>>2],h)>>1]<w[e+183|0]){Ve(d,h)}while(1)if((g|0)==8){j=a+484344|0;xg(j,w[e+183|0]);n=c&1;f=0;while(1){if(w[e+183|0]<=f>>>0){h=1;if(!(c&2)){break a}c=_c(e+40|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>x[a+480190>>1]){break b}wg(c,(B(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(n){if(ph(j,f&65535,64)){break d}}_b(b,1536);break c}v[e+24>>2]=-1;v[e+28>>2]=-1;l=0;e:while(1){if((l|0)==64){d=(e+72|0)+f|0;g=w[d+369|0];if(g>>>0<63){Ae(Zb(v[j>>2],f),Fh(Ue(Oe(e+40|0,14,0),g)))}Ae(Zb(v[j>>2],f),Fh(Oe(e+40|0,16,w[d+241|0])));break c}g=0;d=Zb(v[j>>2],f);h=Df(v[d>>2],v[v[d+48>>2]+12>>2],l);while(1){if((g|0)==8){l=l+1|0;continue e}d=e+40|0;Xq(d,b);i=Oc(d);k=Te(d);i=w[i|0];d=w[e+40|0];if(d>>>0<=253){t[h|0]=(d>>>2|0)+37;t[h+1|0]=(d<<4&48|i>>>4)+1;t[(e+24|0)+g|0]=255;d=w[e+40|0]}if((d&255)!=255){t[h+2|0]=1;t[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=w[k|0];if((d|0)!=255){t[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;f:{g:{if(d&15?0:(d|0)!=48){break g}k=w[i|0];if((k|0)==255){break f}m=k<<24>>24;d=m&15;t[h+5|0]=d;h:{if((m|0)<0){break h}k=k>>>4|0;t[h+3|0]=w[k+26152|0];i:{switch(k-3|0){case 0:t[h+5|0]=d|32;break g;case 1:t[h+5|0]=d|m<<4;break f;case 2:break g;case 3:break i;default:break f}}j:{switch(d|0){case 0:t[h+5|0]=79;break f;case 1:break j;default:break h}}t[h+5|0]=244;break f}t[h+3|0]=0;break f}t[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;ef(d+480280|0);u[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}kb=e+576|0;return h|0}function ao(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;f=kb-96|0;kb=f;q=lz(v[a+24>>2],w[a+32|0]);s=tj(q);c=s;e=v[a>>2];d=yd(e,v[a+4>>2]);a:{if(c>>>0>d>>>0){i=kb-32|0;kb=i;c=c-d|0;d=v[Gb(a)>>2];e=v[a+4>>2];b:{if(c>>>0<=(d-e|0)/12>>>0){e=kb-16|0;kb=e;c=Qt(e,a,c);d=v[c+4>>2];h=v[c+8>>2];while(1){if((d|0)==(h|0)){lc(c);kb=e+16|0}else{tO(d);d=d+12|0;v[c+4>>2]=d;continue}break}break b}d=Gb(a);d=Ik(i+8|0,kn(a,yd(v[a>>2],e)+c|0),yd(v[a>>2],v[a+4>>2]),d);h=kb-16|0;kb=h;e=DQ(h,d+8|0,c);c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){tO(c);c=v[e>>2]+12|0;v[e>>2]=c;continue}break}Ud(e);kb=h+16|0;h=v[a>>2];c=v[a+4>>2];e=d+4|0;while(1){if((c|0)!=(h|0)){c=c-12|0;Xz(v[e>>2]-12|0,c);v[e>>2]=v[e>>2]-12;continue}break}qc(a,e);qc(a+4|0,d+8|0);qc(Gb(a),Cc(d));v[d>>2]=v[d+4>>2];c=v[d+4>>2];while(1){e=v[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;v[d+8>>2]=e;We(e);continue}break}c=v[d>>2];if(c){$o(d);Nb(c)}}kb=i+32|0;break a}if(d>>>0>c>>>0){zO(a,e+B(c,12)|0)}}if(b){c=a+12|0;Xp(c,Td(c));z=Gb(c),A=0,v[z>>2]=A;d=c;c=jc(c);v[d>>2]=c;v[c>>2]=0;v[a+28>>2]=0}i=Tb(f+80|0);c=v[a+24>>2];c=ut(v[c+484344>>2],v[c+484348>>2]);v[23588]=0;h=W(604,f- -64|0,c|0,30220)|0;c=v[23588];v[23588]=0;c:{if((c|0)!=1){e=a+12|0;d:{while(1){if((k|0)==(s|0)){od(h);ic(i);kb=f+96|0;return}c=v[a+24>>2];m=x[dc(v[q>>2],k)>>1];d=EO(c,m);v[f+60>>2]=d;c=Nd(v[a>>2],k);e:{f:{if(b){v[23588]=0;t[f+40|0]=0;U(766,c|0,d|0,f+40|0);d=v[23588];v[23588]=0;if((d|0)!=1){break f}d=P()|0;O()|0;break d}v[23588]=0;R(726,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break e}}v[23588]=0;d=Q(311,q|0,k&65535)|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}g:{if(!d){break g}v[f+40>>2]=b?0:v[c+4>>2];r=v[Kb(f+40|0,f+60|0)>>2];o=xf(e);c=x[dc(v[h>>2],m)>>1];if((c|0)!=65535){d=CO(e,x[ym(f+40|0,c,r)>>1],v[f+44>>2]);h:{if(Ig(d,xf(e))){c=CO(e,x[ym(f+40|0,x[dc(v[h>>2],m)>>1],v[f+60>>2])>>1],v[f+44>>2]);break h}c=xf(e)}v[f+56>>2]=d;while(1){i:{if(!Ig(d,c)){break g}g=Tb(f+40|0);d=hn(wd(d)+8|0);v[23588]=0;R(767,g|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=ok(f+24|0,o);j=ym(f+16|0,k,v[wd(v[f+56>>2])+4>>2]);d=v[d>>2];v[23588]=0;d=fa(768,e|0,d|0,j|0,g|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break i}v[f+32>>2]=d;o=v[Lg(f+32|0)>>2];re(g);d=v[Lg(f+56|0)>>2];continue}}break}d=P()|0;O()|0;re(g);break d}p=Zb(v[v[a+24>>2]+484344>>2],m);c=Qg(v[v[p+48>>2]+12>>2]);v[23588]=0;t[f+40|0]=0;U(749,i|0,c|0,f+40|0);c=v[23588];v[23588]=0;if((c|0)!=1){n=v[f+60>>2];j:while(1){k:{if((n|0)==(r|0)){if(r){break g}z=dc(v[h>>2],m),A=k,u[z>>1]=A;break g}g=1;j=0;c=v[v[p+48>>2]+12>>2];n=n-1|0;d=Df(v[p>>2],c,n);while(1){if(g>>>0<16&Qg(c)>>>0>j>>>0){y=Lb(v[i>>2],j);c=w[y|0];l:{m:{n:{switch(w[d+3|0]-19|0){case 1:l=w[d+5|0];if((l&240)==176){break m}break l;case 0:break n;default:break l}}l=w[d+5|0];if((l&240)!=96){break l}}t[y|0]=l&15;l=w[Lb(v[i>>2],j)|0];c=l?l:c}c=c&255;g=B(c?c+1|0:1,g);d=d+6|0;j=j+1|0;c=v[v[p+48>>2]+12>>2];continue}else{o:{if(g>>>0<=1){continue j}c=Tb(f+40|0);v[23588]=0;R(767,c|0,g|0);d=v[23588];v[23588]=0;if((d|0)==1){break o}d=ok(f+8|0,o);g=ym(f+16|0,k,n);d=v[d>>2];v[23588]=0;o=fa(768,e|0,d|0,g|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break k}re(c);continue j}}break}}break}d=P()|0;O()|0;re(c);break d}d=P()|0;O()|0;break d}k=k+1|0;continue}break}d=P()|0;O()|0}od(h);break c}d=P()|0;O()|0}ic(i);T(d|0);L()}function cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=kb-336|0;kb=d;zc(b);a:{if(!vo(b,d+320|0)){break a}if(!MU(d+320|0)){break a}if(!Sb(d+320|0,14118,4)){_b(b,4)}if(!di(b,d+312|0)){break a}if(Sb(d+312|0,14094,4)){break a}if(!c){n=1;break a}WB(b,d+120|0,v[d+316>>2]);if(x[d+156>>1]>128|x[d+162>>1]>16|(x[d+160>>1]>256|x[d+154>>1]>128)){break a}Bd(a,8192);f=d+32|0;e=yc(f,6542);Jb(a+1298344|0,e);Ab(e);e=yc(f,10091);Jb(a+1298356|0,e);Ab(e);v[a+1298404>>2]=5;e=d+96|0;Ii(e,2,d+120|0);Fc(f,e);Bc(a+1298308|0,f);zb(f);u[d+32>>1]=x[d+162>>1];u[d+96>>1]=1;g=x[le(f,e)>>1];u[a+480188>>1]=g;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[Xb(f,e)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=w[d+165|0];b:{if((e|0)==128){v[d+32>>2]=256/(g>>>0);v[d+96>>2]=128;l=v[Kb(d+32|0,d+96|0)>>2];break b}l=e&127}v[a+480228>>2]=l;f=0;while(1){if((f|0)==16){g=a+484376|0;hv(Wb(v[a+484360>>2],w[g|0]),d+184|0,x[d+156>>1]);e=x[d+154>>1];if(e>>>0<x[d+156>>1]){Ve(Wb(v[a+484360>>2],w[g|0]),e)}q=c&2;o=a+484344|0;n=1;r=c&1;l=d+68|0;m=a+480190|0;f=a+480188|0;while(1){if(!di(b,d+312|0)){break a}c=d+32|0;ae(c,b,v[d+316>>2]);h=kc(d+96|0,c);Bb(c);c:{d:{if(!(Sb(d+312|0,13490,4)|!r)){v[23588]=0;g=p&65535;e=W(226,o|0,g|0,64)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(!e){break c}v[23588]=0;Q(188,h|0,2)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}Fj(d+32|0);j=0;e:{while(1){c=v[h>>2];v[23588]=0;e=W(156,c|0,v[d+104>>2],1)|0;c=v[23588];v[23588]=0;f:{if((c|0)!=1){if(!(e&j>>>0<64)){break e}v[23588]=0;k=S(206,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(k){break f}j=j+1|0;continue}break d}i=d+32|0;e=k&15;if(e>>>0<x[f>>1]){c=Zb(v[o>>2],g);i=jd(v[c>>2],v[v[c+48>>2]+12>>2],j,e)}g:{if(!(k&128)){break g}v[23588]=0;e=S(206,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(!e){break g}t[i|0]=e>>>0<109?e+12|0:e}if(k&64){v[23588]=0;e=S(206,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}t[i+1|0]=e}if(k&32){t[i+2|0]=1;v[23588]=0;e=S(206,h|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}t[d+16|0]=e;t[d|0]=64;s=i,y=w[Xb(d+16|0,d)|0],t[s+4|0]=y}if(!(k&16)){continue}v[23588]=0;R(260,d+16|0,h|0);c=v[23588];v[23588]=0;if((c|0)!=1){e=Oc(d+16|0);h:{i:{j:{k:{l:{c=w[d+16|0];switch(c-17|0){case 2:break k;case 0:case 1:break l;default:break j}}c=c&15;break i}t[d+16|0]=33;t[e|0]=145;c=w[d+16|0];break h}if(c>>>0<17){break h}c=(c&240)==32?9:-1}t[d+16|0]=c}Pf(i,c&255,w[e|0]);continue}break}break d}p=p+1|0;break c}if(Sb(d+312|0,13495,4)){break c}c=x[m>>1];if(!Yh(c)){break c}e=c+1|0;u[m>>1]=e;v[23588]=0;R(319,h|0,d+32|0);c=v[23588];v[23588]=0;m:{if((c|0)==1){break m}v[23588]=0;e=(B(e&65535,104)+a|0)+484380|0;R(320,d+32|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break m}Ii(d,2,l);v[23588]=0;R(222,d+16|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break m}c=d+16|0;Dc(((x[m>>1]<<5)+a|0)+946304|0,c);zb(c);if(!q){break c}j=w[d+45|0]|w[d+46|0]<<8;i=2;c=d+16|0;g=_c(c,8,1,0,1);n:{if(!(j&64)){i=0;if(!(j&2)){break n}}dg(g,i)}if(j&4){xd(g,16)}v[23588]=0;W(219,c|0,e|0,h|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break c}}}a=P()|0;O()|0;Bb(h);T(a|0);L()}Bb(h);continue}}g=(f<<5)+a|0;ef(g+480280|0);e=w[(d+f|0)+168|0];if(e>>>0<=128){u[g+480284>>1]=e<<1}f=f+1|0;continue}}kb=d+336|0;return n|0}function qfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=kb-192|0;kb=e;zc(b);a:{if(!jB(b,e+144|0)){break a}if(!UQ(e+144|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(TQ(w[e+175|0],w[e+177|0]),nb))){break a}b:{if(!c){break b}Bd(a,256);g=e+32|0;Dj(g,2,e+144|0);d=e- -64|0;Fc(d,g);Bc(a+1298308|0,d);zb(d);f=yc(d,15303);Jb(a+1298344|0,f);Ab(f);d=yc(d,10070);Jb(a+1298356|0,d);Ab(d);Sf(g,4274);v[23588]=0;R(249,e+128|0,e+175|0);d=v[23588];v[23588]=0;c:{d:{if((d|0)!=1){v[23588]=0;X(672,e- -64|0,e+32|0,e+174|0,e+128|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=e- -64|0;Jb(a+1298368|0,d);Ab(d);Ab(e+128|0);bc(e+32|0);v[a+1298404>>2]=5;d=Ob(a+1074312|0,107,1);v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;Ob(d,107,1);f=w[e+176|0];d=w[e+175|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|B(g,-10)+f}g=(f&255?f:96)&255;f=Vz(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=f;f=0;if(d>>>0>=11){t[e+64|0]=64;o=a,p=w[Xb(e+178|0,e- -64|0)|0]<<2,v[o+480200>>2]=p}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){Yt(b,e+32|0);d=w[e+44|0];if(d?(d|0)!=46:0){break c}h=kb-32|0;kb=h;d=(B(f,104)+a|0)+484380|0;nd(d,0);k=e+32|0;g=k;uk(h,2,g);i=h+16|0;Fc(i,h);Ce(d+43|0,i);zb(i);v[d+24>>2]=w[g+24|0]|w[g+25|0]<<8;t[h+16|0]=w[g+22|0];t[h|0]=64;o=d,p=w[Xb(i,h)|0]<<2,u[o+30>>1]=p;i=w[g+16|0]|w[g+17|0]<<8;v[d>>2]=i;j=w[g+18|0]|w[g+19|0]<<8;v[d+4>>2]=j;g=w[g+20|0]|w[g+21|0]<<8;v[d+8>>2]=g;e:{if(i>>>0<=1){v[d>>2]=0;break e}if((g|0)==65535|i>>>0<=j>>>0|g>>>0<=j>>>0){break e}u[d+34>>1]=2;o=d,p=v[Kb(d+8|0,d)>>2],v[o+8>>2]=p}kb=h+32|0;g=e+16|0;uk(g,2,k);d=e+128|0;Fc(d,g);Dc(((f<<5)+a|0)+946304|0,d);zb(d);u[((f<<1)+e|0)+62>>1]=x[e+46>>1];f=f+1|0;continue}break}d=a+484360|0;g=a+484376|0;to(Wb(v[d>>2],w[g|0]),b,w[e+175|0]?128:64,65535,65535);f=0;if(!RQ(Wb(v[d>>2],w[g|0]))){break a}m=c&1;if(m){xg(a+484344|0,w[e+177|0])}i=a+484344|0;while(1){if(w[e+177|0]<=l>>>0){f=1;if(!(c&2)){break a}c=_c(e+32|0,8,1,0,0);while(1){if((f|0)==32){break b}d=B(f,104)+a|0;g=d+484380|0;f:{if(!v[g>>2]|!x[d+484410>>1]){break f}d=x[((f<<1)+e|0)+62>>1];if(d>>>0<4){break f}if(!dd(b,d<<4)){break f}wg(c,g,b)}f=f+1|0;continue}}f=0;g:{h:{if(m){if(ph(i,l&65535,64)){break h}}while(1){if((f|0)==256){break g}if((Me(b)+2&255)>>>0<=252){_b(b,3)}f=f+1|0;continue}}o=e,p=Fb(v[Zb(v[i>>2],l)>>2]),v[o+128>>2]=p;u[e+14>>1]=65535;v[e+16>>2]=63;h=0;i:while(1){f=0;if((h|0)==64){d=x[e+14>>1];if((d|0)==65535){break g}Ae(Zb(v[i>>2],l),Mm(Ue(Oe(e+32|0,12,d&255),v[e+16>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=Me(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}t[v[e+128>>2]]=254;break j}d=e+32|0;Xq(d,b);j=w[Lb(d,0)|0];k=w[Lb(d,1)|0];n=w[Lb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(B(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=v[e+128>>2];t[d|0]=g;break k}h=h+1|0;continue i}d=v[e+128>>2]}t[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){t[d+4|0]=g;t[d+2|0]=1}t[d+5|0]=n;QQ(d,k&15,h,w[e+175|0],e+14|0,e+16|0)}f=f+1|0;bA(e+128|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;ef(d+480280|0);u[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=P()|0;O()|0;Ab(e+128|0);break d}f=P()|0;O()|0}bc(e+32|0);T(f|0);L()}f=0;break a}f=1}kb=e+192|0;return f|0}function Dy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0,D=0,E=0;f=kb-16|0;kb=f;k=B(b,872)+a|0;m=k+1075800|0;i=w[m|0];l=a+1074312|0;Db(f+8|0,l,23);h=c&15;a:{b:{c:{if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[m|0]=h;break c}e=w[m|0];if(e){g=e-1|0;t[m|0]=g;e=0;if(g&255){break c}}t[m|0]=h;e=1;break c}Db(f+8|0,l,52);d:{e:{g=c&256;if(!(!g|!Cb(v[v[f+8>>2]>>2],v[f+12>>2]))){g=v[a+480208>>2]&4096;if(!g){break e}e=B(b,872)+a|0;if(w[e+1075781|0]){i=DT(w[e+1075780|0])?1:i}if(w[(B(b,872)+a|0)+1075784|0]?w[e+1075782|0]==1:0){break b}e=0;if(h>>>0>i>>>0){break c}if(!g){break d}if($c(w[(B(b,872)+a|0)+1075780|0])){break c}break d}j=v[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((h?h:1)>>>0)|0:1);i=i+1|0;break c}f:{if((j|0)!=16){if((j|0)!=1){break f}g=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!g){if($c(w[(B(b,872)+a|0)+1075780|0])){break a}}e=h?!((g>>>0)%(h>>>0)|0):e;break c}e=v[a+1074392>>2]==(h|0)&(h|0)!=0;break c}g:{if(!g){break g}e=B(b,872)+a|0;if(w[e+1075782|0]!=1){break g}h=(w[e+1075785|0]>15)+h|0}h:{if(v[a+480208>>2]&4096?g:1){h=h?h:1;e=0;e=!v[a+1074416>>2]|g?e:!(y[a+1074392>>2]%(h>>>0)|0);i=i+1|0;break h}e=0;i=j&1048580?0:i}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!g?v[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){e=1}Db(f+8|0,l,52);if(!Cb(v[v[f+8>>2]>>2],v[f+12>>2])|c){break c}e=!v[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;e=1}h=k+1074992|0;n=(B(b,872)+a|0)+1075068|0;i:{if(v[n>>2]){break i}Db(f+8|0,l,38);if(!Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break i}if(!qj(v[h+656>>2])){break a}}Db(f+8|0,l,106);if(C=0,D=Cb(v[v[f+8>>2]>>2],v[f+12>>2]),E=v[(B(b,872)+a|0)+1075688>>2],E?C:D){break a}if(e){j=B(b,872)+a|0;q=j+1075680|0;g=v[q>>2];v[f+4>>2]=g;e=c>>>4&15;j:{if(!e){e=v[j+1075080>>2];break j}Db(f+8|0,l,52);k:{if(C=Cb(v[v[f+8>>2]>>2],v[f+12>>2]),D=0,E=w[(B(b,872)+a|0)+1075782|0]==1,E?C:D){break k}if(!(16191>>>e&1)){v[f+4>>2]=(B(g,t[e+33696|0])|0)/16;break k}v[f+4>>2]=g+(t[e+33712|0]<<2)}pe(f+4|0,0,256);g=(B(b,872)+a|0)+1075080|0;e=v[g>>2]|2097152;v[g>>2]=e}k=B(b,872)+a|0;r=k+1075692|0;s=v[r>>2];g=w[k+1075794|0];j=0;if(e&512){Db(f+8|0,l,108);j=Cb(v[v[f+8>>2]>>2],v[f+12>>2])}if(!((j^-1)&v[a+480180>>2]==2|(!v[n>>2]|(g-1&255)>>>0>119))){jN(a,b,0,g,1)}k=k+1075080|0;l:{if(!(v[a+480180>>2]&1048580)){break l}u=(c|0)<256;if((c|0)>255){break l}e=w[(B(b,872)+a|0)+1075781|0];if(!e){break l}u=1;Up(a,h,e,0,0,1)}o=B(b,872)+a|0;p=o+1075652|0;z=v[p>>2];A=v[k>>2];v[p>>2]=0;Db(f+8|0,l,23);e=1;m:{if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break m}e=0;if(v[a+480180>>2]!=2){break m}e=(j^1)&v[n>>2]!=0}ot(a,h,g,e,u,0,b);if(!w[o+1075781|0]){v[p>>2]=z}if(!(!(A&4096)|v[a+480180>>2]!=4)){v[k>>2]=v[k>>2]|4096}j=o+1075780|0;v[q>>2]=v[f+4>>2];if(x[a+480192>>1]){t[j|0]=g;hN(a,b)}g=v[a+480180>>2];if(!(!(g&16777248)|(w[j|0]|!s))){v[r>>2]=s}if(e){v[h>>2]=0;v[h+4>>2]=0}e=g&16777250;n:{if(d-11>>>0<4294967286){break n}g=v[(B(b,872)+a|0)+1075096>>2];if(!g){break n}o:{if((d|0)==1){b=v[(B(b,872)+a|0)+1075656>>2];break o}j=(B(b,872)+a|0)+1075656|0;b=v[Eb(g+68|0,d-2|0)>>2];v[j>>2]=b}_n(a,h,b)}i=e?i:0}a=f+8|0;Db(a,l,52);b=v[v[f+8>>2]>>2];d=v[f+12>>2];Db(a,l,23);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}i=(Cb(b,d)&c>>>8)+i|0}t[m|0]=i}kb=f+16|0}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-112|0;kb=e;g=a+140|0;Cj(e+88|0,g,1296125513);v[23588]=0;f=S(178,v[e+88>>2])|0;h=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Mb(e+32|0);v[23588]=0;h=S(160,v[e+88>>2])|0;i=v[23588];v[23588]=0;if((i|0)==1){break p}v[23588]=0;U(776,e+88|0,f|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break p}h=x[a+174>>1];v[23588]=0;U(777,e+72|0,h|0,f|0);h=v[23588];v[23588]=0;if((h|0)==1){break o}v[23588]=0;U(8,e+8|0,c|0,e+72|0);c=v[23588];v[23588]=0;if((c|0)==1){break n}c=e+8|0;Dc(d,c);zb(c);Ab(e+72|0);zb(f)}if(w[a+176|0]){v[23588]=0;R(778,e+32|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}c=e+32|0;Ce(b+43|0,c);zb(c)}v[23588]=0;U(771,e+32|0,g|0,1413894985);c=v[23588];v[23588]=0;if((c|0)==1){break l}v[23588]=0;f=S(779,e+32|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}g=e+32|0;Bb(g);c=a+40|0;zc(c);v[23588]=0;g=Q(780,c|0,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break j}if(g){q:{if(y[e+60>>2]<2){break q}v[23588]=0;g=Q(781,c|0,e+8|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break i}if(!g){break q}fM(e+8|0,b+12|0,b+16|0,v[b>>2],b+34|0,8,16,f)}v[23588]=0;c=Q(781,c|0,e+8|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break i}if(c){fM(e+8|0,b+4|0,b+8|0,v[b>>2],b+34|0,2,4,f)}c=v[e+44>>2];t[b+42|0]=c&128?0:c+1|0;Dk(b)}r:{if(w[b+42|0]){break r}c=v[a+60>>2];v[23588]=0;c=Q(651,c|0,7)|0;f=v[23588];v[23588]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;zc(c);v[23588]=0;c=Q(782,c|0,e+8|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break d}if(!c){break r}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}c=v[a+120>>2];v[23588]=0;c=S(178,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break j}if(!c){break f}v[23588]=0;h=a+120|0;c=S(157,h|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}v[e+72>>2]=c;xc(e+72|0,9);f=b+68|0;g=v[e+72>>2];c=0;while(1){if((c|0)==(g|0)){break g}v[23588]=0;R(783,h|0,e+8|0);i=v[23588];v[23588]=0;if((i|0)==1){break h}j=Eb(f,c),k=v[e+12>>2],v[j>>2]=k;c=c+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;Ab(e+72|0)}zb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Bb(e+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Zz(f+(g<<2)|0,xT(f),42680)}c=a+80|0;zc(c);v[23588]=0;f=Q(784,c|0,e+8|0)|0;g=v[23588];v[23588]=0;s:{if((g|0)==1){break s}if(!f){break b}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}u[e+72>>1]=x[e+12>>1];u[e+6>>1]=256;j=b,k=x[Wc(e+72|0,e+6|0)>>1],u[j+28>>1]=k;u[e+72>>1]=x[e+14>>1];u[e+6>>1]=256;j=b,k=x[Wc(e+72|0,e+6|0)>>1],u[j+30>>1]=k;u[e+72>>1]=x[e+16>>1];u[e+6>>1]=64;j=b,k=x[Wc(e+72|0,e+6|0)>>1],u[j+32>>1]=k;t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];f=v[a+88>>2];a=v[a+80>>2];v[23588]=0;a=W(156,a|0,f|0,32)|0;f=v[23588];v[23588]=0;if((f|0)==1){break s}if(!a){break b}v[23588]=0;R(785,c|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break s}v[23588]=0;a=S(202,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break s}v[23588]=0;U(786,c|0,b+43|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Bb(e+88|0);kb=e+112|0;return}Bb(e+88|0);T(a|0);L()}function Yv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=kb-96|0;kb=c;i=a+32|0;Sc(c+56|0,i,11);a:{if(k=1,l=Cb(v[v[c+56>>2]>>2],v[c+60>>2]),m=v[a+8>>2],m?k:l){d=v[a+36>>2];b=v[a+76>>2]+v[a+20>>2]|0;f=v[a+16>>2];e=f+v[a+72>>2]|0;b=Yg(c+80|0,e,e>>>0<f>>>0?b+1|0:b);e=v[b+12>>2];v[c+24>>2]=v[b+8>>2];v[c+28>>2]=e;e=v[b+4>>2];v[c+16>>2]=v[b>>2];v[c+20>>2]=e;Yj(d,c+16|0);b=v[a+36>>2];if(_k(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){uh(a,2,256);break a}b=v[a+104>>2];e=a+52|0;f=v[e>>2];d=Ri(f,v[e+4>>2]);b:{if(b>>>0>d>>>0){h=kb-32|0;kb=h;f=b-d|0;d=v[Gb(e)>>2];g=v[e+4>>2];c:{if(f>>>0<=(d-g|0)/24>>>0){d=kb-16|0;kb=d;b=lE(d,e,f);e=v[b+4>>2];f=v[b+8>>2];while(1){if((e|0)==(f|0)){lc(b);kb=d+16|0}else{kE(e);e=e+24|0;v[b+4>>2]=e;continue}break}break c}b=Gb(e);d=oE(h+8|0,qE(e,Ri(v[e>>2],g)+f|0),Ri(v[e>>2],v[e+4>>2]),b);b=kb-16|0;kb=b;v[b>>2]=v[d+8>>2];g=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=g+B(f,24);f=v[b>>2];while(1){if(v[b+4>>2]!=(f|0)){kE(f);f=v[b>>2]+24|0;v[b>>2]=f;continue}break}Ud(b);kb=b+16|0;nE(e,d);mE(d)}kb=h+32|0;break b}if(b>>>0<d>>>0){Od(e,f+B(b,24)|0)}}h=a+40|0;rn(h,v[a+104>>2]<<2);e=0;while(1){if(y[a+104>>2]>e>>>0){d=v[a+36>>2];if(_k(v[(v[v[d>>2]-12>>2]+d|0)+16>>2])){uh(a,2,1024);break a}b=x[a+24>>1];u[c+32>>1]=b;if((b|0)==65535){_v(d,c+32|0);b=x[c+32>>1]}d=fd(v[a+40>>2],v[a+44>>2]);f=b&65535;d:{if(!f){b=0;break d}if(f>>>0>(d^-1)>>>0){break d}Si(h,d+f|0);Vk(v[a+36>>2],Lb(v[a+40>>2],d),f)}f=mf(v[a+52>>2],e);v[f>>2]=d;u[f+20>>1]=b;Sc(c+56|0,i,6);if(Cb(v[v[c+56>>2]>>2],v[c+60>>2])){Kk(v[a+36>>2],c+56|0);d=v[c+56>>2];b=v[c+60>>2];if(!Zv(d,b)){uh(a,2,2048);break a}f=mf(v[a+52>>2],e);v[f+8>>2]=d;v[f+12>>2]=b}d=v[a+8>>2];e:{if(d){b=mf(v[a+52>>2],e);v[b+16>>2]=d;break e}Sc(c+56|0,i,7);if(!Cb(v[v[c+56>>2]>>2],v[c+60>>2])){b=mf(v[a+52>>2],e);break e}Kk(v[a+36>>2],c+56|0);d=v[c+56>>2];if(!Zv(d,v[c+60>>2])){uh(a,2,2048);break a}b=mf(v[a+52>>2],e);v[b+16>>2]=d}f:{if(v[b+16>>2]==-1){break f}Sc(c+56|0,i,6);if(Cb(v[v[c+56>>2]>>2],v[c+60>>2])){break f}g:{if(!e){f=0;b=0;d=mf(v[a+52>>2],0);break g}g=v[a+52>>2];b=mf(g,e-1|0);f=v[b+16>>2];d=v[b+8>>2]+f|0;b=v[b+12>>2];b=d>>>0<f>>>0?b+1|0:b;f=d;d=mf(g,e)}v[d+8>>2]=f;v[d+12>>2]=b}Sc(c+56|0,i,8);if(Cb(v[v[c+56>>2]>>2],v[c+60>>2])){u[c+78>>1]=0;_v(v[a+36>>2],c+78|0);Sc(c+56|0,i,9);bm(v[a+36>>2],x[c+78>>1]<<Cb(v[v[c+56>>2]>>2],v[c+60>>2]))}e=e+1|0;continue}break}ne(c+56|0,v[a+36>>2]);b=v[c+68>>2];v[a+80>>2]=v[c+64>>2];v[a+84>>2]=b}e=c+56|0;Sc(e,i,4);Ze(e,1);f=v[a+84>>2];h=v[a+96>>2];g=v[a+16>>2];d=h+g|0;j=v[a+100>>2];b=j+v[a+20>>2]|0;b=d>>>0<g>>>0?b+1|0:b;g=d;d=(h|0)==v[a+72>>2]&(j|0)==v[a+76>>2];h=d?v[a+80>>2]:g;v[a+88>>2]=h;b=d?f:b;v[a+92>>2]=b;d=v[a+36>>2];b=Yg(c+40|0,h,b);f=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=f;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;Yj(d,c);Sc(e,i,6);if(Cb(v[v[c+56>>2]>>2],v[c+60>>2])){break a}Sc(c+32|0,i,7);if(!(k=1,l=Cb(v[v[c+32>>2]>>2],v[c+36>>2]),m=v[a+8>>2],m?k:l)){break a}b=v[a+88>>2];e=v[a+16>>2];i=b-e|0;d=v[a+92>>2]-(v[a+20>>2]+(b>>>0<e>>>0)|0)|0;f=v[a+52>>2];h=v[a+104>>2];a=0;while(1){if((a|0)==(h|0)){break a}b=mf(f,a);g=b;j=v[b+8>>2];e=j+i|0;b=v[b+12>>2]+d|0;v[g+8>>2]=e;v[g+12>>2]=e>>>0<j>>>0?b+1|0:b;a=a+1|0;continue}}kb=c+96|0}function IK(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=C(0),p=0,q=C(0),r=C(0),s=C(0),u=0,w=C(0);j=kb-16|0;kb=j;b=a+4208|0;i=kk(C(z[Eb(b,12)>>2]*C(3)));v[a+4264>>2]=i;d=C(v[v[a+16>>2]+24620>>2]>>>((i>>>1^-1)&1)>>>0);z[a+4268>>2]=d;u=a,w=C(C(z[Eb(b,9)>>2]*C(100))*C(.0061803399585187435)),z[u+4272>>2]=w;u=j,w=ue(C(10),C(C(HK(a)+C(C(z[Eb(b,5)>>2]*C(11e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[j+8>>2]=1065353216;u=a,w=C(z[om(j+12|0,j+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=w;c=ue(C(10),C(C(C(C(z[Eb(b,1)>>2]*C(1e4))+C(-1e4))/C(100))/C(10)));if(c!=C(1)){d=Cp(C(C(GK(a)*C(6.2831854820251465))/d));f=C(c+c);e=C(c*c);c=az(C(C(C(C(d*f)+C(-2))+C(K(C(C(C(C(d*C(C(d*e)*C(4)))+C(c*C(8)))-C(e*C(4)))-C(C(d*c)*C(8))))))/C(f+C(-2))),C(0),C(1))}else{c=C(0)}z[a+4276>>2]=c;i=kb-16|0;kb=i;c=z[a+4268>>2];b=a+4208|0;d=C(z[Eb(b,6)>>2]*C(.30000001192092896));u=i,w=C(z[Eb(b,8)>>2]*C(.10000000149011612)),z[u+12>>2]=w;v[i+8>>2]=1000593162;f=z[Jx(i+12|0,i+8|0)>>2];e=C(c*C(C(d+f)+C(.007000000216066837)));a:{if(C(D(e))<C(2147483648)){b=~~e;break a}b=-2147483648}v[a+4352>>2]=b;b=1;while(1){if((b|0)==12){u=i,w=C(C(C(C(z[Eb(a+4208|0,10)>>2]*C(100))/C(100))+C(.10000000149011612))*C(.9090999960899353)),z[u+12>>2]=w;v[i+8>>2]=1065353216;d=z[om(i+12|0,i+8|0)>>2];f=C(c*C(C(d*C(75))/C(1e3)));d=C(c*C(C(d*C(67))/C(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=C(c*C(.0035299998708069324));b:{if(C(D(d))<C(2147483648)){b=~~d;break b}b=-2147483648}v[h>>2]=b;h=a+4344|0;d=C(c*C(.0032500000670552254));c:{if(C(D(d))<C(2147483648)){b=~~d;break c}b=-2147483648}v[h>>2]=b;h=a+4340|0;c=C(c*C(.009999999776482582));d:{if(C(D(c))<C(2147483648)){b=~~c;break d}b=-2147483648}v[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=ue(C(.9300000071525574),C(n|0));g=C(f*e);e:{if(C(D(g))<C(2147483648)){k=~~g;break e}k=-2147483648}v[p>>2]=k;k=h+4292|0;e=C(d*e);f:{if(C(D(e))<C(2147483648)){h=~~e;break f}h=-2147483648}v[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){LK((B(b,24)+a|0)+4504|0,v[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}kb=i+16|0}else{k=((B(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=C(c*C(C(f*z[(b<<2)+46944>>2])+d));g:{if(C(D(e))<C(2147483648)){h=~~e;break g}h=-2147483648}v[k>>2]=h;b=b+1|0;continue}break}b=kb-16|0;kb=b;d=xh(a,5);e=xh(a,11);c=C(d*xh(a,4));d=C(C(c*C(.03999999910593033))+C(C(d*C(.02250000089406967))+C(0)));f=C(e*xh(a,10));e=C(C(f*C(.03999999910593033))+C(C(e*C(.02250000089406967))+C(0)));if(t[a+4264|0]&1){g=xh(a,3);l=xh(a,9);g=C(c*g);c=C(g*xh(a,2));d=C(C(c*C(.1444000005722046))+C(C(g*C(.12250000238418579))+d));g=C(f*l);f=C(g*xh(a,8));e=C(C(f*C(.1444000005722046))+C(C(g*C(.12250000238418579))+e))}xh(a,12);g=z[a+4496>>2];l=xh(a,1);m=xh(a,7);q=xh(a,0);r=xh(a,6);u=b,w=ue(C(10),C(C(HK(a)+C(C(z[Eb(a+4208|0,7)>>2]*C(12e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[b+8>>2]=1065353216;o=z[om(b+12|0,b+8|0)>>2];s=c;c=C(g*g);g=C(l*C(s*c));l=C(q*g);c=C(m*C(f*c));f=C(r*c);m=C(C(C(l+f)*C(-.5))+C(1));z[a+4284>>2]=o*C(K(C(m/C(C(l*C(.1444000005722046))+C(C(c*C(.1444000005722046))+d)))));z[a+4288>>2]=o*C(K(C(m/C(C(f*C(.1444000005722046))+C(C(g*C(.1444000005722046))+e)))));kb=b+16|0;t[a+5046|0]=0;kb=j+16|0}function XM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0;if(b){h=a+327720|0;c=kb-400|0;kb=c;QO(c+384|0,8);v[23588]=0;oa(761,c+368|0,9);i=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){v[23588]=0;i=Q(762,c+352|0,14)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}v[23588]=0;R(763,c+384|0,i|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}v[23588]=0;R(763,c+368|0,i|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}PO(c+280|0,4900);PO(c+208|0,32e3);IO(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[23588]=0;e=Q(764,c+104|0,c+384|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break j}xt(c+120|0,c+280|0,e);re(e);v[23588]=0;e=Q(764,c+72|0,c+368|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break i}xt(c+88|0,c+208|0,e);re(e);v[23588]=0;e=Q(764,c+40|0,c+120|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break h}xt(c+56|0,c+136|0,e);re(e);v[23588]=0;e=Q(764,c+8|0,c+88|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break g}g=c+24|0;xt(g,c+136|0,e);re(e);e=c+120|0;_p(e);l=c+56|0;_p(l);m=c+88|0;_p(m);_p(g);p=c+368|0;_p(p);Zp(v[c+120>>2],v[c+124>>2],bo(h,0));Zp(v[c+56>>2],v[c+60>>2],bo(h,1));Zp(v[c+88>>2],v[c+92>>2],bo(h,2));Zp(v[c+24>>2],v[c+28>>2],bo(h,3));Zp(v[c+368>>2],v[c+372>>2],bo(h,4));re(g);re(l);re(m);re(e);Cm(i);re(p);re(c+384|0);kb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;re(c+56|0)}re(c+88|0)}re(c+120|0)}Cm(i)}re(c+368|0)}re(c+384|0);T(a|0);L()}ey(a+131112|0,9.6377,.97);ey(a+196648|0,8.5,.5);ey(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(t=0,x=iM(c,a),y=b,y?t:x)){e=a+24|0;r=A[a+8>>3];g=w[a+16|0];h=kb+-64|0;kb=h;m:while(1){if((n|0)!=8193){s=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){j=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;d=H(A[h+(b<<3)>>3]*32768*j+.5);d=d<-32768?-32768:F(d,32768);n:{if(D(d)<2147483648){i=~~d;break n}i=-2147483648}u[m>>1]=i;b=b+1|0;continue}}else{j=r;f=1;d=+(b|0)-s;q=d+-3.5;if(!(D(q)<1e-8)){o:{p:{switch(g|0){case 0:f=af(d*.8975979010256552)*-.5+.5;break o;case 1:f=af(d*.8975979010256552)*-.46+.54;break o;case 2:f=af(d*1.7951958020513104)*.08+(af(d*.8975979010256552)*-.5+.42);break o;case 3:f=af(d*1.7951958020513104)*.05677+(af(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=af(d*1.7951958020513104)*.07922+(af(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=af(d*1.7951958020513104);k=af(d*.8975979010256552);f=af(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=af(d*1.7951958020513104);k=af(d*.8975979010256552);f=af(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=af(d*1.7951958020513104);k=af(d*.8975979010256552);f=af(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=q*3.141592653589793;j=Di(d*j)/d}j=f*j;A[h+(b<<3)>>3]=j;o=o+j;b=b+1|0;continue}}break}kb=h- -64|0;b=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=b;b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b}}function bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=kb-240|0;kb=f;ne(f+224|0,b);g=kb-48|0;kb=g;v[g+44>>2]=0;pk(b,g+44|0);a:{b:{c:{if(v[g+44>>2]!=(Um(14058)|0)){break c}v[g+40>>2]=0;e=kb-32|0;kb=e;v[e+24>>2]=0;Vv(e+8|0,e+24|0);wn(e+16|0,b,v[e+8>>2],v[e+12>>2]);$l(g+40|0,v[e+24>>2]);kb=e+32|0;e=-1;i=v[g+40>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Mb(g+24|0);v[23588]=0;h=W(483,b|0,i|0,256)|0;j=v[23588];v[23588]=0;if((j|0)==1){break b}if(!h){break e}v[23588]=0;U(11,g+8|0,d|0,i|0);h=v[23588];v[23588]=0;if((h|0)!=1){break f}break b}i=Mb(g+24|0);v[23588]=0;h=Q(485,b|0,i|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break b}if(!h){break d}v[23588]=0;U(11,g+8|0,d|0,i|0);h=v[23588];v[23588]=0;if((h|0)==1){break b}}h=g+8|0;Jb(c,h);Ab(h);zb(i);Wf(b,h);i=0;v[g+24>>2]=0;pk(b,g+24|0);h=v[g+24>>2];if(h>>>0>50){break c}g:{while(1){if((h|0)==(i|0)){break g}i=i+1|0;if(CL(a,b,d)){continue}break}break c}v[g+24>>2]=0;pk(b,g+24|0);e=v[g+24>>2]==(Um(14104)|0)?1:-1;break c}zb(i);break c}zb(i)}kb=g+48|0;break a}a=P()|0;O()|0;zb(i);T(a|0);L()}h:{if(e){break h}Tl(v[v[b>>2]-12>>2]+b|0,0);e=v[f+236>>2];v[f+16>>2]=v[f+232>>2];v[f+20>>2]=e;e=v[f+228>>2];v[f+8>>2]=v[f+224>>2];v[f+12>>2]=e;b=_l(f+112|0,Yj(b,f+8|0));v[23588]=0;e=Q(449,f+96|0,14243)|0;g=v[23588];v[23588]=0;i:{if((g|0)!=1){v[23588]=0;v[f+80>>2]=3;v[f+84>>2]=0;U(450,b|0,e|0,f+80|0);g=v[23588];v[23588]=0;if((g|0)!=1){$b(e);t[f+95|0]=0;v[23588]=0;e=Q(449,f+80|0,14706)|0;g=v[23588];v[23588]=0;if((g|0)!=1){v[23588]=0;U(451,b|0,f+95|0,e|0);g=v[23588];v[23588]=0;if((g|0)!=1){$b(e);v[23588]=0;g=w[f+95|0];e=S(464,b|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){v[23588]=0;i=S(465,b|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){g=g?0:d;v[f+72>>2]=e;j:{k:{l:{m:{while(1){if(!Pb(e,i)){a=Lk(w[b|0]);lh(b);e=a?-1:1;break h}v[23588]=0;d=Q(449,f+56|0,15771)|0;e=v[23588];v[23588]=0;if((e|0)==1){break l}e=v[b+44>>2];h=v[b+40>>2];v[23588]=0;e=fa(466,h|0,e|0,v[f+72>>2],d|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break k}$b(d);n:{o:{if(e){v[23588]=0;X(467,b|0,f+72|0,c|0,g|0);d=v[23588];v[23588]=0;if((d|0)!=1){break o}break j}v[23588]=0;d=Q(449,f+40|0,15441)|0;e=v[23588];v[23588]=0;p:{q:{if((e|0)!=1){e=v[b+44>>2];h=v[b+40>>2];v[23588]=0;e=fa(466,h|0,e|0,v[f+72>>2],d|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break q}$b(d);if(!e){break p}v[23588]=0;U(468,b|0,f+72|0,f+70|0);d=v[23588];v[23588]=0;if((d|0)==1){break j}break o}a=P()|0;O()|0;break i}a=P()|0;O()|0;$b(d);break i}v[23588]=0;d=Q(449,f+24|0,15340)|0;e=v[23588];v[23588]=0;if((e|0)==1){break n}e=v[b+44>>2];h=v[b+40>>2];v[23588]=0;e=fa(466,h|0,e|0,v[f+72>>2],d|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break m}$b(d);if(!e){break o}v[23588]=0;X(469,b|0,f+72|0,a|0,g|0);d=v[23588];v[23588]=0;if((d|0)==1){break j}}Ux(f+72|0);e=v[f+72>>2];continue}break}a=P()|0;O()|0;break i}a=P()|0;O()|0;$b(d);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;$b(d);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;$b(e);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;$b(e);break i}a=P()|0;O()|0}lh(b);T(a|0);L()}kb=f+240|0;return e|0}function pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=kb-400|0;kb=e;g=kb-32|0;kb=g;d=g+8|0;MA(d,b);Uu(g,d);v[23588]=0;U(463,e+240|0,v[g>>2],v[g+4>>2]);b=v[23588];v[23588]=0;a:{if((b|0)!=1){Uc(g+8|0);kb=g+32|0;break a}a=P()|0;O()|0;Uc(g+8|0);T(a|0);L()}v[23588]=0;U(446,e+128|0,v[e+240>>2],v[e+244>>2]);b=v[23588];v[23588]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){v[23588]=0;g=Q(89,e+256|0,e+128|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break z}zb(e+128|0);ic(e+240|0);if(c>>>0<2189){break g}b=_l(e+128|0,g);v[23588]=0;c=Q(449,e+112|0,10074)|0;d=v[23588];v[23588]=0;if((d|0)==1){break x}v[23588]=0;v[e+96>>2]=19988498;v[e+100>>2]=0;U(450,b|0,c|0,e+96|0);d=v[23588];v[23588]=0;if((d|0)==1){break w}$b(c);t[e+111|0]=0;v[23588]=0;c=Q(449,e+96|0,10968)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}v[23588]=0;U(451,b|0,e+111|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break v}$b(c);c=0;c=w[e+111|0]?c:v[a+1298404>>2];f=v[a+4>>2];v[23588]=0;d=Q(449,e+80|0,15771)|0;h=v[23588];v[23588]=0;if((h|0)==1){break u}v[23588]=0;X(452,b|0,f|0,d|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break t}$b(d);v[23588]=0;d=Q(449,e- -64|0,15441)|0;f=v[23588];v[23588]=0;if((f|0)==1){break s}v[23588]=0;X(453,b|0,a|0,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break r}$b(d);v[23588]=0;c=Q(449,e+48|0,15340)|0;d=v[23588];v[23588]=0;if((d|0)==1){break q}v[23588]=0;d=a+484360|0;U(454,b|0,d|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break p}$b(c);v[23588]=0;c=Q(449,e+32|0,26646)|0;f=v[23588];v[23588]=0;if((f|0)==1){break o}v[23588]=0;U(455,b|0,a+484344|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break n}$b(c);f=v[a+1298404>>2];v[23588]=0;c=Q(449,e+16|0,26652)|0;h=v[23588];v[23588]=0;if((h|0)==1){break m}v[23588]=0;X(456,b|0,d|0,c|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break l}$b(c);if(Lk(w[b|0])){v[23588]=0;c=Q(1,e|0,16250)|0;d=v[23588];v[23588]=0;if((d|0)==1){break k}a=v[a+1298464>>2];v[23588]=0;U(376,a|0,1,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}Ab(c)}lh(b);break f}a=P()|0;O()|0;break y}a=P()|0;O()|0;zb(e+128|0)}ic(e+240|0);break b}a=P()|0;O()|0;break h}a=P()|0;O()|0;$b(c);break h}a=P()|0;O()|0;$b(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;$b(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;$b(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;$b(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;$b(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;$b(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(c);break h}a=P()|0;O()|0}lh(b);break c}b=Mb(e+128|0);d=v[a+1298404>>2];f=v[a+4>>2];v[23588]=0;d=fa(457,f|0,g|0,b|0,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}A:{if((d|0)!=1){v[23588]=0;c=Q(1,e+112|0,16556)|0;d=v[23588];v[23588]=0;B:{if((d|0)!=1){a=v[a+1298464>>2];v[23588]=0;U(376,a|0,1,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break B}Ab(c);break A}a=P()|0;O()|0;break d}a=P()|0;O()|0;Ab(c);break d}d=v[a+1298404>>2];v[23588]=0;X(458,g|0,a|0,d|0,c>>>0<2188|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}}Ab(b)}sf(g);kb=e+400|0;return}a=P()|0;O()|0}Ab(b)}sf(g)}T(a|0);L()}function Nb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[116100]){break a}a=a+b|0;if(v[116101]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=464384,j=v[116096]&Ska(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+464688|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=464388,j=v[116097]&Ska(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[116098]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[116102]==(f|0)){v[116102]=d;a=v[116099]+a|0;v[116099]=a;v[d+4>>2]=a|1;if(v[116101]!=(d|0)){break a}v[116098]=0;v[116101]=0;return}if(v[116101]==(f|0)){v[116101]=d;a=v[116098]+a|0;v[116098]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=464384,j=v[116096]&Ska(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+464688|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=464388,j=v[116097]&Ska(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[116101]!=(d|0)){break f}v[116098]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){b=(a&-8)+464424|0;c=v[116096];a=1<<(a>>>3);k:{if(!(c&a)){v[116096]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;v[d+16>>2]=0;v[d+20>>2]=0;g=(e<<2)+464688|0;l:{m:{c=v[116097];b=1<<e;n:{if(!(c&b)){v[116097]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[116104]-1|0;v[116104]=a?a:-1}}function _I(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=kb-48|0;kb=g;a:{b:{if(ts(c)){h=v[b+484344>>2];if(ye(h,v[b+484348>>2],c&65535)){break b}}c=a;a=Mb(g+32|0);b=Mb(g+16|0);oi(c,a,b);zb(b);zb(a);break a}c=Zb(h,c);if(!(v[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Mb(g+32|0);b=Mb(g+16|0);oi(c,a,b);zb(b);zb(a);break a}if(!(x[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Mb(g+32|0);b=Mb(g+16|0);oi(c,a,b);zb(b);zb(a);break a}if(f>>>0>=6){c=a;a=Mb(g+32|0);b=Mb(g+16|0);oi(c,a,b);zb(b);zb(a);break a}c=jd(v[c>>2],v[v[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=w[c|0];if(!$c(d)){if(!Lp(d)){break k}}e=g+16|0;yM(e,b,d,w[c+1|0]);v[23588]=0;R(1015,g+32|0,e|0);b=v[23588];v[23588]=0;d=1;if((b|0)!=1){break j}c=P()|0;O()|0;break g}d=0;v[23588]=0;Q(55,g+32|0,16730)|0;b=v[23588];v[23588]=0;if((b|0)==1){break i}}b=9918;c=w[c|0];if(!$c(c)){b=Lp(c)?10228:16730}v[23588]=0;b=Q(55,g|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break h}c=a;a=g+32|0;oi(c,a,b);zb(b);zb(a);if(!d){break a}Ab(g+16|0);break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;zb(g+32|0);if(!d){break d}}Ab(g+16|0);break d;case 1:b=c+1|0;l:{if(w[c+1|0]){$t(g+32|0,b);break l}Nc(g+32|0,16735)}b=w[b|0];v[23588]=0;b=Q(55,g+16|0,(b?10722:16735)|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}c=a;a=g+32|0;oi(c,a,b);zb(b);zb(a);break a;case 2:m:{if(gh(w[c|0])){Nc(g+32|0,17790);break m}d=w[c+2|0];if(d){pf(g+32|0,1,_L(v[v[b+8>>2]+88>>2],d));break m}Nc(g+32|0,17790)}b=17790;if(!gh(w[c|0])){b=w[c+2|0]?5508:17790}v[23588]=0;b=Q(55,g+16|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){c=a;a=g+32|0;oi(c,a,b);zb(b);zb(a);break a}c=P()|0;O()|0;zb(g+32|0);break d;case 4:n:{if(gh(w[c|0])){i=g,j=hk(w[c+2|0],w[c+4|0])&255,v[i>>2]=j;sA(g+32|0,g);break n}if(w[c+2|0]){$t(g+32|0,c+4|0);break n}Nc(g+32|0,16735)}b=5492;if(!gh(w[c|0])){b=w[c+2|0]?5492:16735}v[23588]=0;b=Q(55,g+16|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){c=a;a=g+32|0;oi(c,a,b);zb(b);zb(a);break a}c=P()|0;O()|0;zb(g+32|0);break d;case 3:o:{if(gh(w[c|0])){i=g,j=(hk(w[c+3|0],w[c+5|0])&3840)!=0,t[i|0]=j;b=kb-32|0;kb=b;v[b+8>>2]=-1;v[b+12>>2]=0;v[b>>2]=0;Mb(b+16|0);v[23588]=0;v[b>>2]=v[b>>2]&-1332|1058;v[b+4>>2]=1;U(1084,g+32|0,g|0,b|0);d=v[23588];v[23588]=0;p:{if((d|0)!=1){km(b);kb=b+32|0;break p}a=P()|0;O()|0;km(b);T(a|0);L()}break o}d=w[c+3|0];if(d){pf(g+32|0,1,ZL(v[v[b+8>>2]+84>>2],d));break o}Nc(g+32|0,16736)}b=12227;if(!gh(w[c|0])){b=w[c+3|0]?12227:16736}v[23588]=0;b=Q(55,g+16|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){c=a;a=g+32|0;oi(c,a,b);zb(b);zb(a);break a}c=P()|0;O()|0;zb(g+32|0);break d;case 5:break f;default:break c}}q:{if(gh(w[c|0])){i=g,j=hk(w[c+3|0],w[c+5|0])&255,v[i>>2]=j;sA(g+32|0,g);break q}if(w[c+3|0]){$t(g+32|0,c+5|0);break q}Nc(g+32|0,16735)}b=11087;if(!gh(w[c|0])){b=w[c+3|0]?11087:16735}v[23588]=0;b=Q(55,g+16|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){c=a;a=g+32|0;oi(c,a,b);zb(b);zb(a);break a}c=P()|0;O()|0;zb(g+32|0);break d}c=P()|0;O()|0;zb(g+32|0)}T(c|0);L()}c=a;a=Mb(g+32|0);b=Mb(g+16|0);oi(c,a,b);zb(b);zb(a)}kb=g+48|0}function Gg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=kb-112|0;kb=j;k=i&2147483647;l=e&2147483647;m=l;a:{b:{p=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:p)){n=k-2147418112|0;if(!h&(n|0)==-2147418112?f|g:(n|0)==-2147418112&(h|0)!=0|n>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?p:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){m=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:m;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);k=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;o=k?f:b;l=k?g:c;m=k?i:e;r=m;q=k?h:d;n=m&65535;e=k?e:i;s=e;h=k?d:h;m=e>>>16&32767;p=r>>>16&32767;if(!p){d=!(n|q);e=d<<6;i=E(d?o:q)+32|0;d=E(d?l:n);d=e+((d|0)==32?i:d)|0;Lf(j+96|0,o,l,q,n,d-15|0);q=v[j+104>>2];n=v[j+108>>2];o=v[j+96>>2];p=16-d|0;l=v[j+100>>2]}f=k?b:f;g=k?c:g;i=s&65535;if(!m){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;Lf(j+80|0,f,g,h,i,b-15|0);m=16-b|0;h=v[j+88>>2];i=v[j+92>>2];g=v[j+84>>2];f=v[j+80>>2]}b=h;k=i<<3|b>>>29;d=b<<3|g>>>29;e=k|524288;b=q;c=n<<3|b>>>29;h=b<<3|l>>>29;i=c;b=f;c=g<<3|b>>>29;b=b<<3;g=r^s;c:{if((m|0)==(p|0)){break c}f=p-m|0;if(f>>>0>127){d=0;e=0;b=1;c=0;break c}Lf(j- -64|0,b,c,d,e,128-f|0);Fm(j+48|0,b,c,d,e,f);b=v[j+48>>2]|(v[j+64>>2]|v[j+72>>2]|(v[j+68>>2]|v[j+76>>2]))!=0;c=v[j+52>>2];d=v[j+56>>2];e=v[j+60>>2]}m=h;q=i|524288;f=o;k=l<<3|f>>>29;n=f<<3;d:{if((g|0)<0){f=0;g=0;h=0;i=0;if(!(b^n|d^m|(c^k|e^q))){break a}o=n-b|0;l=k-((b>>>0>n>>>0)+c|0)|0;f=m-d|0;b=(c|0)==(k|0)&b>>>0>n>>>0|c>>>0>k>>>0;i=(q-((d>>>0>m>>>0)+e|0)|0)-(f>>>0<b>>>0)|0;h=f-b|0;if(i>>>0>524287){break d}b=!(h|i);c=b<<6;d=E(b?o:h)+32|0;b=E(b?l:i);b=c+((b|0)==32?d:b)|0;b=b-12|0;Lf(j+32|0,o,l,h,i,b);p=p-b|0;h=v[j+40>>2];i=v[j+44>>2];o=v[j+32>>2];l=v[j+36>>2];break d}k=c+k|0;f=b+n|0;k=f>>>0<n>>>0?k+1|0:k;o=f;l=k;f=(c|0)==(k|0)&b>>>0>f>>>0|c>>>0>k>>>0;c=e+q|0;b=d+m|0;c=b>>>0<m>>>0?c+1|0:c;d=b;b=f+b|0;h=b;i=b>>>0<d>>>0?c+1|0:c;if(!(i&1048576)){break d}o=o&1|((l&1)<<31|o>>>1);c=h;l=c<<31|l>>>1;p=p+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}d=0;e=r&-2147483648;if((p|0)>=32767){h=d;i=e|2147418112;f=0;g=0;break a}m=0;e:{if((p|0)>0){m=p;break e}Lf(j+16|0,o,l,h,i,p+127|0);Fm(j,o,l,h,i,1-p|0);o=v[j>>2]|(v[j+16>>2]|v[j+24>>2]|(v[j+20>>2]|v[j+28>>2]))!=0;l=v[j+4>>2];h=v[j+8>>2];i=v[j+12>>2]}c=h<<29;b=l>>>3|0;n=(l&7)<<29|o>>>3;l=o&7;g=l>>>0>4;f=n+g|0;b=b|c;k=f>>>0<g>>>0?b+1|0:b;c=f;g=k;b=(b|0)==(k|0)&c>>>0<n>>>0|b>>>0>k>>>0;c=d|((i&7)<<29|h>>>3);b=b+c|0;i=e|(i>>>3&65535|m<<16);i=b>>>0<c>>>0?i+1|0:i;h=b;f:{if((l|0)==4){c=g+0|0;e=f&1;b=f+e|0;c=b>>>0<f>>>0?c+1|0:c;f=b;g=c;c=(d|0)==(c|0)&b>>>0<e>>>0|c>>>0<d>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;kb=j+112|0}function jK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=e|0;var f=0,g=0,h=0,i=0;f=kb-144|0;kb=f;v[f+140>>2]=c;v[f+136>>2]=b;A[f+128>>3]=d;a:{if(!c){break a}g=w[dl(b,c)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}kl(f+104|0,b,c,c-1|0);b=v[f+108>>2];v[f+136>>2]=v[f+104>>2];v[f+140>>2]=b}b=f+104|0;Xd(b);c=v[f+104>>2];Xd(f+88|0);g=cl(c,v[f+92>>2],f+136|0);Xd(b);b=v[f+140>>2];c=v[f+136>>2];b:{c:{d:{e:{if((g|0)==v[f+108>>2]){a=rc(f+120|0,21619);if(Qc(c,b,v[a>>2],v[a+4>>2])){b=ba(8)|0;v[23588]=0;R(964,f+88|0,f+128|0);a=v[23588];v[23588]=0;f:{g:{h:{if((a|0)!=1){v[23588]=0;U(967,f+104|0,17598,f+88|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}a=0;c=sc(b,f+104|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(f+104|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}zb(f+88|0);if(!a){break c}}ca(b|0);break c}if(!e){break e}b=ba(8)|0;v[23588]=0;e=Lh(f+56|0,v[f+136>>2],v[f+140>>2]);a=v[23588];v[23588]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23588]=0;U(967,f+72|0,17634,e|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[23588]=0;R(969,f+88|0,f+72|0);c=v[23588];v[23588]=0;a=1;if((c|0)==1){break p}v[23588]=0;R(964,f+40|0,f+128|0);a=v[23588];v[23588]=0;if((a|0)==1){break o}v[23588]=0;U(971,f+104|0,f+88|0,f+40|0);c=v[23588];v[23588]=0;a=1;if((c|0)==1){break n}a=sc(b,f+104|0);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(f+104|0);a=0;break m}c=P()|0;O()|0;break i}c=P()|0;a=1;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;a=1;O()|0;break l}c=P()|0;O()|0}zb(f+40|0)}zb(f+88|0)}zb(f+72|0)}zb(e);if(!a){break c}}ca(b|0);break c}e=rc(f+32|0,21619);if(Qc(c,b,v[e>>2],v[e+4>>2])){b=ba(8)|0;v[23588]=0;R(964,f+88|0,f+128|0);a=v[23588];v[23588]=0;r:{s:{t:{if((a|0)!=1){v[23588]=0;U(967,f+104|0,17598,f+88|0);a=v[23588];v[23588]=0;if((a|0)==1){break t}a=0;c=sc(b,f+104|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(f+104|0);break s}c=P()|0;O()|0;break r}c=P()|0;a=1;O()|0}zb(f+88|0);if(!a){break c}}ca(b|0);break c}e=rc(f+24|0,7719);if(Qc(c,b,v[e>>2],v[e+4>>2])){if(!Qd(w[a+28|0])){break e}if(d<=0|d>4){a=ba(8)|0;v[23588]=0;b=Q(55,f+104|0,7814)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}a=v[a+24>>2];h=a,i=Qe(65536/d),v[h+480244>>2]=i;Np(a);break e}e=rc(f+16|0,7771);if(Qc(c,b,v[e>>2],v[e+4>>2])){if(!Qd(w[a+28|0])){break e}if(d<=0|d>4){a=ba(8)|0;v[23588]=0;b=Q(55,f+104|0,7835)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;ca(a|0);break c}a=v[a+24>>2];h=a,i=Qe(d*65536),v[h+480240>>2]=i;Np(a);break e}e=b;b=rc(f+8|0,7789);if(!Qc(c,e,v[b>>2],v[b+4>>2])){break e}h=v[a+24>>2],i=zl(d*65536),v[h+480236>>2]=i}kb=f+144|0;return}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}function Zea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;h=kb-4144|0;kb=h;g=Ib(w[a+14|0]|w[a+15|0]<<8);a:{if(!g|g>>>0>20){break a}j=b+480190|0;if(x[j>>1]<=w[a+23|0]){break a}nd(d,32);u[d+34>>1]=1;f=h+24|0;g=a+20|0;v[f>>2]=g;v[f+4>>2]=(g+80|0)-g>>2;vQ(h+4136|0,v[h+24>>2],v[h+28>>2],Ib(w[a+14|0]|w[a+15|0]<<8));g=v[h+4136>>2];k=w[Eb(g,0)+3|0];v[h+24>>2]=1;k=v[Zc(Hi(b,k+1|0)+24|0,f)>>2];i=f;f=v[h+4140>>2];vQ(i,g,f,c?f:1);q=1/+(k>>>0);f=v[h+24>>2];g=Eb(f,v[h+28>>2]);k=v[h+4136>>2];j=x[j>>1];while(1){if((f|0)==(g|0)){b:{r=Og(d);if(!r){break b}g=v[h+4140>>2];k=h+4120|0;v[k>>2]=0;v[k+4>>2]=0;Hc(k+8|0);if(g){f=kb-16|0;kb=f;v[f+12>>2]=4925421;v[f+8>>2]=2147483647;j=v[Kb(f+12|0,f+8|0)>>2];kb=f+16|0;if(g>>>0>j>>>0){cd();L()}if(g>>>0>=4925422){Mg();L()}g=B(g,872);f=tc(g);v[k>>2]=f;v[k+4>>2]=f;C=Gb(k),D=f+g|0,v[C>>2]=D;f=kb-16|0;kb=f;v[f>>2]=k;j=v[k+4>>2];v[f+4>>2]=j;v[f+8>>2]=g+j;i=v[f+4>>2];g=v[f+8>>2];while(1){if((g|0)==(i|0)){lc(f);kb=f+16|0}else{jQ(Ub(i,0,872));i=i+872|0;v[f+4>>2]=i;continue}break}}j=(e<<12>>>0)/1e4|0;s=v[k>>2];n=v[h+4136>>2];z=v[h+4140>>2];A=b+480190|0;f=0;i=0;while(1){if((f|0)==(z|0)){g=b+24648|0}else{g=Eb(n,f);e=uQ(s,f);l=w[g+3|0];c:{if(l>>>0>=x[A>>1]){break c}o=t[g+1|0];if((o|0)<0){break c}m=0;g=w[g+2|0];if((g+14&255)>>>0<=5){m=t[g+26798|0]}g=Hi(b,l+1|0);l=v[g+24>>2];p=q*(ni(+(m<<24>>24)/96+ +(o-t[Eb(n,0)+1|0]|0)/12)*+(l>>>0));if(p<=0){break c}m=tQ(p);v[e+8>>2]=m;l=nb;v[e+12>>2]=l;v[e+16>>2]=v[g+20>>2];o=v[g>>2];v[e+76>>2]=o;v[e+88>>2]=x[g+34>>1]&1023;d:{if(c){v[e+664>>2]=i;i=Qe(+(o>>>0)/Rz(m,l))+i|0;g=j;break d}g=(j>>>0)/(Ib(w[a+14|0]|w[a+15|0]<<8)>>>0)|0}v[e+20>>2]=g;v[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){e:{a=v[d>>2];if(a>>>0>b>>>0){Ub(h+24|0,0,4096);v[h+16>>2]=512;v[h+12>>2]=a-b;c=v[Kb(h+16|0,h+12|0)>>2];C=h,D=Fb(v[k>>2]),v[C+16>>2]=D;j=Fb(v[k+4>>2]);while(1){a=v[h+16>>2];if(!Pb(a,j)){break e}f:{g:{if(!v[a+16>>2]){break g}e=v[a+664>>2];if(e>>>0>=c>>>0){v[a+664>>2]=e-c;break g}f=v[a+88>>2];v[h+12>>2]=c-e;C=h,D=Qe((+y[a+76>>2]-Rz(v[a>>2],v[a+4>>2]))/Rz(v[a+8>>2],v[a+12>>2])),v[C+8>>2]=D;i=v[Kb(h+12|0,h+8|0)>>2];v[23588]=0;X(v[((f&1|(f&64?18:16))<<2)+27392>>2],a|0,g|0,(h+24|0)+(e<<3)|0,i|0);e=v[23588];v[23588]=0;if((e|0)==1){break f}v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break g}v[a+16>>2]=0}v[h+16>>2]=v[h+16>>2]+872;continue}break}a=P()|0;O()|0;Rt(k);T(a|0);L()}Rt(k);break b}e=v[d+20>>2]+(b<<1)|0;f=h+24|0;a=kb-16|0;kb=a;v[a+12>>2]=c;xc(a+12|0,512);i=v[a+12>>2];while(1){if(i){j=ld(v[f>>2]+2048|0,12);j=(j|0)<32767?j:32767;u[e>>1]=(j|0)>-32768?j:-32768;f=f+8|0;e=e+2|0;i=i-1|0;continue}break}kb=a+16|0;b=b+c|0;continue}}f=(r|0)!=0}else{i=w[f+3|0];h:{if(i>>>0>=j>>>0){break h}n=t[f+1|0];if((n|0)<0){break h}i=Hi(b,i+1|0);m=v[i>>2];p=ni(+(n-t[Eb(k,0)+1|0]|0)/-12);C=d,D=v[d>>2]+Qe(q*(p*+(m>>>0)*+y[i+24>>2]))|0,v[C>>2]=D}f=f+4|0;continue}break}}kb=h+4144|0;return f|0}function MH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[116101]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=464384,j=v[116096]&Ska(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+464688|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=464388,j=v[116097]&Ska(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[116098]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[116102]==(f|0)){v[116102]=a;b=v[116099]+b|0;v[116099]=b;v[a+4>>2]=b|1;if(v[116101]!=(a|0)){break a}v[116098]=0;v[116101]=0;return}if(v[116101]==(f|0)){v[116101]=a;b=v[116098]+b|0;v[116098]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=464384,j=v[116096]&Ska(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+464688|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=464388,j=v[116097]&Ska(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[116101]!=(a|0)){break g}v[116098]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){c=(b&-8)+464424|0;d=v[116096];b=1<<(b>>>3);l:{if(!(d&b)){v[116096]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;v[a+16>>2]=0;v[a+20>>2]=0;g=(e<<2)+464688|0;m:{d=v[116097];c=1<<e;n:{if(!(d&c)){v[116097]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function lK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=kb-192|0;kb=f;v[f+188>>2]=c;v[f+184>>2]=b;t[f+183|0]=d;a:{if(!c){break a}g=w[dl(b,c)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}kl(f+8|0,b,c,c-1|0);b=v[f+12>>2];v[f+184>>2]=v[f+8>>2];v[f+188>>2]=b}b=f+8|0;Xd(b);c=v[f+8>>2];Xd(f+152|0);g=cl(c,v[f+156>>2],f+184|0);Xd(b);b=v[f+188>>2];c=v[f+184>>2];b:{c:{d:{e:{f:{g:{h:{if((g|0)==v[f+12>>2]){a=rc(f+168|0,21619);if(Qc(c,b,v[a>>2],v[a+4>>2])){b=ba(8)|0;v[23588]=0;R(960,f+152|0,f+183|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}v[23588]=0;U(967,f+8|0,17598,f+152|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}d=0;a=sc(b,f+8|0);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(f+8|0);break e}if(!e){break h}b=ba(8)|0;v[23588]=0;d=Lh(f+120|0,v[f+184>>2],v[f+188>>2]);a=v[23588];v[23588]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[23588]=0;U(967,f+136|0,17634,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break p}v[23588]=0;R(969,f+152|0,f+136|0);c=v[23588];v[23588]=0;a=1;if((c|0)==1){break o}v[23588]=0;R(960,f+104|0,f+183|0);a=v[23588];v[23588]=0;if((a|0)==1){break n}v[23588]=0;U(971,f+8|0,f+152|0,f+104|0);c=v[23588];v[23588]=0;a=1;if((c|0)==1){break m}a=sc(b,f+8|0);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(f+8|0);a=0;break l}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;a=1;O()|0;break k}c=P()|0;O()|0}zb(f+104|0)}zb(f+152|0)}zb(f+136|0)}zb(d);if(a){break d}break c}e=rc(f+96|0,21619);if(Qc(c,b,v[e>>2],v[e+4>>2])){b=ba(8)|0;v[23588]=0;R(960,f+152|0,f+183|0);a=v[23588];v[23588]=0;q:{r:{if((a|0)!=1){v[23588]=0;U(967,f+8|0,17598,f+152|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}d=0;a=sc(b,f+8|0);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(f+8|0);break q}c=P()|0;O()|0;break d}c=P()|0;d=1;O()|0}zb(f+152|0);if(d){break d}break c}s:{e=rc(f+88|0,7422);if(!Qc(c,b,v[e>>2],v[e+4>>2])){e=rc(f+80|0,7404);if(!Qc(c,b,v[e>>2],v[e+4>>2])){break s}}t[a+60|0]=d;break h}t:{e=rc(f+72|0,6937);if(!Qc(c,b,v[e>>2],v[e+4>>2])){e=rc(f- -64|0,6918);if(!Qc(c,b,v[e>>2],v[e+4>>2])){break t}}t[a+61|0]=d;break h}e=rc(f+56|0,7021);if(Qc(c,b,v[e>>2],v[e+4>>2])){t[a+62|0]=d;break h}e=rc(f+48|0,6067);if(Qc(c,b,v[e>>2],v[e+4>>2])){t[a+63|0]=d;break h}e=rc(f+40|0,7471);if(Qc(c,b,v[e>>2],v[e+4>>2])){t[a+64|0]=d;break h}e=b;b=rc(f+32|0,13296);if(!Qc(c,e,v[b>>2],v[b+4>>2])){break h}b=v[a+24>>2];c=b+24664|0;e=v[c+4>>2];v[f+24>>2]=v[c>>2];v[f+28>>2]=e;c=b+24656|0;e=v[c+4>>2];v[f+16>>2]=v[c>>2];v[f+20>>2]=e;c=v[b+24652>>2];v[f+8>>2]=v[b+24648>>2];v[f+12>>2]=c;if(d){a=NJ(v[a+56>>2])}else{a=0}v[f+28>>2]=a;if(!xx(f+8|0,b+24648|0)){break h}py(b,f+8|0)}kb=f+192|0;return}c=P()|0;O()|0;break d}c=P()|0;d=1;O()|0}zb(f+152|0);if(!d){break c}}ca(b|0)}T(c|0)}L()}function rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=kb-736|0;kb=e;zc(b);f=kb-16|0;kb=f;h=e+120|0;jV(f+8|0,h);g=v[f+12>>2];j=b;nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(g|0)){_b(j,v[f+12>>2])}kb=f+16|0;b=(b|0)==(g|0);if(!b){iV(h)}a:{if(!b){break a}if(!kV(e+120|0)){break a}b:{if(!c){break b}Bd(a,67108864);ag(a);b=w[e+145|0];u[a+480190>>1]=31;u[a+480188>>1]=b;v[a+480228>>2]=256/(b>>>0);b=yc(e,8139);Jb(a+1298344|0,b);Ab(b);b=yc(e,10725);Jb(a+1298356|0,b);Ab(b);d=e+96|0;Sf(d,4177);f=w[e+144|0];v[e+72>>2]=f>>>4;b=0;v[23588]=0;v[e+116>>2]=f&15;X(302,e|0,d|0,e+72|0,e+116|0);d=v[23588];v[23588]=0;c:{d:{if((d|0)!=1){Jb(a+1298368|0,e);Ab(e);bc(e+96|0);v[a+1298404>>2]=14;Iq(Wb(v[a+484360>>2],w[a+484376|0]),e+168|0,w[e+167|0]+1|0);while(1){e:{if((b|0)==31){MB(j,a+1298308|0,32);d=1;break e}d=b+1|0;g=B(d,104)+a|0;h=g+484380|0;nd(h,1);f=(e+120|0)+(b<<2)|0;p=h,q=cc(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[p>>2]=q;k=cc(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[g+484384>>2]=k;f=cc(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24));v[g+484388>>2]=f+k;if(f){f=g+484414|0;u[f>>1]=x[f>>1]|2}Dk(h);b=(e+120|0)+b|0;t[e|0]=w[b+548|0];t[e+96|0]=64;p=g+484410|0,q=w[Xb(e,e+96|0)|0]<<2,u[p>>1]=q;t[g+484417|0]=w[b+579|0]<<4;b=d;continue}break}while(1){if((d|0)!=32){hV(j,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}n=c&1;if(n){xg(a+484344|0,w[e+166|0]+1|0)}k=a+484344|0;m=a+480188|0;f=0;while(1){if(w[e+166|0]<f>>>0){d=1;if(!(c&2)){break a}b=_c(e,8,1,1,0);while(1){if((d|0)==32){break b}wg(b,(B(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}g=Jh(e+96|0);f:{g:{if(w[e+146|0]){v[23588]=0;b=S(271,j|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}v[23588]=0;U(190,e+72|0,j|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break f}break g}b=x[m>>1];v[23588]=0;U(190,e+72|0,j|0,b<<8);b=v[23588];v[23588]=0;if((b|0)==1){break d}}b=e+72|0;d=kc(e,b);hd(g,d);Bb(d);Bb(b);h:{if(!n){break h}v[23588]=0;b=W(226,k|0,f&65535,64)|0;d=v[23588];v[23588]=0;if((d|0)==1){break d}if(!b){break h}b=0;if(w[e+146|0]){h=0;v[23588]=0;R(303,g|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}i:while(1){if((h|0)==64){break h}i=e+h|0;b=128;d=0;l=Zb(v[k>>2],f);l=Df(v[l>>2],v[v[l+48>>2]+12>>2],h);while(1){if(x[m>>1]<=d>>>0){h=h+1|0;continue i}j:{if(!(w[i|0]&b)){break j}v[23588]=0;R(304,g|0,l+B(d,6)|0);o=v[23588];v[23588]=0;if((o|0)!=1){break j}break d}b=b>>>1|0;d=d+1|0;continue}}}k:while(1){d=0;h=b&65535;if(h>>>0>=x[m>>1]){break h}while(1){if((d|0)==64){b=b+1|0;continue k}i=Zb(v[k>>2],f);i=jd(v[i>>2],v[v[i+48>>2]+12>>2],d,h);v[23588]=0;R(304,g|0,i|0);i=v[23588];v[23588]=0;if((i|0)!=1){d=d+1|0;continue}break}break}break d}Bb(g);f=f+1|0;continue}break}break d}d=P()|0;O()|0;bc(e+96|0);break c}d=P()|0;O()|0;Bb(g)}T(d|0);L()}d=1}kb=e+736|0;return d|0}function tT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=kb-176|0;kb=g;i=Yf(g+160|0);a:{b:{c:{if(d){v[23588]=0;U(470,a|0,i|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){break c}break b}v[23588]=0;U(471,a|0,i|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}}k=Tb(g+144|0);m=b+480192|0;n=b+1298464|0;c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=c&65535;if(h>>>0<=x[m>>1]){v[23588]=0;u[g+142>>1]=0;R(472,a|0,g+142|0);d=v[23588];v[23588]=0;t:{u:{v:{w:{if((d|0)!=1){j=kb-16|0;kb=j;o=x[g+142>>1];d=Td(i);e=jc(i);f=kb-16|0;kb=f;while(1){if(d){l=no(x[d+16>>1],o);e=l?e:d;d=v[(l?d+4|0:d)>>2];continue}break}d=v[fc(f+8|0,e)>>2];kb=f+16|0;x:{if(Pb(d,Zf(i))){if(!no(x[g+142>>1],x[wd(d)>>1])){break x}}d=Zf(i)}d=fc(j+8|0,d);kb=j+16|0;j=((h<<2)+b|0)+900380|0;if(!v[j>>2]){break d}d=v[d>>2];if(!Ig(d,xf(i))){break u}v[23588]=0;d=Q(3,g+128|0,wd(d)+4|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break t}v[23588]=0;e=Q(1,g+112|0,16746)|0;f=v[23588];v[23588]=0;if((f|0)==1){break v}f=nq(d,e);Ab(e);if(f){break p}e=v[b+4>>2];v[23588]=0;e=Q(473,e|0,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break r}v[v[j>>2]+44>>2]=e;if(!v[v[j>>2]+44>>2]){break w}break e}c=P()|0;O()|0;break f}v[23588]=0;e=Q(1,g+96|0,13327)|0;f=v[23588];v[23588]=0;y:{z:{A:{if((f|0)!=1){B:{if(!nq(d,e)){v[23588]=0;f=Q(1,g+80|0,13577)|0;h=v[23588];v[23588]=0;if((h|0)==1){break A}h=nq(d,f);Ab(f);Ab(e);if(h){break B}break s}Ab(e)}v[23588]=0;e=S(474,d|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break z}v[g+56>>2]=e;e=v[b+4>>2];f=v[eg(g+72|0,g+56|0)>>2];v[23588]=0;e=Q(475,e|0,f|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break y}sg(g+56|0);if(e){break e}break s}c=P()|0;O()|0;break g}c=P()|0;O()|0;Ab(e);break g}c=P()|0;O()|0;break g}c=P()|0;O()|0;sg(g+56|0);break g}c=P()|0;O()|0;break g}d=v[j>>2];if(!d){break d}v[d+44>>2]=0;break d}c=P()|0;O()|0;break f}Sl(k);sT(i);kb=g+176|0;return}e=Fb(v[k>>2]);h=Fb(v[k+4>>2]);f=kb-16|0;kb=f;v[f+8>>2]=e;while(1){C:{if(!Pb(e,h)){break C}if(nq(e,d)){break C}e=v[mq(f+8|0)>>2];continue}break}kb=f+16|0;if(Pb(e,Fb(v[k+4>>2]))){break p}v[23588]=0;R(476,k|0,d|0);e=v[23588];v[23588]=0;if((e|0)!=1){break q}}c=P()|0;O()|0;break g}v[23588]=0;e=Q(1,g+24|0,17447)|0;f=v[23588];v[23588]=0;if((f|0)==1){break o}v[23588]=0;U(477,g+40|0,e|0,d|0);f=v[23588];v[23588]=0;if((f|0)==1){break n}v[23588]=0;f=Q(1,g+8|0,16299)|0;h=v[23588];v[23588]=0;if((h|0)==1){break m}v[23588]=0;U(2,g+56|0,g+40|0,f|0);h=v[23588];v[23588]=0;if((h|0)==1){break l}h=v[n>>2];v[23588]=0;U(376,h|0,2,g+56|0);h=v[23588];v[23588]=0;if((h|0)==1){break k}Ab(g+56|0);Ab(f);Ab(g+40|0);Ab(e)}v[v[j>>2]+44>>2]=0;break e}c=P()|0;O()|0;break g}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;O()|0;Ab(g+56|0)}Ab(f)}Ab(g+40|0)}Ab(e)}Ab(d)}Sl(k);break a}Ab(d)}c=c+1|0;continue}}c=P()|0;O()|0}sT(i);T(c|0);L()}function hY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-352|0;kb=d;e=kb-16|0;kb=e;v[a+4>>2]=0;t[a|0]=0;f=a+40|0;rn(f,32);t[e+15|0]=0;qn(f,e+15|0);kb=e+16|0;e=v[a+36>>2];a:{if(!Zg(v[v[e>>2]-12>>2]+e|0)){uh(a,2,16777216);break a}f=d+88|0;ne(f,e);e=v[f+12>>2];v[a+16>>2]=v[f+8>>2];v[a+20>>2]=e;v[f>>2]=3;h=v[a+36>>2];g=d+24|0;e=0;while(1){if(y[f>>2]>e>>>0){ii(h,e+g|0);e=e+1|0;continue}break}if(Sb(g,25952,3)){uh(a,2,512);break a}t[d+351|0]=0;ii(v[a+36>>2],d+351|0);Ub(d+88|0,0,256);e=w[d+351|0];if(e){Vk(v[a+36>>2],d+88|0,e)}g=b;b=Mk(d+24|0,d+88|0,e);e=cw(g,b);$b(b);if(!e){uh(a,2,4096)}if(Lk(w[a|0])){break a}ii(v[a+36>>2],d+87|0);g=w[d+87|0];b=g&3;u[a+24>>1]=(b|0)==3?4:b;if(Ti(g,6)){b=d+24|0;Sc(b,a+32|0,9);Ze(b,1)}v[d+80>>2]=0;vE(v[a+36>>2],d+80|0);b=v[d+80>>2];t[d+79|0]=0;if(b>>>0>=2){ii(v[a+36>>2],d+87|0);e=-1;if(!w[d+87|0]){ii(v[a+36>>2],d+79|0);e=-2}bm(v[a+36>>2],b+e|0)}v[d+64>>2]=0;v[d+68>>2]=0;b:{if(!Ti(g,4)){break b}Kk(v[a+36>>2],d- -64|0);b=v[d+68>>2];e=v[d+64>>2];v[a+64>>2]=e;v[a+68>>2]=b;f=v[c+4>>2];if((f|0)==(b|0)&y[c>>2]>=e>>>0|b>>>0<f>>>0){break b}uh(a,1,4)}if(Ti(g,5)){ii(v[a+36>>2],d+87|0);bm(v[a+36>>2],w[d+87|0])}c=w[d+79|0];c:{if(!Ti(c,0)){break c}ii(v[a+36>>2],d+87|0);b=w[d+87|0];b=b&1?-1:b>>>1|0;u[a+24>>1]=b;if(b){break c}uh(a,1,2)}v[a+8>>2]=0;e=1;if(Ti(c,1)){vE(v[a+36>>2],a+8|0)}h=Ti(g,2);b=d+24|0;f=a+32|0;Sc(b,f,6);Ze(b,h);h=Ti(g,3);Sc(b,f,7);Ze(b,h);h=x[a+24>>1];Sc(b,f,5);Ze(b,(h|0)!=0);g=Ti(g,7);Sc(b,f,8);Ze(b,g);Sc(b,f,5);d:{if(Cb(v[v[d+24>>2]>>2],v[d+28>>2])){break d}Sc(d+8|0,f,6);if(Cb(v[v[d+8>>2]>>2],v[d+12>>2])){break d}Sc(d+56|0,f,7);if(Cb(v[v[d+56>>2]>>2],v[d+60>>2])){break d}Sc(d+48|0,f,8);e=Cb(v[v[d+48>>2]>>2],v[d+52>>2])}b=d+40|0;Sc(b,f,11);Ze(b,e);Sc(d+24|0,f,11);if(Ti(c,2)){u[d+8>>1]=0;_v(v[a+36>>2],d+8|0);b=v[a+36>>2];e=x[d+8>>1];Sc(d+24|0,f,9);bm(b,B(e,Cb(v[v[d+24>>2]>>2],v[d+28>>2])?2:1))}if(Ti(c,3)){bm(v[a+36>>2],5)}Kk(v[a+36>>2],d- -64|0);c=v[d+68>>2];g=c;b=v[d+64>>2];if(!c&b>>>0>=16001|c){uh(a,2,8192);break a}v[a+104>>2]=b;if(!b){uh(a,1,1)}Sc(d+24|0,f,11);e:{if(!Cb(v[v[d+24>>2]>>2],v[d+28>>2])){break e}Kk(v[a+36>>2],d- -64|0);c=v[d+68>>2];g=c;b=v[d+64>>2];if(Zv(b,c)){break e}uh(a,2,2048);break a}c=d+8|0;ne(c,v[a+36>>2]);e=v[a+16>>2];h=v[a+20>>2];i=v[c+4>>2];v[d+24>>2]=v[c>>2];v[d+28>>2]=i;i=v[c+12>>2];v[d+32>>2]=v[c+8>>2];v[d+36>>2]=i;c=v[d+32>>2];h=v[d+36>>2]-(h+(e>>>0>c>>>0)|0)|0;v[d+32>>2]=c-e;v[d+36>>2]=h;e=v[d+32>>2];c=v[d+36>>2];if((c|0)<0){uh(a,2,16384);break a}v[a+96>>2]=e;v[a+100>>2]=c;c=d+24|0;Sc(c,f,11);e=v[a+100>>2];h=b;i=v[a+96>>2];b=Cb(v[v[d+24>>2]>>2],v[d+28>>2]);v[a+72>>2]=b?h:i;v[a+76>>2]=b?g:e;Sc(c,f,11);if(!Cb(v[v[d+24>>2]>>2],v[d+28>>2])){b=v[a+100>>2]+v[a+20>>2]|0;e=v[a+16>>2];c=e+v[a+96>>2]|0;v[a+80>>2]=c;v[a+84>>2]=c>>>0<e>>>0?b+1|0:b}a=d+24|0;Sc(a,f,10);Ze(a,1)}kb=d+352|0}function vM(a,b){var c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=C(0),t=0;if(b){qy(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;AM(a)}uM(a+24648|0);o=v[a+24620>>2];f=kb-144|0;kb=f;e=a+397456|0;c=v[e+4>>2];if(c>>>0>=29){v[e+4>>2]=0;c=0}h=B(c,44)+47520|0;if(!(b?0:(h|0)==v[e+8>>2])){v[e+8>>2]=h;m=C(o>>>0);c=f+8|0;d=v[h+24>>2];v[c>>2]=d;j=v[h+16>>2];v[c+4>>2]=j;v[c+8>>2]=v[h+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){i=j;j=k+600|0;v[c+4>>2]=i-j;v[c>>2]=d-j}g=C(z[h+36>>2]*C(79.30999755859375));a:{if(C(D(g))<C(2147483648)){d=~~g;break a}d=-2147483648}v[c+16>>2]=d- -8192;g=C(C(C(z[h+32>>2]*C(.0036000001709908247))+C(.15000000596046448))*C(32767));b:{if(C(D(g))<C(2147483648)){d=~~g;break b}d=-2147483648}v[c+20>>2]=(d|0)<32512?d:32512;j=0;g=z[h+8>>2];l=C(C(F(z[h+20>>2],C(.10000000149011612)))*m);c:{if(C(D(l))<C(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)>96?d:96;i=k-7500|0;n=k>>>0<i>>>0?0:i;l=C(z[h+28>>2]*m);d:{if(C(D(l))<C(2147483648)){i=~~l;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)>128?d:128;p=i>>>0<3800?i:3800;v[c+24>>2]=p;n=(d|0)<128?d-128|0:0;g=C(g*m);e:{if(C(D(g))<C(2147483648)){q=~~g;break e}q=-2147483648}d=i-3800|0;i=(q+n|0)+(d>>>0>i>>>0?0:d)|0;v[c+32>>2]=i;n=k>>>0<7500?k:7500;while(1){if((j|0)==8){g=C(i|0);l=C(ue(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/g))*C(32768));f:{if(C(D(l))<C(2147483648)){d=~~l;break f}d=-2147483648}v[c+12>>2]=d;g=C(z[h+12>>2]*g);r=c,s=ue(C(.0010000000474974513),g<=C(4720)?C(1):C(C(4720)/g)),z[r+28>>2]=s}else{d=B(j,12);k=d+c|0;u[k+42>>1]=x[d+48810>>1];u[k+36>>1]=x[d+48804>>1];u[k+40>>1]=x[d+48808>>1];u[k+38>>1]=x[d+48806>>1];v[k+44>>2]=n+((B(v[d+48800>>2],p)+50|0)/100|0);j=j+1|0;continue}break}v[e+20>>2]=v[f+40>>2];c=xK(yK(v[f+16>>2]),m);u[e+86>>1]=c;u[e+84>>1]=c;c=x[f+24>>1]<<1;u[e+94>>1]=c;u[e+92>>1]=c;c=0;while(1){if((c|0)==8){v[e+49892>>2]=v[f+32>>2];c=v[f+12>>2];if((c|0)>-9e3){c=wK(c)}else{c=0}v[e+80>>2]=c;d=e+49948|0;c=v[f+8>>2];if((c|0)>=-8999){c=wK(c)}else{c=0}v[d>>2]=c;c=v[f+28>>2];d=e+49932|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[e+49906>>1]=c;u[e+49904>>1]=c;u[e+49902>>1]=c;u[e+49900>>1]=c;v[f+4>>2]=v[f+20>>2];pe(f+4|0,0,32752);c=x[f+4>>1];u[e+49914>>1]=c;d=e+49910|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49908>>1]=c;g=z[f+36>>2];r=f,t=xK(C(g*g),m),v[r>>2]=t;pe(f,256,32512);c=x[f>>1];u[e+49922>>1]=c;d=e+49918|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+8|0)+B(c,12)|0;j=v[h+44>>2];v[d+100>>2]=j;v[d+104>>2]=j;u[d+108>>1]=x[h+36>>1];u[d+110>>1]=x[h+42>>1];u[d+112>>1]=x[h+40>>1];u[d+114>>1]=x[h+38>>1];c=c+1|0;continue}break}}c=a+397448|0;d=a+397452|0;if(b){v[e+16>>2]=0;AK(e,c,d)}b=B(o,5);if(b>>>0>y[e+20>>2]){v[e+20>>2]=b}kb=f+144|0;b=v[a+1298300>>2];if(Fd(b)){YO(b,v[a+24620>>2])}}function LW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;e=kb-32|0;kb=e;v[e+28>>2]=b;a:{if((d|0)<=0){break a}v[e+8>>2]=d;v[e+16>>2]=214748364;u=e,x=B(v[Kb(e+28|0,e+16|0)>>2],20),v[u+20>>2]=x;rn(c,v[Kb(e+8|0,e+20|0)>>2]);v[e+12>>2]=b;v[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=rh(a,b,i);h=rh(a,b,i+4|0);f=rh(a,b,i+5|0);u=e,x=rh(a,b,i+6|0)<<8|rh(a,b,i+7|0),v[u+24>>2]=x;n=f|h<<8;s=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<n>>>0){i=ba(8)|0;v[23588]=0;a=S(193,i|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(n|0)){u=e,x=rh(a,b,i+s|0),t[u+20|0]=x;qn(c,e+20|0);i=i+1|0;continue}break};r=n;break b;case 1:break g;default:break e}}bi(e+24|0,d);r=v[e+24>>2];o=rh(a,b,i+10|0);t[e+20|0]=o;qn(c,e+20|0);j=i+11|0;n=n+3&65532;i=r-1|0;h=0;l=0;p=0;m=0;while(1){if((i|0)<=0){break c}f=Bg(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;m=8;break l}g=h+1|0;m:{if(!f){if(!Bg(j,g,1,e+8|0)){break i}k=2;n:{o:{f=h+2|0;if(!Bg(j,f,1,e+8|0)){break o}k=3;f=h+3|0;if(!Bg(j,f,1,e+8|0)){break o}k=Bg(j,f,3,e+8|0);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((m<<3)+k|0)-17|0;s:{if((h|0)<0){a=ba(8)|0;v[23588]=0;b=S(193,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=ba(8)|0;v[23588]=0;b=S(193,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break q}}b=P()|0;O()|0;ca(a|0);T(b|0);L()}ha(b|0,26056,168);L()}ha(b|0,26056,168);L()}m=w[h+26096|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((p|0)>19){break k}}f=0;break j}p=p+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;q=rh(v[e+8>>2],v[e+12>>2],h);o=o-ld((rh(v[e+8>>2],v[e+12>>2],h+1|0)<<8|q<<16|rh(v[e+8>>2],v[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;t[e+20|0]=o;qn(c,e+20|0);f=f-1|0;i=i-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!Bg(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!Bg(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!Bg(j,f,1,e+8|0)){h=6;break v}f=g+5|0;if(!Bg(j,g+4|0,1,e+8|0)){g=g+8|0;f=Bg(j,f,3,e+8|0)+8|0;break t}g=g+10|0;h=16;f=Bg(j,f,5,e+8|0);break u}g=f+2|0;f=Bg(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(Bg(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=Bg(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}q=g+1|0;g=Bg(j,q,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)>1?l:1)-1|0}k=(g^-1)+k|0;g=fd(v[c>>2],v[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+q|0;while(1){if((f|0)<=0|(i|0)<=0){break h}o=w[Lb(v[c>>2],g)|0];t[e+20|0]=o;qn(c,e+20|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=ba(8)|0;v[23588]=0;a=S(193,i|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}ha(a|0,26056,168);L()}p=p-(p>>3)|0;continue}}ha(a|0,26056,168);L()}i=pc(v[c>>2],v[c+4>>2])^1;break a}a=P()|0;O()|0;ca(i|0);T(a|0);L()}v[e+24>>2]=i}d=d-r|0;i=n+s|0;continue}}kb=e+32|0;return i|0}function x6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=kb-96|0;kb=f;a:{if(Re(b)){break a}e=w[QJ(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+80|0;Qv(e,b,0,Hb(b)-1|0);Bc(b,e);zb(e)}g=f+80|0;Xd(g);e=v[f+80>>2];Xd(f- -64|0);e=PJ(e,v[f+68>>2],b);Xd(g);b:{c:{d:{e:{if((e|0)==v[f+84>>2]){if(ve(b,21619)){a=ba(8)|0;v[23588]=0;U(958,f+80|0,17598,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}a=sc(a,f+80|0);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(f+80|0);break c}if(!d){break e}a=ba(8)|0;v[23588]=0;U(958,f+48|0,17634,b|0);b=v[23588];v[23588]=0;f:{g:{h:{i:{j:{if((b|0)!=1){v[23588]=0;R(969,f- -64|0,f+48|0);b=v[23588];v[23588]=0;if((b|0)==1){break j}v[23588]=0;U(529,f+80|0,f- -64|0,c|0);b=v[23588];v[23588]=0;d=1;if((b|0)==1){break i}b=sc(a,f+80|0);v[23588]=0;U(119,b|0,62688,956);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;zb(f+80|0);d=0;break h}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0;break g}b=P()|0;O()|0}zb(f- -64|0)}zb(f+48|0);if(!d){break c}}ca(a|0);break c}k:{switch(v[e+4>>2]){case 0:Ge(f+40|0,b);b=kb-192|0;kb=b;e=b+16|0;pi(e,c);v[23588]=0;R(88,b+32|0,e|0);c=v[23588];v[23588]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[23588]=0;c=Q(89,b+48|0,b+32|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break p}zb(b+32|0);zb(b+16|0);e=v[v[c>>2]-12>>2];v[23588]=0;g=ga(62)|0;h=v[23588];v[23588]=0;if((h|0)==1){break n}v[23588]=0;U(63,b+8|0,c+e|0,g|0);e=v[23588];v[23588]=0;if((e|0)==1){break n}ac(b+8|0);v[23588]=0;e=Q(1066,c|0,b+32|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break n}c=_k(v[(e+v[v[e>>2]-12>>2]|0)+16>>2]);g=w[b+32|0];sf(e);kb=b+192|0;b=(c^-1)&(g|0)!=0;break l}a=P()|0;O()|0;break o}a=P()|0;O()|0;zb(b+32|0)}zb(b+16|0);break m}a=P()|0;O()|0;sf(c)}T(a|0);L()}lK(a,v[f+40>>2],v[f+44>>2],b,d);break e;case 1:Ge(f+32|0,b);b=kb-192|0;kb=b;e=b+16|0;pi(e,c);v[23588]=0;R(88,b+32|0,e|0);c=v[23588];v[23588]=0;q:{r:{s:{t:{u:{if((c|0)!=1){v[23588]=0;c=Q(89,b+48|0,b+32|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break u}zb(b+32|0);zb(b+16|0);e=v[v[c>>2]-12>>2];v[23588]=0;g=ga(62)|0;h=v[23588];v[23588]=0;if((h|0)==1){break s}v[23588]=0;U(63,b+8|0,c+e|0,g|0);e=v[23588];v[23588]=0;if((e|0)==1){break s}ac(b+8|0);v[23588]=0;e=Q(96,c|0,b+32|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break s}c=_k(v[(e+v[v[e>>2]-12>>2]|0)+16>>2]);g=v[b+32>>2];h=v[b+36>>2];sf(e);kb=b+192|0;b=c?0:g;c=c?0:h;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;zb(b+32|0)}zb(b+16|0);break r}a=P()|0;O()|0;sf(c)}T(a|0);L()}iK(a,v[f+32>>2],v[f+36>>2],b,c,d);break e;case 2:Ge(f+24|0,b);i=vH(c);jK(a,v[f+24>>2],v[f+28>>2],i,d);break e;case 3:break k;default:break e}}Ge(f+16|0,b);Ge(f+8|0,c);hK(a,v[f+16>>2],v[f+20>>2],v[f+8>>2],v[f+12>>2],d)}kb=f+96|0;return}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=kb-32|0;kb=j;a:{b:{if(Dt(a)>>>0<b>>>0){if((b|0)<0){break b}n=ho(j+16|0);v[23588]=0;R(730,n|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}vl(j+8|0,v[a>>2]);Dm(j,v[a>>2],v[a+4>>2]);m=kb-48|0;kb=m;c=v[n+4>>2];e=hc(m+40|0,v[j+8>>2],v[j+12>>2]);f=hc(m+32|0,v[j>>2],v[j+4>>2]);b=kb-16|0;kb=b;e=hc(b+8|0,v[e>>2],v[e+4>>2]);f=hc(b,v[f>>2],v[f+4>>2]);e=nR(v[e>>2],v[e+4>>2],v[f>>2],v[f+4>>2]);kb=b+16|0;e=c+e|0;v[n+4>>2]=e;c:{d:{if(!c){b=e-1|0;break d}b=e-1|0;if((b^c-1)>>>0<32){break c}}v[v[n>>2]+((e>>>0<33?0:b>>>5|0)<<2)>>2]=0}f=hc(m+24|0,v[j+8>>2],v[j+12>>2]);e=hc(m+16|0,v[j>>2],v[j+4>>2]);b=m+8|0;Mo(b,v[n>>2],c);c=v[f>>2];o=kb-48|0;kb=o;f=v[f+4>>2];e:{if((f|0)==v[b+4>>2]){f=hc(o+40|0,c,f);c=hc(o+32|0,v[e>>2],v[e+4>>2]);b=hc(o+24|0,v[b>>2],v[b+4>>2]);e=kb-16|0;kb=e;g=v[f>>2];d=v[f+4>>2];c=ul(v[c>>2],v[c+4>>2],g,d);v[e+12>>2]=c;f:{if((c|0)<=0){c=v[b>>2];break f}if(d){i=32-d|0;v[e+8>>2]=i;k=c;c=v[td(e+8|0,e+12|0)>>2];v[e+12>>2]=k-c;h=v[b>>2];d=-1<<d&-1>>>i-c;v[h>>2]=v[h>>2]&(d^-1)|d&v[g>>2];c=c+v[b+4>>2]|0;v[b+4>>2]=c&31;v[b>>2]=h+(c>>>3&536870908);g=v[f>>2]+4|0;v[f>>2]=g;c=v[e+12>>2]}k=g;d=(c|0)/32|0;g=d<<2;hj(v[b>>2],k,g);d=c-(d<<5)|0;v[e+12>>2]=d;c=g+v[b>>2]|0;v[b>>2]=c;if((d|0)<=0){break f}c=f;f=g+v[f>>2]|0;v[c>>2]=f;c=v[b>>2];g=-1>>>32-d|0;v[c>>2]=v[c>>2]&(g^-1)|g&v[f>>2];v[b+4>>2]=v[e+12>>2]}hc(m,c,v[b+4>>2]);break e}g=hc(o+16|0,c,f);c=hc(o+8|0,v[e>>2],v[e+4>>2]);f=hc(o,v[b>>2],v[b+4>>2]);e=kb-16|0;kb=e;k=v[c>>2];d=v[c+4>>2];b=v[g>>2];c=v[g+4>>2];d=ul(k,d,b,c);v[e+12>>2]=d;g:{if((d|0)<=0){c=v[f+4>>2];break g}h:{if(!c){c=v[f+4>>2];break h}l=32-c|0;v[e+8>>2]=l;i=e+8|0;h=v[td(i,e+12|0)>>2];v[e+12>>2]=d-h;d=v[f+4>>2];p=v[b>>2];v[e+8>>2]=h;k=32-d|0;v[e+4>>2]=k;b=v[f>>2];q=v[b>>2];i=v[Kb(i,e+4|0)>>2];l=p&(-1<<c&-1>>>l-h);v[b>>2]=(-1<<d&-1>>>k-i^-1)&q|(c>>>0<d>>>0?l<<d-c:l>>>c-d|0);d=d+i|0;c=d&31;v[f+4>>2]=c;d=b+(d>>>3&536870908)|0;v[f>>2]=d;b=h-i|0;if((b|0)>0){v[d>>2]=v[d>>2]&(-1>>>32-b^-1)|l>>>i+v[g+4>>2];v[f+4>>2]=b;c=b}b=v[g>>2]+4|0;v[g>>2]=b;d=v[e+12>>2]}h=32-c|0;i=-1<<c;l=i^-1;while(1){if((d|0)>=32){d=v[f>>2];b=v[b>>2];v[d>>2]=l&v[d>>2]|b<<c;v[f>>2]=d+4;v[d+4>>2]=i&v[d+4>>2]|b>>>h;d=v[e+12>>2]-32|0;v[e+12>>2]=d;b=v[g>>2]+4|0;v[g>>2]=b;continue}break}if((d|0)<=0){break g}l=v[b>>2];v[e+8>>2]=h;g=v[f>>2];b=v[g>>2];k=b;b=v[td(e+12|0,e+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-d;v[g>>2]=k|h<<c;d=b+c|0;c=d&31;v[f+4>>2]=c;g=g+(d>>>3&536870908)|0;v[f>>2]=g;d=v[e+12>>2]-b|0;v[e+12>>2]=d;if((d|0)<=0){break g}v[g>>2]=v[g>>2]&(-1>>>32-d^-1)|h>>>b;c=v[e+12>>2];v[f+4>>2]=c}hc(m,v[f>>2],c)}kb=e+16|0;kb=o+48|0;kb=m+48|0;Mt(a,n);We(n)}kb=j+32|0;return}cd();L()}a=P()|0;O()|0;We(n);T(a|0);L()}function pE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-176|0;kb=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)<=5){Wv(d+128|0,b);v[23588]=0;b=Q(1,d+112|0,17734)|0;e=v[23588];v[23588]=0;if((e|0)==1){break E}v[23588]=0;U(2,d+144|0,d+128|0,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break D}v[23588]=0;c=Q(3,d+80|0,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break C}v[23588]=0;e=Q(1,d- -64|0,19562)|0;f=v[23588];v[23588]=0;if((f|0)==1){break B}v[23588]=0;U(4,d+96|0,c|0,e|0);f=v[23588];v[23588]=0;if((f|0)==1){break A}v[23588]=0;U(2,d+160|0,d+144|0,d+96|0);f=v[23588];v[23588]=0;if((f|0)==1){break z}Ab(d+96|0);Ab(e);Ab(c);c=d+144|0;Ab(c);Ab(b);Ab(d+128|0);b=v[a>>2];v[23588]=0;U(5,c|0,1,(b?b:21619)|0);b=v[23588];v[23588]=0;if((b|0)==1){break t}b=v[a+4>>2];v[23588]=0;U(5,d+128|0,1,(b?b:21619)|0);b=v[23588];v[23588]=0;if((b|0)==1){break s}a=v[a+8>>2];v[23588]=0;v[d+48>>2]=a;R(6,d+96|0,d+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}v[23588]=0;Y(7,17613);a=v[23588];v[23588]=0;if((a|0)==1){break q}v[23588]=0;U(8,d+48|0,0,d+144|0);a=v[23588];v[23588]=0;if((a|0)==1){break p}v[23588]=0;Y(9,d+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break o}v[23588]=0;Y(7,17407);a=v[23588];v[23588]=0;if((a|0)==1){break o}v[23588]=0;U(8,d+32|0,0,d+96|0);a=v[23588];v[23588]=0;if((a|0)==1){break n}v[23588]=0;Y(9,d+32|0);a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;Y(7,17405);a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;Y(7,17734);a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;U(8,d+16|0,0,d+160|0);a=v[23588];v[23588]=0;if((a|0)==1){break l}v[23588]=0;Y(9,d+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break k}v[23588]=0;Y(7,13353);a=v[23588];v[23588]=0;if((a|0)==1){break k}v[23588]=0;U(8,d|0,0,d+128|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}v[23588]=0;Y(9,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;Y(7,13351);a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;Z(10);a=v[23588];v[23588]=0;if((a|0)==1){break i}zb(d);zb(d+16|0);zb(d+32|0);zb(d+48|0);Ab(d+96|0);Ab(d+128|0);Ab(d+144|0);Ab(d+160|0)}kb=d+176|0;return}a=P()|0;O()|0;break u}a=P()|0;O()|0;break v}a=P()|0;O()|0;break w}a=P()|0;O()|0;break x}a=P()|0;O()|0;break y}a=P()|0;O()|0;Ab(d+96|0)}Ab(e)}Ab(c)}Ab(d+144|0)}Ab(b)}Ab(d+128|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(d)}zb(d+16|0)}zb(d+32|0)}zb(d+48|0)}Ab(d+96|0)}Ab(d+128|0)}Ab(d+144|0)}Ab(d+160|0)}T(a|0);L()}function RW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=kb-160|0;kb=d;zc(b);Xo(a);a:{if(!xv(b,d+120|0)){break a}if(!qD(d+120|0)){break a}j=v[b+8>>2];b:{if(!dd(b,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){break b}while(1){c:{if((w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0>h>>>0){if(Qb(v[b>>2],v[b+8>>2],5)){break c}}f=i&1;break b}f=0;g=1;d:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((ui(b)|0)<=0){break d}}while(1){l=Me(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(Qp(l<<24>>24)&255)==w[f+13017|0]}g=e;f=f+1|0;continue}break}_b(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}dd(b,j);if(!f){break a}if(!Qb(v[b>>2],v[b+8>>2],pD(d+120|0))){break a}if(!c){k=1;break a}g=kb-16|0;kb=g;e=d+120|0;dd(b,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));i=d+104|0;f=Tb(i);c=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[23588]=0;R(181,f|0,c|0);c=v[23588];v[23588]=0;e:{f:{g:{if((c|0)!=1){c=0;h:{i:{while(1){if((w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0<=c>>>0){break h}h=v[b+8>>2];j=v[b>>2];v[23588]=0;h=W(156,j|0,h|0,5)|0;j=v[23588];v[23588]=0;if((j|0)==1){break g}if(!h){break h}h=w[e+4|0]|w[e+5|0]<<8;v[23588]=0;U(182,g|0,b|0,h|0);h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;R(183,f|0,g|0);h=v[23588];v[23588]=0;if((h|0)==1){break i}c=c+1|0;zb(g);continue}break}c=P()|0;O()|0;break f}c=P()|0;O()|0;zb(g);break f}kb=g+16|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0}Xe(f);T(c|0);L()}v[23588]=0;X(176,d+88|0,b|0,e|0,i|0);c=v[23588];v[23588]=0;j:{if((c|0)!=1){v[23588]=0;Q(155,b|0,v[d+144>>2])|0;c=v[23588];v[23588]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if(y[d+140>>2]>k>>>0){c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,8)|0;e=v[23588];v[23588]=0;if((e|0)==1){break q}if(c){break p}}k=pc(v[a>>2],v[a+4>>2])^1;wc(d+88|0);Xe(d+104|0);break a}b=P()|0;O()|0;break k}v[23588]=0;da(177,d- -64|0,b|0,d+120|0,d+88|0,d+104|0);c=v[23588];v[23588]=0;if((c|0)!=1){e=Yo(d- -64|0);v[23588]=0;c=S(178,v[d+64>>2])|0;f=v[23588];v[23588]=0;if((f|0)==1){break o}if(c){v[23588]=0;c=S(179,d+24|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break n}e=v[e>>2];r:{if((e|0)<0){break r}f=v[d+104>>2];if(yd(f,v[d+108>>2])>>>0<=e>>>0){break r}v[23588]=0;U(11,d+8|0,8,Nd(f,e)|0);e=v[23588];v[23588]=0;if((e|0)==1){break m}e=d+8|0;Jb(c,e);Ab(e)}vv(g,d- -64|0);v[23588]=0;R(180,a|0,c|0);e=v[23588];v[23588]=0;if((e|0)==1){break m}jr(c)}k=k+1|0;Bb(d- -64|0);continue}break}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;jr(c)}Bb(d- -64|0);break k}b=P()|0;O()|0}wc(d+88|0);break j}b=P()|0;O()|0}Xe(d+104|0);T(b|0);L()}kb=d+160|0;return k|0}function FK(a){var b=C(0),c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),r=C(0),s=0,t=C(0),u=0,w=C(0),x=C(0);d=a+4208|0;eO(Eb(d,0),z[a+4272>>2]);b=C(C(z[Eb(d,0)>>2]*C(15920))+C(80));t=ue(C(10),C(C(C(z[Eb(d,2)>>2]+C(-.5))*C(30))/C(40)));c=C(C(b/C(y[v[a+16>>2]+24620>>2]))*C(6.2831854820251465));b=WK(c);w=Cp(c);x=b;f=C(C(c*C(C(C(z[Eb(d,1)>>2]*C(35))+C(1))*C(.02888113260269165)))/b);m=(l(2,(p(f),j(2))&-2147483648|1056964608),q());g=(p(f),j(2))&2147483647;c=(l(2,g),q());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(p(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((h|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=C(b-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=C(c*C(.5));i=C(c*b);r=C(C(i*C(C(i*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));b=C(C(3)-C(r*b));r=C(i*C(C(r-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*r)-i));if(!d){break b}e=C(C(C(c*C(r-e))-e)-i);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}b=C(c-e);b=C(C(b+b)+C(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(17014118346046923e22)):C(c*b))+C(-1));break b}i=(l(2,1065353216-h|0),q());c=C((d>>>0<=22?C(C(C(1)-i)+C(c-e)):C(C(c-C(e+i))+C(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=C(m*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}f=C(m*C(b+C(b/C(b+C(1)))));break a}m=C(C(m+m)*C(1661534994731145e20));b=C(c+C(-162.88958740234375));d=cx(b)&2047;j:{k:{if(cx(C(88))>>>0>d>>>0){break k}c=C(0);if(((p(b),j(2))|0)==-8388608){break j}c=C(b+b);if(cx(C(N))>>>0<=d>>>0){break j}if(b>C(88.72283172607422)){c=GD(0);break j}if(!(b<C(-103.97207641601562))){break k}c=fD(0);break j}k=A[165]*+b;s=A[164];u=k+s;k=k-(u-s);s=(A[166]*k+A[167])*(k*k)+(A[168]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;g=v[d>>2];d=v[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=C(s*+n())}f=C(C(m*c)*C(1661534994731145e20))}c=C(x*f);f=C(c/t);b=C(f+C(1));z[a+4236>>2]=C(C(1)-f)/b;f=C(C(w*C(-2))/b);z[a+4232>>2]=f;c=C(c*t);z[a+4228>>2]=C(C(1)-c)/b;z[a+4224>>2]=f;z[a+4220>>2]=C(c+C(1))/b}function sF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=kb-48|0;kb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;A[b>>3]=c;A[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;A[b>>3]=c;A[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(D(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;A[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;A[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;A[b>>3]=a}A[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=h;h=0;if(m){continue}break}A[i+32>>3]=a;d=2;while(1){h=d;d=d-1|0;if(A[(i+16|0)+(h<<3)>>3]==0){continue}break}d=TH(i+16|0,i,(k>>>20|0)-1046|0,h+1|0,1);a=A[i>>3];if((e|0)<0){A[b>>3]=-a;A[b+8>>3]=-A[i+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[i+8>>3]}kb=i+48|0;return d}function iK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-128|0;kb=g;v[g+124>>2]=c;v[g+120>>2]=b;v[g+112>>2]=d;v[g+116>>2]=e;a:{if(!c){break a}h=w[dl(b,c)|0];if((h|0)==33){f=1}else{if((h|0)!=63){break a}f=0}kl(g+88|0,b,c,c-1|0);b=v[g+92>>2];v[g+120>>2]=v[g+88>>2];v[g+124>>2]=b}b=g+88|0;Xd(b);c=v[g+88>>2];Xd(g+72|0);h=cl(c,v[g+76>>2],g+120|0);Xd(b);b=v[g+124>>2];c=v[g+120>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[g+92>>2]){a=rc(g+104|0,21619);if(Qc(c,b,v[a>>2],v[a+4>>2])){b=ba(8)|0;v[23588]=0;R(962,g+72|0,g+112|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}v[23588]=0;U(967,g+88|0,17598,g+72|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}a=0;c=sc(b,g+88|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(g+88|0);break e}if(!f){break h}b=ba(8)|0;v[23588]=0;a=Lh(g+40|0,v[g+120>>2],v[g+124>>2]);c=v[23588];v[23588]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((c|0)!=1){v[23588]=0;U(967,g+56|0,17634,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break p}v[23588]=0;R(969,g+72|0,g+56|0);c=v[23588];v[23588]=0;f=1;if((c|0)==1){break o}v[23588]=0;R(962,g+24|0,g+112|0);c=v[23588];v[23588]=0;if((c|0)==1){break n}v[23588]=0;U(971,g+88|0,g+72|0,g+24|0);c=v[23588];v[23588]=0;if((c|0)==1){break m}c=sc(b,g+88|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(g+88|0);f=0;break l}c=P()|0;O()|0;break d}c=P()|0;f=1;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0}zb(g+24|0)}zb(g+72|0)}zb(g+56|0)}zb(a);if(f){break d}break c}f=rc(g+16|0,21619);if(Qc(c,b,v[f>>2],v[f+4>>2])){b=ba(8)|0;v[23588]=0;R(962,g+72|0,g+112|0);a=v[23588];v[23588]=0;q:{r:{if((a|0)!=1){v[23588]=0;U(967,g+88|0,17598,g+72|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}a=0;c=sc(b,g+88|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(g+88|0);break q}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0}zb(g+72|0);if(a){break d}break c}f=rc(g+8|0,10895);if(Qc(c,b,v[f>>2],v[f+4>>2])){bK(a,Ic(d,e));break h}f=b;b=rc(g,8587);if(!Qc(c,f,v[b>>2],v[b+4>>2])){break h}a=v[a+32>>2];b=bz(d,e);b=b>>>0<4?b:1;c=kb-16|0;kb=c;s:{if((ck(w[a+140|0])|0)==(b|0)){d=a+120|0;As(w[d+20|0]);b=kb-16|0;kb=b;v[b+8>>2]=c+8;a=kb-16|0;kb=a;e=v[15595];v[a+8>>2]=v[15594];v[a+12>>2]=e;e=v[15593];v[a>>2]=v[15592];v[a+4>>2]=e;ob[v[wp(a,ck(w[d+20|0]))>>2]](b+8|0,d);kb=a+16|0;kb=b+16|0;break s}KJ(a,b,LJ(a))}kb=c+16|0}kb=g+128|0;return}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0}zb(g+72|0);if(!a){break c}}ca(b|0)}T(c|0)}L()}function Bm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-80|0;kb=e;h=Tb(a);v[23588]=0;a=S(279,b|0)|0;c=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=v[b+8>>2];d=v[b>>2];v[23588]=0;c=W(156,d|0,c|0,a|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}if(c){break d}v[23588]=0;a=S(202,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;Q(188,b|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[23588]=0;U(190,e+32|0,b|0,a|0);b=v[23588];v[23588]=0;f:{g:{h:{if((b|0)!=1){b=e+32|0;c=kc(e+56|0,b);Bb(b);if(a>>>0<10){break g}v[23588]=0;b=S(707,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}if(!b){break g}v[23588]=0;b=S(279,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}v[e+28>>2]=b;a=a-10|0;xc(e+28|0,a>>>0>25264513?-1:B(a,170));v[23588]=0;d=v[e+28>>2];R(285,h|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){break h}break b}a=P()|0;O()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=v[c+8>>2];f=v[c>>2];v[23588]=0;a=Q(708,f|0,a|0)|0;f=v[23588];v[23588]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}v[23588]=0;a=S(519,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}v[23588]=0;a=S(206,c|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=v[c+8>>2];i=v[c>>2];v[23588]=0;g=W(156,i|0,g|0,a|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}if(!g){continue}se(e+32|0,v[h>>2],v[h+4>>2]);Cq(e+16|0,v[e+32>>2],v[e+36>>2],b,a);v[23588]=0;Ok(459,e+8|0,c,v[e+16>>2],v[e+20>>2]);f=v[23588];v[23588]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}v[23588]=0;a=S(206,c|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}v[23588]=0;i=Q(709,c|0,e+24|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+24|0;i=jc(f);qh(f,i,Rf(Fb(v[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}v[23588]=0;a=Q(709,c|0,e+24|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}if(!a){continue}a=e+24|0;f=jc(a);qh(a,f,Rf(Fb(v[h>>2]),b));qh(a,f,Rf(Rf(Fb(v[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}v[23588]=0;a=S(206,c|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}a=Tb(e+32|0);Mt(a,h);ic(a);break f}v[23588]=0;U(327,c|0,h|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}}Bb(c)}kb=e+80|0;return}a=P()|0;O()|0;Bb(c)}ic(h);T(a|0);L()}function gba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=43568;v[a+4>>2]=0;v[a>>2]=32176;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;cq(a+24604|0);aN(a+24648|0,0);v[a+397448>>2]=0;v[a+397452>>2]=0;b=a+397456|0;v[b>>2]=8;v[b+4>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;t[b+12|0]=0;v[b+8>>2]=0;u[b+24>>1]=0;Ub(b+28|0,0,40);Ub(b+68|0,0,49824);Ub(b+49892|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;h=Tb(a+480248|0);v[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;LC(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Tb(c);v[f+12>>2]=a;v[23588]=0;i=Q(808,a+484360|0,a|0)|0;b=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){v[23588]=0;b=S(681,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}v[23588]=0;S(809,a+901404|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break h}d=a+906300|0;b=0;while(1){WM(d+B(b,160)|0);b=b+1|0;if((b|0)!=250){continue}break}v[a+946300>>2]=0;e=a+1074304|0;g=a+946304|0;b=g;while(1){b=At(b)+32|0;if((e|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;ir(a+1074312|0);v[23588]=0;Z(810);b=v[23588];v[23588]=0;if((b|0)==1){break g}r=a,s=VM(),v[r+1074328>>2]=s;b=a+1074332|0;v[b+12>>2]=1065353216;LM(b,4);v[23588]=0;e=S(811,a+1074376|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break g}v[23588]=0;j=W(581,a+1298264|0,a|0,255)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}k=Hc(a+1298300|0);l=Hc(a+1298304|0);m=Mb(a+1298308|0);n=Mb(a+1298320|0);o=Mb(a+1298332|0);p=$M(a+1298344|0);q=Tb(a+1298408|0);t[a+1298420|0]=0;b=a+1298424|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298464>>2]=0;Op(a+12|0);zy(a+8204|0);zy(a+12300|0);b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;Ub(c,0,1024);UM(g);v[23588]=0;b=S(812,12)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;r=a,s=Tb(b),v[r+4>>2]=s;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;_M(q);Cy(p);zb(o);Ab(n);zb(m);By(l);Ay(k);nt(j)}Ny(e)}ZM(d)}zz(i)}RM(f);wc(h);T(b|0);L()}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=kb-560|0;kb=f;a:{if(!dd(b,1464)){break a}if(!oo(b,f+556|0)){break a}Bd(a,1);Ob(Ob(_f(a+1074312|0,83),84,1),85,1);b:{if(oe(f+556|0,26889)){d=f+32|0;e=yc(d,8390);Jb(a+1298344|0,e);Ab(e);e=yc(d,14781);Jb(a+1298356|0,e);Ab(e);d=yc(d,14846);Jb(a+1298368|0,d);break b}if(!oe(f+556|0,15497)){break a}d=f+32|0;e=yc(d,8564);Jb(a+1298344|0,e);Ab(e);e=yc(d,12192);Jb(a+1298356|0,e);Ab(e);d=yc(d,15404);Jb(a+1298368|0,d)}Ab(d);v[a+1298404>>2]=14;dd(b,0);OA(b,a+1298308|0,20);u[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+552|0;ev(d,b);m=Oc(d);if(w[f+552|0]>128){break a}e=f+32|0;d=kb-16|0;kb=d;c:{if(!Qb(v[b>>2],v[b+8>>2],512)){VR(e);break c}Mu(d+8|0,e);ud(d,b,v[d+8>>2],v[d+12>>2])}kb=d+16|0;d=0;e=w[m|0];while(1){n=(d|0)==512;if(!n){g=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=w[g|0]){continue}break a}break}if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;oh(a,0);o=a+484376|0;vg(Wb(v[a+484360>>2],w[o|0]),w[f+552|0]);l=a+484344|0;xg(l,w[f+552|0]);while(1){if(w[f+552|0]<=i>>>0){if(!(c&2)){break a}dd(b,(w[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(B(d,104)+a|0)+484380|0;if(v[c>>2]){wg(_c(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}s=dc(v[Wb(v[a+484360>>2],w[o|0])>>2],i),x=i,u[s>>1]=x;d:{if(!ph(l,i&65535,64)){break d}r=i<<2;e=0;e:while(1){if((e|0)==4){s=f,x=Fb(v[Zb(v[l>>2],i)>>2]),v[s+24>>2]=x;e=0;while(1){if((e|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{t[f+31|0]=p;t[f+30|0]=q;d=h&255;if(d){break g}h=0;break f}}else{g=v[f+24>>2];h:{if((w[g+3|0]&254)!=16){break h}t[g+3|0]=16;h=0;k=w[g+5|0];if(k>>>0<16){break h}h=k>>>4|0;t[g+5|0]=h;j=h;h=k&15;g=(j|0)==(h|0)|!h;q=g?q:j;p=g?p:h;h=!g}d=d+1|0;bA(f+24|0);continue}break}Ae(Zb(v[l>>2],i),Ue(Oe(f+8|0,16,w[(d+f|0)+29|0]),e));h=h+1|0;h=(h&255)==3?1:h}e=e+1|0;continue}}dd(b,(w[f+32+(e+r)|0]<<8)+1468|0);g=0;d=Zb(v[l>>2],i);d=jd(v[d>>2],v[v[d+48>>2]+12>>2],0,e&65535);while(1)if((g|0)==64){e=e+1|0;continue e}else{j=f+8|0;Iu(j,b,d);k=w[f+8|0];j=w[Oc(j)|0];i:{if(!(!(k|j)|(k-5&255)>>>0<5|(k|0)==14&j>>>0>15)){Pf(d,k,j);break i}t[d+3|0]=0}d=d+24|0;g=g+1|0;continue}}}i=i+1|0;continue}}else{g=jA(b,f+32|0,(B(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}kb=f+560|0;return n|0}function c3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=kb-192|0;kb=d;v[d+184>>2]=c;a:{b:{c:{if(b>=.8){v[23588]=0;e=ga(1076)|0;f=v[23588];v[23588]=0;d:{e:{f:{if((f|0)!=1){v[d+80>>2]=e;v[23588]=0;c=S(1077,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break e}v[d+176>>2]=c;In(e,c);a=ke(d+152|0,a);v[23588]=0;f=v[a+12>>2];c=d- -64|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=f;v[d+72>>2]=v[a+16>>2];c=v[a+4>>2];v[d+56>>2]=v[a>>2];v[d+60>>2]=c;a=W(1069,e|0,d+56|0,15)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}if(a){v[23588]=0;Y(813,e|0);a=v[23588];v[23588]=0;g=1;if((a|0)==1){break f}}jj(d+176|0);kj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;jj(d+176|0);break d}c=V(0)|0;O()|0}kj(d+80|0);break c}if(b>=.6){v[23588]=0;e=ga(1076)|0;f=v[23588];v[23588]=0;g:{h:{i:{if((f|0)!=1){v[d+80>>2]=e;v[23588]=0;c=S(1077,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break h}v[d+176>>2]=c;In(e,c);a=ke(d+128|0,a);v[23588]=0;c=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=c;v[d+48>>2]=v[a+16>>2];c=v[a+4>>2];v[d+32>>2]=v[a>>2];v[d+36>>2]=c;a=W(1069,e|0,d+32|0,2)|0;c=v[23588];v[23588]=0;if((c|0)==1){break i}if(a){v[23588]=0;Y(813,e|0);a=v[23588];v[23588]=0;g=.8;if((a|0)==1){break i}}jj(d+176|0);kj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;jj(d+176|0);break g}c=V(0)|0;O()|0}kj(d+80|0);break c}g=.2;if(b>=.2){v[23588]=0;e=ga(1076)|0;f=v[23588];v[23588]=0;j:{k:{l:{if((f|0)!=1){v[d+80>>2]=e;v[23588]=0;c=S(1077,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break k}v[d+176>>2]=c;In(e,c);a=ke(d+104|0,a);v[23588]=0;c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;v[d+24>>2]=v[a+16>>2];c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;a=W(1069,e|0,d+8|0,0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break l}g=0;if(a){v[23588]=0;Y(813,e|0);a=v[23588];v[23588]=0;g=.6;if((a|0)==1){break l}}jj(d+176|0);kj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;jj(d+176|0);break j}c=V(0)|0;O()|0}kj(d+80|0);break c}if(!(b>=.1)){break b}v[23588]=0;U(203,d+80|0,a|0,2048);c=v[23588];v[23588]=0;if((c|0)!=1){c=Je(d+80|0);a=v[a>>2];v[23588]=0;e=v[d+80>>2];a=S(160,a|0)|0;f=v[23588];v[23588]=0;m:{if((f|0)==1){break m}v[23588]=0;a=lF(1078,c,e,a,0);c=v[23588];v[23588]=0;if((c|0)==1){break m}g=A[(a<<3)+62392>>3];Uc(d+80|0);break b}c=V(0)|0;O()|0;Uc(d+80|0);break c}c=V(0)|0;O()|0}_(c|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;g=0;if((a|0)==1){break a}}Ee(d+184|0);kb=d+192|0;return+g}a=P()|0;O()|0;Ee(d+184|0);T(a|0);L()}function iaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=kb-48|0;kb=c;a:{b:{if(!Pb(v[b>>2],v[b+4>>2])){break b}l=v[b+12>>2];k=Qg(v[v[b+48>>2]+12>>2]);d=k;f=c+32|0;v[f>>2]=0;v[f+4>>2]=0;Hc(f+8|0);if(d){mu(f,d);g=kb-16|0;kb=g;e=Gq(g,f,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){lc(e);kb=g+16|0}else{t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;ug(d);d=d+6|0;v[e+4>>2]=d;continue}break}}while(1){c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(j>>>0>=l>>>0){break r}if(!Zg(v[v[a>>2]-12>>2]+a|0)){break r}v[23588]=0;t[c+31|0]=0;Q(875,a|0,c+31|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}d=t[c+31|0];if(!d){j=j+1|0;continue}t[c+30|0]=0;s:{if((d|0)>=0){break s}v[23588]=0;Q(875,a|0,c+30|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break s}break a}t[c+29|0]=0;Fj(c+16|0);t:{d=d&127;g=(d?d-1|0:0)&65535;i=g>>>0>=k>>>0;u:{v:{if(!i){h=jd(v[b>>2],v[v[b+48>>2]+12>>2],j,g);d=w[c+30|0];if(d&1){break v}e=Id(v[f>>2],g);break u}h=c+16|0;d=w[c+30|0];if(!(d&1)){break t}}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break t}e=Id(v[f>>2],g);t[e|0]=w[c+29|0]}t[h|0]=w[e|0];d=w[c+30|0];if(!(d&2)){break p}break q}if(d&2){break q}break o}vk(f);break b}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break o}e=Id(v[f>>2],g);t[e+1|0]=w[c+29|0]}t[h+1|0]=w[e+1|0];if(d&4){break n}break m}if(!(d&4)){break l}}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break l}e=Id(v[f>>2],g);t[e+2|0]=w[c+29|0]}t[h+2|0]=w[e+2|0];if(!(d&8)){break j}break k}if(!(d&8)){break i}}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break i}e=Id(v[f>>2],g);t[e+4|0]=w[c+29|0]}t[h+4|0]=w[e+4|0];if(d&16){break h}break g}if(!(d&16)){break f}}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break f}e=Id(v[f>>2],g);t[e+3|0]=w[c+29|0]}t[h+3|0]=w[e+3|0];if(!(d&32)){break d}break e}if(!(d&32)){break c}}v[23588]=0;Q(875,a|0,c+29|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break c}e=Id(v[f>>2],g);t[e+5|0]=w[c+29|0]}t[h+5|0]=w[e+5|0]}if(!(d&64)){continue}v[23588]=0;Q(875,a|0,c+15|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;Q(876,a|0,w[c+15|0])|0;d=v[23588];v[23588]=0;if((d|0)!=1){continue}}break}break a}kb=c+48|0;return}a=P()|0;O()|0;vk(f);T(a|0);L()}function Yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;g=kb-32|0;kb=g;a:{if(!Qb(v[a>>2],v[a+8>>2],2)){ph(c+484344|0,b,64);break a}l=c+484344|0;m=Dd(Hj(a),1,1024);if(!ph(l,b,m)){break a}p=x[c+480188>>1];q=c+480190|0;b:while(1){if((k|0)==(m|0)){break a}i=0;e=Zb(v[l>>2],b);n=Df(v[e>>2],v[v[e+48>>2]+12>>2],k);while(1)if((i|0)==(p|0)){k=k+1|0;continue b}else{f=g+24|0;Tm(f,a);e=B(i,6)+n|0;r=Te(f);f=Mi(f);h=w[g+24|0];c:{if((h-1&255)>>>0>35){break c}t[e|0]=h+48;o=w[Oc(g+24|0)|0];h=o+1|0;t[e+1|0]=h;j=h;h=h&255;if((j|0)!=(h|0)|h>>>0>x[q>>1]){break c}h=Hi(c,h);j=Lb(d,i);if(!(!w[j|0]|x[h+30>>1]>255)){t[e+4|0]=64;t[e+2|0]=1}h=v[Eb(h+68|0,0)>>2];if(!(w[j|0]|h?w[j|0]?(h|0)==1:0:1)){break c}t[e+1|0]=o+101}d:{e:{switch(w[r|0]){case 1:if(!w[f|0]){break d}t[e+3|0]=2;t[e+5|0]=w[f|0];break d;case 2:if(!w[f|0]){break d}t[e+3|0]=3;t[e+5|0]=w[f|0];break d;case 12:if(!w[f|0]){break d}t[e+3|0]=1;t[e+5|0]=w[f|0];break d;case 13:if(!w[f|0]){break d}t[e+3|0]=39;t[g+23|0]=15;s=e,u=w[Xb(g+23|0,f)|0]|16,t[s+5|0]=u;break d;case 30:if(!w[f|0]){break d}t[e+3|0]=38;t[g+22|0]=15;s=e,u=w[Xb(g+22|0,f)|0]|16,t[s+5|0]=u;break d;case 21:if(!w[f|0]){break d}t[e+3|0]=39;t[g+21|0]=15;s=e,u=w[Xb(g+21|0,f)|0]|80,t[s+5|0]=u;break d;case 17:if(!w[f|0]){break d}t[e+3|0]=38;t[g+20|0]=15;s=e,u=w[Xb(g+20|0,f)|0]|80,t[s+5|0]=u;break d;case 15:t[e+3|0]=19;t[e+5|0]=w[f|0]!=0;break d;case 25:t[e+3|0]=12;t[e+5|0]=w[f|0];break d;case 27:jo(e);t[e|0]=255;break d;case 28:if(w[f|0]>31){break d}t[e+3|0]=16;t[e+5|0]=w[f|0];break d;case 31:h=w[f|0];if(h&15){s=e,u=w[Lb(d,i)|0]?22:11,t[s+3|0]=u;t[e+5|0]=w[f|0]&15;h=w[f|0]}f:{g:{switch(h>>>4|0){case 4:if((h|0)!=64){break f}case 0:case 1:case 2:case 3:if(w[Lb(d,i)|0]){t[e+3|0]=21;t[e+5|0]=w[f|0];break f}t[e+2|0]=1;f=w[f|0];t[e+3|0]=0;t[e+4|0]=f;break f;case 5:t[e+5|0]=w[e+5|0]<<4;break f;case 6:t[g+19|0]=w[e+5|0];t[g+18|0]=14;s=e,u=w[Xb(g+19|0,g+18|0)|0]|240,t[s+5|0]=u;break f;case 7:t[g+17|0]=w[e+5|0];t[g+16|0]=14;s=e,u=w[Xb(g+17|0,g+16|0)|0]<<4|15,t[s+5|0]=u;break f;default:break g}}t[e+3|0]=0}if((w[e+3|0]-21&255)>>>0>1){break d}f=B(t[Lb(d,i)|0]+i|0,6)+n|0;Pq(g+8|0,w[f+3|0],w[f+5|0],1);if(w[g+8|0]){h=x[g+8>>1];t[f+4|0]=h>>>8;t[f+2|0]=h}t[f+3|0]=w[e+3|0];t[f+5|0]=w[e+5|0];break d;case 0:break d;default:break e}}t[e+3|0]=0}i=i+1|0;continue}}}kb=g+32|0}function sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=kb+-64|0;kb=d;u[d+62>>1]=c;Ff(d+62|0,32);j=Tb(a);v[23588]=0;o=x[d+62>>1];R(523,j|0,o|0);a=v[23588];v[23588]=0;a:{b:{if((a|0)!=1){k=b+480190|0;p=b+480192|0;c:{d:{while(1){if((q&65535)>>>0>=o>>>0){break d}e=1;c=x[k>>1];a=c+1|0;u[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){f=e&65535;if(f>>>0>c>>>0){break h}i:{g=Hi(b,f);if(!_d(v[g>>2],v[g+20>>2])){if(!Pb(cA(Fb(v[j>>2]),Fb(v[j+4>>2]),e),Fb(v[j+4>>2]))){break i}c=x[k>>1]}e=e+1|0;continue}break}u[d+60>>1]=e;a=1;while(1){if(x[p>>1]<a>>>0){a=e;break h}j:{c=v[((a<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;g=zq(c);while(1){if((c|0)==(g|0)){break j}if((f|0)==x[c>>1]){u[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}}if((a&65535)>>>0<4e3){break g}e=ho(d+48|0);v[23588]=0;a=Q(746,b|0,e|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}if(!a){break e}v[23588]=0;R(747,b|0,e|0);c=v[23588];v[23588]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=x[p>>1]){k:{c=v[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;f=zq(c);while(1){if((c|0)==(f|0)){break k}g=x[c>>1];l:{if(g>>>0>=y[d+52>>2]){break l}Db(d+40|0,v[e>>2],g);if(Cb(v[v[d+40>>2]>>2],v[d+44>>2])){break l}u[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}vl(d+24|0,v[e>>2]);RP(d+32|0,v[d+24>>2],v[d+28>>2],1);Dm(d+16|0,v[e>>2],v[d+52>>2]);m=kb-16|0;kb=m;g=d+40|0;c=hc(m,v[d+32>>2],v[d+36>>2]);a=ul(v[d+16>>2],v[d+20>>2],v[d+32>>2],v[d+36>>2]);f=kb-16|0;kb=f;v[f+12>>2]=a;h=v[c+4>>2];m:{if(h){i=32-h|0;v[f+8>>2]=i;n=v[Kb(f+8|0,f+12|0)>>2];l=-1<<h&-1>>>i-n;i=v[c>>2];l=l&(v[i>>2]^-1);if(l){hc(g,i,Nka(l));break m}if((a|0)==(n|0)){RP(g,i,h,a);break m}a=a-n|0;v[f+12>>2]=a;v[c>>2]=i+4}while(1){if(a>>>0>=32){h=v[c>>2];i=v[h>>2];if((i|0)!=-1){hc(g,h,Nka(i^-1));break m}else{v[c>>2]=h+4;a=a-32|0;v[f+12>>2]=a;continue}}break}if(!a){hc(g,v[c>>2],0);break m}c=v[c>>2];h=(v[c>>2]^-1)&-1>>>32-a;if(!h){hc(g,c,a);break m}hc(g,c,Nka(h))}kb=f+16|0;kb=m+16|0;vl(d+8|0,v[e>>2]);a=ul(v[d+40>>2],v[d+44>>2],v[d+8>>2],v[d+12>>2]);u[d+60>>1]=a;We(e);if((a&65535)>>>0>3999){break f}}v[23588]=0;R(257,j|0,d+60|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}if(x[k>>1]>=(a&65535)>>>0){break f}u[k>>1]=a}q=q+1|0;continue}break}We(e)}kb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;We(e)}od(j);T(c|0);L()}function A3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=kb-192|0;kb=d;h=DJ(d+176|0);v[h>>2]=49332;Tb(h+4|0);In(v[a+24>>2],h);e=v[a+24>>2];i=w[a+62|0];f=w[a+61|0];g=w[a+60|0];b=ke(d+152|0,b);v[23588]=0;j=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=j;v[d+24>>2]=v[b+16>>2];j=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=j;b=g?13:15;b=f?b&14:b;b=W(1069,e|0,d+8|0,(i?b&3:b)|0)|0;e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ba(8)|0;v[23588]=0;c=Q(55,d+136|0,11930)|0;a=v[23588];v[23588]=0;if((a|0)!=1){a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}a=P()|0;O()|0;ca(b|0);break b}if(!w[a+63|0]){v[23588]=0;R(1070,a|0,a+36|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}}t[a+28|0]=1;In(v[a+24>>2],v[a+4>>2]);v[23588]=0;R(1071,d+136|0,h|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}k=d,l=Fb(v[d+136>>2]),v[k+128>>2]=l;e=a+68|0;i=Fb(v[d+140>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=v[d+128>>2];if(!Pb(b,i)){k=d,l=Gi(v[c>>2]),v[k+112>>2]=l;c=xf(c);while(1){b=v[d+112>>2];if(!Ig(b,c)){break d}v[23588]=0;e=wd(b);b=Q(54,d+32|0,e|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break h}v[23588]=0;X(968,a|0,b|0,e+12|0,0);e=v[23588];v[23588]=0;if((e|0)==1){break g}zb(b);Lg(d+112|0);continue}}f=v[a+24>>2];g=v[b>>2];v[23588]=0;j=f;f=b+4|0;U(1072,j|0,g|0,f|0);g=v[23588];v[23588]=0;if((g|0)!=1){b=v[b>>2];v[23588]=0;R(1073,d- -64|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break r}v[23588]=0;R(1015,d+80|0,d- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break q}v[23588]=0;b=Q(55,d+48|0,17734)|0;g=v[23588];v[23588]=0;if((g|0)==1){break p}v[23588]=0;U(971,d+96|0,d+80|0,b|0);g=v[23588];v[23588]=0;if((g|0)==1){break o}v[23588]=0;U(529,d+112|0,d+96|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break n}v[23588]=0;R(183,e|0,d+112|0);f=v[23588];v[23588]=0;if((f|0)==1){break m}zb(d+112|0);zb(d+96|0);zb(b);zb(d+80|0);Ab(d- -64|0);fq(d+128|0);continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;break l}a=P()|0;O()|0;zb(d+112|0)}zb(d+96|0)}zb(b)}zb(d+80|0)}Ab(d- -64|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(b)}vx(d+136|0);break b}a=P()|0;O()|0;break b}vx(d+136|0);ys(h);kb=d+192|0;return}a=P()|0;O()|0}ys(h);T(a|0)}L()}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=kb-32|0;kb=e;a:{b:{if(!c){break b}s=e,u=Me(a),t[s+16|0]=u;qn(b,e+16|0);k=c-1|0;c=0;while(1){g=1;if(!k){break a}c:{d:{d=c<<1;c=d&254;if(!c){if(!of(a,e+16|0)){break b}i=1;d=w[e+16|0]<<1|1;c=d&255;if(d>>>0<=255){break d}break c}if((d&65535)>>>0<=255){break d}i=1;break c}if(!of(a,e+16|0)){break b}CU(b,e+16|0);k=k-1|0;continue}while(1){e:{f:{g:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!of(a,e+16|0)){break g}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}i=kq(i,1)+c|0;c=d<<1&254;if(c){break f}if(!of(a,e+16|0)){break g}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(d>>>0>127){continue}}break}h:{if((i|0)<=2){j=0;h=i-2|0;break h}if(!of(a,e+16|0)){break b}d=kq(i-3|0,8)|w[e+16|0];j=((d|0)>1279?2:1)+((d|0)>31999)|0;n=d^-1;h=0}d=c<<1&254;if(d){f=c>>>0>127}else{if(!of(a,e+16|0)){break b}c=w[e+16|0]<<1|1;d=c&255;f=c>>>0>255}g=kq(h,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!of(a,e+16|0)){break b}d=w[e+16|0]<<1|1;c=d&255;d=d>>>0>255}i=1;h=k;d=kq(f+g|0,1)+d|0;if(!d){while(1){i:{j:{k:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!of(a,e+16|0)){break k}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}i=kq(i,1)+c|0;c=d<<1&254;if(c){break j}if(!of(a,e+16|0)){break k}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break i}c=0;break i}if(d>>>0>127){continue}}break}d=i+2|0}f=h;h=d+j|0;g=0;if(f>>>0<h>>>0|(h|0)<=0|(n|0)>=0){break a}d=v[b+4>>2];g=0;if((0-fd(v[b>>2],d)|0)>(n|0)){break a}d=fc(e+24|0,Fb(d));t[e+16|0]=0;l=e+16|0;o=kb-32|0;kb=o;f=v[d>>2];d=v[b>>2];j=so(f,Fb(d))+d|0;f=v[Gb(b)>>2];g=v[b+4>>2];l:{if(h>>>0<=f-g>>>0){d=h;f=g-j|0;if(d>>>0>f>>>0){No(b,h-f|0,l);d=f;if(!d){break l}}p=kb-16|0;kb=p;f=g;r=v[b+4>>2];g=(r-(h+j|0)|0)+j|0;q=Pk(p,b,f-g|0);m=v[q+4>>2];i=g;while(1){if(i>>>0>=f>>>0){lc(q);Bq(j,g,r);kb=p+16|0}else{xd(m,w[i|0]);m=m+1|0;v[q+4>>2]=m;i=i+1|0;continue}break}ci(j,d,(j>>>0<=l>>>0?y[b+4>>2]>l>>>0?h:0:0)+l|0);break l}d=Gb(b);d=Zl(o+8|0,Xl(b,fd(v[b>>2],g)+h|0),j-v[b>>2]|0,d);eT(d,h,l);j=DU(b,d,j);Yl(d)}Fb(j);kb=o+32|0;s=e,u=Rf(sS(Fb(v[b+4>>2]),h),n),v[s+16>>2]=u;s=e,u=sS(Fb(v[b+4>>2]),h),v[s+8>>2]=u;d=h;while(1){f=w[rS(e+16|0)|0];s=rS(e+8|0),u=f,t[s|0]=u;f=d>>>0>1;d=d-1|0;if(f){continue}break}k=k-h|0;continue}}g=0}f=g;kb=e+32|0;return f|0}function E6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-128|0;kb=e;v[e+124>>2]=c;v[e+120>>2]=b;a:{if(!c){break a}f=w[dl(b,c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}kl(e+96|0,b,c,c-1|0);b=v[e+100>>2];v[e+120>>2]=v[e+96>>2];v[e+124>>2]=b}c=e+96|0;Xd(c);b=v[e+96>>2];Xd(e+80|0);b=cl(b,v[e+84>>2],e+120|0);Xd(c);b:{c:{d:{e:{if((b|0)==v[e+100>>2]){b=v[e+120>>2];c=v[e+124>>2];a=rc(e+112|0,21619);if(Qc(b,c,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23588]=0;b=Q(55,e+96|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}b=0;if(!d){break e}b=ba(8)|0;v[23588]=0;d=Lh(e+80|0,v[e+120>>2],v[e+124>>2]);a=v[23588];v[23588]=0;f:{g:{h:{if((a|0)!=1){v[23588]=0;U(967,e+96|0,17634,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}a=0;c=sc(b,e+96|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(e+96|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}zb(d);if(!a){break c}}ca(b|0);break c}if(v[b+4>>2]){a=ba(8)|0;v[23588]=0;b=Q(55,e+96|0,11504)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;ca(a|0);break c}c=v[e+120>>2];d=v[e+124>>2];b=rc(e+72|0,21619);if(Qc(c,d,v[b>>2],v[b+4>>2])){a=ba(8)|0;v[23588]=0;b=Q(55,e+96|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;ca(a|0);break c}i:{b=rc(e- -64|0,7422);if(!Qc(c,d,v[b>>2],v[b+4>>2])){b=rc(e+56|0,7404);if(!Qc(c,d,v[b>>2],v[b+4>>2])){break i}}b=w[a+60|0]!=0;break e}j:{b=rc(e+48|0,6937);if(!Qc(c,d,v[b>>2],v[b+4>>2])){b=rc(e+40|0,6918);if(!Qc(c,d,v[b>>2],v[b+4>>2])){break j}}b=w[a+61|0]!=0;break e}b=rc(e+32|0,7021);if(Qc(c,d,v[b>>2],v[b+4>>2])){b=w[a+62|0]!=0;break e}b=rc(e+24|0,6067);if(Qc(c,d,v[b>>2],v[b+4>>2])){b=w[a+63|0]!=0;break e}b=rc(e+16|0,7471);if(Qc(c,d,v[b>>2],v[b+4>>2])){b=w[a+64|0]!=0;break e}f=c;c=rc(e+8|0,13296);b=0;if(!Qc(f,d,v[c>>2],v[c+4>>2])){break e}b=v[v[a+24>>2]+24668>>2]!=0}kb=e+128|0;return b|0}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}function yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=kb-16|0;kb=h;f=v[a+8>>2];e=v[a>>2];v[23588]=0;f=Q(600,e|0,f|0)|0;e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){if(f){break b}v[23588]=0;f=S(206,a|0)|0;e=v[23588];v[23588]=0;c:{if((e|0)==1){break c}v[23588]=0;j=d+484344|0;k=Dd(f+1|0,1,1024);f=W(226,j|0,b|0,k|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}if(!f){break b}d=x[d+480188>>1];if(!d){break b}l=d-1|0;d=0;d:while(1){if(d>>>0>=k>>>0){break b}while(1){f=v[a+8>>2];e=v[a>>2];v[23588]=0;f=W(156,e|0,f|0,1)|0;e=v[23588];v[23588]=0;e:{if((e|0)!=1){if(!f){break b}v[23588]=0;i=S(206,a|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}if(i){break e}d=d+1|0;continue d}break a}e=v[j>>2];u[h+14>>1]=i&31;u[h+12>>1]=l;e=Zb(e,b);e=jd(v[e>>2],v[v[e+48>>2]+12>>2],d,x[Wc(h+14|0,h+12|0)>>1]);if(!(i&224)){continue}break}f:{if(!(i&128)){break f}v[23588]=0;g=S(206,a|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break a}t[e+5|0]=g;v[23588]=0;g=S(206,a|0)|0;f=v[23588];v[23588]=0;g:{h:{if((f|0)!=1){if(g>>>0<26){break h}break g}break a}f=w[g+42688|0];t[e+3|0]=f;i:{switch(f-1|0){case 0:if(!w[e+5|0]){break g}break f;case 12:if(w[e+2|0]){break f}t[e+2|0]=1;f=w[e+5|0];t[e+5|0]=0;t[e+3|0]=0;m=e,n=Dd(f,0,64),t[m+4|0]=n;break f;case 5:case 6:case 10:case 23:case 28:f=w[e+5|0]&240;if(!f){break f}t[e+5|0]=f;break f;case 8:f=w[e+5|0];if(f>>>0<=128){m=e,n=tg(f<<1),t[m+5|0]=n;break f}if((f|0)!=164){break f}t[e+5|0]=145;t[e+3|0]=20;break f;case 13:f=w[e+5|0];t[e+5|0]=B(f>>>4|0,10)+(f&15);break f;case 18:Wu(e);break f;case 16:if(w[e+5|0]>31){break f}t[e+3|0]=16;break f;case 27:break i;default:break f}}g=w[e+5|0];f=g&240;j:{if((f|0)==16){f=2}else{if((f|0)!=32){break j}f=3}t[e+3|0]=f}t[e+5|0]=g&15|224;break f}t[e+3|0]=0}k:{l:{if(!(i&64)){break l}v[23588]=0;R(260,h+8|0,a|0);f=v[23588];v[23588]=0;if((f|0)==1){break k}t[e+1|0]=w[h+8|0];g=w[Oc(h+8|0)|0];t[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break l}}t[e|0]=f}if(!(i&32)){continue}t[e+2|0]=1;v[23588]=0;g=S(206,a|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break a}t[e+4|0]=g;if(!c){continue}t[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}Bb(a);kb=h+16|0;return}b=P()|0;O()|0;Bb(a);T(b|0);L()}function a4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Mb(a);v[23588]=0;Z(105);c=v[23588];v[23588]=0;a:{b:{if((c|0)==1){c=Xa(62688,92948,93532,0)|0;d=O()|0;c:{d:{e:{if((ea(62688)|0)==(d|0)){c=_(c|0)|0;v[23588]=0;b=Q(941,a|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;b=Q(941,b|0,17734)|0;d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;d=Q(941,b|0,17710)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}b=ob[v[v[c>>2]+8>>2]](c)|0;v[23588]=0;Q(941,d|0,(b?b:21619)|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ea(92948)|0)==(d|0)){c=_(c|0)|0;v[23588]=0;b=Q(941,a|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}v[23588]=0;b=Q(941,b|0,17734)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}v[23588]=0;d=Q(941,b|0,17685)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}b=ob[v[v[c>>2]+8>>2]](c)|0;v[23588]=0;Q(941,d|0,(b?b:21619)|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ea(93532)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[23588]=0;b=Q(941,a|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;b=Q(941,b|0,17734)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;d=Q(941,b|0,17701)|0;b=v[23588];v[23588]=0;if((b|0)==1){break g}b=ob[v[v[c>>2]+8>>2]](c)|0;v[23588]=0;Q(941,d|0,(b?b:21619)|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break g}v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[23588]=0;b=Q(941,a|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}v[23588]=0;b=Q(941,b|0,17734)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}v[23588]=0;Q(941,b|0,13664)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Vb()}L()}return}zb(a);T(b|0);L()}function wW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=kb-384|0;kb=f;zc(b);d=kb-16|0;kb=d;h=f+344|0;HC(d+8|0,h);e=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);i=v[d+4>>2];if((i|0)==(e|0)){_b(b,v[d+12>>2])}kb=d+16|0;d=(e|0)==(i|0);if(!d){GC(h)}a:{if(!d){break a}if(!JC(f+344|0)){break a}if(!Qb(v[b>>2],v[b+8>>2],Ec(IC(w[f+379|0]),nb))){break a}b:{if(!c){break b}Bd(a,2097152);ag(a);oh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);j=a+480190|0;u[j>>1]=w[f+378|0];d=w[f+381|0];if(d>>>0<w[f+380|0]){Ve(Wb(v[a+484360>>2],w[a+484376|0]),d)}d=f+80|0;g=yc(d,6522);Jb(a+1298344|0,g);Ab(g);g=yc(d,11070);Jb(a+1298356|0,g);Ab(g);v[a+1298404>>2]=5;fv(b,d);Wq(Wb(v[a+484360>>2],w[a+484376|0]),d,w[f+380|0],65535,65535);g=1;while(1){i=g&65535;if(i>>>0>x[j>>1]){_b(b,B(64-w[f+378|0]|0,37));h=a+484344|0;xg(h,w[f+379|0]);i=c&1;g=0;while(1){if(w[f+379|0]<=g>>>0){if(!(c&2)){break b}c=_c(f+40|0,8,1,0,0);d=a+480190|0;g=1;while(1){e=g&65535;if(e>>>0>x[d>>1]){break b}wg(c,(B(e,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(i){if(ph(h,g&65535,64)){break d}}_b(b,2048);break c}d=Zb(v[h>>2],g);n=f,o=Fb(v[d>>2]),v[n+40>>2]=o;j=Fb(v[d+4>>2]);while(1){d=v[f+40>>2];if(!Pb(d,j)){break c}e=f+24|0;Tm(e,b);k=Oc(e);m=Te(e);e=Mi(e);l=w[f+24|0];if((l-1&255)>>>0<=106){t[d|0]=l+13}t[d+1|0]=w[k|0];Pf(d,w[m|0],w[e|0]);Ck(f+40|0);continue}}g=g+1|0;continue}}else{d=f+40|0;FC(b,d);h=kb-16|0;kb=h;e=(B(i,104)+a|0)+484380|0;nd(e,0);t[e+37|0]=w[d+22|0]<<4;t[h+15|0]=w[d+23|0];t[h+14|0]=64;n=e,o=w[Xb(h+15|0,h+14|0)|0]<<2,u[n+30>>1]=o;t[e+36|0]=w[d+24|0];v[e>>2]=w[d+25|0]|w[d+26|0]<<8|(w[d+27|0]<<16|w[d+28|0]<<24);k=w[d+33|0]|w[d+34|0]<<8|(w[d+35|0]<<16|w[d+36|0]<<24);if(!(k>>>0<3|k+(w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24))>>>0>(w[d+25|0]|w[d+26|0]<<8|(w[d+27|0]<<16|w[d+28|0]<<24))>>>0)){u[e+34>>1]=x[e+34>>1]|2;v[e+4>>2]=w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24);v[e+8>>2]=(w[d+33|0]|w[d+34|0]<<8|(w[d+35|0]<<16|w[d+36|0]<<24))+(w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24))}kb=h+16|0;e=f+8|0;Il(e,2,d);d=f+24|0;Fc(d,e);Dc(((i<<5)+a|0)+946304|0,d);g=g+1|0;zb(d);continue}}}g=1}kb=f+384|0;return g|0}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=kb-48|0;kb=f;s=v[a+16>>2];u=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;o=v[a+128>>2];if(o){e=v[a+8>>2];k=v[a+12>>2];p=lg(e,k,o);q=nb;i=v[a+76>>2];Qf(v[a>>2],v[a+4>>2],lf(e,k,d),nb);k=i>>>0<nb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}l=v[a+40>>2];m=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;k=k-1|0;p=k?p:0;q=k?q:0;n=(((b&2147483647)<<1|e>>>31)&-2)+s|0;e=o;a:{b:while(1){c:{if((e|0)<=0){Rb(j,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(!h){break a}e=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Sd(j,(g|0)/8<<16>>16);Rd(j,4);Rb(f+40|0,p,q);e=e-1|0;continue b}else{g=(t[n+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[n+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Sd(j,(g|0)/8<<16>>16);Rd(j,h);v[j>>2]=v[j>>2];v[j+4>>2]=0}b=jg(j,u);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=v[r>>2];i=(f+16|0)+(b<<3)|0;G=v[i+8>>2];g=v[i+4>>2];v[i+8>>2]=g;n=e<<8;e=n;e=Oka(E,F,e,e>>31);h=nb;H=i;i=e;e=Yb(g,-16777216,16776704);e=Oka(C,D,e,e>>31);g=i+e|0;i=nb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Yb(G,-16777216,16776704);h=Oka(z,A,e,e>>31);g=h+g|0;e=nb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Yc(h,e,24);v[H+4>>2]=e-(n&y);v[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];m=v[a+28>>2]+m|0;v[c>>2]=v[c>>2]+B(v[f>>2],m>>12);l=b+l|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],l>>12);Rb(f+8|0,w,x);c=c+8|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=f+48|0}function bW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0;f=kb-32|0;kb=f;k=ug(f+24|0);p=k+3|0;q=k+5|0;r=k+4|0;s=k+2|0;x=k+1|0;d=f+16|0;z=d|5;A=d|3;while(1){a:{if(y[a+12>>2]>m>>>0){C=Df(v[a>>2],v[v[a+48>>2]+12>>2],m);b:while(1){if(!Qb(v[c>>2],v[c+8>>2],1)){break a}l=Me(c);if((l|0)==255){break a}d=l&31;g=B(d,6)+C|0;i=Qg(v[v[a+48>>2]+12>>2])>>>0>d>>>0;j=i?g:k;e=1;if(!(l&64)){d=Me(c);h=d<<24>>24;e=255;d=d&127;c:{d:{if((d|0)==1){break d}e=d-1|0;if(b?e>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}e=d+13|0}t[j|0]=e}E=i?g+1|0:x,F=Me(c),t[E|0]=F;e=(h|0)<0}h=i?g+3|0:p;d=i?g+5|0:q;n=i?g+4|0:r;i=i?g+2|0:s;while(1){e:{f:{g:{if(e&1){v[f+16>>2]=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);u[f+20>>1]=w[j+4|0]|w[j+5|0]<<8;o=Me(c);g=o&63;if(o&64){t[i|0]=1;t[n|0]=g;break e}e=Me(c);t[d|0]=e;if(g>>>0<=15){Pf(j,g,e);h:{i:{j:{e=w[h|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[h|0]=9;t[d|0]=B(w[d|0]&15,17);break f}t[h|0]=0;t[i|0]=1;v[f+12>>2]=w[d|0]+1>>>1;v[f+8>>2]=64;E=n,F=v[td(f+12|0,f+8|0)>>2],t[E|0]=F;break f}if((e|0)!=19){break f}if(w[d|0]==128){break g}Wu(j);break f}if(g>>>0>44){break f}t[h|0]=w[g+26208|0];k:{switch(g-16|0){case 0:if(e>>>0>1){break g}t[d|0]=e|158;break f;case 1:case 2:t[f+12|0]=15;E=d,F=w[Xb(f+12|0,d)|0]|224,t[E|0]=F;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=e+1;E=d,F=v[td(f+12|0,f+8|0)>>2]/2|240,t[E|0]=F;break f;case 14:l:{m:{n:{o:{p:{g=e>>>4|0;switch(g-1|0){case 1:break n;case 0:break o;default:break p}}switch(g-10|0){case 1:break l;case 0:break m;default:break g}}t[h|0]=2;t[d|0]=e|240;break f}t[h|0]=3;t[d|0]=e|240;break f}t[h|0]=11;t[d|0]=(e<<3&120)+8|15;break f}t[h|0]=11;t[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=e+1>>>1;v[f+8>>2]=64;E=d,F=v[td(f+12|0,f+8|0)>>2],t[E|0]=F;break f}if(!(l&128)){continue b}break a}t[h|0]=0}Vu(h,d,A,z);e=w[f+19|0];D=Ki(e);g=w[h|0];if(D>>>0<=Ki(g)>>>0){break e}if(!w[i|0]){Pq(f,g,w[d|0],1);g=w[f+1|0];t[i|0]=w[f|0];t[n|0]=g}t[h|0]=e;t[d|0]=w[f+21|0]}e=o>>>7|0;continue}}}kb=f+32|0;return}m=m+1|0;continue}}function tt(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=kb-16|0;kb=i;f=v[a+24>>2];h=lz(f,w[a+32|0]);j=v[h>>2];a:{if(Rc(j,v[h+4>>2])>>>0<=b>>>0){break a}if(EO(f,x[dc(j,b)>>1])>>>0<=c>>>0){break a}h=v[a>>2];b:{if(yd(h,v[a+4>>2])>>>0>b>>>0){if(y[Nd(h,b)+4>>2]>c>>>0){break b}}ao(a,0);if(yd(v[a>>2],v[a+4>>2])>>>0<=b>>>0){break a}f=v[a+24>>2]}gc(i,v[d>>2],x[f+480188>>1]);d=i+8|0;h=v[i>>2];f=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;j=v[i+4>>2];while(1){if(!g&(k|0)==(j|0)){v[d>>2]=f;v[d+4>>2]=e}else{l=w[uQ(h,k)+841|0];m=l^Oka(f^k,e^g,435,256);l=!l;f=(q=f,r=Oka(m,nb,435,256),s=l,s?q:r);e=l?e:nb;k=k+1|0;g=k?g:g+1|0;continue}break}e=d;d=0;f=ym(i,b,c);h=kb-16|0;kb=h;k=a+12|0;g=uO(x[f>>1],v[f+4>>2],Td(k),jc(k));c:{if(Pb(g,Zf(k))){j=x[f>>1];l=v[f+4>>2];f=wd(g);if(!ml(j,l,x[f>>1],v[f+4>>2])){break c}}g=Zf(k)}f=v[fc(h+8|0,g)>>2];kb=h+16|0;if(Ig(f,xf(k))){d=wd(f);d=pc(v[d+8>>2],v[d+12>>2])^1}h=v[e>>2]!=-2078137563|v[e+4>>2]!=-873292572;Db(i,v[Nd(v[a>>2],b)>>2],c);g=1;j=d|h;m=Cb(v[v[i>>2]>>2],v[i+4>>2])^1;if(!(m?1:j)){break a}d:{e:{f:{g:{if(d){l=wd(f);f=Fb(v[l+8>>2]);n=Fb(v[l+12>>2]);o=v[e>>2];p=v[e+4>>2];j=kb-16|0;kb=j;v[j+8>>2]=f;while(1){if(!(!Pb(f,n)|v[f>>2]==(o|0)&v[f+4>>2]==(p|0))){f=v[vt(j+8|0)>>2];continue}break}kb=j+16|0;if(Pb(f,Fb(v[l+12>>2]))){break a}if(!h){break e}break g}if(h){break g}if(!j){break d}break f}v[a+28>>2]=v[a+28>>2]+1}if(d|m){break e}d=sO(k,ym(i,b,c));h:{if(y[d+4>>2]<y[Gb(d)>>2]){g=kb-16|0;kb=g;d=rO(g,d);pO(v[d+4>>2]);v[d+4>>2]=v[d+4>>2]+8;lc(d);kb=g+16|0;break h}f=kb-32|0;kb=f;g=Gb(d);g=nr(f+8|0,or(d,Vg(v[d>>2],v[d+4>>2])+1|0),Vg(v[d>>2],v[d+4>>2]),g);pO(v[g+8>>2]);v[g+8>>2]=v[g+8>>2]+8;Ed(d,g);mr(g);kb=f+32|0}}d=sO(k,ym(i,b,c));i:{if(y[d+4>>2]<y[Gb(d)>>2]){g=kb-16|0;kb=g;d=rO(g,d);qO(v[d+4>>2],v[e>>2],v[e+4>>2]);v[d+4>>2]=v[d+4>>2]+8;lc(d);kb=g+16|0;break i}f=kb-32|0;kb=f;g=Gb(d);g=nr(f+8|0,or(d,Vg(v[d>>2],v[d+4>>2])+1|0),Vg(v[d>>2],v[d+4>>2]),g);qO(v[g+8>>2],v[e>>2],v[e+4>>2]);v[g+8>>2]=v[g+8>>2]+8;Ed(d,g);mr(g);kb=f+32|0}}Db(i,v[Nd(v[a>>2],b)>>2],c);Ze(i,1);g=0}kb=i+16|0;return g|0}function Ex(a){a=a|0;var b=0,c=0,d=C(0),e=0;Ub(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[23588]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}da(929,e|0,67,5,c|0,b|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[23588]=0;da(929,a+4528|0,62,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[23588]=0;da(929,a+4552|0,53,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[23588]=0;da(929,a+4576|0,43,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[23588]=0;da(929,a+4600|0,32,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[23588]=0;da(929,a+4624|0,22,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[23588]=0;da(929,a+4648|0,75,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[23588]=0;da(929,a+4672|0,69,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[23588]=0;da(929,a+4696|0,60,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[23588]=0;da(929,a+4720|0,48,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[23588]=0;da(929,a+4744|0,36,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[23588]=0;da(929,a+4768|0,25,5,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;da(929,a+4792|0,0,0,0,0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[23588]=0;da(929,a+4816|0,3,0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[23588]=0;da(929,a+4840|0,3,0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;da(929,a+4864|0,407,1,c|0,0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;da(929,a+4888|0,400,1,c|0,0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;da(929,a+4912|0,10,0,c|0,-1);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;da(929,a+4936|0,10,0,c|0,-1);c=v[23588];v[23588]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(92948)|0;if((O()|0)==(ea(92948)|0)){_(c|0)|0;t[a+5045|0]=0;$();return}T(c|0);L()}function Tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-128|0;kb=d;a:{b:{c:{d:{switch(w[a|0]-23|0){case 0:e=t[a+1|0];f=d,g=aB(c,+w[a+2|0]*1e4/240),t[f|0]=g;v[d+96>>2]=127;v[d+80>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[td(d+96|0,d+80|0)>>2],t[f+127|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:Ku(d+80|0,15572);v[23588]=0;R(544,d- -64|0,d|0);a=v[23588];v[23588]=0;f:{g:{h:{i:{if((a|0)!=1){v[23588]=0;R(544,d+48|0,d+127|0);a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;X(545,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}a=d+96|0;Ge(d+112|0,a);hf(b,v[d+112>>2],v[d+116>>2]);zb(a);zb(d+48|0);zb(d- -64|0);$b(d+80|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(d+48|0)}zb(d- -64|0)}break c;case 1:Ku(d+80|0,15512);v[23588]=0;R(544,d- -64|0,d|0);a=v[23588];v[23588]=0;j:{k:{l:{m:{if((a|0)!=1){v[23588]=0;R(544,d+48|0,d+127|0);a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;X(545,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break l}a=d+96|0;Ge(d+40|0,a);hf(b,v[d+40>>2],v[d+44>>2]);zb(a);zb(d+48|0);zb(d- -64|0);$b(d+80|0);break b}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;zb(d+48|0)}zb(d- -64|0)}break c;default:break e}}a=rc(d+32|0,15599);hf(b,v[a>>2],v[a+4>>2]);break b;case 1:break d;default:break a}}c=t[a+1|0];t[d+127|0]=(c|0)<5?c:0;c=t[a+2|0];t[d+31|0]=(c|0)>=0?c:127;a=t[a+3|0];t[d+30|0]=(a|0)>=0?a:127;a=kb-16|0;kb=a;c=Nc(a,4051);ad(d+80|0,c);zb(c);kb=a+16|0;v[23588]=0;R(544,d- -64|0,d+127|0);a=v[23588];v[23588]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){v[23588]=0;R(544,d+48|0,d+31|0);a=v[23588];v[23588]=0;if((a|0)==1){break s}v[23588]=0;R(544,d|0,d+30|0);a=v[23588];v[23588]=0;if((a|0)==1){break r}v[23588]=0;da(710,d+96|0,d+80|0,d- -64|0,d+48|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}a=d+96|0;Ge(d+16|0,a);hf(b,v[d+16>>2],v[d+20>>2]);zb(a);zb(d);zb(d+48|0);zb(d- -64|0);$b(d+80|0);break b}a=P()|0;O()|0;break n}a=P()|0;O()|0;break o}a=P()|0;O()|0;break p}a=P()|0;O()|0;zb(d)}zb(d+48|0)}zb(d- -64|0)}}$b(d+80|0);T(a|0);L()}e=1}kb=d+128|0;return e|0}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=kb-48|0;kb=f;s=v[a+16>>2];t=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;o=v[a+128>>2];if(o){e=v[a+8>>2];j=v[a+12>>2];p=lg(e,j,o);q=nb;g=v[a+76>>2];Qf(v[a>>2],v[a+4>>2],lf(e,j,d),nb);j=g>>>0<nb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;j=j-1|0;p=j?p:0;q=j?q:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+s|0;b=o;while(1)if((b|0)<=0){Rb(i,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(h){b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Sd(i,(u[(b<<1|2)+l>>1]+u[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(i,h);v[i>>2]=v[i>>2];v[i+4>>2]=0}b=jg(i,t);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=v[r>>2];g=(f+16|0)+(b<<3)|0;G=v[g+8>>2];k=v[g+4>>2];v[g+8>>2]=k;l=e<<8;e=l;e=Oka(E,F,e,e>>31);h=nb;H=g;g=e;e=Yb(k,-16777216,16776704);e=Oka(C,D,e,e>>31);k=g+e|0;g=nb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Yb(G,-16777216,16776704);h=Oka(z,A,e,e>>31);k=h+k|0;e=nb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Yc(h,e,24);v[H+4>>2]=e-(l&y);v[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];n=v[a+28>>2]+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],n>>12);m=b+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],m>>12);Rb(f+8|0,w,x);c=c+8|0;continue a}else{e=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Sd(i,(u[(e<<1|2)+l>>1]+u[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(i,4);Rb(f+40|0,p,q);b=b-1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=f+48|0}function w8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=C(0),A=0,B=0,E=0,F=0,G=0,H=0,I=C(0),J=0,K=0,L=0,M=0,N=0,O=C(0),P=0,Q=C(0);a:{if(!v[a+4316>>2]){break a}if(!ai(a+44|0)){break a}G=a+4300|0;H=a+4288|0;J=a+4264|0;K=a+4276|0;e=v[a+44>>2];s=Kc(e,0);t=Kc(e,1);e=v[a+56>>2];u=Kc(e,0);x=Kc(e,1);L=ob[v[v[a>>2]+196>>2]](a)|0;y=C(C(ob[v[v[a>>2]+204>>2]](a))/C(100));I=C(ob[v[v[a>>2]+192>>2]](a));A=ob[v[v[a>>2]+216>>2]](a)|0;M=A&1;o=v[a+4324>>2];i=v[a+4320>>2];m=v[a+4328>>2];k=v[a+4312>>2];N=v[a+4276>>2];p=v[a+4264>>2];B=v[a+4256>>2];E=w[a+4260|0];r=a+4316|0;F=d;while(1){if(F){h=z[t>>2];l=z[s>>2];j=v[r>>2];e=Mn(j,k+B|0);j=Mn(j,k);b:{if(E){P=Eb(H,m),Q=l,z[P>>2]=Q;P=Eb(G,m),Q=h,z[P>>2]=Q;q=Eb(p,e);P=Eb(p,j),Q=C(C(z[q>>2]*y)+l),z[P>>2]=Q;g=C(C(z[Eb(N,e)>>2]*y)+h);e=K;break b}g=C(C(z[Eb(p,e)>>2]*y)+C(C(l+h)*C(.5)));e=J}P=Eb(v[e>>2],j),Q=g,z[P>>2]=Q;c:{if(L){f=z[a+4244>>2];g=C(f+z[a+4236>>2]);z[a+4236>>2]=g;f=C(f+z[a+4240>>2]);z[a+4240>>2]=f;if(g>C(1)){g=C(g+C(-2));z[a+4236>>2]=g}if(f>C(1)){f=C(f+C(-2));z[a+4240>>2]=f}g=C(D(g));g=C(C(g+g)+C(-1));f=C(D(f));f=C(C(f+f)+C(-1));break c}f=z[a+4240>>2];n=z[a+4244>>2];g=C(C(f*n)+z[a+4236>>2]);z[a+4236>>2]=g;f=C(f-C(g*n));z[a+4240>>2]=f}if(E){e=(m+2|0)%3|0;l=z[Eb(H,e)>>2];h=z[Eb(G,e)>>2]}e=v[r>>2];j=Eb(p,Mn(e,i+k|0));q=e;e=k+4096|0;O=z[Eb(p,Mn(q,e+i|0))>>2];n=z[j>>2];z[u>>2]=C(C(C(C(C(O-n)*C(C(i&4095)*C(.000244140625)))+n)-l)*I)+l;i=v[(E?4276:4264)+a>>2];j=v[r>>2];q=Eb(i,Mn(j,k+o|0));n=z[Eb(i,Mn(j,e+o|0))>>2];l=z[q>>2];z[x>>2]=C(C(C(C(C(n-l)*C(C(o&4095)*C(.000244140625)))+l)-h)*I)+h;m=((m|0)<=0?m+3|0:m)-1|0;v[a+4328>>2]=m;k=(((k|0)>0?0:v[r>>2]<<12)+k|0)-4096|0;v[a+4312>>2]=k;h=M?f:g;f=z[a+4248>>2];h=C(h*f);d:{if(C(D(h))<C(2147483648)){e=~~h;break d}e=-2147483648}o=(A>>>0>1?e:0-e|0)+B|0;v[a+4324>>2]=o;i=A>>>0<4;t=t+4|0;s=s+4|0;g=C(g*f);e:{if(C(D(g))<C(2147483648)){e=~~g;break e}e=-2147483648}i=(i?e:0-e|0)+B|0;v[a+4320>>2]=i;F=F-1|0;x=x+4|0;u=u+4|0;continue}else{e=a;a=v[a+56>>2];si(e,b,c,Kc(a,0),Kc(a,1),d)}break}}}function e7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=C(0),n=0,o=C(0),p=C(0),q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,A=C(0),B=0,D=0,E=0,F=0,G=C(0),H=0,I=0,J=0,K=0,L=C(0),M=C(0),N=C(0),O=C(0),P=C(0),Q=0,R=C(0);if(ai(a+44|0)){f=v[a+44>>2];B=Kc(f,0);D=Kc(f,1);f=v[a+56>>2];E=Kc(f,0);F=Kc(f,1);s=v[a+4296>>2];g=s+1|0;l=a+4304|0;f=a+4272|0;u=g+v[Eb(f,0)>>2]&4095;q=l+(u<<4)|0;w=g+v[Eb(f,1)>>2]&4095;n=((w<<4)+l|0)+4|0;x=g+v[Eb(f,2)>>2]&4095;j=((x<<4)+l|0)+8|0;h=Eb(f,3);i=v[Eb(f,4)>>2];r=v[a+4300>>2];i=i+r|0;y=g+v[h>>2]&4095;h=((y<<4)+l|0)+12|0;t=v[Eb(f,5)>>2]+r|0;g=a+4232|0;H=a+69840|0;I=a+78032|0;f=d;while(1){if(f){L=z[h>>2];M=z[j>>2];N=z[n>>2];O=z[q>>2];A=z[D>>2];P=z[B>>2];J=i&1023;j=(J<<3)+H|0;k=z[j+4>>2];u=u-1&4095;q=(u<<4)+l|0;e=z[q>>2];h=r<<3;i=h+H|0;w=w-1&4095;n=(w<<4)+l|0;m=z[n+4>>2];o=m;p=C(m*C(.6180340051651001));G=z[j>>2];m=z[Eb(g,0)>>2];p=C(p+C(G*m));z[i+4>>2]=o+C(p*C(-.6180340051651001));o=e;e=C(C(k*m)+C(e*C(-.6180340051651001)));z[i>>2]=o+C(e*C(.6180340051651001));z[q>>2]=p;z[n+4>>2]=e;t=t&1023;K=(t<<3)+I|0;m=z[K+4>>2];x=x-1&4095;i=(x<<4)+l|0;e=z[i+8>>2];h=h+I|0;y=y-1&4095;j=(y<<4)+l|0;k=z[j+12>>2];o=k;G=z[K>>2];p=z[Eb(g,1)>>2];k=C(C(k*C(.6180340051651001))+C(G*p));z[h+4>>2]=o+C(k*C(-.6180340051651001));o=e;e=C(C(m*p)+C(e*C(-.6180340051651001)));z[h>>2]=o+C(e*C(.6180340051651001));z[i+8>>2]=k;z[j+12>>2]=e;e=C(P+C(1.0000000031710769e-30));z[E>>2]=k+C(C(e*z[a+4224>>2])+z[q>>2]);k=C(A+C(1.0000000031710769e-30));z[F>>2]=C(C(k*z[a+4224>>2])+z[n+4>>2])+z[j+12>>2];h=(s<<4)+l|0;m=e;e=z[a+4228>>2];A=C(m*e);Q=h,R=C(A+C(C(z[q>>2]*z[Eb(g,2)>>2])+C(O*z[Eb(g,3)>>2]))),z[Q>>2]=R;e=C(k*e);Q=h,R=C(e+C(C(z[n+4>>2]*z[Eb(g,4)>>2])+C(N*z[Eb(g,5)>>2]))),z[Q+4>>2]=R;Q=h,R=C(C(C(z[i+8>>2]*z[Eb(g,6)>>2])+C(M*z[Eb(g,7)>>2]))-e),z[Q+8>>2]=R;Q=h,R=C(A+C(C(z[j+12>>2]*z[Eb(g,8)>>2])+C(L*z[Eb(g,9)>>2]))),z[Q+12>>2]=R;h=j+12|0;j=i+8|0;n=n+4|0;f=f-1|0;F=F+4|0;E=E+4|0;D=D+4|0;B=B+4|0;t=t-1|0;i=J-1|0;r=r-1&1023;s=s-1&4095;continue}else{v[a+4300>>2]=r;v[a+4296>>2]=s;f=a;a=v[a+56>>2];si(f,b,c,Kc(a,0),Kc(a,1),d)}break}}}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=kb-48|0;kb=f;q=v[a+16>>2];r=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;m=v[a+128>>2];if(m){e=v[a+8>>2];k=v[a+12>>2];n=lg(e,k,m);o=nb;i=v[a+76>>2];Qf(v[a>>2],v[a+4>>2],lf(e,k,d),nb);k=i>>>0<nb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];u=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;k=k-1|0;n=k?n:0;o=k?o:0;l=(((b&2147483647)<<1|e>>>31)&-2)+q|0;e=m;a:{b:while(1){c:{if((e|0)<=0){Rb(j,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(!h){break a}e=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Sd(j,(g|0)/8<<16>>16);Rd(j,4);Rb(f+40|0,n,o);e=e-1|0;continue b}else{g=(t[l+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[l+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Sd(j,(g|0)/8<<16>>16);Rd(j,h);v[j>>2]=v[j>>2];v[j+4>>2]=0}b=jg(j,r);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];i=(f+16|0)+(b<<3)|0;G=v[i+8>>2];g=v[i+4>>2];v[i+8>>2]=g;l=e<<8;e=l;e=Oka(E,F,e,e>>31);h=nb;H=i;i=e;e=Yb(g,-16777216,16776704);e=Oka(C,D,e,e>>31);g=i+e|0;i=nb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Yb(G,-16777216,16776704);h=Oka(z,A,e,e>>31);g=h+g|0;e=nb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Yc(h,e,24);v[H+4>>2]=e-(l&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],u);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],s);Rb(f+8|0,w,x);c=c+8|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=f+48|0}function vP(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=kb-128|0;kb=j;a:{b:{c:{if(!Hm(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}Jd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];HP(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((Hm(b,c,l,p,f,g,h,k)|0)<=0){if(Hm(b,c,l,p,f,g,m,k)){h=b;i=c;break a}Jd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Jd(j+96|0,b,c,l,p,0,0,0,1081540608);h=v[j+108>>2];p=h;l=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Jd(j+80|0,f,g,m,k,0,0,0,1081540608);f=v[j+92>>2];k=f;m=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){Jd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}Jd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Jd(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;kb=j+128|0}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=kb-16|0;kb=h;c=rf(a,c);ne(h,v[a+36>>2]);j=a;a:{if(!c){Sc(h,a+32|0,5);e=0;if(Cb(v[v[h>>2]>>2],v[h+4>>2])){break a}}e=kb-240|0;kb=e;g=_l(e+128|0,v[a+36>>2]);v[23588]=0;f=Q(449,e+112|0,27800)|0;a=v[23588];v[23588]=0;b:{c:{d:{e:{if((a|0)!=1){v[23588]=0;v[e+96>>2]=19988498;v[e+100>>2]=0;U(450,g|0,f|0,e+96|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}$b(f);if(!Lk(w[g|0])){break d}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;$b(f);break c}t[e+111|0]=0;v[23588]=0;f=Q(449,e+96|0,5508)|0;a=v[23588];v[23588]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23588]=0;U(451,g|0,e+111|0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break q}$b(f);f=Mb(e+80|0);v[23588]=0;a=Q(449,e- -64|0,10044)|0;i=v[23588];v[23588]=0;if((i|0)==1){break p}v[23588]=0;U(755,g|0,f|0,a|0);i=v[23588];v[23588]=0;if((i|0)==1){break o}$b(a);v[23588]=0;U(11,e+48|0,(w[e+111|0]?0:d)|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break n}v[23588]=0;R(273,b|0,e+48|0);d=v[23588];v[23588]=0;if((d|0)==1){break m}d=e+48|0;Ab(d);u[e+46>>1]=0;v[23588]=0;d=Q(449,d|0,10704)|0;a=v[23588];v[23588]=0;if((a|0)==1){break g}v[23588]=0;W(479,g|0,e+46|0,d|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break l}$b(d);Ff(e+46|0,4e3);v[23588]=0;d=Q(449,e+32|0,13325)|0;a=v[23588];v[23588]=0;if((a|0)==1){break k}i=x[e+46>>1];a=v[fc(e+24|0,i)>>2];v[23588]=0;X(756,g|0,b|0,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}$b(d);u[e+22>>1]=65535;v[23588]=0;d=Q(449,e+8|0,8924)|0;a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;k=W(479,g|0,e+22|0,d|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break h}a=x[e+22>>1];$b(d);if(a>>>0<i>>>0&k){Ve(b,a)}zb(f);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;$b(f);break c}b=P()|0;O()|0;break f}b=P()|0;O()|0;$b(a);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;Ab(e+48|0);break f}b=P()|0;O()|0;$b(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;$b(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;$b(d);break f}b=P()|0;O()|0}zb(f)}lh(g);T(b|0);L()}lh(g);kb=e+240|0;e=c}Ye(j,e);kb=h+16|0}function Xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=kb-48|0;kb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;t=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;w=v[a+32>>2];x=v[a+28>>2];y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;while(1){if(d){b=v[e+16>>2];G=((((v[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+s|0;H=u[b+14>>1];g=u[b+12>>1];q=u[b+10>>1];r=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=G+(p<<1)|0;v[(e+8|0)+(p<<2)>>2]=(((((((B(u[i-8>>1],f)+B(u[i-12>>1],b)|0)+B(u[i-4>>1],k)|0)+B(u[i>>1],h)|0)+B(u[i+4>>1],r)|0)+B(u[i+8>>1],q)|0)+B(g,u[i+12>>1])|0)+B(H,u[i+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=v[q>>2];g=(e+24|0)+(o<<3)|0;r=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Oka(E,F,b,b>>31);f=nb;i=g;g=b;b=Yb(h,-16777216,16776704);b=Oka(C,D,b,b>>31);h=g+b|0;g=nb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Yb(r,-16777216,16776704);f=Oka(z,A,b,b>>31);h=f+h|0;b=nb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Yc(f,b,24);v[i+4>>2]=b-(k&y);v[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+x|0;v[c>>2]=v[c>>2]+B(v[e+8>>2],n>>12);m=m+w|0;v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],m>>12);Rb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=e+48|0}function oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0),h=0,i=C(0);d=kb-112|0;kb=d;c=kb-16|0;kb=c;e=b+16|0;aT(c+8|0,e);f=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);h=v[c+4>>2];if((h|0)==(f|0)){_b(a,v[c+12>>2])}kb=c+16|0;if((f|0)!=(h|0)){Ub(e,0,128)}t[b+79|0]=0;t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;c=d- -64|0;ae(c,a,Cg(a));f=kc(d+88|0,c);Bb(c);v[23588]=0;c=S(202,f|0)|0;e=v[23588];v[23588]=0;a:{b:{if((e|0)==1){break b}v[23588]=0;R(285,b+4|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}se(d+56|0,v[b+4>>2],v[b+8>>2]);v[23588]=0;Ok(459,d- -64|0,f,v[d+56>>2],v[d+60>>2]);c=v[23588];v[23588]=0;if((c|0)!=1){v[23588]=0;c=S(157,a|0)|0;e=v[23588];v[23588]=0;c:{if((e|0)==1){break c}v[23588]=0;U(190,d+32|0,a|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=d+32|0;c=kc(d- -64|0,a);Bb(a);a=v[c>>2];v[23588]=0;a=S(178,a|0)|0;e=v[23588];v[23588]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{a=v[c+8>>2];e=v[c>>2];v[23588]=0;a=W(156,e|0,a|0,5)|0;e=v[23588];v[23588]=0;if((e|0)==1){break e}if(!a){break f}v[23588]=0;Q(460,c|0,d+28|0)|0;a=v[23588];v[23588]=0;h:{if((a|0)!=1){a=4;if(!Sb(d+28|0,13510,4)){break h}if(!Sb(d+28|0,14071,4)){break h}v[23588]=0;a=S(157,c|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[23588]=0;U(190,d+8|0,c|0,a|0);a=v[23588];v[23588]=0;i:{j:{k:{if((a|0)!=1){a=d+8|0;e=kc(d+32|0,a);Bb(a);if(Sb(d+28|0,13510,4)){break k}v[23588]=0;g=C(Ca(461,e|0));a=v[23588];v[23588]=0;if((a|0)==1){break g}z[d+8>>2]=g;v[d+4>>2]=0;v[d>>2]=1065353216;g=z[lq(d+8|0,d+4|0,d)>>2];z[b+144>>2]=g;i=C(D(g));if((i<C(11754943508222875e-54)^-1)&(!(i>=C(N))&g==g)){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if(Sb(d+28|0,14071,4)){break j}v[23588]=0;a=S(157,e|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break i}v[b+148>>2]=a}Bb(e);continue}}break}a=P()|0;O()|0;Bb(e);break d}Bb(c);Bb(f);kb=d+112|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}Bb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Bb(f);T(a|0);L()}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=kb-48|0;kb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;w=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;x=v[a+32>>2];y=v[a+28>>2];z=v[a+72>>2];b=v[a+68>>2];A=b;C=b>>31;b=v[a+64>>2];D=b;E=b>>31;b=v[a+60>>2];F=b;G=b>>31;while(1){if(d){b=v[e+16>>2];H=(((v[e+20>>2]&2147483647)<<1|b>>>31)&-2)+w|0;b=(b>>>16&65520)+s|0;I=u[b+14>>1];g=u[b+12>>1];q=u[b+10>>1];r=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=p+H|0;v[(e+8|0)+(p<<2)>>2]=(((((((B(t[i-4|0],f)+B(t[i-6|0],b)|0)+B(t[i-2|0],k)|0)+B(t[i|0],h)|0)+B(t[i+2|0],r)|0)+B(t[i+4|0],q)|0)+B(g,t[i+6|0])|0)+B(I,t[i+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=v[q>>2];g=(e+24|0)+(o<<3)|0;r=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Oka(F,G,b,b>>31);f=nb;i=g;g=b;b=Yb(h,-16777216,16776704);b=Oka(D,E,b,b>>31);h=g+b|0;g=nb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Yb(r,-16777216,16776704);f=Oka(A,C,b,b>>31);h=f+h|0;b=nb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Yc(f,b,24);v[i+4>>2]=b-(k&z);v[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+y|0;v[c>>2]=v[c>>2]+B(v[e+8>>2],n>>12);m=m+x|0;v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],m>>12);Rb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=e+48|0}function o6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=kb-96|0;kb=j;a:{b:{c:{k=yp(1,32);d:{e:{if(!k){a=nm(ba(4)|0);v[23588]=0;U(119,a|0,92948,26);a=v[23588];v[23588]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:933;c=Yf(j+80|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[23588]=0;d=Q(55,j- -64|0,d|0)|0;f=v[23588];v[23588]=0;j:{if((f|0)!=1){v[23588]=0;f=Q(944,c|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break j}v[23588]=0;R(270,f|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;zb(d);break f}v[23588]=0;d=Q(55,j+48|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}Ls(c,d)}zb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23588]=0;a=S(812,104)|0;i=v[23588];v[23588]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[23588]=0;b=Q(945,d|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}v[j+16>>2]=b;b=v[eg(j+24|0,j+16|0)>>2];d=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=d;v[23588]=0;d=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=d;b=fa(975,a|0,j|0,b|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break k}i=V(0)|0;O()|0;Ee(j+16|0);break l}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0}Nb(a);break f}v[k+28>>2]=b;Ee(j+16|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;ll(c);break d}i=V(0)|0;O()|0}ll(c);_(i|0)|0;v[23588]=0;X(939,11260,k|0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){a=v[k+28>>2];if(a){ob[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Nb(a);v[k+20>>2]=0}Nb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;v[23588]=0;X(939,11260,0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}$()}kb=j+96|0;return k|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}V(0)|0;O()|0;Vb()}L()}function C6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-80|0;kb=e;v[e+76>>2]=c;v[e+72>>2]=b;a:{if(!c){break a}g=w[dl(b,c)|0];if((g|0)==33){d=1}else{if((g|0)!=63){break a}d=0}kl(e+48|0,b,c,c-1|0);b=v[e+52>>2];v[e+72>>2]=v[e+48>>2];v[e+76>>2]=b}c=e+48|0;Xd(c);b=v[e+48>>2];Xd(e+32|0);b=cl(b,v[e+36>>2],e+72|0);Xd(c);b:{c:{d:{e:{if((b|0)==v[e+52>>2]){b=v[e+72>>2];c=v[e+76>>2];a=rc(e- -64|0,21619);if(Qc(b,c,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23588]=0;b=Q(55,e+48|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}f=0;if(!d){break e}a=ba(8)|0;v[23588]=0;b=Lh(e+32|0,v[e+72>>2],v[e+76>>2]);c=v[23588];v[23588]=0;f:{g:{h:{if((c|0)!=1){v[23588]=0;U(967,e+48|0,17634,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break h}d=0;c=sc(a,e+48|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(e+48|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}zb(b);if(!d){break c}}ca(a|0);break c}if(v[b+4>>2]!=2){a=ba(8)|0;v[23588]=0;b=Q(55,e+48|0,11504)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;ca(a|0);break c}b=v[e+72>>2];c=v[e+76>>2];d=rc(e+24|0,21619);if(Qc(b,c,v[d>>2],v[d+4>>2])){a=ba(8)|0;v[23588]=0;b=Q(55,e+48|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=rc(e+16|0,7719);if(Qc(b,c,v[d>>2],v[d+4>>2])){f=1;if(!Qd(w[a+28|0])){break e}f=65536/+y[v[a+24>>2]+480244>>2];break e}d=rc(e+8|0,7771);if(Qc(b,c,v[d>>2],v[d+4>>2])){f=1;if(!Qd(w[a+28|0])){break e}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}d=b;b=rc(e,7789);f=0;if(!Qc(d,c,v[b>>2],v[b+4>>2])){break e}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}kb=e+80|0;return+f}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}function LO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=kb-176|0;kb=c;i=1;p=2;d=v[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;w=B(i,3);x=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=v[a+12>>2];continue a}d=v[a>>2];e=Kd(d,h<<1);hM(c+160|0,A[e>>3],A[e+8>>3]);d=Kd(d,h);hM(c+144|0,A[d>>3],A[d+8>>3]);vi(c+128|0,A[c+144>>3],A[c+152>>3],A[c+160>>3],A[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=v[b>>2];e=Kd(f,d);g=e+8|0;j=v[g+4>>2];v[c+120>>2]=v[g>>2];v[c+124>>2]=j;g=v[e+4>>2];v[c+112>>2]=v[e>>2];v[c+116>>2]=g;k=d+i|0;g=Kd(f,k);n=A[g+8>>3];o=A[g>>3];r=d+x|0;g=Kd(f,r);j=v[g+12>>2];v[c+104>>2]=v[g+8>>2];v[c+108>>2]=j;j=v[g+4>>2];v[c+96>>2]=v[g>>2];v[c+100>>2]=j;s=d+w|0;f=Kd(f,s);t=A[f+8>>3];u=A[f>>3];g=c+80|0;f=c+112|0;gl(g,f,o,n);j=c- -64|0;nj(j,f,o,n);l=c+96|0;gl(c+48|0,l,u,t);f=c+16|0;nj(f,l,u,t);vi(c+32|0,0,1,A[c+16>>3],A[c+24>>3]);gl(f,g,A[c+48>>3],A[c+56>>3]);l=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=l;l=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=l;gl(c,j,A[c+32>>3],A[c+40>>3]);vi(f,A[c+160>>3],A[c+168>>3],A[c>>3],A[c+8>>3]);e=Kd(v[b>>2],k);k=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=k;k=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=k;nj(c,g,A[c+48>>3],A[c+56>>3]);vi(f,A[c+144>>3],A[c+152>>3],A[c>>3],A[c+8>>3]);e=Kd(v[b>>2],r);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;nj(c,j,A[c+32>>3],A[c+40>>3]);vi(f,A[c+128>>3],A[c+136>>3],A[c>>3],A[c+8>>3]);e=Kd(v[b>>2],s);f=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=f;f=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=v[b>>2];a=Kd(h,d+i|0);m=Kd(h,d);n=A[a>>3];o=A[a+8>>3];nj(c+160|0,m,n,o);h=v[c+172>>2];v[a+8>>2]=v[c+168>>2];v[a+12>>2]=h;h=v[c+164>>2];v[a>>2]=v[c+160>>2];v[a+4>>2]=h;cy(Kd(v[b>>2],d),n,o);d=d+1|0;continue}}kb=c+176|0}function lt(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=kb-16|0;kb=f;e=B(c,872)+b|0;h=e+704|0;v[h>>2]=v[h>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){Db(f+8|0,a+1074312|0,15);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break b}}if(v[a+480180>>2]!=268435456){break a}}g=B(c,872)+b|0;d=d?d:w[(B(c,872)+b|0)+1427|0];t[g+1427|0]=d;t[g+1428|0]=d}if(d){u[(B(c,872)+b|0)+1384>>1]=d}c:{d:{g=e+616|0;j=v[g+656>>2];if(wj(j)){a=x[(B(c,872)+b|0)+1384>>1];if(!a){break d}e=0;d=v[b+16>>2];e=d?v[(B(c,872)+b|0)+1472>>2]:e;k=0-a|0;l=a;i=B(c,872)+b|0;g=i+1324|0;a=v[g>>2];m=(+(d>>>0)+1)*+(((a|0)<0?k:l)|0)/+y[b+40>>2];e:{if(D(m)<2147483648){d=~~m;break e}d=-2147483648}i=i+1472|0;v[i>>2]=d;if(w[h+2|0]&16){d=B(v[v[j+44>>2]+36>>2]+1|0,d);v[i>>2]=d}d=d-e|0;h=d>>31;e=a>>31;if((e^a)-e>>>0<=(d^h)-h>>>0){if(!a){break d}b=B(c,872)+b|0;c=b+1468|0;v[c>>2]=a+v[c>>2];v[g>>2]=0;a=b+1467|0;t[a|0]=w[a|0]|64;a=0;break c}b=B(c,872)+b|0;c=b+1468|0;v[c>>2]=d+v[c>>2];v[g>>2]=a-d;a=b+1467|0;t[a|0]=w[a|0]|64;break d}h=1;j=B(c,872)+b|0;e=j+1467|0;f:{if(!(t[e|0]&1)){break f}d=v[a+480180>>2];if(d&524352){break f}if(v[b+40>>2]==1){Db(f+8|0,a+1074312|0,6);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break f}d=v[a+480180>>2]}h=0;if((d|0)!=8){break f}h=(w[a+480208|0]&2)>>>1|0}i=v[a+480180>>2];d=x[j+1384>>1];if(!((i|0)!=268435456|d>>>0<240)){h=t[e|0]&1;d=d-240|0}d=B((i|0)==64?2:4,d);j=B(c,872)+b|0;b=j+1316|0;g:{if(!v[b>>2]){break g}c=j+1324|0;if(!v[c>>2]|!h){break g}i=oj(a)?d:0-d|0;l=v[b>>2];k=v[c>>2];if(!(w[e|0]&16?0:(l|0)>=(k|0))){gk(a,g,b,i,1);c=v[c>>2];if((c|0)>=v[b>>2]){break g}v[b>>2]=c;break g}if((l|0)<=(k|0)){break g}gk(a,g,b,0-i|0,1);g=v[b>>2];c=v[c>>2];h:{if((g|0)<(c|0)){v[b>>2]=c;break h}if((c|0)!=(g|0)){break g}}Db(f+8|0,a+1074312|0,112);if(!Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break g}t[e|0]=w[e|0]|16}c=v[b>>2];b=j+1324|0;i:{if((c|0)!=v[b>>2]){break i}Db(f+8|0,a+1074312|0,25);if(!Cb(v[v[f+8>>2]>>2],v[f+12>>2])&v[a+480180>>2]!=1){break i}v[b>>2]=0}a=h?d:0;break c}a=0}kb=f+16|0;return a}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=kb-48|0;kb=f;q=v[a+16>>2];r=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;m=v[a+128>>2];if(m){e=v[a+8>>2];j=v[a+12>>2];n=lg(e,j,m);o=nb;g=v[a+76>>2];Qf(v[a>>2],v[a+4>>2],lf(e,j,d),nb);j=g>>>0<nb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];t=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;j=j-1|0;n=j?n:0;o=j?o:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=m;while(1)if((b|0)<=0){Rb(i,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(h){b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Sd(i,(u[(b<<1|2)+l>>1]+u[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(i,h);v[i>>2]=v[i>>2];v[i+4>>2]=0}b=jg(i,r);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];g=(f+16|0)+(b<<3)|0;G=v[g+8>>2];k=v[g+4>>2];v[g+8>>2]=k;l=e<<8;e=l;e=Oka(E,F,e,e>>31);h=nb;H=g;g=e;e=Yb(k,-16777216,16776704);e=Oka(C,D,e,e>>31);k=g+e|0;g=nb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Yb(G,-16777216,16776704);h=Oka(z,A,e,e>>31);k=h+k|0;e=nb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Yc(h,e,24);v[H+4>>2]=e-(l&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],t);v[c+4>>2]=v[c+4>>2]+B(s,v[f+4>>2]);Rb(f+8|0,w,x);c=c+8|0;continue a}else{e=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Sd(i,(u[(e<<1|2)+l>>1]+u[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(i,4);Rb(f+40|0,n,o);b=b-1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=f+48|0}function Ae(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=kb-16|0;kb=h;e=v[a>>2];a:{if(pc(e,v[a+4>>2])){break a}g=v[b+4>>2];if(g>>>0>=y[a+12>>2]){break a}c=x[b+8>>1];i=v[v[a+48>>2]+12>>2];f=Qg(i);if(c>>>0>=f>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?f-1|0:c;f=g;g=d?0:c;c=jd(e,i,f,g);f=w[b+12|0];j=f&4;b:{c:{if(f&2){break c}k=w[b+10|0];e=c;d=g;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((k|0)!=w[e+3|0]){break d}break b}if((k|0)==w[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}k=l&65535;d=c;e=g;while(1){if(k>>>0>=(e&65535)>>>0){e:{if(!j){if(w[d+3|0]){break e}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break b}if(w[d+2|0]){break e}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(f&1)){break f}d=v[i+480180>>2]&2;g:{h:{i:{if(!j){while(1){if((g&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(w[c+3|0]-9|0){case 4:if(!hU(v[v[i+8>>2]+88>>2])){break j}d=1;t[c+2|0]=1;t[c+4|0]=w[c+5|0];t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){e=w[c+5|0];if(e>>>0>128){break j}t[c+2|0]=2;t[c+3|0]=w[b+10|0];a=1;break l}t[c+2|0]=2;t[c+3|0]=w[b+10|0];e=w[c+5|0];a=2}t[c+4|0]=a+e>>>a;t[c+5|0]=w[b+11|0];break b}c=c+6|0;g=g+1|0;continue}break}if(!j){break i}}e=w[b+11|0];g=13;m:{switch(w[b+10|0]-1|0){case 1:g=9;e=Ml(B(d?2:4,e));break;case 0:break m;default:break g}}t[b+11|0]=e;t[b+10|0]=g;f=f&254;break h}t[h+15|0]=0;t[h+14|0]=0;g=b;c=!d;d=w[b+10|0];n:{if(!(c|(d|0)!=9)){e=w[b+11|0];if(e>>>0>128){break g}d=2;c=e>>>1|0;break n}e=h+8|0;Pq(e,d,w[b+11|0],1);qB(h,h+15|0,h+14|0);pB(h,e);d=w[h+15|0];if(!d){f=w[b+12|0];break g}f=w[b+12|0];c=w[h+14|0]}t[g+11|0]=c;t[b+10|0]=d;f=f&254}t[b+12|0]=f}d=1;if(f&1){break f}t[b+12|0]=f^4;if(Ae(a,b)){break a}}d=0;o:{p:{switch(v[b>>2]-1|0){case 0:c=v[b+4>>2]+1|0;if(c>>>0>=y[a+12>>2]){break a}v[b+4>>2]=c;break o;case 1:break p;default:break a}}c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1}t[b+12|0]=w[b+12|0]|1;d=Ae(a,b);break a}d=1}kb=h+16|0;return d}function pK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=kb-96|0;kb=j;a:{b:{c:{d:{e:{f:{k=yp(1,28);if(!k){a=nm(ba(4)|0);v[23588]=0;U(119,a|0,92948,26);a=v[23588];v[23588]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:933;c=Yf(j+80|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[23588]=0;d=Q(55,j- -64|0,d|0)|0;f=v[23588];v[23588]=0;k:{if((f|0)!=1){v[23588]=0;f=Q(944,c|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break k}v[23588]=0;R(270,f|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;zb(d);break g}v[23588]=0;d=Q(55,j+48|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break h}Ls(c,d)}zb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23588]=0;a=S(812,80)|0;i=v[23588];v[23588]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[23588]=0;b=Q(945,d|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break n}v[j+16>>2]=b;b=v[eg(j+24|0,j+16|0)>>2];d=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=d;v[23588]=0;d=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=d;b=fa(946,a|0,j|0,b|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break l}i=V(0)|0;O()|0;Ee(j+16|0);break m}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0}Nb(a);break g}v[k+24>>2]=b;Ee(j+16|0);ll(c);i=k;break d}i=V(0)|0;O()|0}ll(c);_(i|0)|0;v[23588]=0;X(939,15170,k|0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Nb(Ks(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Nb(a);v[k+20>>2]=0}Nb(k);break d}i=V(0)|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[23588]=0;X(939,15170,0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}$()}kb=j+96|0;return i|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}V(0)|0;O()|0;Vb()}L()}function JG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=v[d>>2];if(!h){break k}if(!a){g=c;break j}v[d>>2]=0;g=c;break i}l:{if(!v[v[116090]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=t[e|0];if(g){v[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return yg(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=w[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=v[e>>2];if((d|d-16843009)&-2139062144){break p}v[a>>2]=d&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=w[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}v[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=v[(f<<2)+82768>>2];d=1;continue}d=w[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=w[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=w[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;v[a>>2]=d;g=g-1|0;a=a+4|0;break q}v[116064]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=w[e|0];if(!(e&3|d-1>>>0>126)){d=v[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=v[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=v[(h<<2)+82768>>2];d=1;continue}d=w[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=w[e|0]}if(d&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-g|0}v[116064]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c}function si(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=C(0),q=0,r=C(0);m=ob[v[v[a>>2]+140>>2]](a)|0;g=v[a+20>>2];h=m?h:w[g+25|0];j=z[g+144>>2];k=C(1);if(!(ob[v[v[a>>2]+140>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((ob[v[v[a>>2]+156>>2]](a)|0)<=0){break a}if(!jL(w[v[a+20>>2]+24|0])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(k*n);j=C(j*n);g=0;l=v[a+44>>2];m=Kc(l,0);l=Kc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(C(z[d+g>>2]*j)+C(k*z[g+m>>2]));i=c+g|0;z[i>>2]=z[i>>2]+C(C(z[e+g>>2]*j)+C(k*z[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;z[i>>2]=z[i>>2]+C(z[h+m>>2]-C(z[d+h>>2]*j));i=c+h|0;z[i>>2]=z[i>>2]+C(z[h+l>>2]-C(z[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;z[i>>2]=z[i>>2]+C(z[d+h>>2]-C(z[h+m>>2]*k));i=c+h|0;z[i>>2]=z[i>>2]+C(z[e+h>>2]-C(z[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;z[i>>2]=z[i>>2]-C(z[d+h>>2]-C(z[h+m>>2]*j));i=c+h|0;z[i>>2]=z[i>>2]-C(z[e+h>>2]-C(z[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=z[i>>2];q=i;r=k;n=z[h+m>>2];i=c+h|0;o=z[i>>2];p=z[h+l>>2];k=C(C(C(C(k+n)+o)+p)*C(.5));z[q>>2]=r-C(C(k+C(k-C(z[d+h>>2]*j)))-n);z[i>>2]=o-C(C(k+C(k-C(z[e+h>>2]*j)))-p);g=g+1|0;continue}}g=jL(w[v[a+20>>2]+24|0]);j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=C(z[d+g>>2]-z[g+m>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[i>>2]=z[i>>2]+C(C(j*n)+C(k*o));g=c+g|0;z[g>>2]=z[g>>2]+C(C(k*n)+C(j*o));h=h+1|0;continue}}i:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break i}if(ob[v[v[a>>2]+140>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;z[d>>2]=z[a+m>>2]+z[d>>2];d=a+c|0;z[d>>2]=z[a+l>>2]+z[d>>2];g=g+1|0;continue}}}function ih(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Mb(a);d=Hb(c);v[23588]=0;R(46,a|0,d|0);d=v[23588];v[23588]=0;d:{if((d|0)!=1){e:{while(1){if(Hb(c)>>>0>b>>>0){d=v[Ai(c,b)>>2];v[23588]=0;R(47,a|0,(d>>>0<128?d:63)<<24>>24);d=v[23588];v[23588]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Mb(a);d=Hb(c);v[23588]=0;R(46,a|0,d|0);d=v[23588];v[23588]=0;f:{if((d|0)!=1){g:{while(1){if(Hb(c)>>>0>b>>>0){d=v[Ai(c,b)>>2];v[23588]=0;R(47,a|0,(d>>>0<256?d:63)<<24>>24);d=v[23588];v[23588]=0;if((d|0)==1){break g}b=b+1|0;continue}break}break f}}break a}return;case 3:ql(a,c,49552);return;case 5:ql(a,c,50576);return;case 4:ql(a,c,51600);return;case 6:ql(a,c,52624);return;case 7:ql(a,c,53648);return;case 8:ql(a,c,54672);return;case 9:ql(a,c,55696);return;case 10:uz(a,c,56720);return;case 11:uz(a,c,49552);return;case 12:uz(a,c,53648);return;default:a=ba(8)|0;v[23588]=0;b=Q(45,a|0,11027)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}b=P()|0;O()|0;ca(a|0);T(b|0);L();case 0:break c}}e=kb-16|0;kb=e;f=Mb(a);h:{while(1){i:{j:{k:{if(Hb(c)>>>0>g>>>0){b=v[Ai(c,g)>>2];if(b>>>0>=2097152){v[23588]=0;R(47,f|0,63);a=v[23588];v[23588]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;t[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=w[e+10|0]|64}else{a=w[e+10|0]}v[23588]=0;R(47,f|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break j}break i}kb=e+16|0;break h}i=(-1<<b^-1)<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=w[j|0];v[23588]=0;R(47,f|0,(a|i)<<24>>24);h=v[23588];v[23588]=0;a=d;break l}v[23588]=0;a=a-1|0;R(47,f|0,t[a+(e+10|0)|0]|-128);h=v[23588];v[23588]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=P()|0;O()|0;zb(f);T(a|0);L()}return}ha(b|0,93080,25);L()}b=P()|0;O()|0;zb(a);T(b|0);L()}function $ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;e=kb-48|0;kb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];t=v[a+20>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;w=v[a+72>>2];b=v[a+68>>2];x=b;y=b>>31;b=v[a+64>>2];z=b;A=b>>31;b=v[a+60>>2];C=b;D=b>>31;while(1){if(d){b=v[e+16>>2];E=((((v[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=(b>>>16&65520)+q|0;F=u[b+14>>1];g=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=E+(n<<1)|0;v[(e+8|0)+(n<<2)>>2]=(((((((B(u[i-8>>1],f)+B(u[i-12>>1],b)|0)+B(u[i-4>>1],k)|0)+B(u[i>>1],h)|0)+B(u[i+4>>1],p)|0)+B(u[i+8>>1],o)|0)+B(g,u[i+12>>1])|0)+B(F,u[i+16>>1])|0)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=v[o>>2];g=(e+24|0)+(m<<3)|0;p=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Oka(C,D,b,b>>31);f=nb;i=g;g=b;b=Yb(h,-16777216,16776704);b=Oka(z,A,b,b>>31);h=g+b|0;g=nb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Yb(p,-16777216,16776704);f=Oka(x,y,b,b>>31);h=f+h|0;b=nb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Yc(f,b,24);v[i+4>>2]=b-(k&w);v[o>>2]=(b|0)/256;m=m+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],t);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],s);Rb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=e+48|0}function ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;e=kb-48|0;kb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];w=v[a+20>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;x=v[a+72>>2];b=v[a+68>>2];y=b;z=b>>31;b=v[a+64>>2];A=b;C=b>>31;b=v[a+60>>2];D=b;E=b>>31;while(1){if(d){b=v[e+16>>2];F=(((v[e+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=(b>>>16&65520)+q|0;G=u[b+14>>1];g=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=n+F|0;v[(e+8|0)+(n<<2)>>2]=(((((((B(t[i-4|0],f)+B(t[i-6|0],b)|0)+B(t[i-2|0],k)|0)+B(t[i|0],h)|0)+B(t[i+2|0],p)|0)+B(t[i+4|0],o)|0)+B(g,t[i+6|0])|0)+B(G,t[i+8|0])<<8)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=v[o>>2];g=(e+24|0)+(m<<3)|0;p=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Oka(D,E,b,b>>31);f=nb;i=g;g=b;b=Yb(h,-16777216,16776704);b=Oka(A,C,b,b>>31);h=g+b|0;g=nb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Yb(p,-16777216,16776704);f=Oka(y,z,b,b>>31);h=f+h|0;b=nb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Yc(f,b,24);v[i+4>>2]=b-(k&x);v[o>>2]=(b|0)/256;m=m+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],s);Rb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=e+48|0}function D$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=kb-16|0;kb=j;k=Qw(g);o=xw(g);ch(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23588]=0;g=Q(1154,k|0,g<<24>>24)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[23588]=0;g=Q(1154,k|0,48)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[23588]=0;g=Q(1154,k|0,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Hd();if(!XG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Hd();if(!ak(h)){break d}g=g+1|0;continue}}e:{if(Re(j)){h=v[f>>2];v[23588]=0;X(1148,k|0,i|0,g|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break e}am(i,g);v[23588]=0;q=S(1146,o|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Tr((i-a<<2)+d|0,v[f>>2]);break e}f:{if(t[Tc(j,l)|0]<=0){break f}if(t[Tc(j,l)|0]!=(m|0)){break f}m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;l=(Hb(j)-1>>>0>l>>>0)+l|0;m=0}p=t[h|0];v[23588]=0;p=Q(1154,k|0,p|0)|0;n=v[23588];v[23588]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[23588]=0;i=S(1149,o|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}l=v[f>>2];h=l+4|0;v[f>>2]=h;v[l>>2]=i;g=g+1|0;break g}v[23588]=0;i=Q(1154,k|0,i<<24>>24)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[23588]=0;X(1148,k|0,g|0,c|0,h|0);i=v[23588];v[23588]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;zb(j);kb=j+16|0;return}a=P()|0;O()|0;zb(j);T(a|0);L()}function ls(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Pd(b)}if(b>>>0>=4294967232){v[116064]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[116216]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;MH(c,b);return a}if(v[116102]==(f|0)){c=c+v[116099]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[116099]=c;v[116102]=b;return a}if(v[116101]==(f|0)){c=c+v[116098]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[116101]=d;v[116098]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=464384,o=v[116096]&Ska(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+464688|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=464388,o=v[116097]&Ska(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;MH(b,l);return a}c=Pd(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;uc(c,a,b>>>0>d>>>0?d:b);Nb(a);a=c}return a}function Xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=kb-1104|0;kb=d;v[d+1100>>2]=c;i=wB(d+40|0,b);q=Eq(i);e=Tb(a);v[23588]=0;a=S(202,b|0)|0;c=v[23588];v[23588]=0;a:{if((c|0)!=1){v[d+8>>2]=a;v[d+36>>2]=85899345;s=d,z=B(v[Kb(d+8|0,d+36|0)>>2],50),v[s+24>>2]=z;a=v[Kb(d+1100|0,d+24|0)>>2];v[23588]=0;R(322,e|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;h=S(334,d+24|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;f=Q(335,d+8|0,8192)|0;a=v[23588];v[23588]=0;b:{if((a|0)!=1){a=v[h>>2];c=0;while(1){if((c|0)!=256){g=Eb(a,c);t[g+2|0]=c;u[g>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){r=m&255;e:{while(1){j=n&65535;while(1){v[23588]=0;o=Q(164,i|0,r|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(fd(v[e>>2],v[e+4>>2])>>>0>=y[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:g;a=v[h>>2];l=8192;while(1){c=c&65535;a=Eb(a,c);l=l-1|0;p=l&65535;s=Lb(v[f>>2],p),z=w[a+2|0],t[s|0]=z;a=v[h>>2];c=x[Eb(a,c)>>1];if(c>>>0<8192){continue}break}a=fc(d,Fb(v[e+4>>2]));c=Rf(Fb(v[f>>2]),p);l=Fb(v[f+4>>2]);a=v[a>>2];v[23588]=0;X(323,e|0,a|0,c|0,l|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=v[f>>2];v[23588]=0;R(336,e|0,Lb(a,p)|0);a=v[23588];v[23588]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(fd(v[e>>2],v[e+4>>2])>>>0>=y[d+1100>>2]){continue}break}a=w[Lb(v[f>>2],p)|0];c=Eb(v[h>>2],j);u[c>>1]=g;t[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<r)+m|0;n=a;continue}break}break}a=Eq(i);v[23588]=0;Q(155,b|0,((a-q|0)+3&-4)+q|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}ic(f);wc(h);Bb(i);kb=d+1104|0;return}c=P()|0;O()|0;ic(f);break b}c=P()|0;O()|0}wc(h);break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0}ic(e);Bb(i);T(c|0);L()}function Qha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=kb-48|0;kb=c;a:{b:{c:{d:{e:{f:{g:{if(Fd(v[a+24>>2])){break g}h=a+4|0;k=Hb(h);e=kb-32|0;kb=e;d=e+24|0;b=d;v[b>>2]=-1;v[b+4>>2]=-1;v[23588]=0;f=kF(39);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[e+8>>2]=f;v[e+12>>2]=nb;g=kb-16|0;kb=g;i=e+8|0;b=i;l=g,m=Oka(v[b>>2],v[b+4>>2],1e3,0),v[l>>2]=m;v[g+4>>2]=nb;f=sl(g+8|0,g);b=v[f+4>>2];kb=g+16|0;v[e+16>>2]=v[f>>2];v[e+20>>2]=b;b=e+16|0;l=e,m=pA(v[b>>2],v[b+4>>2]),v[l+16>>2]=m;v[e+20>>2]=nb;g=iS(d,b,Gb(b));v[23588]=0;d=kF(40);f=v[23588];v[23588]=0;if((f|0)==1){break a}j=a+24|0;v[e+8>>2]=d;v[e+12>>2]=nb;d=kb-16|0;kb=d;a=v[i+4>>2];v[d>>2]=v[i>>2];v[d+4>>2]=a;f=sl(d+8|0,d);a=v[f+4>>2];kb=d+16|0;v[e+16>>2]=v[f>>2];v[e+20>>2]=a;l=e,m=pA(v[b>>2],v[b+4>>2]),v[l+16>>2]=m;v[e+20>>2]=nb;a=iS(g,b,Gb(b));b=v[a>>2];a=v[a+4>>2];kb=e+32|0;if(k){d=Tb(c+32|0);v[23588]=0;v[c+16>>2]=a;R(33,d|0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}v[23588]=0;v[c+16>>2]=b;R(33,d|0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}a=0;h:{while(1){if(Hb(h)>>>0<=a>>>0){b=Fb(v[d>>2]);a=Fb(v[d+4>>2]);v[23588]=0;f=W(34,c+16|0,b|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break c}b=w[Tc(h,a)|0];v[23588]=0;v[c+16>>2]=b;R(33,d|0,c+16|0);b=v[23588];v[23588]=0;if((b|0)!=1){a=a+1|0;continue}break}a=P()|0;O()|0;break c}v[23588]=0;b=S(35,f|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){v[c+8>>2]=b;a=c+8|0;rA(j,a);zj(a);Gm(f);wc(d);break g}a=P()|0;O()|0;Gm(f);break c}nb=b;v[c+16>>2]=a;v[c+20>>2]=nb;b=Tb(c+32|0);v[23588]=0;U(38,b|0,c+16|0,c+24|0);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;wc(b);T(a|0);L()}v[23588]=0;f=S(35,b|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}v[c+8>>2]=f;a=c+8|0;rA(j,a);zj(a);Gm(b)}kb=c+48|0;return}a=P()|0;O()|0;Gm(b);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0}wc(d)}T(a|0);L()}V(0)|0;O()|0;Vb();L()}function T4(a,b,c){a=a|0;b=C(b);c=c|0;var d=0,e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),k=C(0),m=0,n=0,o=0;d=kb-16|0;kb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(p(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=C(C(-1)/C(b*b));if(!(a&2147483647)){break e}e=C(C(b-b)/C(0));if((a|0)<0){break e}a=(p(C(b*C(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=C((a>>>23|0)+c|0);b=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));f=C(b*C(b*C(.5)));g=C(b/C(b+C(2)));h=C(g*g);i=C(h*h);e=b;b=(l(2,(p(C(b-f)),j(2))&-4096),q());f=C(C(g*C(f+C(C(h*C(C(i*C(.2849878668785095))+C(.6666666269302368)))+C(i*C(C(i*C(.24279078841209412))+C(.40000972151756287))))))+C(C(e-b)-f));b=C(C(k*C(.3010292053222656))+C(C(b*C(.434326171875))+C(C(f*C(.434326171875))+C(C(k*C(7.903415166765626e-7))+C(C(f+b)*C(-3168997136526741e-20))))))}e=b}b=C(e*C(2e3));if(!(C(D(b))<C(2147483648))){break c}a=~~b;break b;case 1:a=(B(v[a+24604>>2],100)|0)/128|0;break b;case 2:c=kb-16|0;kb=c;h:{i:{j:{k:{a=w[a+24648|0];if(a>>>0>=6){a=ba(8)|0;v[23588]=0;c=Q(55,c|0,5126)|0;d=v[23588];v[23588]=0;if((d|0)==1){break k}a=sc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break i}d=P()|0;O()|0;zb(c);break j}kb=c+16|0;a=v[(a<<2)+62408>>2];break h}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}break b;case 3:v[d>>2]=0;m=v[a+24640>>2];c=kb-80|0;kb=c;a=v[a+24636>>2];v[c+40>>2]=a;v[c>>2]=m;n=c+40|0;o=v[Pe(n,c)>>2];l:{if((a|0)==v[cq(n)+32>>2]){a=-1;if(v[cq(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}v[d>>2]=a;kb=c+80|0;a=v[d>>2];break b;default:break d}}c=ba(8)|0;v[23588]=0;d=Q(55,d|0,10335)|0;a=v[23588];v[23588]=0;m:{if((a|0)!=1){a=sc(c,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(d);break m}a=P()|0;O()|0;ca(c|0)}T(a|0);L()}a=-2147483648}kb=d+16|0;return a|0}L()}function N$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=kb-16|0;kb=j;k=iv(g);o=Dw(g);ch(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23588]=0;g=Q(20,k|0,g<<24>>24)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[23588]=0;g=Q(20,k|0,48)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[23588]=0;g=Q(20,k|0,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Hd();if(!XG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Hd();if(!ak(h)){break d}g=g+1|0;continue}}e:{if(Re(j)){h=v[f>>2];v[23588]=0;X(1134,k|0,i|0,g|0,h|0);h=v[23588];v[23588]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break e}am(i,g);v[23588]=0;q=S(1132,o|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){am((i-a|0)+d|0,v[f>>2]);break e}f:{if(t[Tc(j,m)|0]<=0){break f}if(t[Tc(j,m)|0]!=(l|0)){break f}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;m=(Hb(j)-1>>>0>m>>>0)+m|0;l=0}p=t[h|0];v[23588]=0;p=Q(20,k|0,p|0)|0;n=v[23588];v[23588]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break g}v[23588]=0;i=S(1135,o|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[23588]=0;X(1134,k|0,g|0,c|0,i|0);i=v[23588];v[23588]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;zb(j);kb=j+16|0;return}v[23588]=0;i=Q(20,k|0,i<<24>>24)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;zb(j);T(a|0);L()}function MO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;c=kb-176|0;kb=c;e=v[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=v[a+12>>2]}else{i=v[b>>2];h=Kd(i,e+l|0);d=Kd(i,e);o=A[h>>3];p=A[h+8>>3];nj(c+160|0,d,o,p);i=v[c+172>>2];v[h+8>>2]=v[c+168>>2];v[h+12>>2]=i;i=v[c+164>>2];v[h>>2]=v[c+160>>2];v[h+4>>2]=i;cy(Kd(v[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){x=B(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=v[a>>2];e=Kd(d,j<<1);d=Kd(d,j);o=A[d>>3];p=A[d+8>>3];r=A[e>>3];s=A[e+8>>3];vi(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=v[b>>2];d=Kd(f,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=c+128|0;t=e+h|0;k=Kd(f,t);vi(g,r,s,A[k>>3],A[k+8>>3]);u=e+y|0;k=Kd(f,u);vi(c+112|0,o,p,A[k>>3],A[k+8>>3]);m=A[c+160>>3];n=A[c+168>>3];w=e+x|0;f=Kd(f,w);vi(c+96|0,m,n,A[f>>3],A[f+8>>3]);k=c+80|0;f=c+144|0;m=A[c+112>>3];n=A[c+120>>3];gl(k,f,m,n);q=c- -64|0;nj(q,f,m,n);m=A[c+96>>3];n=A[c+104>>3];gl(c+48|0,g,m,n);f=c+16|0;ol(f,-0,-1);nj(c,g,m,n);vi(c+32|0,A[c+16>>3],A[c+24>>3],A[c>>3],A[c+8>>3]);gl(f,k,A[c+48>>3],A[c+56>>3]);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;nj(f,k,A[c+48>>3],A[c+56>>3]);d=Kd(v[b>>2],t);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;gl(f,q,A[c+32>>3],A[c+40>>3]);d=Kd(v[b>>2],u);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;nj(f,q,A[c+32>>3],A[c+40>>3]);d=Kd(v[b>>2],w);f=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=f;f=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=f;e=e+1|0;continue}}}break}kb=c+176|0}function B6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-80|0;kb=e;v[e+76>>2]=c;v[e+72>>2]=b;a:{if(!c){break a}f=w[dl(b,c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}kl(e+48|0,b,c,c-1|0);b=v[e+52>>2];v[e+72>>2]=v[e+48>>2];v[e+76>>2]=b}c=e+48|0;Xd(c);b=v[e+48>>2];Xd(e+32|0);b=cl(b,v[e+36>>2],e+72|0);Xd(c);b:{c:{d:{e:{if((b|0)==v[e+52>>2]){b=v[e+72>>2];c=v[e+76>>2];a=rc(e- -64|0,21619);if(Qc(b,c,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23588]=0;b=Q(55,e+48|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}b=0;c=0;if(!d){break e}b=ba(8)|0;v[23588]=0;d=Lh(e+32|0,v[e+72>>2],v[e+76>>2]);a=v[23588];v[23588]=0;f:{g:{h:{if((a|0)!=1){v[23588]=0;U(967,e+48|0,17634,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}a=0;c=sc(b,e+48|0);v[23588]=0;U(119,c|0,62688,956);c=v[23588];v[23588]=0;if((c|0)!=1){break b}c=P()|0;O()|0;zb(e+48|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}zb(d);if(!a){break c}}ca(b|0);break c}if(v[b+4>>2]!=1){a=ba(8)|0;v[23588]=0;b=Q(55,e+48|0,11504)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=v[e+72>>2];f=v[e+76>>2];b=rc(e+24|0,21619);if(Qc(d,f,v[b>>2],v[b+4>>2])){a=ba(8)|0;v[23588]=0;b=Q(55,e+48|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;ca(a|0);break c}b=rc(e+16|0,10895);if(Qc(d,f,v[b>>2],v[b+4>>2])){a=v[a+8>>2];b=a;c=a>>31;break e}b=0;g=d;d=rc(e+8|0,8587);c=0;if(!Qc(g,f,v[d>>2],v[d+4>>2])){break e}b=ck(w[v[a+32>>2]+140|0]);c=0}kb=e+80|0;nb=c;return b|0}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}function m6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=kb+-64|0;kb=k;a:{b:{c:{j=yp(1,32);d:{e:{if(!j){a=nm(ba(4)|0);v[23588]=0;U(119,a|0,92948,26);a=v[23588];v[23588]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:933;c=Yf(k+48|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[23588]=0;d=Q(55,k+32|0,d|0)|0;f=v[23588];v[23588]=0;j:{if((f|0)!=1){v[23588]=0;f=Q(944,c|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break j}v[23588]=0;R(270,f|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;zb(d);break f}v[23588]=0;d=Q(55,k+16|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}Ls(c,d)}zb(d);i=i+8|0;continue}}v[23588]=0;d=S(812,104)|0;e=v[23588];v[23588]=0;k:{l:{m:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[23588]=0;e=Q(945,f|0,e|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break m}v[k>>2]=e;e=v[eg(k+8|0,k)>>2];v[23588]=0;a=ja(976,d|0,a|0,b|0,e|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break k}i=V(0)|0;O()|0;Ee(k);break l}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0}Nb(d);break f}v[j+28>>2]=a;Ee(k);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;ll(c);break d}i=V(0)|0;O()|0}ll(c);_(i|0)|0;v[23588]=0;X(939,4976,j|0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){a=v[j+28>>2];if(a){ob[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Nb(a);v[j+20>>2]=0}Nb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[23588]=0;X(939,4976,0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}$()}kb=k- -64|0;return j|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}V(0)|0;O()|0;Vb()}L()}function jh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Mb(a);d=Hb(c);v[23588]=0;R(48,a|0,d|0);d=v[23588];v[23588]=0;d:{if((d|0)!=1){e:{while(1){if(Hb(c)>>>0>b>>>0){d=t[hg(c,b)|0];v[23588]=0;R(49,a|0,((d|0)<0?65533:d&255)|0);d=v[23588];v[23588]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Mb(a);d=Hb(c);v[23588]=0;R(48,a|0,d|0);d=v[23588];v[23588]=0;f:{if((d|0)!=1){while(1){if(Hb(c)>>>0<=b>>>0){break f}d=w[hg(c,b)|0];v[23588]=0;R(49,a|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){b=b+1|0;continue}break}}break a}return;case 3:nl(a,c,49552);return;case 5:nl(a,c,50576);return;case 4:nl(a,c,51600);return;case 6:nl(a,c,52624);return;case 7:nl(a,c,53648);return;case 8:nl(a,c,54672);return;case 9:nl(a,c,55696);return;case 10:kz(a,c,56720);return;case 11:kz(a,c,49552);return;case 12:kz(a,c,53648);return;default:a=ba(8)|0;v[23588]=0;b=Q(45,a|0,11027)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}b=P()|0;O()|0;ca(a|0);T(b|0);L();case 0:break c}}e=kb-16|0;kb=e;f=Mb(a);g=e,h=rt(c),v[g+8>>2]=h;g=e,h=qt(c),v[g>>2]=h;a=0;g:{h:{while(1){i:{if(!zi(e+8|0,e)){if(!a){break i}v[23588]=0;R(49,f|0,65533);a=v[23588];v[23588]=0;if((a|0)!=1){break i}break h}b=w[v[e+8>>2]];j:{k:{if(!a){if(!(b&128)){a=0;v[23588]=0;R(49,f|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break j}break h}if((b&224)==192){d=b&31;a=1;break j}if((b&240)==224){d=b&15;a=2;break j}d=65533;if((b&248)!=240){break k}d=b&7;a=3;break j}if((b&192)!=128){d=0;v[23588]=0;R(49,f|0,65533);c=v[23588];v[23588]=0;a=0;if((c|0)==1){break h}}d=b&63|d<<6;a=a-1|0;if(a){break j}}a=0;v[23588]=0;R(49,f|0,d|0);b=v[23588];v[23588]=0;d=0;if((b|0)==1){break h}}He(e+8|0);continue}break}kb=e+16|0;break g}a=P()|0;O()|0;Gc(f);T(a|0);L()}return}ha(b|0,93080,25);L()}b=P()|0;O()|0;Gc(a);T(b|0);L()}function Hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;g=kb-48|0;kb=g;p=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;v[i+4>>2]=v[e+44>>2];v[i+8>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){f=v[g+16>>2];l=((((v[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=u[b+14>>1];h=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];o=u[b+6>>1];F=u[b+4>>1];G=u[b+2>>1];H=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=l+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((((B(u[b+8>>1],m)+B(u[b+4>>1],n)|0)+B(h,u[b+12>>1])|0)+B(j,u[b+16>>1])|0)/2|0)+((((B(u[b-8>>1],G)+B(u[b-12>>1],H)|0)+B(u[b-4>>1],F)|0)+B(u[b>>1],o)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=v[l>>2];b=(g+24|0)+(f<<3)|0;j=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;m=e<<8;e=m;e=Oka(A,C,e,e>>31);n=nb;o=b;b=Yb(h,-16777216,16776704);h=Oka(y,z,b,b>>31);e=h+e|0;b=nb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Yb(j,-16777216,16776704);j=Oka(w,x,e,e>>31);e=h+j|0;b=nb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Yc(e,b,24);v[o+4>>2]=b-(m&t);v[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);i=i+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],i>>12);Rb(g+16|0,D,E);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}kb=g+48|0}function gk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;i=kb-16|0;kb=i;a:{if(!d){break a}g=v[c>>2];if(!g){break a}b:{c:{d:{e:{f=v[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=B(d,20)+g|0;break d}f=((B(d,36318)|0)/1024|0)+g|0;break d}f:{g:{h:{if(w[a+480208|0]&16){if((f|0)==4){break h}f=d>>31;v[i+12>>2]=(f^d)-f;xc(i+12|0,1020);h=v[i+12>>2];i:{if((d|0)>0){if(h>>>0<=15){f=kb-16|0;kb=f;Db(f+8|0,a+1074312|0,7);j=Cb(v[v[f+8>>2]>>2],v[f+12>>2]);kb=f+16|0;h=v[(h<<2)+(j?37008:37072)>>2];break i}f=kb-16|0;kb=f;Db(f+8|0,a+1074312|0,7);j=Cb(v[v[f+8>>2]>>2],v[f+12>>2]);kb=f+16|0;h=v[(h>>>2<<2)+(j?37136:38160)>>2];break i}if(h>>>0<=15){f=kb-16|0;kb=f;Db(f+8|0,a+1074312|0,7);j=Cb(v[v[f+8>>2]>>2],v[f+12>>2]);kb=f+16|0;h=v[(h<<2)+(j?37072:37008)>>2];break i}f=kb-16|0;kb=f;Db(f+8|0,a+1074312|0,7);j=Cb(v[v[f+8>>2]>>2],v[f+12>>2]);kb=f+16|0;h=v[(h>>>2<<2)+(j?38160:37136)>>2]}h=Oka(h,h>>31,g,g>>31)+32768|0;f=nb;f=Ic(Pka(h,h>>>0<32768?f+1|0:f,65536,0),nb);v[c>>2]=f;if((f|0)!=(g|0)){break c}Db(i,a+1074312|0,7);g=v[c>>2];if(!(Cb(v[v[i>>2]>>2],v[i+4>>2])^(d|0)>0)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}Db(i,a+1074312|0,7);if(Cb(v[v[i>>2]>>2],v[i+4>>2])){break g}g=v[c>>2]}f=g-d|0;break d}f=v[c>>2];if((d|0)<0){g=Oka(f,0,14317456,0);h=nb;f=Oka(f,0,0-d|0,0)+14317456|0;d=nb;f=rN(Rka(g,h,f,f>>>0<14317456?d+1|0:d),nb);break d}d=Oka(f,f>>31,d,0);g=nb;if((g|0)>=0&d>>>0>=14317456|(g|0)>0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}d=rN(Rka(Oka(f,0,14317456,0),nb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),nb);v[c>>2]=d;if((d|0)>0){break a}break b}f=d+g|0}v[c>>2]=f}if((f|0)>0){break a}}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}kb=i+16|0}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=kb-48|0;kb=g;p=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;v[i+4>>2]=v[e+44>>2];v[i+8>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+32>>2];s=v[a+28>>2];w=v[a+72>>2];b=v[a+68>>2];x=b;y=b>>31;b=v[a+64>>2];z=b;A=b>>31;b=v[a+60>>2];C=b;D=b>>31;E=v[a+8>>2];F=v[a+12>>2];while(1){if(d){f=v[g+16>>2];l=(((v[g+20>>2]&2147483647)<<1|f>>>31)&-2)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=u[b+14>>1];h=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];o=u[b+6>>1];G=u[b+4>>1];H=u[b+2>>1];I=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+l|0;v[(g+8|0)+(e<<2)>>2]=(((((B(t[b+4|0],m)+B(t[b+2|0],n)|0)+B(h,t[b+6|0])|0)+B(j,t[b+8|0])<<8)/2|0)+((((B(t[b-4|0],H)+B(t[b-6|0],I)|0)+B(t[b-2|0],G)|0)+B(t[b|0],o)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=v[l>>2];b=(g+24|0)+(f<<3)|0;j=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;m=e<<8;e=m;e=Oka(C,D,e,e>>31);n=nb;o=b;b=Yb(h,-16777216,16776704);h=Oka(z,A,b,b>>31);e=h+e|0;b=nb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Yb(j,-16777216,16776704);j=Oka(x,y,e,e>>31);e=h+j|0;b=nb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Yc(e,b,24);v[o+4>>2]=b-(m&w);v[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);i=i+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],i>>12);Rb(g+16|0,E,F);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}kb=g+48|0}function z6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=kb-80|0;kb=f;v[f+76>>2]=d;v[f+72>>2]=c;a:{if(!d){break a}g=w[dl(c,d)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}kl(f+48|0,c,d,d-1|0);c=v[f+52>>2];v[f+72>>2]=v[f+48>>2];v[f+76>>2]=c}c=f+48|0;Xd(c);d=v[f+48>>2];Xd(f+32|0);g=cl(d,v[f+36>>2],f+72|0);Xd(c);c=v[f+76>>2];d=v[f+72>>2];b:{c:{d:{e:{if((g|0)==v[f+52>>2]){b=rc(f- -64|0,21619);if(Qc(d,c,v[b>>2],v[b+4>>2])){a=ba(8)|0;v[23588]=0;b=Q(55,f+48|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}d=P()|0;O()|0;zb(b);break c}if(e){b=ba(8)|0;v[23588]=0;c=Lh(f+32|0,v[f+72>>2],v[f+76>>2]);a=v[23588];v[23588]=0;f:{g:{h:{if((a|0)!=1){v[23588]=0;U(967,f+48|0,17634,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}a=0;d=sc(b,f+48|0);v[23588]=0;U(119,d|0,62688,956);d=v[23588];v[23588]=0;if((d|0)!=1){break b}d=P()|0;O()|0;zb(f+48|0);break g}d=P()|0;O()|0;break f}d=P()|0;a=1;O()|0}zb(c);if(!a){break c}}ca(b|0);break c}Mb(a);break e}e=rc(f+24|0,21619);if(Qc(d,c,v[e>>2],v[e+4>>2])){a=ba(8)|0;v[23588]=0;b=Q(55,f+48|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}d=P()|0;O()|0;zb(b);break c}d=P()|0;O()|0;ca(a|0);break c}e=rc(f+16|0,12273);if(Qc(d,c,v[e>>2],v[e+4>>2])){i:{switch(v[b+52>>2]){case 0:Nc(a,5604);break e;case 1:Nc(a,11205);break e;case 2:Nc(a,9166);break e;default:break i}}Mb(a);break e}e=c;c=rc(f+8|0,11442);if(Qc(d,e,v[c>>2],v[c+4>>2])){j:{switch(v[b+56>>2]){case 0:Nc(a,15561);break e;case 1:Nc(a,15566);break e;case 2:Nc(a,12547);break e;case 3:Nc(a,9230);break e;default:break j}}Mb(a);break e}Mb(a)}kb=f+80|0;return}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}function oK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=kb+-64|0;kb=k;a:{b:{c:{d:{e:{f:{j=yp(1,28);if(!j){a=nm(ba(4)|0);v[23588]=0;U(119,a|0,92948,26);a=v[23588];v[23588]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:933;c=Yf(k+48|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[23588]=0;d=Q(55,k+32|0,d|0)|0;f=v[23588];v[23588]=0;k:{if((f|0)!=1){v[23588]=0;f=Q(944,c|0,d|0)|0;l=v[23588];v[23588]=0;if((l|0)==1){break k}v[23588]=0;R(270,f|0,e|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;zb(d);break g}v[23588]=0;d=Q(55,k+16|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break h}Ls(c,d)}zb(d);i=i+8|0;continue}}v[23588]=0;d=S(812,80)|0;e=v[23588];v[23588]=0;l:{m:{n:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[23588]=0;e=Q(945,f|0,e|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break n}v[k>>2]=e;e=v[eg(k+8|0,k)>>2];v[23588]=0;a=ja(950,d|0,a|0,b|0,e|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break l}i=V(0)|0;O()|0;Ee(k);break m}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0}Nb(d);break g}v[j+24>>2]=a;Ee(k);ll(c);i=j;break d}i=V(0)|0;O()|0}ll(c);_(i|0)|0;v[23588]=0;X(939,15056,j|0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Nb(Ks(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Nb(a);v[j+20>>2]=0}Nb(j);break d}i=V(0)|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[23588]=0;X(939,15056,0,g|0,h|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}$()}kb=k- -64|0;return i|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}V(0)|0;O()|0;Vb()}L()}function W_(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=kb-1072|0;kb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+960|0;v[a+956>>2]=j;j=Gw(j,100,11090,a+16|0);v[a+48>>2]=1123;k=a+48|0;o=te(a+536|0,0,k);v[a+48>>2]=1123;k=te(a+528|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+544|0;f=a+960|0;break d}j=Hd();v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;j=_i(a+956|0,j,11090,a);if((j|0)!=-1){f=v[a+956>>2];_e(o,f);_e(k,Pd(j<<2));h=v[k>>2];if(!jk(h)){break d}}v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break a}j=P()|0;O()|0;break c}g=a+520|0;gd(g,d);v[23588]=0;q=S(1136,g|0)|0;g=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}v[23588]=0;X(1148,q|0,f|0,f+j|0,h|0);g=v[23588];v[23588]=0;if((g|0)==1){break j}p=(j|0)>0?w[f|0]==45:p;i=Mb(a+488|0);f=Mb(a+472|0);g=Mb(a+456|0);v[23588]=0;na(1175,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,i|0,f|0,g|0,a+452|0);c=v[23588];v[23588]=0;if((c|0)==1){break i}v[a+36>>2]=1123;c=te(a+40|0,0,a+36|0);m=a+48|0;n=v[a+452>>2];k:{if((n|0)<(j|0)){l=((Hb(g)+(j-n<<1)|0)+Hb(f)|0)+1|0;break k}l=(Hb(g)+Hb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}_e(c,Pd(l<<2));m=v[c>>2];if(m){break h}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)!=1){break a}break g}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[23588]=0;pa(1176,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],i|0,f|0,g|0,n|0);h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;b=ka(1157,b|0,m|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break b}}}j=P()|0;O()|0;Xc(c)}Gc(g);Gc(f);zb(i)}ac(a+520|0)}Xc(k);Xc(o);T(j|0);L()}Xc(c);Gc(g);Gc(f);zb(i);ac(a+520|0);Xc(k);Xc(o);kb=a+1072|0;return b|0}L()}function ig(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;c=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:b=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((b>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=b;b=x[a+46>>1];f=c+(b?g&b?0:f:f)|0;u[a+20>>1]=f;b=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:b=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=c+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:b=0;v[a+72>>2]=0;break a;case 0:break d}}b=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((c^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=c+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>0){break b}}v[a+16>>2]=b;u[a+20>>1]=h}i=((c+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+28400>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+28400>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+28400>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+28400>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+28400>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+28400>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];c=a;a=b+i&65535;a=a>>>0<8191?a:8191;b=0-(d&1)^x[((a&255)<<1)+27888>>1]+1024>>>(a>>>8)<<1;u[c+72>>1]=b}return b<<16>>16}function QR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=w[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){t[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[a+4|0]=c}e=w[b+4|0];d=w[b+5|0];c=w[b+6|0];d:{if(!(c?1:e|d)){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;h=a,i=w[Xb(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d;case 0:Pf(a,c,d);g=w[b+6|0]==15;break d;case 1:t[a+3|0]=2;h=a,i=tg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 2:t[a+3|0]=3;h=a,i=tg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 3:t[a+3|0]=4;h=a,i=tg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 4:t[a+3|0]=5;t[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){t[a+5|0]=d;t[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d;case 12:t[a+3|0]=13;t[a+5|0]=c>>>1;break d;case 15:if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}RA(a,c,d,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=d;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=c>>>1;break d}t[a+3|0]=31;t[a+5|0]=c>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=c>>>2}b=w[b+3|0];l:{if(!b){break l}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break l}if(w[a+2|0]){break l}t[a+2|0]=2;t[a+4|0]=b>>>2}kb=f+16|0;return g}function Wp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-16|0;kb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);pe(e+12|0,0,127);pe(e+8|0,0,127);k=a+1074312|0;Db(e,k,1);j=v[e+12>>2];a:{if(Cb(v[v[e>>2]>>2],v[e+4>>2])){i=v[e+8>>2];break a}u[b+780>>1]=0;t[b+837|0]=j;i=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=i}Db(e,k,36);l=B(j,d+256|0);m=(l|0)/256|0;b:{if(!(!Cb(v[v[e>>2]>>2],v[e+4>>2])|i|(l|0)<65024)){m=-1;if(!$c(w[b+788|0])){break b}if(wm(w[b+790|0],w[b+791|0])|x[b+786>>1]|!(w[b+851|0]&2)){break b}v[b+88>>2]=v[b+88>>2]&-32769;break b}v[b+88>>2]=v[b+88>>2]|32768;f=ue(C(10),C(C(0-i|0)*C(.00937500037252903)));i=kb-16|0;kb=i;g=C(B(j,d+256|0)>>>0);c:{if(v[a+480180>>2]!=33554432){h=C(110);g=C(C(g/(w[a+480209|0]&128?C(10240):C(12288)))+C(.25));break c}h=C(125);g=C(C(g*C(6))/C(65024))}n=i,o=Th(C(ue(C(2),g)*h)),v[n+12>>2]=o;pe(i+12|0,120,2e4);d=v[i+12>>2];j=v[a+24620>>2];kb=i+16|0;Db(e,k,36);g=C(C(((j|0)<d<<1?j>>>1|0:d)>>>0)*C(6.2831854820251465));d:{if(!(!Cb(v[v[e>>2]>>2],v[e+4>>2])|v[a+480208>>2]&32768)){h=C(C(y[a+24620>>2])/g);g=C(C(C(f*h)+f)+C(-1));z[e>>2]=g;f=C(h*h);break d}h=C(f+f);f=C(g/C(y[a+24620>>2]));z[e>>2]=C(C(1)-h)*f;eO(e,C(2));g=C(C(h-z[e>>2])/f);z[e>>2]=g;f=C(C(1)/C(f*f))}h=C(f+C(g+C(1)));g=C(C(f+C(f+g))/h);f=C(C(-f)/h);h=C(C(1)/h);e:{if(w[b+845|0]==1){n=b,o=Th(C(C(C(1)-h)*C(16777216))),v[n+60>>2]=o;n=b,o=Th(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Th(C(f*C(16777216))),v[n+68>>2]=o;a=-1;break e}d=Th(C(h*C(16777216)));v[b+60>>2]=d;n=b,o=Th(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Th(C(f*C(16777216))),v[n+68>>2]=o;a=0;if(d){break e}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break b}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}kb=e+16|0;return m}function __(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=kb-464|0;kb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+352|0;v[a+348>>2]=j;j=Gw(j,100,11090,a+16|0);v[a+48>>2]=1123;k=a+48|0;o=te(a+232|0,0,k);v[a+48>>2]=1123;k=te(a+224|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+240|0;f=a+352|0;break d}j=Hd();v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;j=_i(a+348|0,j,11090,a);if((j|0)!=-1){f=v[a+348>>2];_e(o,f);_e(k,Pd(j));h=v[k>>2];if(!jk(h)){break d}}v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break a}j=P()|0;O()|0;break c}g=a+216|0;gd(g,d);v[23588]=0;q=S(19,g|0)|0;g=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}v[23588]=0;X(1134,q|0,f|0,f+j|0,h|0);g=v[23588];v[23588]=0;if((g|0)==1){break j}p=(j|0)>0?w[f|0]==45:p;i=Mb(a+192|0);f=Mb(a+176|0);g=Mb(a+160|0);v[23588]=0;na(1173,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,i|0,f|0,g|0,a+156|0);c=v[23588];v[23588]=0;if((c|0)==1){break i}v[a+36>>2]=1123;c=te(a+40|0,0,a+36|0);m=a+48|0;n=v[a+156>>2];k:{if((n|0)<(j|0)){l=((Hb(g)+(j-n<<1)|0)+Hb(f)|0)+1|0;break k}l=(Hb(g)+Hb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}_e(c,Pd(l));m=v[c>>2];if(m){break h}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)!=1){break a}break g}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[23588]=0;pa(1174,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],i|0,f|0,g|0,n|0);h=v[23588];v[23588]=0;if((h|0)!=1){v[23588]=0;b=ka(15,b|0,m|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break b}}}j=P()|0;O()|0;Xc(c)}zb(g);zb(f);zb(i)}ac(a+216|0)}Xc(k);Xc(o);T(j|0);L()}Xc(c);zb(g);zb(f);zb(i);ac(a+216|0);Xc(k);Xc(o);kb=a+464|0;return b|0}L()}function sM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=kb-16|0;kb=g;e=B(b,872)+a|0;j=e+1074992|0;a:{b:{i=v[e+1075080>>2];if(i&131072){h=a+480180|0;e=v[h>>2];i=1;c:{d:{e:{f=v[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}i=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}if(!i){break c}Db(g+8|0,a+1074312|0,21);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break c}e=B(b,872)+a|0;f=e+1075811|0;t[f|0]=w[f|0]+(w[e+1075815|0]<<2)}f=B(b,872)+a|0;k=f+1075814|0;l=f+1075811|0;e=oy(a,w[k|0],w[l|0]);f:{if(wj(v[j+656>>2])){z[d>>2]=z[d>>2]+C(C(C(B(w[f+1075816|0],e)|0)*C(.05000000074505806))/C(7680));c=f+1075843|0;d=w[c|0];t[c|0]=d&159|64;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break f}t[c|0]=d|96;break f}d=v[a+480208>>2];if((d&2101248)==2101248){break a}f=v[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(w[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Db(g+8|0,k,21);f=v[a+480208>>2];g:{if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=v[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}Db(g+8|0,k,80);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=(0-B(w[(B(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0;gk(a,j,c,d,0);e=v[j+656>>2];c=Pp(a,v[j+88>>2],e);if(!c){break f}ob[v[v[c>>2]+92>>2]](c,d,(e?t[e+33|0]:2)<<24>>24,b)}if(!i){break a}Db(g+8|0,a+1074312|0,21);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}t[l|0]=w[l|0]+w[(B(b,872)+a|0)+1075815|0];break a}if(!(w[e+1075662|0]&2)){break a}a=Pp(a,i,v[j+656>>2]);if(!a){break a}ob[v[v[a>>2]+92>>2]](a,0,0,b);break a}a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1}kb=g+16|0}function wZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=kb-16|0;kb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!w[j|0]){break a}j=j+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=v[b+4>>2];v[r+8>>2]=v[b>>2];v[r+12>>2]=i;s=kb-16|0;kb=s;u=ki(s+8|0,v[a+8>>2]);m=j-c|0;k=0;o=0;n=kb-1040|0;kb=n;i=v[e>>2];v[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=JG(p,n+12|0,l>>>0>q>>>0?q:l,b);if((q|0)==-1){k=-1;l=0;i=v[n+12>>2];break g}t=(n+16|0)==(p|0)?0:q;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=v[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=Xr(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}v[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){v[e>>2]=o}kb=n+1040|0;ji(u);kb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{v[h>>2]=f;if(v[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=FF(f,c,j-c|0,r+8|0,v[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}v[e>>2]=c;break n}g=b}c=c+g|0;f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(k<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break k}c=v[e>>2];if((d|0)==(j|0)){j=d;continue}if(!FF(f,c,1,b,v[a+8>>2])){break m}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!w[j|0]){break b}j=j+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}kb=r+16|0;return a|0}f=v[h>>2];continue}}function oR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=kb-16|0;kb=l;a:{if((c|0)==(g|0)){f=hc(l+8|0,f,c);i=kb-16|0;kb=i;g=ul(d,e,b,c);v[i+12>>2]=g;b:{if((g|0)<=0){g=v[f>>2];break b}c:{if(!c){c=v[f>>2];break c}h=32-c|0;v[i+8>>2]=h;d=v[td(i+8|0,i+12|0)>>2];v[i+12>>2]=g-d;e=v[f>>2];c=-1<<c&-1>>>h-d;v[e>>2]=v[e>>2]&(c^-1)|c&v[b>>2];c=d+v[f+4>>2]|0;v[f+4>>2]=c&31;c=e+(c>>>3&536870908)|0;v[f>>2]=c;b=b+4|0;g=v[i+12>>2]}e=c;d=(g|0)/32|0;c=d<<2;hj(e,b,c);d=g-(d<<5)|0;v[i+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<=0){break b}d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[b+c>>2];v[f+4>>2]=v[i+12>>2]}hc(a,g,v[f+4>>2]);kb=i+16|0;break a}i=a;h=hc(l,f,g);g=kb-16|0;kb=g;f=ul(d,e,b,c);v[g+12>>2]=f;d:{if((f|0)<=0){a=v[h+4>>2];break d}e:{if(!c){a=v[h+4>>2];break e}j=32-c|0;v[g+8>>2]=j;e=g+8|0;d=v[td(e,g+12|0)>>2];v[g+12>>2]=f-d;a=v[h+4>>2];k=v[b>>2];v[g+8>>2]=d;m=32-a|0;v[g+4>>2]=m;f=v[h>>2];n=v[f>>2];e=v[Kb(e,g+4|0)>>2];j=k&(-1<<c&-1>>>j-d);v[f>>2]=(-1<<a&-1>>>m-e^-1)&n|(a>>>0>c>>>0?j<<a-c:j>>>c-a|0);k=a+e|0;a=k&31;v[h+4>>2]=a;f=f+(k>>>3&536870908)|0;v[h>>2]=f;d=d-e|0;if((d|0)>0){v[f>>2]=v[f>>2]&(-1>>>32-d^-1)|j>>>c+e;v[h+4>>2]=d;a=d}b=b+4|0;f=v[g+12>>2]}d=32-a|0;e=-1<<a;j=e^-1;while(1){if((f|0)>=32){c=v[h>>2];f=v[b>>2];v[c>>2]=j&v[c>>2]|f<<a;v[h>>2]=c+4;v[c+4>>2]=e&v[c+4>>2]|f>>>d;f=v[g+12>>2]-32|0;v[g+12>>2]=f;b=b+4|0;continue}break}if((f|0)<=0){break d}j=v[b>>2];v[g+8>>2]=d;c=v[h>>2];b=v[c>>2];k=b;b=v[td(g+12|0,g+8|0)>>2];d=k&(e&-1>>>d-b^-1);e=j&-1>>>32-f;v[c>>2]=d|e<<a;d=a+b|0;a=d&31;v[h+4>>2]=a;c=c+(d>>>3&536870908)|0;v[h>>2]=c;d=v[g+12>>2]-b|0;v[g+12>>2]=d;if((d|0)<=0){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|e>>>b;a=v[g+12>>2];v[h+4>>2]=a}hc(i,v[h>>2],a);kb=g+16|0}kb=l+16|0}function Ur(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=kb-128|0;kb=i;v[i+120>>2]=b;k=GG(c,d);v[i+4>>2]=1123;m=FG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Pd(k);if(!j){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}_e(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[23588]=0;h=Q(1125,a|0,i+120|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[23588]=0;b=Q(1126,a|0,i+120|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[23588]=0;n=S(1127,b|0)|0;b=v[23588];v[23588]=0;g:{if((b|0)!=1){if(g){break g}v[23588]=0;n=Q(1128,e|0,n|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[23588]=0;S(1129,a|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Hb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[hg(b,o)|0];j:{if(g){break j}v[23588]=0;p=Q(1128,e|0,p<<24>>24)|0;s=v[23588];v[23588]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((Hb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Xc(m);kb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Re(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Xc(m);T(b|0)}L()}function vi(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!Bi(p)){break a}if(!Bi(m)){break a}h=nf(b);f=nf(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=Bi(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=Bi(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=nf(d);f=nf(e);b:{if(f?1:h){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Bi(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Bi(c),w?u:v);break b}if(k){break b}c:{if(nf(s)){break c}if(nf(t)){break c}if(nf(r)){break c}if(!nf(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Bi(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Bi(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=Bi(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=Bi(e),w?u:v)}m=(b*e+d*c)*N;p=(b*d-e*c)*N}ol(a,p,m)}function kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=kb-224|0;kb=c;e=_l(c+112|0,a);v[23588]=0;d=Q(449,c+96|0,43806)|0;a=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[23588]=0;v[c+80>>2]=19988498;v[c+84>>2]=0;U(450,e|0,d|0,c+80|0);a=v[23588];v[23588]=0;if((a|0)==1){break n}$b(d);if(Lk(w[e|0])){break e}v[23588]=0;d=Q(449,c+80|0,13250)|0;a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;X(481,e|0,b|0,d|0,871);a=v[23588];v[23588]=0;if((a|0)==1){break l}$b(d);v[c+76>>2]=0;v[c+72>>2]=0;v[23588]=0;d=Q(449,c+56|0,16715)|0;a=v[23588];v[23588]=0;if((a|0)==1){break k}v[23588]=0;U(872,e|0,c+76|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}$b(d);v[23588]=0;d=Q(449,c+40|0,16687)|0;a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;U(872,e|0,c+72|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}$b(d);a=v[c+76>>2];d=v[c+72>>2];o:{if(!a|d>>>0<a>>>0){break o}f=v[v[v[v[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}v[b+20>>2]=d;v[b+16>>2]=a}d=Tb(c+24|0);v[23588]=0;f=Q(449,c+8|0,14076)|0;a=v[23588];v[23588]=0;if((a|0)==1){break d}v[23588]=0;U(873,e|0,d|0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}$b(f);if(pc(v[d>>2],v[d+4>>2])){break f}a=v[b+16>>2];v[23588]=0;R(826,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;$b(d);break a}a=P()|0;O()|0;$b(f);break b}v[23588]=0;R(874,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}wc(d)}lh(e);kb=c+224|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}wc(d)}lh(e);T(a|0);L()}function Sr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=kb-128|0;kb=i;v[i+120>>2]=b;k=GG(c,d);v[i+4>>2]=1123;m=FG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Pd(k);if(!j){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}_e(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[23588]=0;h=Q(1141,a|0,i+120|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[23588]=0;b=Q(1142,a|0,i+120|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[23588]=0;n=S(1143,b|0)|0;b=v[23588];v[23588]=0;g:{if((b|0)!=1){if(g){break g}v[23588]=0;n=Q(1144,e|0,n|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[23588]=0;S(1145,a|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Hb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[Ai(b,o)>>2];j:{if(g){break j}v[23588]=0;p=Q(1144,e|0,p|0)|0;s=v[23588];v[23588]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((Hb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Xc(m);kb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Re(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Xc(m);T(b|0)}L()}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=kb-48|0;kb=g;o=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;v[j+4>>2]=v[e+44>>2];v[j+8>>2]=v[e+48>>2];f=f+1|0;continue}break}j=v[a+24>>2];p=v[a+20>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){f=v[g+16>>2];k=((((v[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=u[b+14>>1];h=u[b+12>>1];l=u[b+10>>1];m=u[b+8>>1];n=u[b+6>>1];D=u[b+4>>1];E=u[b+2>>1];F=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=k+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((((B(u[b+8>>1],l)+B(u[b+4>>1],m)|0)+B(h,u[b+12>>1])|0)+B(i,u[b+16>>1])|0)/2|0)+((((B(u[b-8>>1],E)+B(u[b-12>>1],F)|0)+B(u[b-4>>1],D)|0)+B(u[b>>1],n)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=v[k>>2];b=(g+24|0)+(f<<3)|0;i=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;l=e<<8;e=l;e=Oka(y,z,e,e>>31);m=nb;n=b;b=Yb(h,-16777216,16776704);h=Oka(w,x,b,b>>31);e=h+e|0;b=nb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Yb(i,-16777216,16776704);i=Oka(s,t,e,e>>31);e=h+i|0;b=nb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Yc(e,b,24);v[n+4>>2]=b-(l&r);v[k>>2]=(b|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],p);v[c+4>>2]=v[c+4>>2]+B(j,v[g+12>>2]);Rb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}kb=g+48|0}function G6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb+-64|0;kb=d;f=1;a:{if(Re(c)){break a}e=w[QJ(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+48|0;Qv(e,c,0,Hb(c)-1|0);Bc(c,e);zb(e)}e=d+48|0;Xd(e);g=v[d+48>>2];Xd(d+40|0);g=PJ(g,v[d+44>>2],c);Xd(e);b:{c:{d:{e:{f:{if((g|0)==v[d+52>>2]){if(ve(c,21619)){a=ba(8)|0;v[23588]=0;b=Q(55,d+48|0,10432)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}if(!f){break f}a=ba(8)|0;v[23588]=0;U(958,d+48|0,17634,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){a=sc(a,d+48|0);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(d+48|0);break c}c=P()|0;O()|0;ca(a|0);break c}e=Mb(d+48|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:Ge(d+32|0,c);v[23588]=0;b=fa(959,b|0,v[d+32>>2],v[d+36>>2],f|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){v[23588]=0;t[d+40|0]=b;R(960,a|0,d+40|0);a=v[23588];v[23588]=0;if((a|0)!=1){break g}}break i;case 1:Ge(d+24|0,c);v[23588]=0;b=nF(b,v[d+24>>2],v[d+28>>2],f);c=nb;f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;v[d+40>>2]=b;v[d+44>>2]=c;R(962,a|0,d+40|0);a=v[23588];v[23588]=0;if((a|0)!=1){break g}}break i;case 2:Ge(d+16|0,c);v[23588]=0;h=+za(963,b|0,v[d+16>>2],v[d+20>>2],f|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;A[d+40>>3]=h;R(964,a|0,d+40|0);a=v[23588];v[23588]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}Ge(d+8|0,c);v[23588]=0;da(965,a|0,b|0,v[d+8>>2],v[d+12>>2],f|0);a=v[23588];v[23588]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;zb(e);break c}ad(a,e)}zb(e);break e}Mb(a)}kb=d- -64|0;return}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}function Yba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=kb-48|0;kb=h;f=OO(h+32|0,1<<v[b+12>>2]);g=v[f>>2];while(1){c=v[a>>2];if(Vg(c,v[a+4>>2])>>>0>d>>>0){c=bf(c,d);NO(Kd(g,d),A[c>>3]);d=d+1|0;continue}break}MO(b,f);x=h,y=Fb(v[f>>2]),v[x+8>>2]=y;w=Fb(v[f+4>>2]);while(1){g=v[h+8>>2];if(Pb(g,w)){m=A[g+8>>3];k=kb-32|0;kb=k;o(+A[g>>3]);e=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;q=e&2147483647;t=c&2147483647;d=t;c=(q|0)==(d|0)&r>>>0<s>>>0|d>>>0>q>>>0;e=c?r:s;c=c?q:d;d=c;l(0,e|0);l(1,c|0);p=+n();u=c>>>20|0;i=p;a:{if((u|0)==2047){break a}c=(q|0)==(t|0)&r>>>0>s>>>0|q>>>0>t>>>0;l(0,(c?r:s)|0);c=c?q:t;l(1,c|0);m=+n();b:{if(!(d|e)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-u|0)>=65){break a}c:{if(c>>>0>=1534){p=p*190109156629516e-225;m=m*190109156629516e-225;i=5.260135901548374e210;break c}i=1;if(u>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=190109156629516e-225}_H(k+24|0,k+16|0,m);_H(k+8|0,k,p);i=i*K(A[k>>3]+A[k+16>>3]+A[k+8>>3]+A[k+24>>3]);break a}i=m}p=i;kb=k+32|0;NO(g,Ap(p));fq(h+8|0);continue}break}LO(b,f);KO(f);e=v[f>>2];g=mk(e,v[f+4>>2])>>>1|0;c=g>>>0>1?g:1;d=1;while(1){if((c|0)!=(d|0)){nz(Kd(e,d),2);nz(Kd(e,d+g|0),0);d=d+1|0;continue}break}MO(b,f);x=h,y=Fb(v[f>>2]),v[x+24>>2]=y;g=Fb(v[f+4>>2]);while(1){e=v[h+24>>2];if(Pb(e,g)){JO(h+8|0,A[e>>3],A[e+8>>3]);c=v[h+20>>2];v[e+8>>2]=v[h+16>>2];v[e+12>>2]=c;c=v[h+12>>2];v[e>>2]=v[h+8>>2];v[e+4>>2]=c;fq(h+24|0);continue}break}LO(b,f);KO(f);g=v[a>>2];c=Vg(g,v[a+4>>2]);b=v[f>>2];d=0;while(1){if((c|0)==(d|0)){Cm(f);kb=h+48|0}else{a=Kd(b,d);x=bf(g,d),z=A[a>>3],A[x>>3]=z;d=d+1|0;continue}break}}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;g=kb-48|0;kb=g;o=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;v[j+4>>2]=v[e+44>>2];v[j+8>>2]=v[e+48>>2];f=f+1|0;continue}break}j=v[a+24>>2];p=v[a+20>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+72>>2];b=v[a+68>>2];s=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){if(d){f=v[g+16>>2];k=(((v[g+20>>2]&2147483647)<<1|f>>>31)&-2)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=u[b+14>>1];h=u[b+12>>1];l=u[b+10>>1];m=u[b+8>>1];n=u[b+6>>1];E=u[b+4>>1];F=u[b+2>>1];G=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+k|0;v[(g+8|0)+(e<<2)>>2]=(((((B(t[b+4|0],l)+B(t[b+2|0],m)|0)+B(h,t[b+6|0])|0)+B(i,t[b+8|0])<<8)/2|0)+((((B(t[b-4|0],F)+B(t[b-6|0],G)|0)+B(t[b-2|0],E)|0)+B(t[b|0],n)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=v[k>>2];b=(g+24|0)+(f<<3)|0;i=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;l=e<<8;e=l;e=Oka(z,A,e,e>>31);m=nb;n=b;b=Yb(h,-16777216,16776704);h=Oka(x,y,b,b>>31);e=h+e|0;b=nb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Yb(i,-16777216,16776704);i=Oka(s,w,e,e>>31);e=h+i|0;b=nb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Yc(e,b,24);v[n+4>>2]=b-(l&r);v[k>>2]=(b|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],p);v[c+4>>2]=v[c+4>>2]+B(j,v[g+12>>2]);Rb(g+16|0,C,D);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}kb=g+48|0}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=kb-16|0;kb=g;i=rf(a,c);ne(g,v[a+36>>2]);j=a;a:{if(!i){Sc(g,a+32|0,5);c=0;if(Cb(v[v[g>>2]>>2],v[g+4>>2])){break a}}e=kb-192|0;kb=e;f=_l(e+80|0,v[a+36>>2]);v[23588]=0;a=Q(449,e- -64|0,27807)|0;c=v[23588];v[23588]=0;b:{c:{d:{e:{if((c|0)!=1){v[23588]=0;v[e>>2]=19988498;v[e+4>>2]=0;U(450,f|0,a|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}$b(a);if(!Lk(w[f|0])){break d}break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;$b(a);break c}t[e+63|0]=0;t[e+62|0]=0;v[23588]=0;a=Q(449,e+48|0,10044)|0;c=v[23588];v[23588]=0;f:{g:{h:{i:{if((c|0)!=1){v[23588]=0;U(489,f|0,e+63|0,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break i}$b(a);if(!w[e+63|0]){break b}wf(e+63|0,50);v[23588]=0;a=Q(449,e+32|0,13140)|0;c=v[23588];v[23588]=0;if((c|0)==1){break f}v[23588]=0;U(489,f|0,e+62|0,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break g}$b(a);a=v[b>>2];c=sj(a,v[b+4>>2]);h=w[e+63|0];if(c>>>0<h>>>0){a=Bz(e,v[b+12>>2]);v[23588]=0;U(490,b|0,h|0,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break h}rl(a);a=v[b>>2]}k=x[yj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=w[e+62|0];n=b,o=sj(v[b>>2],v[b+4>>2])>>>0>a>>>0?a:0,t[n+16|0]=o;break b}Ve(yj(v[b>>2],a),k);l=v[b>>2];v[23588]=0;R(491,e|0,c|0);m=v[23588];v[23588]=0;if((m|0)!=1){v[23588]=0;X(492,f|0,yj(l,a)|0,e|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}c=c+1|0;$b(e);continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;$b(e);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;$b(a);break c}c=P()|0;O()|0;rl(a);break c}c=P()|0;O()|0;$b(a);break c}c=P()|0;O()|0}lh(f);T(c|0);L()}lh(f);kb=e+192|0;c=i}Ye(j,c);kb=g+16|0}function TW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=kb+-64|0;kb=f;zc(b);Xo(a);a:{if(!di(b,f+56|0)){break a}if(!tD(f+56|0)){break a}if(!c){l=1;break a}if(!Qb(v[b>>2],v[b+8>>2],4)){break a}Mv(a);p=f,q=Lv(),v[p+32>>2]=q;c=f+32|0;Kv(Uj(v[a+4>>2])+32|0,c);sr(c);k=v[Uj(v[a+4>>2])+32>>2];c=Wg(v[b>>2]);if(c&1){break a}d=c-4|0;dd(b,d);h=kb-16|0;kb=h;c=h+8|0;zv(c,b);e=w[Lb(c,0)|0];i=w[Lb(c,1)|0];c=w[Lb(c,2)|0];kb=h+16|0;h=c|(i<<8|e<<16);if(!h){break a}v[23588]=0;R(175,k|0,h|0);c=v[23588];v[23588]=0;l=1;if((c|0)==1){a=V(92948)|0;if((O()|0)==(ea(92948)|0)){_(a|0)|0;$();l=0;break a}T(a|0);L()}dd(b,4);m=f+32|0;sD(m,b);i=v[k>>2];e=kb-32|0;kb=e;b=v[f+32>>2];t[e+24|0]=w[b|0];t[e+25|0]=w[b+1|0];t[e+26|0]=w[b+2|0];t[e+27|0]=w[b+3|0];c=ir(e+8|0);d=b+d|0;v[c+12>>2]=d-4;v[c+8>>2]=b;Sj(c,w[d-1|0]);b=h;b:while(1){c:{d:{e:{if(!b){break e}if(Sj(c,1)){break d}d=1;while(1){g=Sj(c,2);d=g+d|0;if((g|0)==3){continue}break}v[e+4>>2]=d;xc(e+4|0,b);d=0;g=v[e+4>>2];while(1)if((d|0)==(g|0)){if(!b){break e}break d}else{b=b-1|0;p=i+b|0,q=Sj(c,8),t[p|0]=q;d=d+1|0;continue}}kb=e+32|0;break c}g=Sj(c,2);d=g+2|0;v[e+4>>2]=d;f:{if((g|0)==3){if(Sj(c,1)){g=w[Lb(e+24|0,3)|0]}else{g=7}g=Sj(c,g);while(1){j=Sj(c,3);d=j+d|0;if((j|0)==7){continue}break}v[e+4>>2]=d;break f}g=Sj(c,w[Lb(e+24|0,g)|0])}xc(e+4|0,b);d=0;o=v[e+4>>2];while(1){if((d|0)==(o|0)){continue b}j=0;n=b+g|0;if(h>>>0>n>>>0){j=w[i+n|0]}b=b-1|0;t[i+b|0]=j;d=d+1|0;continue}}break}se(f+16|0,v[k>>2],v[k+4>>2]);$g(f+24|0,v[f+16>>2],v[f+20>>2]);b=fe(f+8|0);b=qr(m,v[f+24>>2],v[f+28>>2],v[b>>2],v[b+4>>2]);hd(Uj(v[a+4>>2])+12|0,b);Bb(b)}kb=f- -64|0;return l|0}function mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=kb-48|0;kb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){e=v[g+16>>2];m=((((v[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+o|0;b=e>>>21&2040;j=u[b+39718>>1];i=u[b+39716>>1];n=u[b+39714>>1];l=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=m+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((B(u[f>>1],n)+B(u[f-4>>1],l)|0)+B(i,u[f+4>>1])|0)+B(j,u[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Oka(y,z,f,f>>31);l=nb;D=e;e=Yb(i,-16777216,16776704);i=Oka(w,x,e,e>>31);f=i+f|0;e=nb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Yb(j,-16777216,16776704);j=Oka(s,t,f,f>>31);f=l+j|0;e=nb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[D+4>>2]=e-(n&r);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Rb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=g+48|0}function hN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=kb-16|0;kb=c;d=a+1074376|0;e=B(b,872);a:{if(v[(d+e|0)+704>>2]&134218752){break a}h=v[(a+e|0)+1075648>>2];if(!qj(h)|w[h+15|0]&2){break a}d=Pl(a,d,b,2,1)-1|0;if((d&255)>>>0>249){break a}g=v[Md(a+906300|0,d)>>2];if(!g){break a}f=B(b,872)+a|0;j=f+1075780|0;d=w[j|0];b:{if(w[f+1075782|0]==1){t[c+8|0]=64;e=w[Xb(f+1075784|0,c+8|0)|0];break b}e=255;if(w[f+1075783|0]!=13){break b}t[c+8|0]=64;e=w[Xb((B(b,872)+a|0)+1075785|0,c+8|0)|0]}i=a+1074312|0;Db(c+8|0,i,2);if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){if(d){if($c(d)){d=w[Lb(h+108|0,d-1|0)|0]}tm(a,b,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((e|0)==255){break a}ob[v[v[g>>2]+76>>2]](g,39,e,b);break a}k=v[h+4>>2];c:{if(!d){break c}f=w[h+35|0]?k<<2:v[(B(b,872)+a|0)+1075680>>2];l=u[(B(b,872)+a|0)+1075768>>1];Db(c+8|0,i,28);m=c,n=f+(Cb(v[v[c+8>>2]>>2],v[c+12>>2])?l<<2:l)|0,v[m+4>>2]=n;pe(c+4|0,0,256);f=d;if($c(d)){f=w[Lb(h+108|0,d-1|0)|0]}Db(c+8|0,i,117);if(!Cb(v[v[c+8>>2]>>2],v[c+12>>2])){if(wm(w[j+2|0],w[j+3|0])){break c}}tm(a,b,f&255,x[c+4>>1])}f=w[h+35|0];Db(c+8|0,i,101);if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){a=(d|0)!=0}else{a=$c(d)}if(a^1|(f|0)!=1?(a|(e|0)==255)==1:0){break a}d:{switch(w[h+36|0]){case 1:if((e|0)!=255){ft(v[g+20>>2],C(C(C(e<<1)/C(-127))+C(1)));break a}ft(v[g+20>>2],C(C(C(k<<1>>>0)/C(-127))+C(1)));break a;case 0:break d;default:break a}}if((e|0)!=255){t[c+8|0]=127;t[c+4|0]=e<<1;n=g,o=7,p=w[Xb(c+8|0,c+4|0)|0],q=b,m=v[v[g>>2]+76>>2],ob[m](n|0,o|0,p|0,q|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;q=g,p=7,o=w[Kb(c+8|0,c+4|0)|0],n=b,m=v[v[g>>2]+76>>2],ob[m](q|0,p|0,o|0,n|0)}kb=c+16|0}function nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=kb-48|0;kb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){if(d){e=v[g+16>>2];m=(((v[g+20>>2]&2147483647)<<1|e>>>31)&-2)+o|0;b=e>>>21&2040;j=u[b+39718>>1];i=u[b+39716>>1];n=u[b+39714>>1];l=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+m|0;v[(g+8|0)+(e<<2)>>2]=(((B(t[f|0],n)+B(t[f-2|0],l)|0)+B(i,t[f+2|0])|0)+B(j,t[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Oka(z,A,f,f>>31);l=nb;E=e;e=Yb(i,-16777216,16776704);i=Oka(x,y,e,e>>31);f=i+f|0;e=nb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Yb(j,-16777216,16776704);j=Oka(s,w,f,f>>31);f=l+j|0;e=nb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[E+4>>2]=e-(n&r);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Rb(g+16|0,C,D);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=g+48|0}function vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=kb-48|0;kb=h;k=c+484344|0;xg(k,w[b+70|0]|w[b+71|0]<<8);a:{b:{while(1){if((w[b+70|0]|w[b+71|0]<<8)>>>0<=j>>>0){break b}f=v[a+8>>2];e=Cg(a);_b(a,1);c:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Me(a)+1|0;break c}c=Sg(a)}d=Sg(a);dd(a,e+f|0);ae(h,a,d);f=kc(h+24|0,h);Bb(h);v[23588]=0;c=W(226,k|0,j&65535,(c?c>>>0<1024?c:1024:64)|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Zb(v[k>>2],j);m=h,n=Fb(v[c>>2]),v[m>>2]=n;l=Fb(v[c+4>>2]);while(1){c=v[h>>2];if(!Pb(c,l)){break d}v[23588]=0;d=S(206,f|0)|0;e=v[23588];v[23588]=0;e:{f:{g:{if((e|0)!=1){if(!(d&128)){break g}if(d&1){v[23588]=0;e=S(206,f|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}t[c|0]=e}if(d&2){break f}break e}break a}t[c|0]=d;d=255}v[23588]=0;e=S(206,f|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break a}t[c+1|0]=e}i=0;e=0;if(d&4){v[23588]=0;e=S(206,f|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}}if(d&8){v[23588]=0;i=S(206,f|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}}if(d&16){v[23588]=0;d=S(206,f|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}t[c+5|0]=d}h:{i:{d=w[c|0];if(!d){break i}g=255;if((d|0)==97){break h}if(d>>>0>96){break i}g=d+12|0;break h}g=0}t[c|0]=g;d=w[c+5|0];j:{if((d|i)&255){Pf(c,i,d);break j}t[c+3|0]=0}if(w[c+1|0]==255){t[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){t[c+4|0]=d;t[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;t[c+4|0]=d;e=e-96>>4;t[c+2|0]=w[e+27134|0];if((e|0)!=6){break k}t[c+4|0]=d<<2}Ck(h);continue}}Bb(f);j=j+1|0;continue}break}break a}kb=h+48|0;return}a=P()|0;O()|0;Bb(f);T(a|0);L()}function KL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){while(1){g=Ch(d);d=v[d+8>>2];if(!g){continue}break}break c}d=MT(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(Ch(d)){c=v[d+8>>2];v[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=v[d+8>>2];v[c+4>>2]=e}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){f=v[b+8>>2];v[d+8>>2]=f;i=f+(Ch(b)?0:4)|0,j=d,v[i>>2]=j;f=v[b>>2];v[d>>2]=f;mm(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){mm(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=w[c+12|0];f:{g:{if(!Ch(c)){if(!b){t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;sq(b);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];h:{if(!(w[b+12|0]?0:b)){d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[c+12|0]=0;i:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break i}a=b}t[a+12|0]=1;return}if(!Ch(b)){break g}b=v[b+8>>2]+4|0;break f}d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[b+12|0]=1;t[c+12|0]=0;rq(c);c=v[c+8>>2];d=v[c+4>>2]}a=v[c+8>>2];t[c+12|0]=w[a+12|0];t[a+12|0]=1;t[d+12|0]=1;sq(a);return}if(!b){t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;rq(b);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];j:{if(w[d+12|0]?0:d){break j}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(Ch(b)){b=v[b+8>>2]+4|0;break f}b=v[b+8>>2];break f}if(w[d+12|0]?0:d){break j}t[b+12|0]=1;t[c+12|0]=0;sq(c);c=v[c+8>>2];d=v[c>>2]}a=v[c+8>>2];t[c+12|0]=w[a+12|0];t[a+12|0]=1;t[d+12|0]=1;rq(a);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function f$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=kb-624|0;kb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=1158;h=te(a+200|0,a+208|0,a+16|0);b=a+192|0;gd(b,e);v[23588]=0;i=S(1136,b|0)|0;b=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+191|0]=0;b=v[e+4>>2];v[23588]=0;b=qa(1166,a+616|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(!b){break e}b=w[14609]|w[14610]<<8|(w[14611]<<16|w[14612]<<24);t[a+183|0]=b;t[a+184|0]=b>>>8;t[a+185|0]=b>>>16;t[a+186|0]=b>>>24;b=w[14606]|w[14607]<<8|(w[14608]<<16|w[14609]<<24);v[a+176>>2]=w[14602]|w[14603]<<8|(w[14604]<<16|w[14605]<<24);v[a+180>>2]=b;v[23588]=0;X(1148,i|0,a+176|0,a+186|0,a+128|0);b=v[23588];v[23588]=0;if((b|0)==1){break g}v[a+4>>2]=1123;d=te(a+8|0,0,a+4|0);e=a+16|0;b=v[a+196>>2];c=b-v[h>>2]|0;if((c|0)<393){break f}_e(d,Pd((c>>2)+2|0));e=v[d>>2];if(e){break f}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)==1){break c}break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}if(w[a+191|0]){t[e|0]=45;e=e+1|0}c=v[h>>2];while(1){if(b>>>0<=c>>>0){t[e|0]=0;v[a>>2]=g;if((QG(a+16|0,a)|0)!=1){v[23588]=0;Y(1160,7960);b=v[23588];v[23588]=0;if((b|0)!=1){break a}break c}Xc(d)}else{b=a+128|0;j=e,k=w[(a+176|0)+(ww(b,b+40|0,v[c>>2])-b>>2)|0],t[j|0]=k;e=e+1|0;c=c+4|0;b=v[a+196>>2];continue}break}}v[23588]=0;b=Q(1142,a+616|0,a+608|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+616>>2];ac(a+192|0);Xc(h);kb=a+624|0;return b|0}c=P()|0;O()|0;break b}c=P()|0;O()|0;Xc(d)}ac(a+192|0);Xc(h);T(c|0);L()}L()}function m$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=kb-288|0;kb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=1158;h=te(a+152|0,a+160|0,a+16|0);b=a+144|0;gd(b,e);v[23588]=0;i=S(19,b|0)|0;b=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+143|0]=0;b=v[e+4>>2];v[23588]=0;b=qa(1159,a+280|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(!b){break e}b=w[14609]|w[14610]<<8|(w[14611]<<16|w[14612]<<24);t[a+135|0]=b;t[a+136|0]=b>>>8;t[a+137|0]=b>>>16;t[a+138|0]=b>>>24;b=w[14606]|w[14607]<<8|(w[14608]<<16|w[14609]<<24);v[a+128>>2]=w[14602]|w[14603]<<8|(w[14604]<<16|w[14605]<<24);v[a+132>>2]=b;v[23588]=0;X(1134,i|0,a+128|0,a+138|0,a+118|0);b=v[23588];v[23588]=0;if((b|0)==1){break g}v[a+4>>2]=1123;d=te(a+8|0,0,a+4|0);e=a+16|0;b=v[a+148>>2];c=b-v[h>>2]|0;if((c|0)<99){break f}_e(d,Pd(c+2|0));e=v[d>>2];if(e){break f}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)==1){break c}break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}if(w[a+143|0]){t[e|0]=45;e=e+1|0}c=v[h>>2];while(1){if(b>>>0<=c>>>0){t[e|0]=0;v[a>>2]=g;if((QG(a+16|0,a)|0)!=1){v[23588]=0;Y(1160,7960);b=v[23588];v[23588]=0;if((b|0)!=1){break a}break c}Xc(d)}else{b=a+118|0;j=e,k=w[((xi(b,WT(b),c)-a|0)+a|0)+10|0],t[j|0]=k;e=e+1|0;c=c+1|0;b=v[a+148>>2];continue}break}}v[23588]=0;b=Q(1126,a+280|0,a+272|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+280>>2];ac(a+144|0);Xc(h);kb=a+288|0;return b|0}c=P()|0;O()|0;break b}c=P()|0;O()|0;Xc(d)}ac(a+144|0);Xc(h);T(c|0);L()}L()}function N4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-48|0;kb=c;g=Tb(a);a:{b:{c:{d=b+36|0;a=v[d>>2];f=v[b+40>>2];d:{if(Pb(a,f)){Hc(c+40|0);break d}v[23588]=0;R(1028,c+24|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}v[23588]=0;a=S(1012,c+24|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}v[c+40>>2]=a;Xf(c+24|0);f=v[b+40>>2];a=v[b+36>>2]}if(!Pb(a,f)){d=v[c+40>>2];a=v[d>>2]}f=v[d+4>>2];v[23588]=0;R(181,g|0,Ri(a,f)|0);a=v[23588];v[23588]=0;e:{if((a|0)!=1){i=c,j=Fb(v[d>>2]),v[i+16>>2]=j;f=Fb(v[d+4>>2]);f:{g:{h:{i:{j:{k:{while(1){a=v[c+16>>2];if(!Pb(a,f)){bl(c+40|0);kb=c+48|0;return}d=w[a+16|0];e=v[v[b+24>>2]+484360>>2];v[23588]=0;d=yj(e,d);R(1029,c|0,d|0);e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;R(1015,c+24|0,c|0);e=v[23588];v[23588]=0;if((e|0)==1){break k}v[23588]=0;R(183,g|0,c+24|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}zb(c+24|0);Ab(c);l:{if(!Re(px(v[g+4>>2]))){break l}e=w[a+12|0];v[23588]=0;e=Q(311,d|0,e|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break f}if(!e){break l}e=v[b+24>>2];h=v[e+1298404>>2];a=x[dc(v[d>>2],v[a+12>>2])>>1];d=v[e+484344>>2];v[23588]=0;R(1022,c|0,Zb(d,a)|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}v[23588]=0;X(235,c+24|0,0,h|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}a=c+24|0;Bc(px(v[g+4>>2]),a);zb(a);zb(c)}Ux(c+16|0);continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break i}a=P()|0;O()|0;zb(c+24|0)}Ab(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;zb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}bl(c+40|0);break a}a=P()|0;O()|0;Xf(c+24|0);break a}a=P()|0;O()|0}Xe(g);T(a|0);L()}function ny(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=kb-16|0;kb=e;i=rM(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}f=v[i>>2];j=a+1074312|0;Db(e+8|0,j,31);g=Cb(v[v[e+8>>2]>>2],v[e+12>>2]);d=jv(v[b+656>>2],c);if(pc(v[d>>2],v[d+4>>2])){break a}g=f+(g^1)|0;Db(e+8|0,j,31);f=w[d+12|0];b:{c:{if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){d:{if(!(f&2)){break d}h=w[d+14|0];k=!(v[a+480180>>2]&1048580)+x[Eb(v[d>>2],h)>>1]|0;if(!(w[b+89|0]&8)|(!(f&4)|(h|0)!=w[d+16|0])){f=l}else{Db(e+8|0,j,70);f=Cb(v[v[e+8>>2]>>2],v[e+12>>2])}if(f|(g|0)!=(k|0)){break d}g=x[Eb(v[d>>2],w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){a=v[d>>2];if((x[Eb(a,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Eb(a,w[d+15|0])>>1];Db(e+8|0,j,93);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}k=1;f=x[Bj(v[d+4>>2])>>1];if(g>>>0>f>>>0){break c}break b}e:{f:{if(!(!(f&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}Db(e+8|0,j,97);if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}f=w[d+12|0]}if(f&2){h=v[d>>2];f=x[Eb(h,w[d+13|0])>>1];h=x[Eb(h,w[d+14|0])>>1]+1|0;break e}f=x[Bj(v[d+4>>2])>>1];k=g>>>0>f>>>0;h=f;break e}h=v[d>>2];f=x[Eb(h,w[d+15|0])>>1];h=x[Eb(h,w[d+16|0])>>1]+1|0}f=g>>>0<h>>>0?g:f}g:{if(!k|c){break g}g=v[a+480180>>2];c=v[b+88>>2];if(!(!(g&16777248)&(!(c&2048)|(g|0)==16384))){c=c|4096;v[b+88>>2]=c}if(w[Bj(v[d+4>>2])+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=c|4096}g=f}Db(e+8|0,j,31);m=i,n=Cb(v[v[e+8>>2]>>2],v[e+12>>2])+g|0,v[m>>2]=n}kb=e+16|0}function bt(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=kb-144|0;kb=g;a:{b:{c:{d:{e:{f:{g:{h:{if(!d){break h}e=v[d+4>>2];if(!e&c>>>0<=y[d>>2]|e){break h}a=ba(8)|0;v[23588]=0;b=Q(27,a|0,21619)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break g}b=P()|0;O()|0;ca(a|0);break a}if(!b){a=ba(8)|0;v[23588]=0;b=S(815,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break f}b=P()|0;O()|0;ca(a|0);break a}e=kb-16|0;kb=e;$g(e+8|0,b,c);h=g+120|0;QD(h,v[e+8>>2],v[e+12>>2]);v[h+12>>2]=0;kb=e+16|0;i:{j:{if(a&2){b=an(g+96|0,h);v[23588]=0;b=S(816,b|0)|0;f=v[23588];v[23588]=0;e=1;if((f|0)==1){break i}if((b|0)==1){break j}e=an(g+72|0,h);v[23588]=0;f=S(817,e|0)|0;i=v[23588];v[23588]=0;e=1;if((i|0)==1){break e}k=(f|0)==1;if(k){break j}e=an(g+48|0,h);v[23588]=0;i=Q(818,e|0,d|0)|0;j=v[23588];v[23588]=0;e=1;if((j|0)==1){break d}l=(i|0)==1;if(l){break j}e=an(g+24|0,h);v[23588]=0;j=Q(819,e|0,d|0)|0;m=v[23588];v[23588]=0;e=1;if((m|0)==1){break c}if((j|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(f|0)==-1?-1:b;f=(j|0)==-1?-1:l?b:(i|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31552;while(1){if((b|0)==32092){break k}a=v[b>>2];if(a){e=an(g,h);v[23588]=0;a=Q(a|0,e|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}e=1;if((a|0)==1){break j}f=(a|0)==-1?-1:f}b=b+12|0;continue}}if(d){e=0;if((f|0)!=-1){break j}e=Ec(v[d>>2],v[d+4>>2])>>>0>c>>>0?-1:0;break j}e=0;if((f|0)!=-1){break j}e=c>>>0>2047?1:-1}kb=g+144|0;return e}b=P()|0;O()|0;break a}ha(b|0,93240,25);L()}ha(b|0,93136,25);L()}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}T(b|0);L()}function Cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=kb-48|0;kb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){b=v[g+16>>2];l=b>>>18|0;j=((((v[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=j+(e<<1)|0;f=u[i>>1];v[(g+8|0)+(e<<2)>>2]=f+((B(l,u[i+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Oka(y,z,f,f>>31);m=nb;D=e;e=Yb(i,-16777216,16776704);i=Oka(w,x,e,e>>31);f=i+f|0;e=nb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Yb(j,-16777216,16776704);j=Oka(s,t,f,f>>31);f=m+j|0;e=nb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[D+4>>2]=e-(r&n);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Rb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=g+48|0}function Dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=kb-48|0;kb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){b=v[g+16>>2];l=b>>>10&4194048;j=(((v[g+20>>2]&2147483647)<<1|b>>>31)&-2)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=e+j|0;f=t[i|0];v[(g+8|0)+(e<<2)>>2]=((B(l,t[i+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Oka(y,z,f,f>>31);m=nb;D=e;e=Yb(i,-16777216,16776704);i=Oka(w,x,e,e>>31);f=i+f|0;e=nb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Yb(j,-16777216,16776704);j=Oka(s,u,f,f>>31);f=m+j|0;e=nb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[D+4>>2]=e-(r&n);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Rb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=g+48|0}function Sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=kb-48|0;kb=g;p=v[a+16>>2];m=Tf(1,2);b=nb;q=b;Rb(a,m,b);b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){d=d-1|0;f=((((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&2147483646)<<1)+p|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=u[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){n=(g+8|0)+(b<<2)|0;f=v[n>>2];e=(g+24|0)+(b<<3)|0;k=v[e+8>>2];j=v[e+4>>2];v[e+8>>2]=j;o=f<<8;f=o;f=Oka(A,C,f,f>>31);l=nb;F=e;e=Yb(j,-16777216,16776704);j=Oka(y,z,e,e>>31);f=j+f|0;e=nb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Yb(k,-16777216,16776704);k=Oka(w,x,f,f>>31);f=l+k|0;e=nb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[F+4>>2]=e-(t&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],i>>12);h=h+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Rb(g+16|0,D,E);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}mg(a,m,q);kb=g+48|0}function U_(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;v[c>>2]=a;y=d&512;z=h<<2;while(1){if((x|0)==4){if(Hb(n)>>>0>1){f=ie(n);e=kb-16|0;kb=e;v[e+8>>2]=f;f=v[Le(e+8|0)>>2];kb=e+16|0;B=c,C=Qi(f,Uk(n),v[c>>2]),v[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}}else{a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];h=$r(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 3:if(Re(n)){break a}h=v[Ai(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 2:if(Re(m)|!y){break a}B=c,C=Qi(ie(m),Uk(m),v[c>>2]),v[B>>2]=C;break a;case 4:break b;default:break a}}A=v[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!Xk(g,64,v[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=v[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){h=h-4|0;s=v[h>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=s;q=q-1|0;p=r;continue}break}d:{if(!q){s=0;break d}s=$r(g,48);p=v[c>>2]}while(1){r=p+4|0;if((q|0)>0){v[p>>2]=s;q=q-1|0;p=r;continue}break}v[c>>2]=r;v[p>>2]=j}e:{if((e|0)==(h|0)){p=$r(g,48);q=v[c>>2];h=q+4|0;v[c>>2]=h;v[q>>2]=p;break e}if(Re(l)){s=-1}else{s=t[hg(l,0)|0]}q=0;u=0;while(1){if((e|0)!=(h|0)){r=v[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;v[c>>2]=p;v[r>>2]=k;r=0;u=u+1|0;if(Hb(l)>>>0<=u>>>0){s=q;break f}s=-1;if(w[hg(l,u)|0]==127){break f}s=t[hg(l,u)|0]}h=h-4|0;q=v[h>>2];v[c>>2]=p+4;v[p>>2]=q;q=r+1|0;continue}break}h=v[c>>2]}Tr(A,h)}x=x+1|0;continue}break}}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=kb-48|0;kb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){e=v[g+16>>2];k=((((v[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+m|0;b=e>>>21&2040;i=u[b+39718>>1];h=u[b+39716>>1];l=u[b+39714>>1];j=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=k+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((B(u[f>>1],l)+B(u[f-4>>1],j)|0)+B(h,u[f+4>>1])|0)+B(i,u[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Oka(w,x,f,f>>31);j=nb;A=e;e=Yb(h,-16777216,16776704);h=Oka(s,t,e,e>>31);f=h+f|0;e=nb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Yb(i,-16777216,16776704);i=Oka(q,r,f,f>>31);f=j+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[A+4>>2]=e-(l&p);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],n);Rb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=g+48|0}function QK(a){var b=C(0),c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,k=0,l=C(0),m=0,n=C(0);c=kb-16|0;kb=c;e=a+4208|0;b=Fx(z[Eb(e,2)>>2]);f=v[a+16>>2]+24620|0;z[c+12>>2]=b/C(y[f>>2]);v[c+8>>2]=1056964608;b=Cp(C(z[om(c+12|0,c+8|0)>>2]*C(6.2831854820251465)));b=C(K(C(C(C(b+b)+C(3))/C(5))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));b=C(C(z[Eb(e,1)>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){i=~~b>>>0;break a}i=0}t[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}t[a+4273|0]=k;l=ue(C(10),C(C(C(z[e>>2]*C(60))+C(-60))/C(20)));m=c,n=C(Fx(z[Eb(e,3)>>2])/C(y[f>>2])),z[m+12>>2]=n;v[c+8>>2]=1056964608;g=z[om(c+12|0,c+8|0)>>2];m=c,n=C(Fx(z[Eb(e,4)>>2])/C(y[f>>2])),z[m+12>>2]=n;v[c+8>>2]=1056964608;b=C(C(z[om(c+12|0,c+8|0)>>2]*C(6.2831854820251465))*C(.5));f=kb-16|0;kb=f;e=(p(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=Fn(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=Fn(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=Fn(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=Fn(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=Fn(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=C(b-b);break b}d=ax(b,f+8|0);b=Fn(A[f+8>>3],d&1)}kb=f+16|0;b=C(C(C(1)-b)/C(b+C(1)));z[a+4268>>2]=b;g=Cp(C(g*C(6.2831854820251465)));z[a+4264>>2]=-g;z[a+4260>>2]=C(C(l*C(K(C(C(1)-C(g*g)))))*C(K(C(C(1)-C(b*b)))))*z[(i<<2)+45600>>2];kb=c+16|0}function Tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=kb-48|0;kb=g;p=v[a+16>>2];m=Tf(1,2);b=nb;q=b;Rb(a,m,b);b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+32>>2];s=v[a+28>>2];u=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){d=d-1|0;f=(((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&-2)+p|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=t[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){n=(g+8|0)+(b<<2)|0;f=v[n>>2];e=(g+24|0)+(b<<3)|0;k=v[e+8>>2];j=v[e+4>>2];v[e+8>>2]=j;o=f<<8;f=o;f=Oka(A,C,f,f>>31);l=nb;F=e;e=Yb(j,-16777216,16776704);j=Oka(y,z,e,e>>31);f=j+f|0;e=nb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Yb(k,-16777216,16776704);k=Oka(w,x,f,f>>31);f=l+k|0;e=nb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[F+4>>2]=e-(u&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],i>>12);h=h+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Rb(g+16|0,D,E);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}mg(a,m,q);kb=g+48|0}function aK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0);e=kb-48|0;kb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=v[a+24>>2];if((b|0)==v[d+24604>>2]){break d}a=e+8|0;uc(a,d+24604|0,40);v[e+8>>2]=b;ry(d,a);break d;case 2:f=v[a+24>>2];d=f+24664|0;b=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=b;d=f+24656|0;b=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=b;b=v[f+24652>>2];v[e+8>>2]=v[f+24648>>2];v[e+12>>2]=b;d=kb-16|0;kb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ba(8)|0;v[23588]=0;b=Q(55,d|0,10751)|0;a=v[23588];v[23588]=0;i:{if((a|0)!=1){a=sc(c,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break g}a=P()|0;O()|0;zb(b);break i}a=P()|0;O()|0;ca(c|0)}T(a|0);L()}kb=d+16|0;break f}L()}t[e+8|0]=b;a=v[a+24>>2];if(!xx(e+8|0,a+24648|0)){break d}py(a,e+8|0);break d;case 3:f=e+8|0;d=v[a+24>>2];uc(f,d+24604|0,40);b=kb-48|0;kb=b;j:{if((c|0)==-1){Cs(f,v[cq(b+8|0)+32>>2]);co(f,v[cq(b+8|0)+36>>2]);break j}if((c|0)<=0){Cs(f,0);co(f,0);break j}a=B(c,1e3);Cs(f,a);co(f,a)}kb=b+48|0;if(v[d+24636>>2]==v[e+40>>2]&v[d+24640>>2]==v[e+44>>2]){break d}ry(d,e+8|0);break d;default:d=ba(8)|0;v[23588]=0;c=Q(55,e+8|0,10335)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(d,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break b;case 0:break e}}g=a,h=ue(C(10),C(C(C(c|0)*C(.0010000000474974513))*C(.5))),z[g+48>>2]=h}kb=e+48|0;return}b=P()|0;O()|0;ca(d|0)}T(b|0)}L()}function Jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-112|0;kb=c;Cj(c+88|0,b,1413829443);v[23588]=0;b=S(178,v[c+88>>2])|0;d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[23588]=0;U(771,c- -64|0,a+140|0,1413894985);a=v[23588];v[23588]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[23588]=0;a=Q(848,c- -64|0,13560)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}b=28591;if(a){b=Mb(c+48|0);v[23588]=0;a=S(202,c- -64|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break m}v[23588]=0;U(268,c- -64|0,b|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break m}v[23588]=0;d=Q(54,c+16|0,b|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break l}v[23588]=0;Y(849,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break k}v[23588]=0;U(850,c+32|0,d|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break j}a=c+32|0;e=Bc(b,a);zb(a);zb(c);zb(d);v[23588]=0;U(11,a|0,2,e|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}v[23588]=0;a=S(742,c+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}Ab(c+32|0);zb(e);b=a-1>>>0<19398657?1252:28591}Bb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;zb(c)}zb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ab(c+32|0)}zb(b);break d}a=P()|0;O()|0}Bb(c- -64|0);break b}v[23588]=0;a=W(156,v[c+88>>2],v[c+96>>2],2)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[23588]=0;b=S(194,c+88|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}Bb(c+88|0);T(a|0);L()}Bb(c+88|0);kb=c+112|0;return b|0}function Zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=kb-16|0;kb=h;a:{b:{c:{i=v[a+12>>2];j=v[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];e=v[a+68>>2];w=e;x=e>>31;e=v[a+64>>2];y=e;z=e>>31;e=v[a+60>>2];A=e;C=e>>31;while(1){e=b;if(d){b=Yb(e,-16777216,16776704);b=Oka(y,z,b,b>>31);m=nb;n=b;g=(v[h+12>>2]<<1)+q|0;b=(v[h+8>>2]>>>16&65520)+p|0;g=(((((((B(u[g-4>>1],u[b+2>>1])+B(u[g-6>>1],u[b>>1])|0)+B(u[g-2>>1],u[b+4>>1])|0)+B(u[g>>1],u[b+6>>1])|0)+B(u[g+2>>1],u[b+8>>1])|0)+B(u[g+4>>1],u[b+10>>1])|0)+B(u[g+6>>1],u[b+12>>1])|0)+B(u[g+8>>1],u[b+14>>1])|0)/32768<<8;b=g;b=Oka(b,b>>31,A,C);n=n+b|0;o=nb+m|0;o=b>>>0>n>>>0?o+1|0:o;b=Yb(f,-16777216,16776704);f=Oka(w,x,b,b>>31);m=f+n|0;b=nb+o|0;b=f>>>0>m>>>0?b+1|0:b;f=m+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Yc(f,b,24);b=(f|0)/256|0;l=l+s|0;v[c>>2]=B(b,l>>12)+v[c>>2];k=k+r|0;v[c+4>>2]=v[c+4>>2]+B(b,k>>12);Rb(h+8|0,j,i);b=f-(g&t)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;v[a+40>>2]=k;v[a+20>>2]=l>>12;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=k>>12;kb=h+16|0}function Vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;k=f,l=Aj(b),v[k>>2]=l;e=kb-16|0;kb=e;h=a;c=Td(a);a:{if(c){g=jc(h);while(1){a=c;c=a+14|0;if(Ht(b,c)){g=a;c=v[a>>2];if(c){continue}break a}if(!Ht(c,b)){break a}g=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=jc(h);g=a}v[e+12>>2]=a;b=v[g>>2];if(!b){i=kb-16|0;kb=i;a=jc(h);j=mh(e,tc(48),nh(i+8|0,a));a=v[j>>2];b=v[f>>2];c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+14|0]=d;t[a+15|0]=d>>>8;t[a+16|0]=d>>>16;t[a+17|0]=d>>>24;t[a+18|0]=c;t[a+19|0]=c>>>8;t[a+20|0]=c>>>16;t[a+21|0]=c>>>24;c=w[b+28|0]|w[b+29|0]<<8|(w[b+30|0]<<16|w[b+31|0]<<24);d=w[b+24|0]|w[b+25|0]<<8|(w[b+26|0]<<16|w[b+27|0]<<24);t[a+38|0]=d;t[a+39|0]=d>>>8;t[a+40|0]=d>>>16;t[a+41|0]=d>>>24;t[a+42|0]=c;t[a+43|0]=c>>>8;t[a+44|0]=c>>>16;t[a+45|0]=c>>>24;c=w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24);d=w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24);t[a+30|0]=d;t[a+31|0]=d>>>8;t[a+32|0]=d>>>16;t[a+33|0]=d>>>24;t[a+34|0]=c;t[a+35|0]=c>>>8;t[a+36|0]=c>>>16;t[a+37|0]=c>>>24;c=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);b=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a+22|0]=b;t[a+23|0]=b>>>8;t[a+24|0]=b>>>16;t[a+25|0]=b>>>24;t[a+26|0]=c;t[a+27|0]=c>>>8;t[a+28|0]=c>>>16;t[a+29|0]=c>>>24;u[a+46>>1]=0;k=jc(j),l=1,t[k+4|0]=l;kb=i+16|0;Kg(h,v[e+12>>2],g,v[e>>2]);b=ce(e);rk(e);d=1}Jg(f+8|0,v[fc(e,b)>>2],d);kb=e+16|0;a=ro(v[f+8>>2]);kb=f+16|0;return a+32|0}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=kb-16|0;kb=g;w=v[a+16>>2];x=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);p=v[a+128>>2];a:{if(!p){n=v[a+8>>2];s=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];o=0;break a}b=v[a+12>>2];s=b;n=v[a+8>>2];q=lg(n,b,p);r=nb;k=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Qf(i,e,lf(n,b,d),nb);o=k>>>0<nb>>>0?d:0}h=a+112|0;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=(e<<1)+w|0;b=p;while(1)if((b|0)<=0){Rb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Sd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Rd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];y=v[a+32>>2];m=v[a+28>>2]+m|0;b=v[a+60>>2];e=b;j=b>>31;t=jg(h,x)<<8;b=t;b=Oka(e,j,b,b>>31);z=nb;e=b;b=v[a+64>>2];j=b;A=b>>31;b=Yb(k,-16777216,16776704);j=Oka(j,A,b,b>>31);e=e+j|0;b=nb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Yb(f,-16777216,16776704);e=Oka(e,e>>31,f,f>>31);f=j+e|0;b=nb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Yc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(m>>12,f)+v[c>>2];l=l+y|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,f);Rb(g,n,s);b=b-(i&t)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=k;continue b}else{Sd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Rd(h,4);Rb(g+8|0,q,r);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=l>>12;kb=g+16|0}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;g=kb-48|0;kb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){if(d){e=v[g+16>>2];k=(((v[g+20>>2]&2147483647)<<1|e>>>31)&-2)+m|0;b=e>>>21&2040;i=u[b+39718>>1];h=u[b+39716>>1];l=u[b+39714>>1];j=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+k|0;v[(g+8|0)+(e<<2)>>2]=(((B(t[f|0],l)+B(t[f-2|0],j)|0)+B(h,t[f+2|0])|0)+B(i,t[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Oka(x,y,f,f>>31);j=nb;C=e;e=Yb(h,-16777216,16776704);h=Oka(s,w,e,e>>31);f=h+f|0;e=nb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Yb(i,-16777216,16776704);i=Oka(q,r,f,f>>31);f=j+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[C+4>>2]=e-(l&p);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],n);Rb(g+16|0,z,A);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=g+48|0}function Nba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,A=0;f=kb+-64|0;kb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}s=l-4|0;o=B(b,e);x=o-8|0;h:while(1){b=v[c+8>>2];h=v[c>>2];v[23588]=0;b=W(156,h|0,b|0,l|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}v[23588]=0;U(190,f+16|0,c|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}b=f+16|0;h=kc(f+40|0,b);Bb(b);v[23588]=0;R(560,b|0,h|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}y=Je(f+16|0);p=v[f+16>>2];z=p-4|0;k=0;while(1){if((e|0)==(k|0)){Uc(f+16|0);Bb(h);n=(p-l<<1)+n|0;continue h}v[23588]=0;g=S(553,h|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){v[23588]=0;b=S(206,h|0)|0;j=v[23588];v[23588]=0;if((j|0)==1){break f}v[f+8>>2]=b;pe(f+8|0,0,89);v[23588]=0;Q(188,h|0,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>x>>>0){break j}m=0;if(b>>>0>z>>>0){break j}while(1)if((m|0)==8){b=b+s|0;continue i}else{q=v[f+8>>2];i=w[b+y|0];r=m&1;i=r?i>>>4|0:i&15;v[f+8>>2]=q+t[(i&7)+30264|0];A=g;g=u[(q<<1)+30272>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;v[f+12>>2]=A+(i&8?0-g|0:g);pe(f+8|0,0,88);pe(f+12|0,-32768,32767);g=v[f+12>>2];u[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+r|0;continue}}break}k=k+1|0;continue}break}break}break f}Bb(c);kb=f- -64|0;return}b=P()|0;O()|0;Uc(f+16|0);break d}b=P()|0;O()|0}Bb(h);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}Bb(c);T(b|0);L()}function hh(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=kb-16|0;kb=c;a:{if((d|0)==189){t[a+3843|0]=e>>>7;t[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=B(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){co(f,g);break b}co(f,0)}t[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=B(d&256?b+9|0:b,44)+a|0;v[c+8>>2]=a+16;b=v[a+52>>2];v[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=v[(c+8|0)+(b<<2)>>2];ZO(v[a>>2],d);ZO(v[a+4>>2],d);u[a+22>>1]=h;tz(a);$O(a);t[a+21|0]=f;tz(a);$O(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=v[(c+8|0)+(b<<2)>>2];u[a+20>>1]=x[a+20>>1]&768|e&255;tz(a);b=b+1|0;continue}}t[a+58|0]=(e&32)>>>5;t[a+57|0]=(e&16)>>>4;b=e>>>1&7;u[a+46>>1]=b?9-b|0:0;u[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=t[(d&31)+28992|0];a=(f+B(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:t[a+79|0]=e>>>7;t[a+80|0]=(e&64)>>>6;t[a+78|0]=(e&32)>>>5;t[a+77|0]=(e&16)>>>4;eo(a);u[a+14>>1]=x[((e&15)<<1)+29024>>1];break a;case 1:u[a+68>>1]=w[(e>>>6|0)+21604|0];_O(a);u[a+22>>1]=(e&63)<<2;break a;case 2:u[a+24>>1]=e>>>4;eo(a);u[a+26>>1]=e&15;eo(a);break a;case 3:b=e>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=e&15;eo(a);break a;case 6:break d;default:break a}}u[a+12>>1]=e&7}kb=c+16|0;return}ob[v[v[b>>2]>>2]](b,c,d,e)}function PW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=kb-48|0;kb=f;g=ui(b)^-1;a:{if(vc(v[d>>2],v[d+4>>2])>>>0<=g>>>0){$s(a);break a}ui(b);if((w[c+4|0]|w[c+5|0]<<8)>>>0>=60){_b(b,4)}j=f,k=ui(b),v[j+44>>2]=k;_b(b,4);h=ui(b);i=ui(b);if(!((h|0)>0&(i|0)>36)){$s(a);break a}if(yq(Nd(v[e>>2],v[Eb(v[d>>2],g)>>2]),13017)){$s(a);break a}Iv(f,b,i,h);d=kc(f+24|0,f);Bb(f);b=v[d>>2];v[23588]=0;b=S(178,b|0)|0;e=v[23588];v[23588]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){v[23588]=0;S(187,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break d}break b}b=w[c+4|0]|w[c+5|0]<<8;if(b>>>0<=39){v[23588]=0;Q(188,d|0,8)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}b=w[c+4|0]|w[c+5|0]<<8}if((b&65535)>>>0<=59){v[23588]=0;Q(188,d|0,16)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}}v[23588]=0;S(189,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}e:{f:{b=w[c+4|0]|w[c+5|0]<<8;g:{if(b>>>0>=120){v[23588]=0;S(189,d|0)|0;c=v[23588];v[23588]=0;b=8;break g}h:{if(b>>>0>=100){v[23588]=0;Q(188,d|0,4)|0;b=v[23588];v[23588]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}v[23588]=0;S(189,d|0)|0;c=v[23588];v[23588]=0;b=4}if((c|0)==1){break b}v[23588]=0;Q(188,d|0,b|0)|0;break e}v[23588]=0;S(189,d|0)|0}b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;b=S(189,d|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}v[23588]=0;U(190,f|0,d|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}j=kc(a,f),k=v[f+44>>2],v[j+20>>2]=k;Bb(f)}Bb(d);break a}}a=P()|0;O()|0;Bb(d);T(a|0);L()}kb=f+48|0}function _ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;h=kb-16|0;kb=h;a:{b:{c:{i=v[a+12>>2];k=v[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];b=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];e=v[a+44>>2];f=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=f;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];f=v[a+68>>2];s=f;w=f>>31;f=v[a+64>>2];x=f;y=f>>31;f=v[a+60>>2];z=f;A=f>>31;while(1){f=e;if(d){e=Yb(f,-16777216,16776704);e=Oka(x,y,e,e>>31);g=nb;j=e;b=Yb(b,-16777216,16776704);e=Oka(s,w,b,b>>31);j=j+e|0;b=nb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=v[h+12>>2]+o|0;e=(v[h+8>>2]>>>16&65520)+n|0;g=(((((((B(t[g-2|0],u[e+2>>1])+B(t[g-3|0],u[e>>1])|0)+B(t[g-1|0],u[e+4>>1])|0)+B(t[g|0],u[e+6>>1])|0)+B(t[g+1|0],u[e+8>>1])|0)+B(t[g+2|0],u[e+10>>1])|0)+B(t[g+3|0],u[e+12>>1])|0)+B(t[g+4|0],u[e+14>>1])<<8)/32768<<8;e=g;e=Oka(e,e>>31,z,A);j=e+j|0;b=nb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Yc(e,b,24);b=(e|0)/256|0;m=m+q|0;v[c>>2]=B(b,m>>12)+v[c>>2];l=l+p|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,b);Rb(h+8|0,k,i);e=e-(g&r)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=b;v[a+44>>2]=f;v[a+24>>2]=l>>12;kb=h+16|0}function Y_(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;v[c>>2]=a;z=d&512;while(1){if((x|0)==4){if(Hb(n)>>>0>1){f=rt(n);e=kb-16|0;kb=e;v[e+8>>2]=f;f=v[He(e+8|0)>>2];kb=e+16|0;B=c,C=XF(f,qt(n),v[c>>2]),v[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}return}a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];p=Kl(g,32);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 3:if(Re(n)){break a}p=w[hg(n,0)|0];q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 2:if(Re(m)|!z){break a}B=c,C=XF(rt(m),qt(m),v[c>>2]),v[B>>2]=C;break a;case 4:break b;default:break a}}p=v[g+8>>2];A=v[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!vh(p,64,t[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){r=r-1|0;q=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=q;p=p-1|0;continue}break}if(p){q=Kl(g,48)}else{q=0}while(1){s=v[c>>2];v[c>>2]=s+1;if((p|0)>0){t[s|0]=q;p=p-1|0;continue}break}t[s|0]=j}d:{if((e|0)==(r|0)){p=Kl(g,48);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break d}if(Re(l)){q=-1}else{q=t[hg(l,0)|0]}p=0;u=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=v[c>>2];v[c>>2]=q+1;t[q|0]=k;s=0;u=u+1|0;if(Hb(l)>>>0<=u>>>0){q=p;break e}q=-1;if(w[hg(l,u)|0]==127){break e}q=t[hg(l,u)|0]}r=r-1|0;p=w[r|0];y=v[c>>2];v[c>>2]=y+1;t[y|0]=p;p=s+1|0;continue}}am(A,v[c>>2])}x=x+1|0;continue}}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=kb-16|0;kb=g;w=v[a+16>>2];x=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);p=v[a+128>>2];a:{if(!p){n=v[a+8>>2];s=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];o=0;break a}b=v[a+12>>2];s=b;n=v[a+8>>2];q=lg(n,b,p);r=nb;k=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Qf(i,e,lf(n,b,d),nb);o=k>>>0<nb>>>0?d:0}h=a+112|0;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=e+w|0;b=p;while(1)if((b|0)<=0){Rb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Sd(h,t[e+v[g+12>>2]|0]<<6);Rd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];y=v[a+32>>2];m=v[a+28>>2]+m|0;b=v[a+60>>2];e=b;j=b>>31;u=jg(h,x)<<8;b=u;b=Oka(e,j,b,b>>31);z=nb;e=b;b=v[a+64>>2];j=b;A=b>>31;b=Yb(k,-16777216,16776704);j=Oka(j,A,b,b>>31);e=e+j|0;b=nb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Yb(f,-16777216,16776704);e=Oka(e,e>>31,f,f>>31);f=j+e|0;b=nb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Yc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(m>>12,f)+v[c>>2];l=l+y|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,f);Rb(g,n,s);b=b-(i&u)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=k;continue b}else{Sd(h,t[e+v[g+12>>2]|0]<<6);Rd(h,4);Rb(g+8|0,q,r);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=l>>12;kb=g+16|0}function HV(){var a=0,b=0,c=0;if(!w[468e3]){a=kb-16|0;kb=a;Is(467648);v[116924]=-1;v[116922]=467704;v[116920]=94048;v[116912]=78436;t[467700]=0;b=a+8|0;bs(b,467648);c=v[v[116912]+8>>2];v[23588]=0;R(c|0,467648,b|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){ac(a+8|0);kb=a+16|0;break a}b=P()|0;O()|0;ac(a+8|0);Ln(467648);T(b|0);L()}Ns(466976);v[116744]=78568;v[116742]=78548;v[116743]=0;Kn(466976,467648);fH(467712,94192,467760);Kw(467144,467712);fH(467768,93888,467816);Kw(467312,467768);Kw(467480,v[(v[v[116828]-12>>2]+467312|0)+24>>2]);eH(v[v[116742]-12>>2]+466968|0);ZH(v[v[116828]-12>>2]+467312|0);eH(v[v[116828]-12>>2]+467312|0);a=kb-16|0;kb=a;tH(467824);v[116968]=-1;v[116966]=467880;v[116964]=94048;v[116956]=78828;t[467876]=0;b=a+8|0;bs(b,467824);c=v[v[116956]+8>>2];v[23588]=0;R(c|0,467824,b|0);b=v[23588];v[23588]=0;b:{if((b|0)!=1){ac(a+8|0);kb=a+16|0;break b}b=P()|0;O()|0;ac(a+8|0);es(467824);T(b|0);L()}bH(467064);v[116766]=78960;v[116764]=78940;v[116765]=0;Kn(467064,467824);dH(467888,94192,467936);Jw(467228,467888);dH(467944,93888,467992);Jw(467396,467944);Jw(467564,v[(v[v[116849]-12>>2]+467396|0)+24>>2]);cH(v[v[116764]-12>>2]+467056|0);ZH(v[v[116849]-12>>2]+467396|0);cH(v[v[116849]-12>>2]+467396|0);t[468e3]=1}a=kb-16|0;kb=a;c:{if(fb(a+12|0,a+8|0)|0){break c}b=Pd((v[a+12>>2]<<2)+4|0);v[117002]=b;if(!b){break c}c=Pd(v[a+8>>2]);if(c){v[b+(v[a+12>>2]<<2)>>2]=0;if(!(eb(b|0,c|0)|0)){break c}}v[117002]=0}kb=a+16|0;v[116072]=42;v[116090]=468100}function $4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=kb-80|0;kb=e;f=Tb(a);a=0;c=v[b+24>>2];g=tj(Wb(v[c+484360>>2],w[c+484376|0]));v[23588]=0;R(181,f|0,g|0);c=v[23588];v[23588]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=v[b+24>>2];d=v[c+484344>>2];h=v[c+484348>>2];c=x[dc(v[Wb(v[c+484360>>2],w[c+484376|0])>>2],a)>>1];if(Rm(d,h,c)){v[23588]=0;R(1022,e+48|0,Zb(d,c)|0);c=v[23588];v[23588]=0;c:{d:{e:{if((c|0)!=1){c=v[b+24>>2];v[23588]=0;U(1009,e- -64|0,c|0,e+48|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(183,f|0,e- -64|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}zb(e- -64|0);zb(e+48|0);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(e- -64|0)}zb(e+48|0);break a}f:{switch(c-65534|0){case 0:v[23588]=0;c=Q(55,e+32|0,9200)|0;d=v[23588];v[23588]=0;g:{if((d|0)!=1){v[23588]=0;R(183,f|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}zb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(c);break a;case 1:v[23588]=0;c=Q(55,e+16|0,9162)|0;d=v[23588];v[23588]=0;h:{if((d|0)!=1){v[23588]=0;R(183,f|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break h}zb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(c);break a;default:break f}}v[23588]=0;c=Q(55,e|0,14571)|0;d=v[23588];v[23588]=0;i:{if((d|0)!=1){v[23588]=0;R(183,f|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}zb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(c);break a}kb=e+80|0;return}a=a+1|0;continue}}a=P()|0;O()|0}Xe(f);T(a|0);L()}function Gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=kb-48|0;kb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){b=v[g+16>>2];j=b>>>18|0;i=((((v[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=i+(e<<1)|0;f=u[h>>1];v[(g+8|0)+(e<<2)>>2]=f+((B(j,u[h+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=v[j>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Oka(w,x,f,f>>31);k=nb;A=e;e=Yb(h,-16777216,16776704);h=Oka(s,t,e,e>>31);f=h+f|0;e=nb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Yb(i,-16777216,16776704);i=Oka(q,r,f,f>>31);f=k+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[A+4>>2]=e-(p&l);v[j>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Rb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=g+48|0}function C$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=kb-432|0;kb=i;v[i+424>>2]=37;v[i+428>>2]=0;l=Qr(i+424|1,13830,v[c+4>>2]);v[i+380>>2]=i+384;a=Hd();a:{if(l){b=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=b;j=ah(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=ah(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=1123;k=te(i+368|0,0,i+128|0);b=i+384|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Hd();f:{if(l){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=_i(i+380|0,a,i+424|0,i);break f}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=_i(i+380|0,a,i+424|0,i+32|0)}if((j|0)==-1){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)==1){break d}break e}a=v[i+380>>2];_e(k,a)}f=a+j|0;g=$i(a,f,c);v[i+116>>2]=1123;e=te(i+120|0,0,i+116|0);g:{h:{if((i+384|0)==(a|0)){j=i+128|0;break h}j=Pd(j<<3);if(!j){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}_e(e,j);b=a}a=i+104|0;gd(a,c);v[23588]=0;ia(1156,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[23588];v[23588]=0;i:{if((a|0)!=1){ac(i+104|0);v[23588]=0;a=ka(1157,m|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break i}Xc(e);Xc(k);kb=i+432|0;break b}a=P()|0;O()|0;ac(i+104|0);break g}a=P()|0;O()|0}Xc(e);break c}L()}a=P()|0;O()|0}Xc(k);T(a|0);L()}return a|0}function M$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=kb-256|0;kb=i;v[i+248>>2]=37;v[i+252>>2]=0;l=Qr(i+248|1,13830,v[c+4>>2]);v[i+204>>2]=i+208;a=Hd();a:{if(l){b=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=b;j=ah(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=ah(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=1123;k=te(i+192|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Hd();f:{if(l){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=_i(i+204|0,a,i+248|0,i);break f}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=_i(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)==1){break d}break e}a=v[i+204>>2];_e(k,a)}f=a+j|0;g=$i(a,f,c);v[i+116>>2]=1123;e=te(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Pd(j<<1);if(!j){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}_e(e,j);b=a}a=i+104|0;gd(a,c);v[23588]=0;ia(1151,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[23588];v[23588]=0;i:{if((a|0)!=1){ac(i+104|0);v[23588]=0;a=ka(15,m|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break i}Xc(e);Xc(k);kb=i+256|0;break b}a=P()|0;O()|0;ac(i+104|0);break g}a=P()|0;O()|0}Xc(e);break c}L()}a=P()|0;O()|0}Xc(k);T(a|0);L()}return a|0}function Hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=kb-48|0;kb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;u=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){b=v[g+16>>2];j=b>>>10&4194048;i=(((v[g+20>>2]&2147483647)<<1|b>>>31)&-2)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=e+i|0;f=t[h|0];v[(g+8|0)+(e<<2)>>2]=((B(j,t[h+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=v[j>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Oka(w,x,f,f>>31);k=nb;A=e;e=Yb(h,-16777216,16776704);h=Oka(s,u,e,e>>31);f=h+f|0;e=nb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Yb(i,-16777216,16776704);i=Oka(q,r,f,f>>31);f=k+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[A+4>>2]=e-(p&l);v[j>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Rb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}kb=g+48|0}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=kb-48|0;kb=g;n=v[a+16>>2];k=Tf(1,2);b=nb;o=b;Rb(a,k,b);b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){d=d-1|0;f=((((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&2147483646)<<1)+n|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=u[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;m=f<<8;f=m;f=Oka(y,z,f,f>>31);j=nb;D=e;e=Yb(h,-16777216,16776704);h=Oka(w,x,e,e>>31);f=h+f|0;e=nb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Yb(i,-16777216,16776704);i=Oka(s,t,f,f>>31);f=j+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[D+4>>2]=e-(r&m);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+12>>2]);Rb(g+16|0,A,C);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}mg(a,k,o);kb=g+48|0}function W$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=kb-384|0;kb=a;v[a+368>>2]=c;v[a+376>>2]=b;vw(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Mb(a+200|0);b=bd(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Tc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=v[a+232>>2];i=v[a+236>>2];while(1){d:{v[23588]=0;b=Q(1141,a+376|0,a+368|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+196>>2];b=Hb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+196>>2]=b+c}v[23588]=0;b=S(1143,v[a+376>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(uw(b,a+23|0,a+22|0,c,a+196|0,i,h,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23588]=0;S(1145,a+376|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}sG(a,c,v[a+196>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;Gf(a+216|0,a+32|0,v[a+28>>2],e);v[23588]=0;b=Q(1142,a+376|0,a+368|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];zb(d);zb(a+216|0);kb=a+384|0;break a}}b=P()|0;O()|0;zb(d);zb(a+216|0);T(b|0);L()}return b|0}function d0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=kb-288|0;kb=a;v[a+272>>2]=c;v[a+280>>2]=b;zw(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Mb(a+208|0);b=bd(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Tc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=t[a+238|0];i=t[a+239|0];while(1){d:{v[23588]=0;b=Q(1125,a+280|0,a+272|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+204>>2];b=Hb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+204>>2]=b+c}v[23588]=0;b=S(1127,v[a+280>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(yw(b,a+23|0,a+22|0,c,a+204|0,i,h,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23588]=0;S(1129,a+280|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}sG(a,c,v[a+204>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;Gf(a+224|0,a+32|0,v[a+28>>2],e);v[23588]=0;b=Q(1126,a+280|0,a+272|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];zb(d);zb(a+224|0);kb=a+288|0;break a}}b=P()|0;O()|0;zb(d);zb(a+224|0);T(b|0);L()}return b|0}function S7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=kb-16|0;kb=j;i=kb-32|0;kb=i;h=pf(i+16|0,1,0);a:{b:{c:{while(1){g=Ac(h);d=g+Hb(h)|0;c=v[b>>2];f=v[b+4>>2];if(!((f|0)>0|(f|0)>=0|(d|0)==(g|0))){t[g|0]=45;e=c;c=0-c|0;g=g+1|0;f=0-(f+((e|0)!=0)|0)|0}k=d-g|0;d:{if((k|0)<=19){e=E(f);e=B(64-((e|0)==32?E(c|1)+32|0:e)|0,1233)>>12;n=(e<<3)+25792|0;l=k;k=v[n+4>>2];m=61;if((l|0)<(((f|0)==(k|0)&c>>>0>=y[n>>2]|f>>>0>k>>>0)+e|0)){break d}}e:{if(!f&c>>>0<=99999999){d=Zw(g,c);break e}if((f|0)==2328306&c>>>0<=1874919423|f>>>0<2328306){d=Rka(c,f,1e8,0);e=nb;l=Zw(g,d);d=Oka(d,e,-1e8,0)+c|0;c=d;d=(c>>>0)/1e4|0;d=ej(ej(l,d),c+B(d,-1e4)|0);break e}d=Rka(c,f,1874919424,2328306);e=nb;g=Yw(g,d);d=Oka(d,e,-1874919424,-2328307)+c|0;e=f+nb|0;e=c>>>0>d>>>0?e+1|0:e;c=Rka(d,e,1e8,0);e=nb;f=(c>>>0)/1e4|0;l=ej(ej(g,f),c+B(f,-1e4)|0);c=Oka(c,e,-1e8,0)+d|0;d=(c>>>0)/1e4|0;d=ej(ej(l,d),c+B(d,-1e4)|0)}m=0}v[i+12>>2]=m;v[i+8>>2]=d;if(!v[i+12>>2]){break c}c=dh(Hb(h));v[23588]=0;R(59,h|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){continue}break}break b}b=v[i+8>>2];c=Ac(h);v[23588]=0;R(60,h|0,b-c|0);b=v[23588];v[23588]=0;f:{if((b|0)!=1){v[23588]=0;R(61,j|0,h|0);b=v[23588];v[23588]=0;if((b|0)!=1){break f}break b}break b}zb(h);kb=i+32|0;break a}a=P()|0;O()|0;zb(h);T(a|0);L()}v[23588]=0;R(58,a|0,j|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(j);kb=j+16|0;return}a=P()|0;O()|0;zb(j);T(a|0);L()}function uj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!_d(v[a>>2],v[a+20>>2])){break a}Dk(a);b:{switch(_m(x[a+34>>1])-1|0){case 1:e=kb+-64|0;kb=e;h=v[a+20>>2];c=v[a>>2];d=Ld(x[a+34>>1]);f=h+(B(c,d)<<1)|0;while(1){c:{d:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break d}g=f+(d<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];Db(e+32|0,b+1074312|0,33);tP(e+40|0,g,h+(B(d,f)<<1)|0,i-f|0,d,(c&4)>>>2|0,Cb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];Db(e+32|0,b+1074312|0,33);tP(e+8|0,g+(d<<7)|0,h+(B(a,d)<<1)|0,f-a|0,d,(c&16)>>>4|0,Cb(v[v[e+32>>2]>>2],v[e+36>>2]))}kb=e- -64|0;break c}while(1){if((c|0)!=(d|0)){u[f+(c+i<<1)>>1]=x[f+(c-d<<1)>>1];u[h+(c+j<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;continue}break}g=g+1|0;continue}break};return;case 0:break b;default:break a}}e=kb+-64|0;kb=e;h=v[a+20>>2];c=v[a>>2];d=Ld(x[a+34>>1]);f=h+B(c,d)|0;while(1){e:{f:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break f}g=f+(d<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];Db(e+32|0,b+1074312|0,33);sP(e+40|0,g,h+B(d,f)|0,i-f|0,d,(c&4)>>>2|0,Cb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];Db(e+32|0,b+1074312|0,33);sP(e+8|0,g+(d<<6)|0,h+B(a,d)|0,f-a|0,d,(c&16)>>>4|0,Cb(v[v[e+32>>2]>>2],v[e+36>>2]))}kb=e- -64|0;break e}while(1){if((c|0)!=(d|0)){t[f+(c+i|0)|0]=w[f+(c-d|0)|0];t[h+(c+j|0)|0]=w[c+h|0];c=c+1|0;continue}break}g=g+1|0;continue}break}}}function lW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=kb-32|0;kb=f;zc(c);while(1){a:{if(!Qb(v[c>>2],v[c+8>>2],3)){break a}d=f+24|0;Xq(d,c);i=Oc(d);h=Te(d);d=w[f+24|0];if(d>>>0>=y[a+12>>2]){break a}g=jd(v[a>>2],v[v[a+48>>2]+12>>2],d,b);d=w[i|0];if(d>>>0<=126){if(!(d|w[h|0])){t[g|0]=254;continue}t[g|0]=d+1;if(w[h|0]==255){continue}t[g+2|0]=1;t[g+4|0]=w[h|0];continue}b:{switch(d-127|0){case 1:t[g+1|0]=w[h|0]+1;continue;case 0:continue;default:break b}}e=t[h|0];t[f+23|0]=e;h=0;j=w[i|0];d=j&127;if(d>>>0<=23){h=w[d+26192|0]}c:{d:{e:{f:{g:{switch(d-2|0){case 0:case 8:case 9:if((e|0)>=0){break f}d=0-e&15;break e;case 1:t[f+16|0]=64;e=w[Xb(f+23|0,f+16|0)|0];if(w[g+2|0]>1){break d}t[g+4|0]=e;t[g+2|0]=1;continue;case 2:d=3;if((e|0)>=0){break c}d=0-e&127;break e;case 15:if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e;case 16:case 20:if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;t[f+23|0]=e;j=w[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;t[f+23|0]=e;break c;case 17:d=e&15|-48;break e;case 18:d=e&15|-64;break e;case 21:break g;default:break d}}d=164;if((e|0)==100){break e}v[f+16>>2]=e- -64;v[f+12>>2]=0;v[f+8>>2]=128;e=v[Jj(f+16|0,f+12|0,f+8|0)>>2];if(!w[g+3|0]){break d}h:{switch(w[g+2|0]){case 0:case 2:break h;default:continue}}t[g+2|0]=2;t[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;t[f+23|0]=e}d=h;if(!d){continue}}t[g+5|0]=e;t[g+3|0]=d;continue}break}kb=f+32|0}function Xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=kb-48|0;kb=g;n=v[a+16>>2];k=Tf(1,2);b=nb;o=b;Rb(a,k,b);b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){d=d-1|0;f=(((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&-2)+n|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=t[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;m=f<<8;f=m;f=Oka(y,z,f,f>>31);j=nb;D=e;e=Yb(h,-16777216,16776704);h=Oka(w,x,e,e>>31);f=h+f|0;e=nb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Yb(i,-16777216,16776704);i=Oka(s,u,f,f>>31);f=j+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Yc(f,e,24);v[D+4>>2]=e-(r&m);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+12>>2]);Rb(g+16|0,A,C);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}mg(a,k,o);kb=g+48|0}function Pq(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;t[e+15|0]=c;a:{b:{c:{d:{switch(b-2|0){case 11:t[e+14|0]=64;ee(a,1,Xb(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break c}t[e+14|0]=c>>>2;ee(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break c}t[e+14|0]=c>>>2;ee(a,13,e+14|0);break a;case 2:if(c>>>0>=240){t[e+14|0]=9;ee(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break c}f=w[b+43744|0];e:{if(d){if(c>>>0>f>>>0){break e}break b}if((c|0)==(f|0)){break b}}b=b+1|0;continue};case 3:f:{if(d){t[e+14|0]=c&15;t[e+13|0]=9;c=w[Xb(e+14|0,e+13|0)|0];t[e+15|0]=c;break f}if(c&240|(c&14)>>>0>9){break c}}t[e+14|0]=c&15;ee(a,8,e+14|0);break a;case 24:g:{if(d){t[e+15|0]=0;break g}if(c){break c}}ee(a,8,e+15|0);break a;case 7:t[e+15|0]=(c|0)==255?64:c>>>2|0;ee(a,2,e+15|0);break a;case 9:if(!c){break c}b=c&15;if(!b){t[e+14|0]=c>>>4;ee(a,3,e+14|0);break a}d=c&240;if(!d){ee(a,4,e+15|0);break a}if((b|0)==15){t[e+14|0]=c>>>4;ee(a,5,e+14|0);break a}if((d|0)!=240){break c}t[e+14|0]=c&15;ee(a,6,e+14|0);break a;case 18:if((c&240)!=128){break c}t[e+14|0]=c<<2&60|2;ee(a,2,e+14|0);break a;case 17:break d;default:break c}}h:{switch((c>>>4|0)-8|0){case 0:t[e+14|0]=c<<2&60|2;ee(a,2,e+14|0);break a;case 2:t[e+14|0]=c&15;ee(a,5,e+14|0);break a;case 3:break h;default:break c}}t[e+14|0]=c&15;ee(a,6,e+14|0);break a}t[e+14|0]=0;ee(a,0,e+14|0);break a}t[e+14|0]=b;ee(a,11,e+14|0)}kb=e+16|0}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;g=kb-16|0;kb=g;s=v[a+16>>2];t=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=lg(k,l,n);p=nb;b=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Qf(i,e,lf(k,l,d),nb);m=b>>>0<nb>>>0?d:0}h=a+112|0;f=v[a+48>>2];w=v[a+24>>2];x=v[a+20>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=(e<<1)+s|0;b=n;while(1)if((b|0)<=0){Rb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Sd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Rd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];b=v[a+60>>2];e=b;j=b>>31;r=jg(h,t)<<8;b=r;b=Oka(e,j,b,b>>31);y=nb;e=b;b=v[a+64>>2];j=b;z=b>>31;b=Yb(q,-16777216,16776704);j=Oka(j,z,b,b>>31);e=e+j|0;b=nb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Yb(f,-16777216,16776704);e=Oka(e,e>>31,f,f>>31);f=j+e|0;b=nb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Yc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(f,x)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(f,w);Rb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=q;continue b}else{Sd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Rd(h,4);Rb(g+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=f;v[a+44>>2]=q;kb=g+16|0}function V$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Mb(a+208|0);b=a+16|0;gd(b,d);v[23588]=0;b=S(1136,b|0)|0;c=v[23588];v[23588]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23588]=0;X(1148,b|0,82976,83002,a+224|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}ac(a+16|0);c=Mb(a+192|0);b=bd(c);v[23588]=0;R(60,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=Tc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23588]=0;d=Q(1141,a+344|0,a+336|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=Hb(c);if((g|0)==(d+b|0)){v[23588]=0;R(60,c|0,d<<1);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=bd(c);v[23588]=0;R(60,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=Tc(c,0);v[a+188>>2]=d+b}v[23588]=0;d=S(1143,v[a+344>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}if(yn(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23588]=0;S(1145,a+344|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;ac(a+16|0);break a}v[23588]=0;R(60,c|0,v[a+188>>2]-b|0);b=v[23588];v[23588]=0;f:{if((b|0)==1){break f}b=Mc(c);d=Hd();v[a>>2]=f;if((rG(b,d,a)|0)!=1){v[e>>2]=4}v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(c);zb(h);kb=a+352|0;return b|0}}b=P()|0;O()|0;zb(c)}zb(h);T(b|0);L()}function iE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-96|0;kb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){yc(a,9700);break j}if(!(b&65535)){d=kb-16|0;kb=d;e=yc(d,4402);ad(c+80|0,e);Ab(e);kb=d+16|0;v[23588]=0;v[c+24>>2]=b>>>24;R(109,c- -64|0,c+24|0);d=v[23588];v[23588]=0;k:{l:{m:{n:{if((d|0)!=1){v[23588]=0;v[c+8>>2]=b>>>16&255;R(110,c+48|0,c+8|0);b=v[23588];v[23588]=0;if((b|0)==1){break n}v[23588]=0;X(111,a|0,c+80|0,c- -64|0,c+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break m}Ab(c+48|0);Ab(c- -64|0);bc(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;Ab(c+48|0)}Ab(c- -64|0)}break a}d=kb-16|0;kb=d;e=yc(d,4126);ad(c+80|0,e);Ab(e);kb=d+16|0;v[23588]=0;v[c+44>>2]=b>>>24;R(109,c- -64|0,c+44|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}v[23588]=0;v[c+40>>2]=b>>>16&255;R(110,c+48|0,c+40|0);d=v[23588];v[23588]=0;if((d|0)==1){break h}v[23588]=0;v[c+20>>2]=b>>>8&255;R(110,c+24|0,c+20|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;v[c+4>>2]=b&255;R(110,c+8|0,c+4|0);b=v[23588];v[23588]=0;if((b|0)==1){break f}v[23588]=0;ma(112,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}Ab(c+8|0);Ab(c+24|0);Ab(c+48|0);Ab(c- -64|0);bc(c+80|0)}kb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;Ab(c+8|0)}Ab(c+24|0)}Ab(c+48|0)}Ab(c- -64|0)}bc(c+80|0);T(b|0);L()}function c0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Mb(a+208|0);b=a+16|0;gd(b,d);v[23588]=0;b=S(19,b|0)|0;c=v[23588];v[23588]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23588]=0;X(1134,b|0,82976,83002,a+224|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}ac(a+16|0);c=Mb(a+192|0);b=bd(c);v[23588]=0;R(60,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=Tc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23588]=0;d=Q(1125,a+264|0,a+256|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=Hb(c);if((g|0)==(d+b|0)){v[23588]=0;R(60,c|0,d<<1);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=bd(c);v[23588]=0;R(60,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}b=Tc(c,0);v[a+188>>2]=d+b}v[23588]=0;d=S(1127,v[a+264>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}if(zn(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23588]=0;S(1129,a+264|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;ac(a+16|0);break a}v[23588]=0;R(60,c|0,v[a+188>>2]-b|0);b=v[23588];v[23588]=0;f:{if((b|0)==1){break f}b=Mc(c);d=Hd();v[a>>2]=f;if((rG(b,d,a)|0)!=1){v[e>>2]=4}v[23588]=0;b=Q(1126,a+264|0,a+256|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(c);zb(h);kb=a+272|0;return b|0}}b=P()|0;O()|0;zb(c)}zb(h);T(b|0);L()}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;h=kb-16|0;kb=h;a:{b:{c:{i=v[a+12>>2];j=v[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];f=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];b=v[a+44>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;r=v[a+72>>2];e=v[a+68>>2];s=e;t=e>>31;e=v[a+64>>2];w=e;x=e>>31;e=v[a+60>>2];y=e;z=e>>31;while(1){e=b;if(d){b=Yb(e,-16777216,16776704);b=Oka(w,x,b,b>>31);k=nb;l=b;g=(v[h+12>>2]<<1)+o|0;b=(v[h+8>>2]>>>16&65520)+n|0;g=(((((((B(u[g-4>>1],u[b+2>>1])+B(u[g-6>>1],u[b>>1])|0)+B(u[g-2>>1],u[b+4>>1])|0)+B(u[g>>1],u[b+6>>1])|0)+B(u[g+2>>1],u[b+8>>1])|0)+B(u[g+4>>1],u[b+10>>1])|0)+B(u[g+6>>1],u[b+12>>1])|0)+B(u[g+8>>1],u[b+14>>1])|0)/32768<<8;b=g;b=Oka(b,b>>31,y,z);l=l+b|0;m=nb+k|0;m=b>>>0>l>>>0?m+1|0:m;b=Yb(f,-16777216,16776704);f=Oka(s,t,b,b>>31);k=f+l|0;b=nb+m|0;b=f>>>0>k>>>0?b+1|0:b;f=k+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Yc(f,b,24);b=(f|0)/256|0;v[c>>2]=B(b,q)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,p);Rb(h+8|0,j,i);b=f-(g&r)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;v[a+48>>2]=f;v[a+44>>2]=e;kb=h+16|0}function aY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Mb(a);a=w[b+11|0];g=v[b+4>>2];v[23588]=0;k=Gk(g,a);R(115,h|0,k|0);a=v[23588];v[23588]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=w[pd(b)+a|0];d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(e-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}v[23588]=0;Q(116,h|0,Nd(c,g)|0)|0;j=v[23588];v[23588]=0;g=e;if((j|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;i=e;break d;case 3:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break d}v[23588]=0;Q(116,h|0,Nd(c,i)|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}i=(B(i,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}j=(e|0)!=125;f=-1;e=125;if(j){break d}}f=0;v[23588]=0;Q(117,h|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;v[23588]=0;a=S(118,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){v[23588]=0;U(119,a|0,41812,25);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ca(b|0);break b}a=P()|0;O()|0}Ab(h);T(a|0)}L()}function kea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-48|0;kb=e;u[e+46>>1]=254;c=tj(a);f=e+32|0;v[f>>2]=0;v[f+4>>2]=0;Hc(f+8|0);if(c){iq(f,c);sC(f,c)}a:{b:{while(1){c:{if((b|0)==(c|0)){if(!(d&65535)){break a}c=Fb(v[a>>2]);d=Fb(v[a+4>>2]);b=kb-16|0;kb=b;c=cA(c,d,x[e+46>>1]);v[b+8>>2]=c;if(Pb(c,d)){v[b>>2]=c;while(1){c=v[Se(b)>>2];if(Pb(c,d)){c=x[c>>1];if((c|0)==x[e+46>>1]){continue}u[v[b+8>>2]>>1]=c;Se(b+8|0);continue}break}c=v[b+8>>2]}kb=b+16|0;b=fc(e+24|0,c);c=v[fc(e+16|0,Fb(v[a+4>>2]))>>2];d=v[b>>2];b=v[a>>2];b=(zo(d,Fb(b))<<1)+b|0;if(Pb(d,c)){Od(a,Qi(b+(zo(c,d)<<1)|0,v[a+4>>2],b))}Fb(b);k=e,l=Fb(v[a>>2]),v[k+8>>2]=l;d=Fb(v[a+4>>2]);break c}k=dc(v[f>>2],b),l=b-d|0,u[k>>1]=l;g=v[a+4>>2];h=v[a>>2];v[23588]=0;g=W(748,h|0,g|0,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}b=b+1|0;d=(x[g>>1]==254)+d|0;continue}break}while(1){b=v[e+8>>2];if(!Pb(b,d)){b=v[f>>2];d=Rc(b,v[f+4>>2]);c=x[a+28>>1];if(d>>>0<=c>>>0){break a}k=a,l=x[dc(b,c)>>1],u[k+28>>1]=l;break a}d:{c=v[a+24>>2];g=v[c+484344>>2];b=x[b>>1];if(!ye(g,v[c+484348>>2],b)){break d}b=Zb(g,b);k=e,l=Fb(v[b>>2]),v[k>>2]=l;g=Fb(v[b+4>>2]);h=v[f+4>>2];c=v[f>>2];while(1){b=v[e>>2];if(!Pb(b,g)){break d}e:{if(w[b+3|0]!=12){break e}j=Rc(c,h);i=w[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=w[dc(c,i)|0],t[k+5|0]=l}Ck(e);continue}}Se(e+8|0);continue}}a=P()|0;O()|0;od(f);T(a|0);L()}od(f);kb=e+48|0}function _y(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=kb-16|0;kb=h;f=v[c+656>>2];a:{if(!wj(f)){i=v[c+704>>2];f=kb-16|0;kb=f;v[f+12>>2]=d;g=0;b:{if(!d){break b}j=v[b+480180>>2];if(j&20){e=b+1074312|0;Db(f,e,73);d=Cb(v[v[f>>2]>>2],v[f+4>>2])?d&65535:d;if(w[b+480208|0]&16){Db(f,e,73);e=Cb(v[v[f>>2]>>2],v[f+4>>2])?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=v[((d>>>0)%768<<2)+33936>>2]<<6>>>e|0;break b}if(!d){v[f+12>>2]=1;d=1}g=229079296/(d>>>0)|0;break b}g=227001280/(d>>>0)|0;if(Km(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}xc(f+12|0,16777215);if(j&17408){g=Ec(Rka(Oka(i?i:8363,0,3506176,0),nb,(v[f+12>>2]<<8)+e|0,0),nb);break b}if(oj(b)){d=v[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(w[b+480208|0]&16){g=Ec(Rka(Oka(i?i:8363,0,7012352,0),nb,(v[f+12>>2]<<8)+e|0,0),nb);break b}g=Ec(Rka(-1485242368,13,(v[f+12>>2]<<8)+e|0,0),nb)}e=g;kb=f+16|0;f=v[c+656>>2];break a}e=v[c+700>>2]}v[h+12>>2]=e;c=u[c+774>>1];c:{if(!c){break c}c=f?B(t[f+33|0],c):c;if(!c){break c}e=Qe(ni(+(c|0)/393216)*+(e>>>0));v[h+12>>2]=e}d:{if(!f){break d}c=v[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=v[b+1074420>>2];e=Oka(f,f>>31,e,e>>31);f=d+e|0;d=nb+(d>>31)|0;k=h,l=Ic(Pka(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),nb),v[k+12>>2]=l}xc(h+12|0,2147483647);c=v[h+12>>2];b=Tf(c,v[b+24620>>2]<<4);v[a+8>>2]=c;v[a>>2]=b;v[a+4>>2]=nb;kb=h+16|0}function cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;h=kb-16|0;kb=h;a:{b:{c:{i=v[a+12>>2];k=v[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];b=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];e=v[a+44>>2];f=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=f;p=v[a+72>>2];f=v[a+68>>2];q=f;r=f>>31;f=v[a+64>>2];s=f;w=f>>31;f=v[a+60>>2];x=f;y=f>>31;while(1){f=e;if(d){e=Yb(f,-16777216,16776704);e=Oka(s,w,e,e>>31);g=nb;j=e;b=Yb(b,-16777216,16776704);e=Oka(q,r,b,b>>31);j=j+e|0;b=nb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=v[h+12>>2]+m|0;e=(v[h+8>>2]>>>16&65520)+l|0;g=(((((((B(t[g-2|0],u[e+2>>1])+B(t[g-3|0],u[e>>1])|0)+B(t[g-1|0],u[e+4>>1])|0)+B(t[g|0],u[e+6>>1])|0)+B(t[g+1|0],u[e+8>>1])|0)+B(t[g+2|0],u[e+10>>1])|0)+B(t[g+3|0],u[e+12>>1])|0)+B(t[g+4|0],u[e+14>>1])<<8)/32768<<8;e=g;e=Oka(e,e>>31,x,y);j=e+j|0;b=nb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Yc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(b,o)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,n);Rb(h+8|0,k,i);e=e-(g&p)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=b;v[a+44>>2]=f;kb=h+16|0}function DR(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=kb-16|0;kb=j;a:{if((b|0)==(c|0)){break a}v[j+12>>2]=-1953789045;Zz(b,c,j+12|0);c=c-b|0;e=c>>2;v[j+8>>2]=e;f=vc(v[a>>2],v[a+4>>2]);g=11;b:{if(c>>>0>2488){break b}g=7;if(c>>>0>268){break b}g=5;if(c>>>0>152){break b}g=3;if(c>>>0>24){break b}g=e-1>>>1|0}c=f+1|0;v[j+4>>2]=c;n=v[Zc(j+4|0,j+8|0)>>2];k=e-g>>>1|0;d=(k<<2)+b|0;h=v[d>>2];i=B(Vt(v[((e<<2)+b|0)-4>>2]^(h^v[b>>2])),1664525);v[d>>2]=i+h;g=g+k|0;d=(g<<2)+b|0;f=f+i|0;v[d>>2]=f+v[d>>2];v[b>>2]=f;i=v[a>>2];a=1;while(1)if((a|0)==(c|0)){while(1)if(c>>>0>=n>>>0){c=n;while(1){if(e+n>>>0<=c>>>0){break a}d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=v[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=B(Vt(v[((c-1>>>0)%(e>>>0)<<2)+b>>2]+(h+v[i>>2]|0)|0),1566083941);v[d>>2]=a^h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a-f|0;v[d>>2]=a^v[d>>2];v[i>>2]=a;c=c+1|0;continue}}else{d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=v[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=B(Vt(v[((c-1>>>0)%(e>>>0)<<2)+b>>2]^(h^v[i>>2])),1664525);v[d>>2]=a+h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a+f|0;v[d>>2]=a+v[d>>2];v[i>>2]=a;c=c+1|0;continue}}else{d=a-1|0;l=((a+k>>>0)%(e>>>0)<<2)+b|0;m=v[l>>2];h=(a>>>0)%(e>>>0)|0;o=(h<<2)+b|0;f=B(Vt(v[((d>>>0)%(e>>>0)<<2)+b>>2]^(m^v[o>>2])),1664525);v[l>>2]=f+m;l=((a+g>>>0)%(e>>>0)<<2)+b|0;m=v[l>>2];f=v[Eb(i,d)>>2]+(f+h|0)|0;v[l>>2]=f+m;v[o>>2]=f;a=a+1|0;continue}}kb=j+16|0}function wka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Mb(a);k=Hb(b);v[23588]=0;R(297,h|0,k|0);a=v[23588];v[23588]=0;a:{b:{if((a|0)!=1){a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=t[hg(b,a)|0];g=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(g-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(g-123|0){case 2:m=1;e=i+1|0;f=0;if(d>>>0<=i>>>0){i=e;break d}v[23588]=0;Q(298,h|0,Nd(c,i)|0)|0;g=v[23588];v[23588]=0;i=e;if((g|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(g-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}v[23588]=0;Q(298,h|0,Nd(c,j)|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(B(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}g=(e|0)!=125;f=-1;e=125;if(g){break d}}f=0;v[23588]=0;Q(299,h|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;v[23588]=0;a=S(118,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){v[23588]=0;U(119,a|0,41812,25);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ca(b|0);break b}a=P()|0;O()|0}zb(h);T(a|0)}L()}function xZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=kb-16|0;kb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!v[b>>2]){break a}b=b+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=kb-16|0;kb=r;s=ki(r+8|0,v[a+8>>2]);i=f;j=g-f|0;m=0;o=kb-16|0;kb=o;k=v[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=$w(j>>>0<4?o+12|0:i,v[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}uc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!v[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){v[e>>2]=k}kb=o+16|0;ji(s);kb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=qw(f,v[c>>2],v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=m+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=v[e>>2];b=d;continue}b=qw(n+12|0,0,v[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-v[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=w[c|0];i=v[h>>2];v[h>>2]=i+1;t[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!v[b>>2]){break b}b=b+4|0;continue}}c=v[e>>2]}q=(c|0)!=(d|0)}kb=n+16|0;return q|0}f=v[h>>2];continue}}function TN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-32|0;kb=e;f=v[b+64>>2];a:{b:{h=v[b+60>>2];g=x[b+68>>1];if(!((h|0)==-1&(g|0)==65535)){c:{if((f|0)==-1){break c}f=a+1074312|0;Db(e+24|0,f,68);if(Cb(v[v[e+24>>2]>>2],v[e+28>>2])){break c}Db(e+16|0,f,103);if(i=Cb(v[v[e+16>>2]>>2],v[e+20>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}Db(e+8|0,f,49);if(i=Cb(v[v[e+8>>2]>>2],v[e+12>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}f=v[b+64>>2];break b}if((g|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((h|0)==-1){v[b+60>>2]=0}g=Rc(v[c>>2],v[c+4>>2]);f=x[b+68>>1];if(g>>>0<=f>>>0){f=x[c+28>>1];u[b+68>>1]=f}d:{if(x[b+72>>1]==(f&65535)){break d}c=a+1074312|0;Db(e+24|0,c,26);if(Cb(v[v[e+24>>2]>>2],v[e+28>>2])){break d}Db(e+16|0,c,68);if(Cb(v[v[e+16>>2]>>2],v[e+20>>2])|v[a+480180>>2]==1){break d}c=x[a+480188>>1];f=0;while(1){if((c|0)==(f|0)){break d}t[(B(f,872)+b|0)+1457|0]=0;f=f+1|0;continue}}v[b+52>>2]=v[b+60>>2];if(d){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((f|0)!=-1){break b}c=0;break a}v[b+52>>2]=f;u[b+74>>1]=x[b+72>>1];e:{if(!v[b+20>>2]){break e}c=v[a+480180>>2];if((c|0)==32){Db(e+24|0,a+1074312|0,103);if(Cb(v[v[e+24>>2]>>2],v[e+28>>2])){break e}c=v[a+480180>>2]}if((c|0)==2){break e}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[Zb(v[a+484344>>2],x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}kb=e+32|0;return c}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0;g=kb-16|0;kb=g;s=v[a+16>>2];u=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=lg(k,l,n);p=nb;b=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Qf(i,e,lf(k,l,d),nb);m=b>>>0<nb>>>0?d:0}h=a+112|0;f=v[a+48>>2];w=v[a+24>>2];x=v[a+20>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=e+s|0;b=n;while(1)if((b|0)<=0){Rb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Sd(h,t[e+v[g+12>>2]|0]<<6);Rd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];b=v[a+60>>2];e=b;j=b>>31;r=jg(h,u)<<8;b=r;b=Oka(e,j,b,b>>31);y=nb;e=b;b=v[a+64>>2];j=b;z=b>>31;b=Yb(q,-16777216,16776704);j=Oka(j,z,b,b>>31);e=e+j|0;b=nb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Yb(f,-16777216,16776704);e=Oka(e,e>>31,f,f>>31);f=j+e|0;b=nb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Yc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(f,x)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(f,w);Rb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=q;continue b}else{Sd(h,t[e+v[g+12>>2]|0]<<6);Rd(h,4);Rb(g+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=f;v[a+44>>2]=q;kb=g+16|0}function vy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=ir(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(c,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(c,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1),67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(c,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Ob(Ob(Ob(Ob(c,o,1),n,1),m,1),l,1);g=k;f=j;e=i;d=h}Ob(c,g,1)}Ob(Ob(Ob(c,f,1),e,1),d,1)}}function FI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=kb-16|0;kb=h;g=v[a+32>>2];f=Hs(g);if(!f){f=Gs(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ba(8)|0;v[23588]=0;c=Q(55,h|0,6003)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}if(c>>>0>=120){b=ba(8)|0;v[23588]=0;c=Q(55,h|0,11238)|0;a=v[23588];v[23588]=0;if((a|0)!=1){a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}a=P()|0;O()|0;ca(b|0);break b}f=Hy(g,65535);j=(f|0)==65535?255:f;u[h>>1]=j;f=g+B(j,872)|0;i=f+1074992|0;fo(i,g,65535,1024);c=c+1|0;t[f+1075794|0]=c;t[f+1075791|0]=c;u[f+1075778>>1]=0;um(i);Up(v[a+32>>2],i,b+1|0,0,1,1);v[f+1075688>>2]=65536;ot(v[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=zl(tu(e*128,-128,128)+128),v[l>>2]=m;l=f+1075680|0,m=zl(tu(d*256,0,256)),v[l>>2]=m;c=v[a+32>>2];i=c+1074478|0;b=i;c=b+(x[c+480212>>1]<<1)|0;g=x[h>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=x[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=x[f>>1];if((k|0)==(g|0)){continue}u[b>>1]=k;b=b+2|0;g=x[h>>1];continue}}l=v[a+32>>2],m=fz(i,c),u[l+480212>>1]=m;kb=h+16|0;return j|0}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function Ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-80|0;kb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=kb-16|0;kb=e;f=yc(e,4454);ad(d- -64|0,f);Ab(f);kb=e+16|0;v[23588]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=Oka(e,e>>31,1e4,0)+14780|0;b=nb;b=Pka(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(97,d+48|0,d+44|0);g=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[23588]=0;v[d+28>>2]=(e+B(f,-12)|0)+1;R(99,d+32|0,d+28|0);e=v[23588];v[23588]=0;if((e|0)==1){break j}v[23588]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(99,d+16|0,d+12|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}v[23588]=0;da(403,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}Ab(d+16|0);Ab(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;Ab(d+16|0)}Ab(d+32|0)}Ab(d+48|0)}break a}Sf(d- -64|0,4434);v[23588]=0;R(404,d+48|0,d+78|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}v[23588]=0;U(145,a|0,d- -64|0,d+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}}Ab(d+48|0);bc(d- -64|0);kb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ab(d+48|0)}bc(d- -64|0);T(b|0);L()}function Yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0,A=0,C=0;i=kb-16|0;kb=i;nd(d,32);g=i+8|0;rQ(g,w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24),w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24),v[b>>2]);g=jc(g);rQ(i,w[a+40|0]|w[a+41|0]<<8|(w[a+42|0]<<16|w[a+43|0]<<24),w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24),v[c>>2]);a=0;g=v[g>>2];if(g-838861>>>0>=4294128436){a=v[jc(i)>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;a:{m=Og(d);if(!m){break a}l=g<<2;e=+(l>>>0);q=+(a>>>0)/e;r=+(g>>>0)/e;s=1/+y[d>>2];t=+y[i>>2];z=+y[i+8>>2];g=0;b:while(1){if((g|0)==(l|0)){break a}n=+(g>>>0);o=0;p=0;a=v[b+20>>2];if(_d(v[b>>2],a)){e=n*r+z;c:{if(e<4294967296&e>=0){f=~~e>>>0;break c}f=0}k=x[b+34>>1];j=Ld(k);h=B(f,j);e=e-+(f>>>0);d:{if(k&1){f=x[a+(h<<1)>>1];a=x[a+(h+j<<1)>>1];break d}f=w[a+h|0]<<8;a=w[a+(h+j|0)|0]<<8}p=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}a=v[c+20>>2];if(_d(v[c>>2],a)){e=n*q+t;e:{if(e<4294967296&e>=0){f=~~e>>>0;break e}f=0}k=x[c+34>>1];j=Ld(k);h=B(f,j);e=e-+(f>>>0);f:{if(k&1){f=x[a+(h<<1)>>1];a=x[a+(h+j<<1)>>1];break f}f=w[a+h|0]<<8;a=w[a+(h+j|0)|0]<<8}o=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}f=0;a=g;while(1)if((f|0)==80){g=g+1|0;continue b}else{e=s*+(a>>>0);A=v[d+20>>2]+(a<<1)|0,C=Qz(p*(1-e)+o*e),u[A>>1]=C;a=a+l|0;f=f+1|0;continue}}}a=(m|0)!=0}kb=i+16|0;return a|0}function WA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=kb-16|0;kb=j;a:{if(b&4){break a}c=w[a+14|0];b:{if(c>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|c>>>0<=w[a+13|0]){break a}e=v[a>>2];d=v[a+4>>2];if($d(e,d)>>>0<=c>>>0){break a}e=x[Pc(e,d,c)>>1];d=Pc(v[a>>2],v[a+4>>2],w[a+14|0]-1|0);c=w[a+14|0];if(x[d>>1]<(e-1|0)){c=x[Pc(v[a>>2],v[a+4>>2],c)>>1]-1&65535;e=aq(a,c,64,64);d=fc(j+8|0,zm(Fb(v[a>>2]),w[a+14|0]));k=Al(j,c,e&255);m=kb-32|0;kb=m;c=v[d>>2];d=v[a>>2];c=(cu(c,Fb(d))<<2)+d|0;h=v[a+4>>2];c:{d:{if(h>>>0<y[Gb(a)>>2]){if((c|0)!=(h|0)){break d}PS(a,k);break c}d=Gb(a);f=Vf(m+8|0,qg(a,vc(v[a>>2],h)+1|0),c-v[a>>2]>>2,d);v[23588]=0;R(750,f|0,k|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=v[f+4>>2];i=f+4|0;eq(v[a>>2],c,i);e=v[a+4>>2];g=f+8|0;while(1){if((c|0)!=(e|0)){Im(v[g>>2],x[c>>1]|x[c+2>>1]<<16);v[g>>2]=v[g>>2]+4;c=c+4|0;continue}break}qc(a,i);qc(a+4|0,g);qc(Gb(a),Cc(f));v[f>>2]=v[f+4>>2];c=d;Uf(f);break c}a=P()|0;O()|0;Uf(f);T(a|0);L()}f=kb-16|0;kb=f;i=v[a+4>>2];d=(i-(c+4|0)|0)+c|0;g=Bh(f,a,h-d>>2);l=v[g+4>>2];e=d;while(1){if(e>>>0>=h>>>0){lc(g);Bq(c,d,i);kb=f+16|0}else{Im(l,x[e>>1]|x[e+2>>1]<<16);l=l+4|0;v[g+4>>2]=l;e=e+4|0;continue}break}t[c+2|0]=w[k+2|0];u[c>>1]=x[k>>1]}Fb(c);kb=m+32|0;break a}t[a+14|0]=c-1}if((b|0)!=16777216){t[a+17|0]=255}kb=j+16|0}function $ga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=Lb(h,d),j=w[f+4|0]+1|0,t[i|0]=j;i=dc(g,d),j=(w[f+6|0]|w[f+7|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;i=dc(f,d+12|0),j=(w[g+6|0]|w[g+7|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}oA(a+484|0,b+48|0,0);oA(a+590|0,b+68|0,0);oA(a+696|0,b+88|0,5);v[b>>2]=w[a+806|0]|w[a+807|0]<<8;d=t[a+808|0];b:{if((d|0)<0){t[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(t[a|0]&1){t[b+31|0]=d+1;break b}if(!d){break b}t[b+31|0]=d+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=w[a+810|0];break d}d=t[a+809|0];if((d|0)>=0){u[b+28>>1]=(d&255)+1}d=t[a+810|0];if((d|0)<0){break c}}t[b+30|0]=d+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;i=b,j=w[Xb(e+15|0,e+14|0)|0]>>>1|0,v[i+4>>2]=j}c=w[a+813|0]|w[a+814|0]<<8;if(c>>>0<=256){v[b+8>>2]=c;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];u[e+12>>1]=w[a+820|0]|w[a+821|0]<<8;u[e+10>>1]=100;i=b,j=w[Wc(e+12|0,e+10|0)|0],t[i+20|0]=j;u[e+8>>1]=w[a+822|0]|w[a+823|0]<<8;u[e+6>>1]=256;i=b,j=x[Wc(e+8|0,e+6|0)>>1]>>>2|0,t[i+19|0]=j;c=w[a+824|0];Mj(b,c&127,c>>>7|0);a=w[a+825|0];Lj(b,a&127,a>>>7|0);kb=e+16|0}function IF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=kb-16|0;kb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){c=v[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[c|0];j=i&255;d:{if((i|0)>=0){u[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=w[c+1|0];if((i&192)!=128){break a}u[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=w[c+2|0];i=w[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];i=w[c+2|0];c=w[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;u[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=i<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[a+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];kb=a+16|0;return b|0}function _n(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=kb-16|0;kb=d;h=a+1074312|0;Db(d+8|0,h,96);i=b,j=(k=0,l=v[b+660>>2],m=Cb(v[v[d+8>>2]>>2],v[d+12>>2]),m?k:l)+c|0,v[i+660>>2]=j;g=v[a+480180>>2];e=v[b+84>>2];if(!(!(g&18)|e>>>0>c>>>0|(!(w[b+88|0]&2)|!e))){f=c;c=v[b+80>>2];c=((f-c>>>0)%(e-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&(g|0)==16384)|0;a:{b:{if(!$c(w[b+788|0])){Db(d+8|0,h,114);if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){break b}}e=v[b+656>>2];c:{if(!e){break c}g=w[b+788|0];if(!$c(g)){break c}e=x[dc(e+236|0,g-1|0)>>1];if(!e|e>>>0>x[a+480190>>1]){break a}}d:{if(w[a+480210|0]&32){f=c;c=v[b+660>>2];v[b+660>>2]=f+c;f=0;break d}f=0}v[b>>2]=f;v[b+4>>2]=c;if((!(w[b+88|0]&2)|c>>>0<y[b+84>>2])&c>>>0<y[b+76>>2]){break a}Db(d+8|0,h,57);e:{if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){c=v[a+480180>>2];if((c|0)!=16){break e}}v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break a}if(!(c&1048581)){Db(d+8|0,h,27);if(Cb(v[v[d+8>>2]>>2],v[d+12>>2])){if(w[a+480208|0]&4){c=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=c;break a}v[b>>2]=0;v[b+4>>2]=0;break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;if(!(w[a+480208|0]&4)){break a}a=v[b+76>>2];if(a>>>0<5){break a}v[b>>2]=0;v[b+4>>2]=a-2;break a}if(!(w[b+88|0]&2)|(c|0)!=1){break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;break a}if(!(v[a+480180>>2]&268582928)|c>>>0>=y[b+76>>2]){break a}v[b>>2]=0;v[b+4>>2]=c}kb=d+16|0}function qz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=a;b:{c:{h=a+62|0;f=Lb(h,b);a=t[f|0];if((a|0)==-1){break c}if((a|0)>=0){break b}a=a&127;d=dc(e+26|0,a);g=x[d>>1];if((g|0)!=65535&(b|0)!=(g|0)){break c}u[d>>1]=b;t[f|0]=a;break b}l=e+8|0;i=e+26|0;d=255;a=0;g=255;while(1){if((a|0)!=18){j=dc(i,a);k=x[j>>1];if((k|0)==65535){u[j>>1]=b;t[f|0]=a;break b}else{if(!(w[Lb(l,a)|0]&32)){g=t[Lb(h,k)|0]<0?a:g;d=a}a=a+1|0;continue}}break}if((d&255)!=255){a=(g&255)==255?d:g;d=dc(i,a&255);m=Lb(h,x[d>>1]),n=255,t[m|0]=n;u[d>>1]=b;t[f|0]=a}a=pl(e,b)}g=a&255;if((g|0)==255){break a}if(jk(v[e>>2])){break a}d=Nd(e+318|0,g);a=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=a;t[d+9|0]=a>>>8;t[d+10|0]=a>>>16;t[d+11|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=a;t[d+5|0]=a>>>8;t[d+6|0]=a>>>16;t[d+7|0]=a>>>24;f=VO(g);h=f+3|0;a=0;while(1){if((a|0)==2){hh(v[e>>2],v[e+4>>2],b,zt(g)|192,w[Lb(c,10)|0])}else{d=a?h:f;hh(v[e>>2],v[e+4>>2],b,d|32,w[Lb(c,a)|0]);hh(v[e>>2],v[e+4>>2],b,d|64,w[Lb(c,a+2|0)|0]);hh(v[e>>2],v[e+4>>2],b,d|96,w[Lb(c,a+4|0)|0]);hh(v[e>>2],v[e+4>>2],b,d|128,w[Lb(c,a+6|0)|0]);hh(v[e>>2],v[e+4>>2],b,d|224,w[Lb(c,a+8|0)|0]);a=a+1|0;continue}break}}}function Y$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=kb-368|0;kb=a;v[a+352>>2]=c;v[a+360>>2]=b;vw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Mb(a+184|0);b=bd(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Tc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23588]=0;b=Q(1141,a+360|0,a+352|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=Hb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+180>>2]=b+c}v[23588]=0;b=S(1143,v[a+360>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(uw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23588]=0;S(1145,a+360|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=vG(c,v[a+180>>2],e),z[j>>2]=k;Gf(a+200|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+360|0,a+352|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];zb(d);zb(a+200|0);kb=a+368|0;break a}}b=P()|0;O()|0;zb(d);zb(a+200|0);T(b|0);L()}return b|0}function ufa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=kb-48|0;kb=e;nd(b,2);f=e+16|0;uk(f,2,a+1|0);d=e+32|0;Fc(d,f);Ce(b+43|0,d);zb(d);a:{b:{c:{d:{switch(w[a|0]){case 0:f=v[b+4>>2];d=v[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b>>2]=d;v[e+32>>2]=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);v[e+16>>2]=d-1;d=e+32|0;f=v[Kb(d,e+16|0)>>2];v[b+4>>2]=f;v[e+32>>2]=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);d=v[Kb(d,b)>>2];v[b+8>>2]=d;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}f=e+16|0;Kh(f,a+16|0);d=v[e+16>>2];v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);Kh(f,a+20|0);d=v[e+16>>2];v[e+36>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);Kh(f,a+24|0);d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+40>>2]=d;v[e+8>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Gl(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;g=b,h=w[Xb(e+32|0,e+16|0)|0]<<2,u[g+30>>1]=h;d=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);v[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(w[a|0]==2){d=d&65535;v[b>>2]=d;break e}if(y[b>>2]>=65536){v[b>>2]=65535}d=v[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}v[b>>2]=a}kb=e+48|0}function f0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;zw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Mb(a+192|0);b=bd(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[23588]=0;b=Q(1125,a+264|0,a+256|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=Hb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=b+c}v[23588]=0;b=S(1127,v[a+264>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(yw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23588]=0;S(1129,a+264|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=vG(c,v[a+188>>2],e),z[j>>2]=k;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+264|0,a+256|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(d);zb(a+208|0);kb=a+272|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function X$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=kb-368|0;kb=a;v[a+352>>2]=c;v[a+360>>2]=b;vw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Mb(a+184|0);b=bd(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Tc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23588]=0;b=Q(1141,a+360|0,a+352|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=Hb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+180>>2]=b+c}v[23588]=0;b=S(1143,v[a+360>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(uw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23588]=0;S(1145,a+360|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=tG(c,v[a+180>>2],e),A[j>>3]=k;Gf(a+200|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+360|0,a+352|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];zb(d);zb(a+200|0);kb=a+368|0;break a}}b=P()|0;O()|0;zb(d);zb(a+200|0);T(b|0);L()}return b|0}function e0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;zw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Mb(a+192|0);b=bd(d);v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[23588]=0;b=Q(1125,a+264|0,a+256|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=Hb(d);if((g|0)==(b+c|0)){v[23588]=0;R(60,d|0,b<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=b+c}v[23588]=0;b=S(1127,v[a+264>>2])|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}if(yw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23588]=0;S(1129,a+264|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=tG(c,v[a+188>>2],e),A[j>>3]=k;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+264|0,a+256|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(d);zb(a+208|0);kb=a+272|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function Bha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];b=fu(c,v[a+4>>2]);if(b>>>0<=63){g=kb-32|0;kb=g;f=64-b|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(f>>>0<=(c-d|0)/33>>>0){b=kb-16|0;kb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(f,33);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){lc(b);kb=b+16|0}else{OS(a);a=a+33|0;v[b+4>>2]=a;continue}break}break a}i=Gb(a);c=g+8|0;h=fu(v[a>>2],d)+f|0;d=kb-16|0;kb=d;v[d+12>>2]=h;e=kb-16|0;kb=e;v[e+12>>2]=130150524;v[e+8>>2]=2147483647;b=v[Kb(e+12|0,e+8|0)>>2];kb=e+16|0;b:{if(b>>>0>=h>>>0){e=TS(a);if(e>>>0<b>>>1>>>0){v[d+8>>2]=e<<1;b=v[Zc(d+8|0,d+12|0)>>2]}kb=d+16|0;break b}cd();L()}e=fu(v[a>>2],v[a+4>>2]);pg(c+12|0,i);if(b){if(b>>>0>=130150525){Mg();L()}d=tc(B(b,33))}else{d=0}v[c>>2]=d;e=d+B(e,33)|0;v[c+8>>2]=e;v[c+4>>2]=e;j=Cc(c),k=d+B(b,33)|0,v[j>>2]=k;b=kb-16|0;kb=b;v[b>>2]=v[c+8>>2];d=v[c+8>>2];v[b+8>>2]=c+8;v[b+4>>2]=d+B(f,33);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){OS(d);d=v[b>>2]+33|0;v[b>>2]=d;continue}break}Ud(b);kb=b+16|0;b=c+4|0;f=v[a>>2];d=v[a+4>>2]-f|0;e=v[b>>2]+B((d|0)/-33|0,33)|0;v[b>>2]=e;if((d|0)>0){uc(e,f,d)}qc(a,b);qc(a+4|0,c+8|0);qc(Gb(a),Cc(c));v[c>>2]=v[c+4>>2];b=v[c+4>>2];a=v[c+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;v[c+8>>2]=a;continue}break}a=v[c>>2];if(a){Cc(c);Nb(a)}}kb=g+32|0;return}if((b|0)!=64){Od(a,c+2112|0)}}function oI(a){var b=0,c=0,d=0,e=0;De(v[a+80>>2],v[a+20>>2]);while(1){c=v[a+28>>2];if((b|0)<v[a+24>>2]){De(v[a+80>>2],v[c+(b<<2)>>2]);b=b+1|0;continue}break}De(v[a+80>>2],c);a:{if(!v[a+396>>2]){break a}c=0;while(1){if(v[a+264>>2]<=(c|0)){break a}e=v[a+396>>2]+B(c,24)|0;d=v[e+16>>2];if(d){b=0;while(1){if((b|0)<v[(v[a+124>>2]+B(w[e+13|0],2096)|0)+4>>2]){De(v[a+80>>2],v[(b<<2)+d>>2]);b=b+1|0;d=v[e+16>>2];continue}break}De(v[a+80>>2],d)}De(v[a+80>>2],v[e+20>>2]);c=c+1|0;continue}}d=v[a+124>>2];if(d){c=0;while(1){if((c|0)<v[a+120>>2]){b=B(c,2096)+d|0;De(v[a+80>>2],v[b+8>>2]);De(v[a+80>>2],v[b+28>>2]);De(v[a+80>>2],v[b+32>>2]);De(v[a+80>>2],v[b+2084>>2]);b=v[b+2088>>2];De(v[a+80>>2],b?b-4|0:0);c=c+1|0;d=v[a+124>>2];continue}break}De(v[a+80>>2],d)}De(v[a+80>>2],v[a+260>>2]);De(v[a+80>>2],v[a+396>>2]);c=v[a+404>>2];if(c){b=0;while(1){if((b|0)<v[a+400>>2]){De(v[a+80>>2],v[(B(b,40)+c|0)+4>>2]);b=b+1|0;c=v[a+404>>2];continue}break}De(v[a+80>>2],c)}c=0;b=0;while(1){if(!(v[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;De(v[a+80>>2],v[d+800>>2]);De(v[a+80>>2],v[d+928>>2]);De(v[a+80>>2],v[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;De(v[a+80>>2],v[b+1068>>2]);De(v[a+80>>2],v[b+1076>>2]);De(v[a+80>>2],v[b+1084>>2]);De(v[a+80>>2],v[b+1092>>2]);De(v[a+80>>2],v[b+1100>>2]);c=c+1|0;continue}break}}function YO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=kb-16|0;kb=h;c=v[a>>2];a:{if(jk(c)){i=kb-16|0;kb=i;e=tc(3848);d=e+808|0;c=e+16|0;while(1){v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+42|0]=1;u[c+40>>1]=257;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){v[d>>2]=0;v[d+4>>2]=0;v[d+68>>2]=0;v[d+72>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;u[d+20>>1]=511;v[d+16>>2]=-1;u[d+14>>1]=1;u[d+6>>1]=0;u[d+8>>1]=0;u[d+10>>1]=0;u[d+12>>1]=0;t[d+73|0]=0;t[d+74|0]=0;t[d+75|0]=0;t[d+76|0]=0;t[d+77|0]=0;t[d+78|0]=0;t[d+79|0]=0;t[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}v[e+3832>>2]=0;v[e+3836>>2]=0;c=e+3837|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}eo((e+B(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+B(f,44)|0)+16|0;c=v[(f<<2)+28912>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+B(c,84)|0;bP(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+B(c,84)|0;bP(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{v[(e+B(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}aP(e,b)}else{vd((e+B(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=v[Mf(i+8|0,e)>>2];kb=i+16|0;v[h+8>>2]=b;b=h+8|0;rA(a,b);zj(b);break a}aP(c,b)}XO(a);kb=h+16|0}function Dz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kb-32|0;kb=e;if(b&5){if((b|0)==1){d=Oka(v[a+24>>2],0,8363,0)+4136|0;c=nb;h=a,i=Ec(Rka(d,d>>>0<4136?c+1|0:c,8272,0),nb),v[h+24>>2]=i}d=kb-16|0;kb=d;g=d+8|0;c=kb-16|0;kb=c;f=v[a+24>>2];a:{if(!f){Go(g);break a}yB(c+8|0,Yb(zl(Ap(+(f>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);f=v[c+8>>2];t[c+7|0]=v[c+12>>2];ee(g,f,c+7|0)}kb=c+16|0;qB(d,a+36|0,a+37|0);pB(d,g);kb=d+16|0}if(b&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(b&7){u[a+32>>1]=64;c=x[a+34>>1];if(c&8){d=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=d;c=c&16?c|6:c&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=x[a+34>>1];if(!(c&32)){u[a+28>>1]=128;u[a+34>>1]=c|32}wf(a+40|0,15);wf(a+41|0,63);if(!w[a+41|0]){break b}d=w[a+40|0];if(!d){break b}c=w[a+39|0];if(c){c=Ml(Ec(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}t[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|w[a+38|0]!=2){break d}t[a+38|0]=3;break d}if(w[a+38|0]!=4){break d}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}e:{if(!(!(w[a+35|0]&2)|b&16777218)){v[e+24>>2]=0;v[e+8>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;v[e>>2]=0;v[e+4>>2]=0;Gl(a,0,e);break e}if(!(w[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Lb(a,8);t[b|0]=w[b|0]&3;a=Lb(a,9);t[a|0]=w[a|0]&3}kb=e+32|0}function Aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;f=kb-16|0;kb=f;s=v[a+16>>2];u=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];e=v[a>>2];b=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=lg(k,l,n);p=nb;g=v[a+76>>2];e=v[a>>2];b=v[a+4>>2];Qf(e,b,lf(k,l,d),nb);m=g>>>0<nb>>>0?d:0}h=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[f>>2]=e;v[f+4>>2]=b;while(1){if(d){d=d-1|0;v[f+8>>2]=e;v[f+12>>2]=0;m=m-1|0;g=m;o=g?o:0;p=g?p:0;r=(((b&2147483647)<<1|e>>>31)&-2)+s|0;g=n;b:{c:while(1){d:{if((g|0)<=0){Rb(h,v[a+120>>2],v[a+124>>2]);g=v[a+116>>2];if(!g){break b}q=((v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31)&-2;e=0;b=0;break d}q=((v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31)&-2;b=0;e=0;while(1)if((b|0)==2){Sd(h,(e|0)/8<<16>>16);Rd(h,4);Rb(f+8|0,o,p);g=g-1|0;continue c}else{e=(t[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){e=(t[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}break}Sd(h,(e|0)/8<<16>>16);Rd(h,g);v[h>>2]=v[h>>2];v[h+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;g=jg(h,u);v[c>>2]=B(j>>12,g)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(g,i>>12);Rb(f,k,l);c=c+8|0;e=v[f>>2];b=v[f+4>>2];continue}break}v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;kb=f+16|0}function QP(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-240|0;kb=e;if(!w[94512]){if(!w[94388]){c=kb-16|0;kb=c;Mb(94364);v[23594]=0;t[94380]=0;v[23596]=0;v[23588]=0;b=ga(29)|0;a=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){v[c+8>>2]=b;b=c+8|0;HA(94376,ce(b));zj(b);t[94380]=0;break f}a=Ea(92948,93532)|0;b=O()|0;if((ea(92948)|0)==(b|0)){_(a|0)|0;v[23588]=0;Z(30);c=v[23588];v[23588]=0;if((c|0)==1){break d}L()}if((ea(93532)|0)!=(b|0)){break c}_(a|0)|0;v[23588]=0;t[94380]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){a=P()|0;O()|0;break c}if(w[94380]){break e}}v[23588]=0;Y(31,94360);b=v[23588];v[23588]=0;if((b|0)!=1){break e}a=P()|0;O()|0;break c}kb=c+16|0;break a}a=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)==1){break b}}zj(94384);zj(94376);zb(94364);T(a|0);L()}V(0)|0;O()|0;Vb();L()}t[94388]=1}c=kb+-64|0;kb=c;b=c+16|0;g=kb-16|0;kb=g;h=FP(g+8|0);j=e+120|0;while(1){if((i|0)==12){kb=g+16|0}else{f=kb-48|0;kb=f;a=v[h+4>>2];d=v[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=DP(EP(f+8|0,32));break g}d=E(a);d=EP(f+8|0,(a<<d+1?32:31)-d|0);while(1){k=DP(d);if(a>>>0<=k>>>0){continue}break}a=v[h>>2]+k|0}kb=f+48|0;l=Eb(b,i),m=a,v[l>>2]=m;i=i+1|0;continue}break}b=IP(c,b,KP(b));GP(j,b);Gm(b);kb=c- -64|0;uc(94392,uc(e,j,120),116);t[94512]=1}kb=e+240|0}function dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-16|0;kb=e;h=rf(a,c);ne(e,v[a+36>>2]);i=a;a:{if(!h){Sc(e,a+32|0,5);c=0;if(Cb(v[v[e>>2]>>2],v[e+4>>2])){break a}}d=kb-160|0;kb=d;f=_l(d+48|0,v[a+36>>2]);v[23588]=0;a=Q(449,d+32|0,43811)|0;c=v[23588];v[23588]=0;b:{c:{d:{e:{if((c|0)!=1){v[23588]=0;v[d+16>>2]=19988498;v[d+20>>2]=0;U(450,f|0,a|0,d+16|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}$b(a);if(!Lk(w[f|0])){break d}break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;$b(a);break c}k=d,l=Bf(v[b>>2],v[b+4>>2]),u[k+30>>1]=l;u[d+28>>1]=65535;v[23588]=0;a=Q(449,d+16|0,10055)|0;c=v[23588];v[23588]=0;f:{if((c|0)!=1){v[23588]=0;c=W(479,f|0,d+28|0,a|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break f}$b(a);if(c){u[d+30>>1]=x[d+28>>1]}Ff(d+30|0,4e3);a=x[d+30>>1];g:{if(Bf(v[b>>2],v[b+4>>2])>>>0>=a>>>0){break g}v[23588]=0;R(225,b|0,a|0);c=v[23588];v[23588]=0;if((c|0)!=1){break g}c=P()|0;O()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}g=v[b>>2];v[23588]=0;R(480,d|0,c|0);j=v[23588];v[23588]=0;if((j|0)!=1){v[23588]=0;X(481,f|0,Zb(g,c)|0,d|0,482);g=v[23588];v[23588]=0;if((g|0)==1){break h}c=c+1|0;$b(d);continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;$b(d);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;$b(a)}lh(f);T(c|0);L()}lh(f);kb=d+160|0;c=h}Ye(i,c);kb=e+16|0}function i5(a){a=a|0;var b=0,c=0,d=0,e=0;e=kb-160|0;kb=e;d=Nc(e,11520);v[23588]=0;b=d+12|0;Q(55,b|0,10926)|0;c=v[23588];v[23588]=0;a:{b:{if((c|0)==1){break a}v[23588]=0;b=d+24|0;Q(55,b|0,11350)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+36|0;Q(55,b|0,10918)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+48|0;Q(55,b|0,8203)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+60|0;Q(55,b|0,10903)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+72|0;Q(55,b|0,8269)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+84|0;Q(55,b|0,5623)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+96|0;Q(55,b|0,11924)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+108|0;Q(55,b|0,11293)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+120|0;Q(55,b|0,12125)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+132|0;Q(55,b|0,5475)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;b=d+144|0;Q(55,b|0,7295)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;W(1019,a|0,d|0,13)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}b=d+156|0;while(1){b=zb(b-12|0);if((d|0)!=(b|0)){continue}break}kb=e+160|0;return}b=d+156|0}a=P()|0;O()|0;while(1){b=zb(b-12|0);if((d|0)!=(b|0)){continue}break}T(a|0);L()}function Z$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=cj(d);i=np(d,a+224|0);mp(a+208|0,d,a+332|0);d=Mb(a+192|0);c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23588]=0;g=Q(1141,a+344|0,a+336|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Hb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1143,v[a+344>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(yn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23588]=0;S(1145,a+344|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=wG(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=nb;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function $$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=cj(d);i=np(d,a+224|0);mp(a+208|0,d,a+332|0);d=Mb(a+192|0);c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23588]=0;g=Q(1141,a+344|0,a+336|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Hb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1143,v[a+344>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(yn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23588]=0;S(1145,a+344|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=BG(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=nb;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function jea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=kb-48|0;kb=d;l=a+480190|0;c=x[l>>1];t[d+32|0]=0;DO(b,c+1|0,d+32|0);a:{j=a+480192|0;if(!x[j>>1]){break a}h=Tb(d+32|0);p=d,q=Fb(v[a+484344>>2]),v[p+24>>2]=q;o=Fb(v[a+484348>>2]);m=a+480188|0;while(1){i=v[d+24>>2];if(!Pb(i,o)){c=x[a+480190>>1];while(1)if(c){Db(d+8|0,v[b>>2],c);if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){e=f;f=B(c,104)+a|0;f=e+_d(v[f+484380>>2],v[f+484400>>2])|0}c=c-1|0;continue}else{ic(h);break a}}b:{if(!Pb(v[i>>2],v[i+4>>2])){break b}c=x[m>>1];v[23588]=0;t[d+8|0]=0;U(749,h|0,c|0,d+8|0);c=v[23588];v[23588]=0;if((c|0)!=1){p=d,q=Fb(v[i>>2]),v[p+16>>2]=q;k=0;c:while(1){f=0;if(y[i+12>>2]<=k>>>0){break b}while(1){if(x[m>>1]<=f>>>0){k=k+1|0;continue c}d:{c=v[d+16>>2];if(!$c(w[c|0])){break d}e:{f:{c=w[c+1|0];if(c){g=x[j>>1];break f}g=x[j>>1];c=w[Lb(v[h>>2],f)|0];if(c){break f}c=1;break e}p=Lb(v[h>>2],f),q=c,t[p|0]=q;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break d}e=v[((e<<2)+a|0)+900380>>2];g:{if(!e){break g}e=x[dc(e+236|0,w[v[d+16>>2]]-1|0)>>1];if(e>>>0>x[l>>1]){break g}n=d+8|0;Db(n,v[b>>2],e);Ze(n,1)}c=c+1|0;continue}}f=f+1|0;bA(d+16|0);continue}}}a=P()|0;O()|0;ic(h);T(a|0);L()}MM(d+24|0);continue}}kb=d+48|0;return f&65535}function Mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=kb-16|0;kb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=v[c+4>>2];v[23588]=0;R(656,a|0,b|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;lc(c);kb=c+16|0;break a}a=P()|0;O()|0;lc(c);T(a|0);L()}return}h=kb-32|0;kb=h;i=Gb(a);f=h+8|0;g=hq(v[a>>2],v[a+4>>2])+1|0;d=kb-16|0;kb=d;v[d+12>>2]=g;e=kb-16|0;kb=e;v[e+12>>2]=76695844;v[e+8>>2]=2147483647;c=v[Kb(e+12|0,e+8|0)>>2];kb=e+16|0;b:{if(c>>>0>=g>>>0){e=rR(a);if(e>>>0<c>>>1>>>0){v[d+8>>2]=e<<1;c=v[Zc(d+8|0,d+12|0)>>2]}kb=d+16|0;break b}cd();L()}e=hq(v[a>>2],v[a+4>>2]);pg(f+12|0,i);if(c){if(c>>>0>=76695845){Mg();L()}d=tc(B(c,56))}else{d=0}v[f>>2]=d;e=d+B(e,56)|0;v[f+8>>2]=e;v[f+4>>2]=e;j=Cc(f),k=d+B(c,56)|0,v[j>>2]=k;c=v[f+8>>2];v[23588]=0;R(656,c|0,b|0);b=v[23588];v[23588]=0;c:{if((b|0)!=1){v[f+8>>2]=v[f+8>>2]+56;e=v[a>>2];b=v[a+4>>2];d=f+4|0;while(1){if((b|0)!=(e|0)){b=b-56|0;c=wl(v[d>>2]-56|0,b);wl(c+12|0,b+12|0);Xz(c+24|0,b+24|0);u[c+52>>1]=x[b+52>>1];g=v[b+48>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=g;g=v[b+40>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=g;v[d>>2]=v[d>>2]-56;continue}break}qc(a,d);qc(a+4|0,f+8|0);qc(Gb(a),Cc(f));v[f>>2]=v[f+4>>2];qR(f);kb=h+32|0;break c}a=P()|0;O()|0;qR(f);T(a|0);L()}}function pG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=cj(d);i=np(d,a+224|0);mp(a+208|0,d,a+332|0);d=Mb(a+192|0);c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23588]=0;g=Q(1141,a+344|0,a+336|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Hb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1143,v[a+344>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(yn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23588]=0;S(1145,a+344|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=xG(c,v[a+188>>2],e,b),v[k>>2]=l;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function a0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=cj(d);i=np(d,a+224|0);mp(a+208|0,d,a+332|0);d=Mb(a+192|0);c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23588]=0;g=Q(1141,a+344|0,a+336|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Hb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1143,v[a+344>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(yn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23588]=0;S(1145,a+344|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=DG(c,v[a+188>>2],e,b),v[k>>2]=l;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function _$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=cj(d);i=np(d,a+224|0);mp(a+208|0,d,a+332|0);d=Mb(a+192|0);c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23588]=0;g=Q(1141,a+344|0,a+336|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Hb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1143,v[a+344>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(yn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23588]=0;S(1145,a+344|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=AG(c,v[a+188>>2],e,b),u[k>>1]=l;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1142,a+344|0,a+336|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function JF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=kb-16|0;kb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<=0){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];kb=a+16|0;return f|0}function i0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=kb-240|0;kb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=cj(d);op(a+208|0,d,a+223|0);d=Mb(a+192|0);c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23588]=0;g=Q(1125,a+232|0,a+224|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Hb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1127,v[a+232>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(zn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82976)){break c}v[23588]=0;S(1129,a+232|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=BG(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=nb;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+232|0,a+224|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];zb(d);zb(a+208|0);kb=a+240|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function g0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=kb-240|0;kb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=cj(d);op(a+208|0,d,a+223|0);d=Mb(a+192|0);c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23588]=0;g=Q(1125,a+232|0,a+224|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Hb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1127,v[a+232>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(zn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82976)){break c}v[23588]=0;S(1129,a+232|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=wG(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=nb;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+232|0,a+224|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];zb(d);zb(a+208|0);kb=a+240|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function IW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=kb-1088|0;kb=g;e=Jh(a);Ub(e+20|0,0,1040);v[e+1064>>2]=0;v[e+1068>>2]=0;v[e+1060>>2]=c;t[e+1084|0]=d;a=e+1072|0;v[a>>2]=0;v[a+4>>2]=0;v[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(Ld(x[a+34>>1])>>>0<=d>>>0){break a}v[e+1064>>2]=0;v[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(y[c>>2]<=a>>>0){break j}a=v[b+8>>2];f=v[b>>2];v[23588]=0;a=W(156,f|0,a|0,2)|0;f=v[23588];v[23588]=0;if((f|0)==1){break i}if(!a){break j}v[23588]=0;a=S(194,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break h}if(!a){break e}v[23588]=0;U(190,g|0,b|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}a=rr(g+24|0,g);f=hd(e,a);uc(f+20|0,a+20|0,1040);Bb(a);Bb(g);v[e+1076>>2]=0;v[e+1080>>2]=0;h=v[e+1060>>2];a=v[h+20>>2];if(_m(x[h+34>>1])>>>0>=2){v[23588]=0;R(195,f|0,a+(d<<1)|0);a=v[23588];v[23588]=0;if((a|0)!=1){break e}break f}v[23588]=0;R(196,f|0,a+d|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}break e}d=d+1|0;a=v[e+1060>>2];continue c}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break b}_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break d}}a=v[i>>2];continue}break}break}a=P()|0;O()|0}Bb(e);T(a|0);L()}kb=g+1088|0;return e|0}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;h=kb-16|0;kb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+32>>2];o=v[a+28>>2];p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(s,t,e,e>>31);g=nb;f=Yb(f,-16777216,16776704);k=Oka(q,r,f,f>>31);e=k+e|0;f=nb+g|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=(v[h+12>>2]<<1)+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(u[e+4>>1],u[g+10>>1])+B(u[e+2>>1],u[g+8>>1])|0)+B(u[e+6>>1],u[g+12>>1])|0)+B(u[e+8>>1],u[g+14>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+2>>1])+B(u[e-6>>1],u[g>>1])|0)+B(u[e-2>>1],u[g+4>>1])|0)+B(u[e>>1],u[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;k=Oka(e,e>>31,w,x);e=A+k|0;f=nb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;j=j+o|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+n|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Rb(h+8|0,y,z);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;kb=h+16|0}function UK(a){var b=0,c=C(0),d=0,e=0,f=0,g=C(0),h=0,i=0,k=C(0),m=0,n=0,o=C(0);d=kb-16|0;kb=d;b=v[v[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=ue(C(10),C(C(C(z[Eb(e,0)>>2]*C(120))+C(-60))/C(20))),z[n+4232>>2]=o;k=C(C(b>>>0)/C(1e3));n=a,o=ue(C(10),C(C(-1)/C(k*C(C(z[Eb(e,1)>>2]*C(499.989990234375))+C(.009999999776482582))))),z[n+4236>>2]=o;n=a,o=ue(C(10),C(C(-1)/C(k*C(C(z[Eb(e,2)>>2]*C(2950))+C(50))))),z[n+4240>>2]=o;v[d+12>>2]=1325400064;c=C(ue(C(10),C(C(C(z[Eb(e,3)>>2]*C(60))+C(-60))/C(20)))*C(2147483648));b=(p(c),j(2));g=C(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){b=kb-16|0;z[b+12>>2]=-1;g=C(z[b+12>>2]/C(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=MJ(c);break a}b=(p(C(c*C(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),q())*A[h+3568>>3]+-1;m=i*i;c=C((A[479]*m+(A[480]*i+A[481]))*m+(+(f>>23)*A[478]+A[h+3576>>3]+i))}g=c}z[d+8>>2]=C(C(g*C(67108864))/C(.6931471824645996))+C(67108864);n=a,o=C(z[om(d+12|0,d+8|0)>>2]*C(4.656612873077393e-10)),z[n+4244>>2]=o;n=a,o=C(C(C(-1)/C(C(z[Eb(e,4)>>2]*C(99))+C(1)))+C(1)),z[n+4248>>2]=o;c=C(C(C(z[Eb(e,5)>>2]*C(4))*k)+C(2));c:{if(C(D(c))<C(2147483648)){h=~~c;break c}h=-2147483648}v[a+4252>>2]=h;kb=d+16|0}function ue(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),k=0;f=(p(b),j(2));d=rF(f);a:{b:{c:{d:{c=(p(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=C(1);if((c|0)==1065353216){break b}e=f<<1;if(!e){break b}d=e>>>0<4278190081;e=c<<1;a=C(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=e>>>0>2130706431^(f|0)>=0?C(0):C(b*b);break a}if(rF(c)){i=C(a*a);if((c|0)<0){i=(qF(f)|0)==1?C(-i):i}if((f|0)>=0){break b}a=UH(C(C(1)/i));break a}if((c|0)<0){e=qF(f);if(!e){a=MJ(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((p(C(a*C(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),q())*A[d+93576>>3]+-1;h=g*g;h=((g*.288457581109214+-.36092606229713164)*(h*h)+((g*.480898481472577+-.7213474675006291)*h+(g*1.4426950408774342+(A[d+93584>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=GD(e);break a}if(!(h<=-150)){break f}a=fD(e);break a}k=h;g=A[160];h=g+h;g=k-(h-g);k=(A[161]*g+A[162])*(g*g)+(A[163]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+1024|0;e=v[d>>2];c=e;d=v[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=C(k*+n())}a=i}return a}function yG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=kb-240|0;kb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=cj(d);op(a+208|0,d,a+223|0);d=Mb(a+192|0);c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23588]=0;g=Q(1125,a+232|0,a+224|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Hb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1127,v[a+232>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(zn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82976)){break c}v[23588]=0;S(1129,a+232|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=xG(c,v[a+188>>2],e,b),v[j>>2]=k;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+232|0,a+224|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];zb(d);zb(a+208|0);kb=a+240|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function k0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=kb-240|0;kb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=cj(d);op(a+208|0,d,a+223|0);d=Mb(a+192|0);c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23588]=0;g=Q(1125,a+232|0,a+224|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Hb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1127,v[a+232>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(zn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82976)){break c}v[23588]=0;S(1129,a+232|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=DG(c,v[a+188>>2],e,b),v[j>>2]=k;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+232|0,a+224|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];zb(d);zb(a+208|0);kb=a+240|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function h0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=kb-240|0;kb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=cj(d);op(a+208|0,d,a+223|0);d=Mb(a+192|0);c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){c=Tc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23588]=0;g=Q(1125,a+232|0,a+224|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Hb(d);if((h|0)==(g+c|0)){v[23588]=0;R(60,d|0,g<<1);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=bd(d);v[23588]=0;R(60,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}c=Tc(d,0);v[a+188>>2]=g+c}v[23588]=0;g=S(1127,v[a+232>>2])|0;h=v[23588];v[23588]=0;if((h|0)==1){break d}if(zn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82976)){break c}v[23588]=0;S(1129,a+232|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Hb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=AG(c,v[a+188>>2],e,b),u[j>>1]=k;Gf(a+208|0,a+16|0,v[a+12>>2],e);v[23588]=0;b=Q(1126,a+232|0,a+224|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];zb(d);zb(a+208|0);kb=a+240|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);T(b|0);L()}return b|0}function I$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=kb-16|0;kb=k;l=Qw(g);g=xw(g);ch(k,g);a:{b:{if(Re(k)){v[23588]=0;X(1148,l|0,a|0,c|0,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23588]=0;j=Q(1154,l|0,h<<24>>24)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23588]=0;h=Q(1154,l|0,48)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[23588]=0;h=Q(1154,l|0,h|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}am(j,c);i=0;v[23588]=0;o=S(1146,g|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Tr((j-a<<2)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[Tc(k,h)|0]){break e}if(t[Tc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(Hb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23588]=0;n=Q(1154,l|0,n|0)|0;m=v[23588];v[23588]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;zb(k);T(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;zb(k);kb=k+16|0}function dI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=ge(a,k),v[p>>2]=q;g=d+1076|0;p=g,q=ge(a,k),v[p>>2]=q;i=ge(a,c&-4);v[d+1084>>2]=i;a:{h=v[h>>2];if(!h){break a}g=v[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=C(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))/j);p=i+(e<<2)|0,r=C(af(f)),z[p>>2]=r;p=i+(g<<2)|0,r=C(-C(Di(f))),z[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+C(C(C(e<<2)*C(3.1415927410125732))/j);p=h+l|0,r=C(af(f)),z[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=C(-C(Di(f))),z[p>>2]=r;f=+C(C(C(C(m|0)*C(3.1415927410125732))/j)*C(.5));p=g+l|0,r=C(C(af(f))*C(.5)),z[p>>2]=r;p=g+n|0,r=C(C(Di(f))*C(.5)),z[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=ge(a,k);v[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=C(Di((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=C(Di(+C(j*j)*1.5707963705062866)),z[p>>2]=r;b=b+1|0;continue}break}b=ge(a,c>>2&-2);v[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-jm(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=hm(a)>>>c<<2,u[p>>1]=q;a=a+1|0;continue}break}return 1}ec(a,3);return 0}function h4(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-80|0;kb=e;a:{b:{c:{d:{f=a+36|0;d=v[f>>2];c=v[a+40>>2];e:{if(Pb(d,c)){Hc(e+72|0);break e}c=e+32|0;Jn(c,a);v[23588]=0;c=S(1012,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break d}v[e+72>>2]=c;Xf(e+32|0);c=v[a+40>>2];d=v[a+36>>2]}c=(k=f,l=v[e+72>>2],m=Pb(d,c),m?k:l);f=v[a+8>>2];if((f|0)==-1){d=v[c+4>>2];f=d-24|0;g=v[c>>2];i=Ri(g,d);j=A[f>>3];d=0;while(1){if((d|0)==(i|0)){c=f;break c}c=mf(g,d);if(h+A[c>>3]>b){break c}d=d+1|0;h=h+j;continue}}c=mf(v[c>>2],f);break b}d=P()|0;O()|0;Xf(e+32|0);break a}b=b-h}f=x[c+12>>1];d=v[a+24>>2];v[23588]=0;R(1045,d|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){f:{f=v[a+24>>2];d=w[a+64|0];c=wM(bS(e+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[23588]=0;g=v[c+12>>2];v[e+16>>2]=v[c+8>>2];v[e+20>>2]=g;g=v[c+20>>2];v[e+24>>2]=v[c+16>>2];v[e+28>>2]=g;g=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=g;X(1046,e+56|0,f|0,(d?7:1)|0,e+8|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}c=xM(v[e+60>>2]);f=t[c+26|0]&1;d=v[(f?c+8|0:c+12|0)>>2];f=x[(f?c+20|0:c+22|0)>>1];b=A[c>>3];Ei(e+56|0);c=v[a+24>>2];u[c+1074450>>1]=f;u[c+1074448>>1]=f;v[c+1074428>>2]=d;v[c+1074392>>2]=-2;b=h+b;A[a+16>>3]=b;bl(e+72|0);kb=e+80|0;return+b}}d=P()|0;O()|0;bl(e+72|0)}T(d|0);L()}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;h=kb-16|0;kb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+32>>2];o=v[a+28>>2];p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(s,w,e,e>>31);g=nb;f=Yb(f,-16777216,16776704);k=Oka(q,r,f,f>>31);e=k+e|0;f=nb+g|0;f=e>>>0<k>>>0?f+1|0:f;C=e;e=v[h+12>>2]+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(t[e+2|0],u[g+10>>1])+B(t[e+1|0],u[g+8>>1])|0)+B(t[e+3|0],u[g+12>>1])|0)+B(t[e+4|0],u[g+14>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+2>>1])+B(t[e-3|0],u[g>>1])|0)+B(t[e-1|0],u[g+4>>1])|0)+B(t[e|0],u[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;k=Oka(e,e>>31,x,y);e=C+k|0;f=nb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;j=j+o|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+n|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Rb(h+8|0,z,A);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;kb=h+16|0}function fh(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;v[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=v[a+480180>>2];if(!Km(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=x[((B(a,-12)+e&255)<<1)+33248>>1]<<4>>>a|0;break a}if(!d){v[f+12>>2]=8363;d=8363}if(oj(a)){a=((e&255)>>>0)/12|0;b=Oka(v[(B(a,-12)+e<<6&960)+37136>>2]<<a,0,d,0);a=nb;c=a>>>21|0;h=f,i=Ec((a&2097151)<<11|b>>>21,c),v[h>>2]=i;xc(f,2147483647);e=v[f>>2];break a}if(w[a+480208|0]&16){a=e&255;e=x[((a>>>0)%12<<1)+33248>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;xc(f+12|0,-1>>>a|0);e=Ec(Rka(Oka(x[((B(a,-12)+e&255)<<1)+33248>>1],0,267616,0),nb,v[f+12>>2]<<a,0),nb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{Db(f,a+1074312|0,76);b=Cb(v[v[f>>2]>>2],v[f+4>>2])?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)>1?a:1;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(B(c,-12)+a<<3&248)|0;v[f>>2]=d+8;pe(f,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)>-8?a:-8;e=B(b,x[(((a|0)<95?a:95)<<1)+33744>>1])+B(x[(v[f>>2]<<1)+33728>>1],16-b|0)<<1>>>c|0;break a}if(!((c&255)>>>0<16&b-25>>>0<=83)){a=((e&255)>>>0)/12|0;e=x[(B((c&240)>>>4|0,12)+(B(a,-12)+e&255)<<1)+32848>>1]<<5>>>a|0;break a}e=x[(b<<1)+32622>>1]<<2}kb=f+16|0;return e}function kJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;c=kb+-64|0;kb=c;d=v[a>>2];a=v[d>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];g=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=g;If(c+48|0,c+32|0,f);a=v[d+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=kb-32|0;kb=a;a:{b:{c:{d:{k=v[c+4>>2];if(k>>>0>=g>>>0){l=v[c+20>>2];if(l>>>0<g>>>0){break d}if(f>>>0>y[c+8>>2]){break c}m=v[c+28>>2];if(f>>>0>v[c+24>>2]-m>>>0){break b}n=b+12|0;o=v[c+16>>2];p=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}q=B(h,k);r=B(h+m|0,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=Eb(v[b>>2],d);i=xe(ng(A[(d+q<<3)+p>>3])*134217728);j=e;e=(v[e>>2]>>1)+Jm(i)|0;s=e;e=xs(n)+e&-4096;v[j>>2]=s-e;A[a+24>>3]=+(e|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;j=(d+r<<1)+o|0;i=xe(A[Hg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){e=~~i;break f}e=-2147483648}t=j,w=ed(e),u[t>>1]=w;d=d+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}kb=a+32|0;kb=c- -64|0}function tJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=kb+-64|0;kb=c;d=v[a>>2];a=v[d>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];g=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=g;If(c+48|0,c+32|0,f);a=v[d+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=kb-32|0;kb=a;a:{b:{c:{d:{l=v[c+4>>2];if(l>>>0>=g>>>0){if(y[c+20>>2]<g>>>0){break d}if(f>>>0>y[c+8>>2]){break c}m=v[c+28>>2];if(f>>>0>v[c+24>>2]-m>>>0){break b}n=b+12|0;o=v[c+16>>2];p=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}q=h+m|0;r=B(h,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=Eb(v[b>>2],d);i=xe(ng(A[(d+r<<3)+p>>3])*134217728);j=e;e=(v[e>>2]>>1)+Jm(i)|0;k=e;e=xs(n)+e&-4096;v[j>>2]=k-e;A[a+24>>3]=+(e|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;j=q<<1;k=(d<<2)+o|0;i=xe(A[Hg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){e=~~i;break f}e=-2147483648}s=j+v[k>>2]|0,t=ed(e),u[s>>1]=t;d=d+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}kb=a+32|0;kb=c- -64|0}function kS(a,b){var c=0;a:{b:{c:{d:{if(oe(a,16692)){break d}if(oe(a,17461)){break d}if(oe(a,13490)){break d}if(oe(a,13645)){break d}if(!oe(a,14214)){break c}}u[b+10>>1]=4;v[b>>2]=11956;break b}e:{f:{if(oe(a,17456)){break f}if(oe(a,13500)){break f}if(!oe(a,16677)){break e}}t[b+12|0]=1;v[b>>2]=8351;u[b+10>>1]=4;return 1}g:{if(!oe(a,14260)){if(!oe(a,14265)){break g}}u[b+10>>1]=8;v[b>>2]=8129;break b}h:{if(!oe(a,15347)){if(!oe(a,15352)){break h}}v[b>>2]=17064;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!oe(a,26874)){if(!oe(a,26879)){break i}}v[b+4>>2]=1;v[b>>2]=16870;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(Sb(a,15453,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=8469;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(Sb(a,13573,3)){if(Sb(a,13707,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=8228;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!Sb(a+1|0,13731,3)){t[b+14|0]=1;v[b>>2]=8533;u[b+10>>1]=t[a|0]-48;return 1}if((w[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Sb(c,14063,2)){if(Sb(c,13735,2)){break k}}t[b+14|0]=1;v[b>>2]=8533;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}c=0;if(Sb(a,13356,3)|(w[a+3|0]-49&255)>>>0>8){break a}v[b>>2]=8378;u[b+10>>1]=t[a+3|0]-48}c=1}return c}function T_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=kb-496|0;kb=a;g=a+488|0;gd(g,d);v[23588]=0;m=S(1136,g|0)|0;g=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Hb(f)){g=v[Ai(f,0)>>2];v[23588]=0;h=Q(1154,m|0,45)|0;k=v[23588];v[23588]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Mb(a+456|0);g=Mb(a+440|0);h=Mb(a+424|0);v[23588]=0;na(1175,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}v[a+4>>2]=1123;c=te(a+8|0,0,a+4|0);j=Hb(f);l=v[a+420>>2];h:{if((j|0)>(l|0)){i=((Hb(h)+(j-l<<1)|0)+Hb(g)|0)+1|0;break h}i=(Hb(h)+Hb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}_e(c,Pd(i<<2));j=v[c>>2];if(j){break e}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=Ac(f);f=Hb(f);v[23588]=0;pa(1176,j|0,a+4|0,a|0,o|0,i|0,i+(f<<2)|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;b=ka(1157,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Xc(c)}Gc(h);Gc(g);zb(k)}ac(a+488|0);T(f|0);L()}Xc(c);Gc(h);Gc(g);zb(k);ac(a+488|0);kb=a+496|0;return b|0}function EM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;f=a+484376|0;while(1){a:{c=Wb(v[a+484360>>2],w[f|0]);e=b&65535;if(Rc(v[c>>2],v[c+4>>2])>>>0>e>>>0){if(!Hq(c,e)){break a}c=Wb(v[a+484360>>2],w[a+484376|0])}if(Rc(v[c>>2],v[c+4>>2])>>>0>e>>>0){e=a+1074312|0;f=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(f|0)){DM(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){ao(a+1298264|0,1);v[a+1074456>>2]=v[a+480200>>2];v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+480208>>2]=v[a+480208>>2]&-769;Wy(a+1074376|0);u[a+1074450>>1]=0;v[a+1074392>>2]=-2;b=a+1074428|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074376>>2]=0;v[a+1074380>>2]=0}else{fo((B(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;Db(d+8|0,e,23);if(Cb(v[v[d+8>>2]>>2],v[d+12>>2])){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;continue}break}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}kb=d+16|0;return}b=b+1|0;continue}}function S$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=kb-16|0;kb=k;l=iv(g);g=Dw(g);ch(k,g);a:{b:{if(Re(k)){v[23588]=0;X(1134,l|0,a|0,c|0,d|0);g=v[23588];v[23588]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23588]=0;j=Q(20,l|0,h<<24>>24)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23588]=0;h=Q(20,l|0,48)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[23588]=0;h=Q(20,l|0,h|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}am(j,c);i=0;v[23588]=0;o=S(1132,g|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){am((j-a|0)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[Tc(k,h)|0]){break e}if(t[Tc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Hb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23588]=0;n=Q(20,l|0,n|0)|0;m=v[23588];v[23588]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;zb(k);T(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;zb(k);kb=k+16|0}function Fr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{e=kb-96|0;kb=e;i=v[c>>2];g=kb-32|0;kb=g;f=e- -64|0;j=Mb(f+16|0);v[f>>2]=v[c>>2];v[f+4>>2]=v[c+4>>2];v[f+8>>2]=v[c+8>>2];v[f+12>>2]=v[c+12>>2];v[23588]=0;c=Q(54,g|0,c+16|0)|0;h=v[23588];v[23588]=0;b:{c:{d:{if((h|0)!=1){v[23588]=0;R(58,g+16|0,c|0);h=v[23588];v[23588]=0;if((h|0)==1){break d}f=g+16|0;Bc(j,f);zb(f);zb(c);kb=g+32|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(c)}km(f);T(a|0);L()}v[23588]=0;U(d|0,e|0,b|0,(i&2?16:10)|0);b=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{if((b|0)!=1){c=e+16|0;b=kb-16|0;kb=b;k:{if(!(v[e+64>>2]&32)){break k}k=b,l=ie(e),v[k+8>>2]=l;k=b,l=zh(e),v[k>>2]=l;while(1){if(!zi(b+8|0,b)){break k}d=v[b+8>>2];f=w[d|0];if((f-97&255)>>>0<=25){t[d|0]=f-32}He(b+8|0);continue}}ad(c,e);kb=b+16|0;v[23588]=0;X(75,e+32|0,c|0,v[e+64>>2],v[e+68>>2]);b=v[23588];v[23588]=0;if((b|0)==1){break j}v[23588]=0;U(76,e+48|0,e+32|0,e- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}v[23588]=0;R(58,a|0,e+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}zb(e+48|0);zb(e+32|0);zb(e+16|0);zb(e);km(e- -64|0);kb=e+96|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(e+48|0)}zb(e+32|0)}zb(e+16|0);zb(e)}km(e- -64|0);T(a|0);L()}}function TG(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=v[a+4>>2];h:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break h}c=sd(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=v[a+4>>2];i:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break i}c=sd(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(B(e,10)+c|0)-48|0;d=(e|0)<214748364;c=v[a+4>>2];j:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break j}c=sd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=Oka(e,d,10,0);c=b+c|0;d=nb;d=b>>>0>c>>>0?d+1|0:d;b=c;e=b-48|0;d=d-(b>>>0<48)|0;b=v[a+4>>2];l:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break l}c=sd(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];m:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break m}b=sd(a)}if(b-48>>>0<10){continue}break}}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){v[a+4>>2]=v[a+4>>2]-1}nb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}v[a+4>>2]=v[a+4>>2]-1;break b}if(v[a+116>>2]<0){break a}}v[a+4>>2]=v[a+4>>2]-1}nb=-2147483648;return 0}function $aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=kb-16|0;kb=i;d=v[b+1298304>>2];if(!Fd(d)){e=kb-16|0;kb=e;c=tc(12);v[23588]=0;d=S(907,c|0)|0;f=v[23588];v[23588]=0;a:{if((f|0)!=1){c=v[Mf(e+8|0,d)>>2];kb=e+16|0;break a}a=P()|0;O()|0;Nb(c);T(a|0);L()}v[i+8>>2]=c;c=b+1298304|0;e=i+8|0;TM(c,ce(e));By(e);d=v[c>>2]}f=kb-48|0;kb=f;c=f+16|0;IM(c,a);v[23588]=0;U(8,f+32|0,0,c|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Ab(f+16|0);m=f,n=Fb(v[d>>2]),v[m+8>>2]=n;l=Fb(v[d+4>>2]);c=0;d=0;while(1){d:{h=v[f+8>>2];if(!Pb(h,l)){e:{if(!d){break e}c=v[d+4>>2];if(!c){break e}v[23588]=0;a=W(c|0,d|0,b|0,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}if(!a){break e}b=v[d>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[d>>2]=a}zb(f+32|0);kb=f+48|0;break b}j=0;e=v[h>>2];if(v[e+32>>2]==v[a+16>>2]){j=v[e+36>>2]==v[a+20>>2]}v[23588]=0;R(908,f+16|0,e+8|0);e=v[23588];v[23588]=0;if((e|0)!=1){g=kb-16|0;kb=g;k=f+16|0;Ge(g+8|0,k);Ge(g,f+32|0);e=bN(v[g+8>>2],v[g+12>>2],v[g>>2],v[g+4>>2]);kb=g+16|0;zb(k);f:{if(!(!j|(e|0)!=0)){d=v[h>>2];c=3;break f}if((c|0)<2&j){d=v[h>>2];c=2;break f}e=!e&(c|0)<=0;d=e?v[h>>2]:d;c=e?1:c}Le(f+8|0);continue}}break}d=P()|0;O()|0;zb(f+32|0);break c}d=P()|0;O()|0;Ab(f+16|0)}T(d|0);L()}kb=i+16|0}function X_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=kb-192|0;kb=a;g=a+184|0;gd(g,d);v[23588]=0;m=S(19,g|0)|0;g=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Hb(f)){g=w[hg(f,0)|0];v[23588]=0;h=Q(20,m|0,45)|0;k=v[23588];v[23588]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Mb(a+160|0);g=Mb(a+144|0);h=Mb(a+128|0);v[23588]=0;na(1173,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}v[a+4>>2]=1123;c=te(a+8|0,0,a+4|0);j=Hb(f);l=v[a+124>>2];h:{if((j|0)>(l|0)){i=((Hb(h)+(j-l<<1)|0)+Hb(g)|0)+1|0;break h}i=(Hb(h)+Hb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}_e(c,Pd(i));j=v[c>>2];if(j){break e}v[23588]=0;Z(1124);b=v[23588];v[23588]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=Mc(f);f=Hb(f);v[23588]=0;pa(1174,j|0,a+4|0,a|0,o|0,i|0,f+i|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[23588];v[23588]=0;if((f|0)!=1){v[23588]=0;b=ka(15,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Xc(c)}zb(h);zb(g);zb(k)}ac(a+184|0);T(f|0);L()}Xc(c);zb(h);zb(g);zb(k);ac(a+184|0);kb=a+192|0;return b|0}function eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;f=kb-16|0;kb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){h=v[f+8>>2];o=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;e=(h>>>16&65520)+b|0;p=u[e+14>>1];q=u[e+12>>1];r=u[e+10>>1];s=u[e+8>>1];t=u[e+6>>1];w=u[e+4>>1];x=u[e+2>>1];y=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+o|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],x)+B(u[e-12>>1],y)|0)+B(u[e-4>>1],w)|0)+B(u[e>>1],t)|0)+B(u[e+4>>1],s)|0)+B(u[e+8>>1],r)|0)+B(u[e+12>>1],q)|0)+B(u[e+16>>1],p)|0)/32768;h=h+1|0;continue}break}k=k+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;kb=f+16|0}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=kb-16|0;kb=l;k=kb-32|0;kb=k;h=k+28|0;f=k+24|0;g=kb-16|0;kb=g;a:{b:{if(!pc(b,v[fc(g+8|0,Zf(a))>>2])){e=x[c>>1];i=v[c+4>>2];j=wd(b);m=x[j>>1];j=v[j+4>>2];if(!ml(e,i,m,j)){break b}}v[g+8>>2]=b;e=fc(g,Fb(v[a>>2]));c:{f=v[g+8>>2];if(!pc(f,v[e>>2])){f=v[jz(g+8|0)>>2];e=wd(f);j=x[e>>1];m=v[e+4>>2];e=x[c>>1];i=v[c+4>>2];if(!ml(j,m,e,i)){break c}}if(!v[b>>2]){v[h>>2]=b;break a}v[h>>2]=f;b=f+4|0;break a}b=iz(a,h,e,i);break a}if(ml(m,j,e,i)){d:{f=hz(b);if(!pc(f,v[fc(g+8|0,Zf(a))>>2])){e=x[c>>1];i=v[c+4>>2];j=wd(f);if(!ml(e,i,x[j>>1],v[j+4>>2])){break d}}if(!v[b+4>>2]){v[h>>2]=b;b=b+4|0;break a}v[h>>2]=f;b=f;break a}b=iz(a,h,e,i);break a}v[h>>2]=b;v[f>>2]=b;b=f}kb=g+16|0;f=b;b=v[b>>2];if(!b){b=kb-16|0;kb=b;g=jc(a);h=k+8|0;e=mh(h,tc(36),nh(b+8|0,g));g=v[e>>2]+16|0;i=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=i;wl(g+8|0,d);o=jc(e),p=1,t[o+4|0]=p;kb=b+16|0;Kg(a,v[k+28>>2],f,v[k+8>>2]);b=ce(h);xO(h);n=1}Jg(l,v[fc(k+8|0,b)>>2],n);kb=k+32|0;if(!w[jc(l)|0]){a=wd(v[l>>2])+8|0;wO(a);v[a>>2]=v[d>>2];v[a+4>>2]=v[d+4>>2];b=Gb(d);o=Gb(a),p=v[b>>2],v[o>>2]=p;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[fc(l+8|0,v[l>>2])>>2];kb=l+16|0;return a|0}function Mka(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=E(f)-E(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;lb=a-B(b,c)|0;mb=0;nb=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}lb=a;mb=e&g;a=e>>>Nka(f)|0;nb=0;return a}f=c-1|0;if(!(f&c)){break e}h=(E(c)+33|0)-E(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}lb=0;a=(e>>>0)/(f>>>0)|0;mb=e-B(a,f)|0;nb=0;return a}e=E(f)-E(e)|0;if(e>>>0<31){break d}break b}lb=a&f;mb=0;if((c|0)==1){break a}d=a;c=Nka(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}nb=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}lb=k;mb=f;e=b<<1|a>>>31;a=l|a<<1;nb=e|j;return a}lb=a;mb=b;a=0;b=0}nb=b;return a}function E$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=kb-384|0;kb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=Qr(f+376|1,21619,v[c+4>>2]);v[f+332>>2]=f+336;a=Hd();a:{if(h){b=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=b;g=ah(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;g=ah(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=1123;i=te(f+320|0,0,f+80|0);b=f+336|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Hd();f:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=_i(f+332|0,a,f+376|0,f);break f}A[f+16>>3]=e;g=_i(f+332|0,a,f+376|0,f+16|0)}if((g|0)==-1){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)==1){break d}break e}a=v[f+332>>2];_e(i,a)}j=a+g|0;l=$i(a,j,c);v[f+68>>2]=1123;h=te(f+72|0,0,f+68|0);g:{h:{if((f+336|0)==(a|0)){g=f+80|0;break h}g=Pd(g<<3);if(!g){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}_e(h,g);b=a}a=f+56|0;gd(a,c);v[23588]=0;ia(1156,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=v[23588];v[23588]=0;i:{if((a|0)!=1){ac(f+56|0);v[23588]=0;a=ka(1157,k|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break i}Xc(h);Xc(i);kb=f+384|0;break b}a=P()|0;O()|0;ac(f+56|0);break g}a=P()|0;O()|0}Xc(h);break c}L()}a=P()|0;O()|0}Xc(i);T(a|0);L()}return a|0}function O$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=kb-208|0;kb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=Qr(f+200|1,21619,v[c+4>>2]);v[f+156>>2]=f+160;a=Hd();a:{if(h){b=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=b;g=ah(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;g=ah(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=1123;i=te(f+144|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Hd();f:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=_i(f+156|0,a,f+200|0,f);break f}A[f+16>>3]=e;g=_i(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)==1){break d}break e}a=v[f+156>>2];_e(i,a)}j=a+g|0;l=$i(a,j,c);v[f+68>>2]=1123;h=te(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Pd(g<<1);if(!g){v[23588]=0;Z(1124);a=v[23588];v[23588]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}_e(h,g);b=a}a=f+56|0;gd(a,c);v[23588]=0;ia(1151,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=v[23588];v[23588]=0;i:{if((a|0)!=1){ac(f+56|0);v[23588]=0;a=ka(15,k|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break i}Xc(h);Xc(i);kb=f+208|0;break b}a=P()|0;O()|0;ac(f+56|0);break g}a=P()|0;O()|0}Xc(h);break c}L()}a=P()|0;O()|0}Xc(i);T(a|0);L()}return a|0}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=kb-16|0;kb=e;q=v[a+16>>2];r=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){j=v[a+8>>2];k=v[a+12>>2];f=v[a>>2];g=v[a+4>>2];i=0;break a}j=v[a+8>>2];k=v[a+12>>2];m=lg(j,k,l);n=nb;b=v[a+76>>2];f=v[a>>2];g=v[a+4>>2];Qf(f,g,lf(j,k,d),nb);i=b>>>0<nb>>>0?d:0}h=a+112|0;s=v[a+24>>2];u=v[a+20>>2];v[e>>2]=f;v[e+4>>2]=g;while(1){if(d){b=v[e+4>>2];f=v[e>>2];v[e+8>>2]=f;v[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;p=(((b&2147483647)<<1|f>>>31)&-2)+q|0;f=l;b:{c:while(1){d:{if((f|0)<=0){Rb(h,v[a+120>>2],v[a+124>>2]);f=v[a+116>>2];if(!f){break b}o=((v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31)&-2;g=0;b=0;break d}o=((v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Sd(h,(g|0)/8<<16>>16);Rd(h,4);Rb(e+8|0,m,n);f=f-1|0;continue c}else{g=(t[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}break}Sd(h,(g|0)/8<<16>>16);Rd(h,f);v[h>>2]=v[h>>2];v[h+4>>2]=0}f=v[c>>2];b=jg(h,r);v[c>>2]=f+B(b,u);v[c+4>>2]=v[c+4>>2]+B(b,s);Rb(e,j,k);c=c+8|0;continue}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;kb=e+16|0}function GY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(_g(a,v[b+8>>2],e)){nw(b,c,d);return}a:{if(_g(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;h=f+(v[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}u[b+52>>1]=0;kw(v[f>>2],v[f+4>>2],b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}g=1;if(w[a+8|0]&2){break e}break c}g=1;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}v[b+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];h=a+16|0;Kr(v[h>>2],v[a+20>>2],b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}Kr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}Kr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}Kr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function Dr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{e=kb-96|0;kb=e;i=v[c>>2];g=kb-32|0;kb=g;f=e- -64|0;j=Mb(f+16|0);v[f>>2]=v[c>>2];v[f+4>>2]=v[c+4>>2];v[f+8>>2]=v[c+8>>2];v[f+12>>2]=v[c+12>>2];v[23588]=0;c=Q(3,g|0,c+16|0)|0;h=v[23588];v[23588]=0;b:{c:{d:{if((h|0)!=1){v[23588]=0;R(71,g+16|0,c|0);h=v[23588];v[23588]=0;if((h|0)==1){break d}f=g+16|0;Jb(j,f);Ab(f);Ab(c);kb=g+32|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ab(c)}Pj(f);T(a|0);L()}v[23588]=0;U(d|0,e|0,b|0,(i&2?16:10)|0);b=v[23588];v[23588]=0;e:{f:{g:{h:{i:{j:{if((b|0)!=1){d=e+16|0;c=kb-16|0;kb=c;k:{if(!(v[e+64>>2]&32)){break k}b=Pi(e);v[c+8>>2]=b;f=hr(e);while(1){if(!Pb(b,f)){break k}g=w[b|0];if((g-97&255)>>>0<=25){t[b|0]=g-32}b=v[He(c+8|0)>>2];continue}}ad(d,e);kb=c+16|0;v[23588]=0;X(82,e+32|0,d|0,v[e+64>>2],v[e+68>>2]);b=v[23588];v[23588]=0;if((b|0)==1){break j}v[23588]=0;U(83,e+48|0,e+32|0,e- -64|0);b=v[23588];v[23588]=0;if((b|0)==1){break i}v[23588]=0;R(71,a|0,e+48|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}Ab(e+48|0);Ab(e+32|0);Ab(e+16|0);Ab(e);Pj(e- -64|0);kb=e+96|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;Ab(e+48|0)}Ab(e+32|0)}Ab(e+16|0);Ab(e)}Pj(e- -64|0);T(a|0);L()}}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=kb-16|0;kb=f;q=v[a+16>>2];r=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){l=v[a+8>>2];m=v[a+12>>2];e=v[a>>2];b=v[a+4>>2];h=0;break a}l=v[a+8>>2];m=v[a+12>>2];o=lg(l,m,n);p=nb;h=v[a+76>>2];e=v[a>>2];b=v[a+4>>2];Qf(e,b,lf(l,m,d),nb);h=h>>>0<nb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[f>>2]=e;v[f+4>>2]=b;b:while(1){if(d){d=d-1|0;v[f+8>>2]=e;v[f+12>>2]=0;h=h-1|0;o=h?o:0;p=h?p:0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Rb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){k=(v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31;Sd(g,(u[(k<<1|2)+e>>1]+u[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;e=jg(g,r);v[c>>2]=B(j>>12,e)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Rb(f,l,m);c=c+8|0;e=v[f>>2];b=v[f+4>>2];continue b}else{k=(v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31;Sd(g,(u[(k<<1|2)+e>>1]+u[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Rd(g,4);Rb(f+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;kb=f+16|0}function t3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=kb+-64|0;kb=c;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[c+40>>2]=v[a+20>>2];f=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=f;If(c+48|0,c+32|0,e);a=v[d+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=kb-32|0;kb=a;a:{b:{c:{d:{g=v[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>y[c+20>>2]){break d}if(y[c+8>>2]<e>>>0){break c}h=v[c+28>>2];if(v[c+24>>2]-h>>>0<e>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}n=b+h|0;o=B(b,g);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{r=a,s=+(Jm(xe(ng(A[(d+o<<3)+m>>3])*134217728))+ld(ws(k),21)|0)*7.450580596923828e-9,A[r+24>>3]=s;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;p=n<<1;q=(d<<2)+l|0;i=xe(A[Hg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){j=~~i;break f}j=-2147483648}r=v[q>>2]+p|0,t=ed(j),u[r>>1]=t;d=d+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}kb=a+32|0;kb=c- -64|0}function fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;f=kb-16|0;kb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){h=v[f+8>>2];o=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+l|0;e=(h>>>16&65520)+b|0;p=u[e+14>>1];q=u[e+12>>1];r=u[e+10>>1];s=u[e+8>>1];w=u[e+6>>1];x=u[e+4>>1];y=u[e+2>>1];z=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+o|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],y)+B(t[e-6|0],z)|0)+B(t[e-2|0],x)|0)+B(t[e|0],w)|0)+B(t[e+2|0],s)|0)+B(t[e+4|0],r)|0)+B(t[e+6|0],q)|0)+B(t[e+8|0],p)<<8)/32768;h=h+1|0;continue}break}k=k+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;kb=f+16|0}function k3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=kb+-64|0;kb=c;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[c+40>>2]=v[a+20>>2];f=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=f;If(c+48|0,c+32|0,e);a=v[d+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=kb-32|0;kb=a;a:{b:{c:{d:{g=v[c+4>>2];if(f>>>0<=g>>>0){h=v[c+20>>2];if(f>>>0>h>>>0){break d}if(y[c+8>>2]<e>>>0){break c}i=v[c+28>>2];if(v[c+24>>2]-i>>>0<e>>>0){break b}l=b+12|0;m=v[c+16>>2];n=v[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}o=B(b,g);p=B(b+i|0,h);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{r=a,s=+(Jm(xe(ng(A[(d+o<<3)+n>>3])*134217728))+ld(ws(l),21)|0)*7.450580596923828e-9,A[r+24>>3]=s;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;q=(d+p<<1)+m|0;j=xe(A[Hg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(j)<2147483648){k=~~j;break f}k=-2147483648}r=q,t=ed(k),u[r>>1]=t;d=d+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}kb=a+32|0;kb=c- -64|0}function rf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-96|0;kb=c;d=v[a+36>>2];Tl(v[v[d>>2]-12>>2]+d|0,0);d=a+32|0;Sc(c+56|0,d,4);if(!Cb(v[v[c+56>>2]>>2],v[c+60>>2])){Yv(a)}a:{if(!v[a+8>>2]){break a}Sc(c+56|0,d,6);if(Cb(v[v[c+56>>2]>>2],v[c+60>>2])){break a}Sc(c+88|0,d,7);if(Cb(v[v[c+88>>2]>>2],v[c+92>>2])){break a}h=v[a+36>>2];e=v[a+92>>2];g=B(v[a+28>>2],v[a+8>>2]);f=g+v[a+88>>2]|0;e=Yg(c+72|0,f,f>>>0<g>>>0?e+1|0:e);f=v[e+12>>2];v[c+32>>2]=v[e+8>>2];v[c+36>>2]=f;f=v[e+4>>2];v[c+24>>2]=v[e>>2];v[c+28>>2]=f;Yj(h,c+24|0)}Sc(c+56|0,d,5);e=0;b:{if(!Cb(v[v[c+56>>2]>>2],v[c+60>>2])){break b}f=Ri(v[a+52>>2],v[a+56>>2]);d=0;while(1){if((d|0)==(f|0)){break b}h=(v[a+108>>2]+d>>>0)%(f>>>0)|0;i=mf(v[a+52>>2],h);g=v[i>>2];c:{j=v[a+40>>2];if(fd(j,v[a+44>>2])>>>0<=g>>>0){break c}g=Mk(c+56|0,Lb(j,g),x[i+20>>1]);i=cw(b,g);$b(g);if(!i){break c}v[a+108>>2]=(h+1>>>0)%(f>>>0);e=mf(v[a+52>>2],h);d=e;b=v[d+12>>2];d=v[d+8>>2];if(!(b|d)){break b}e=v[a+36>>2];b=v[a+20>>2]+b|0;f=v[a+16>>2];d=f+d|0;b=Yg(c+40|0,d,d>>>0<f>>>0?b+1|0:b);d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Yj(e,c+8|0);e=mf(v[a+52>>2],h);break b}d=d+1|0;continue}}kb=c+96|0;return e}function Jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=kb-288|0;kb=f;$f(b);a:{if(!Qb(v[a>>2],v[a+8>>2],1)){break a}while(1){d=f+32|0;tn(f+8|0,d,zq(d));k=v[a>>2];g=v[a+8>>2];d=kb-32|0;kb=d;$g(d+16|0,v[f+8>>2],v[f+12>>2]);e=v[v[k>>2]+28>>2];l=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=l;ob[e|0](d+24|0,k,g,d+8|0);$g(f+16|0,v[d+24>>2],v[d+28>>2]);kb=d+32|0;v[f+28>>2]=v[f+20>>2];o=f,p=c-Hb(b)|0,v[o+4>>2]=p;d=v[Kb(f+28|0,f+4|0)>>2];if(!d){break a}t[f+16|0]=0;k=f+32|0;m=k+d|0;d=f+16|0;l=xi(k,m,d);o=f,p=zh(b),v[o+16>>2]=p;e=v[mj(f,d)>>2];g=kb-32|0;kb=g;v[g+24>>2]=e;o=g,p=ie(b),v[o+8>>2]=p;h=On(g+24|0,g+8|0);b:{c:{d=k;i=Sh(d,l);if(!i){break c}if(!_s(b,d)){e=Hb(b);j=bd(b);d:{if(i>>>0<=j-e>>>0){j=Ac(b);if((e|0)==(h|0)){break d}n=h+j|0;Xh(i+n|0,n,e-h|0);break d}sm(b,j,(e+i|0)-j|0,e,h,0,i);j=v[b>>2]}e=e+i|0;Rh(b,e);t[g+8|0]=0;je(e+j|0,g+8|0);e=h+j|0;while(1){if((d|0)==(l|0)){break c}je(e,d);d=d+1|0;e=e+1|0;continue}}d=Uh(g+8|0,d,l);h=Mc(d);i=Hb(d);v[23588]=0;fa(356,b|0,e|0,h|0,h+i|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){zb(d);break b}a=P()|0;O()|0;zb(d);T(a|0);L()}ie(b)}kb=g+32|0;_b(a,l-k|0);if(l>>>0>=m>>>0){continue}break}_b(a,1)}kb=f+288|0}function LF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=kb-16|0;kb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){j=v[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=w[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=w[j+2|0];i=w[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=w[j+3|0];m=w[j+2|0];k=w[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}v[f>>2]=c;v[a+12>>2]=i+j;f=v[a+8>>2]+4|0;v[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];kb=a+16|0;return b|0}function G7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=C(0),r=0,s=0,t=0,u=C(0),w=0;i=kb-16|0;kb=i;a:{if(!ai(a+44|0)){break a}n=v[a+44>>2];j=Kc(n,0);k=Kc(n,1);n=v[a+56>>2];t=Kc(n,0);n=Kc(n,1);u=z[Eb(a+4208|0,1)>>2];v[i+12>>2]=d;s=v[a+4220>>2];q=C(C(1)/C(s>>>0));w=v[a+4216>>2];o=d;f=n;g=t;while(1){if(!o){si(a,b,c,t,n,d);break a}h=v[a+4224>>2];b:{if(s>>>0>h>>>0){v[i+8>>2]=s-h;r=v[Kb(i+12|0,i+8|0)>>2];m=0;c:{if(u<C(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break c}p=C(h>>>0);z[g>>2]=q*C(z[j>>2]*p);z[f>>2]=q*C(z[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){z[g>>2]=z[j>>2];z[f>>2]=z[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;v[i+12>>2]=o;break b}m=w-h|0;v[i+4>>2]=m;l=v[Kb(i+12|0,i+4|0)>>2];e=0;d:{if(u<C(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break d}p=C(m>>>0);z[g>>2]=q*C(z[j>>2]*p);z[f>>2]=q*C(z[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){v[g>>2]=0;v[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;v[i+12>>2]=o;e=h+l|0;l=e>>>0<w>>>0?e:0}v[a+4224>>2]=l;continue}}kb=i+16|0}function iba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=kb-16|0;kb=l;v[l+8>>2]=b;q=xf(a);while(1){if(Ig(b,c)){b=v[fc(l,q)>>2];k=wd(v[l+8>>2]);o=kb-16|0;kb=o;p=0;m=kb-16|0;kb=m;i=kb-32|0;kb=i;g=i+28|0;d=i+24|0;e=kb-16|0;kb=e;a:{b:{if(!pc(b,v[fc(e+8|0,Zf(a))>>2])){f=w[k|0];j=v[k+4>>2];h=wd(b);n=w[h|0];h=v[h+4>>2];if(!Rn(f,j,n,h)){break b}}v[e+8>>2]=b;f=fc(e,Fb(v[a>>2]));c:{d=v[e+8>>2];if(!pc(d,v[f>>2])){d=v[jz(e+8|0)>>2];f=wd(d);h=w[f|0];n=v[f+4>>2];f=w[k|0];j=v[k+4>>2];if(!Rn(h,n,f,j)){break c}}if(!v[b>>2]){v[g>>2]=b;break a}v[g>>2]=d;b=d+4|0;break a}b=Iy(a,g,f,j);break a}if(Rn(n,h,f,j)){d:{d=hz(b);if(!pc(d,v[fc(e+8|0,Zf(a))>>2])){f=w[k|0];j=v[k+4>>2];h=wd(d);if(!Rn(f,j,w[h|0],v[h+4>>2])){break d}}if(!v[b+4>>2]){v[g>>2]=b;b=b+4|0;break a}v[g>>2]=d;b=d;break a}b=Iy(a,g,f,j);break a}v[g>>2]=b;v[d>>2]=b;b=d}kb=e+16|0;d=b;b=v[b>>2];if(!b){b=kb-16|0;kb=b;e=jc(a);g=i+8|0;e=mh(g,tc(28),nh(b+8|0,e));Tz(v[e>>2]+16|0,k);r=jc(e),s=1,t[r+4|0]=s;kb=b+16|0;Kg(a,v[i+28>>2],d,v[i+8>>2]);b=ce(g);rk(g);p=1}Jg(m+8|0,v[fc(i+8|0,b)>>2],p);kb=i+32|0;kb=m+16|0;fc(o+8|0,v[m+8>>2]);kb=o+16|0;b=v[Lg(l+8|0)>>2];continue}else{kb=l+16|0}break}}function Zga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;nd(b,0);Lo(b);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=Qe(ni(+(f+1408|0)/1536)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[Xb(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=w[a+6|0]|w[a+7|0]<<8;if(d>>>0<=256){u[b+28>>1]=d;u[b+34>>1]=x[b+34>>1]|32}v[b>>2]=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+4>>2]=w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24);v[b+8>>2]=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);d=w[a+20|0]|w[a+21|0]<<8;if(d&16){u[b+34>>1]=x[b+34>>1]|2;d=w[a+20|0]|w[a+21|0]<<8}if(d&32){u[b+34>>1]=x[b+34>>1]|4;d=w[a+20|0]|w[a+21|0]<<8}if(d&256){u[b+34>>1]=x[b+34>>1]|8;d=w[a+20|0]|w[a+21|0]<<8}if(d&512){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+39696|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[Xb(e+13|0,e+12|0)|0],u[g+32>>1]=h}v[b+12>>2]=w[a+27|0]|w[a+28|0]<<8|(w[a+29|0]<<16|w[a+30|0]<<24);v[b+16>>2]=w[a+31|0]|w[a+32|0]<<8|(w[a+33|0]<<16|w[a+34|0]<<24);kb=e+16|0}function zQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];e=Ah(c,v[a+4>>2]);if(e>>>0<b>>>0){g=kb-32|0;kb=g;f=b-e|0;b=v[Gb(a)>>2];c=v[a+4>>2];a:{if(f>>>0<=b-c>>8>>>0){b=kb-16|0;kb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(f<<8);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){lc(b);kb=b+16|0}else{iQ(a);a=a+256|0;v[b+4>>2]=a;continue}break}break a}i=Gb(a);b=g+8|0;e=a;h=Ah(v[a>>2],c)+f|0;c=kb-16|0;kb=c;v[c+12>>2]=h;d=kb-16|0;kb=d;v[d+12>>2]=16777215;v[d+8>>2]=2147483647;a=v[Kb(d+12|0,d+8|0)>>2];kb=d+16|0;b:{if(a>>>0>=h>>>0){d=Sz(e);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;break b}cd();L()}d=Ah(v[e>>2],v[e+4>>2]);pg(b+12|0,i);if(a){if(a>>>0>=16777216){Mg();L()}c=tc(a<<8)}else{c=0}v[b>>2]=c;d=c+(d<<8)|0;v[b+8>>2]=d;v[b+4>>2]=d;j=Cc(b),k=c+(a<<8)|0,v[j>>2]=k;a=kb-16|0;kb=a;v[a>>2]=v[b+8>>2];c=v[b+8>>2];v[a+8>>2]=b+8;v[a+4>>2]=c+(f<<8);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){iQ(c);c=v[a>>2]+256|0;v[a>>2]=c;continue}break}Ud(a);kb=a+16|0;Ed(e,b);e=v[b+4>>2];a=v[b+8>>2];while(1){if((a|0)!=(e|0)){a=a-256|0;v[b+8>>2]=a;continue}break}a=v[b>>2];if(a){Cc(b);Nb(a)}}kb=g+32|0;return}if(b>>>0<e>>>0){Od(a,c+(b<<8)|0)}}function DW(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-32|0;kb=d;if(!Sb(a,13603,4)){nd(b,32);Lo(b);_h(d,1,a+4|0);c=d+16|0;Fc(c,d);Ce(b+43|0,c);zb(c);u[b+30>>1]=w[a+19|0]<<2;Ff(b+30|0,256);u[b+32>>1]=w[a+17|0];Ff(b+32|0,64);u[b+28>>1]=(w[a+47|0]&127)<<2;Ff(b+28|0,256);if(t[a+47|0]<0){u[b+34>>1]=x[b+34>>1]|32}c=w[a+18|0];if(c&16){u[b+34>>1]=x[b+34>>1]|2;c=w[a+18|0]}if(c&32){u[b+34>>1]=x[b+34>>1]|8;c=w[a+18|0]}if(c&64){u[b+34>>1]=x[b+34>>1]|4;c=w[a+18|0]}if(c<<24>>24<0){u[b+34>>1]=x[b+34>>1]|16}c=w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24);v[b+24>>2]=c?c>>>0>256?c:256:8363;v[b>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[b+4>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[b+8>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);v[b+12>>2]=w[a+64|0]|w[a+65|0]<<8|(w[a+66|0]<<16|w[a+67|0]<<24);v[b+16>>2]=w[a+68|0]|w[a+69|0]<<8|(w[a+70|0]<<16|w[a+71|0]<<24);Dk(b);t[b+38|0]=w[(w[a+79|0]&7)+39696|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=w[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}u[b+34>>1]=c|x[b+34>>1]}c=w[a+72|0]|w[a+73|0]<<8|(w[a+74|0]<<16|w[a+75|0]<<24)}kb=d+32|0;return c|0}function Bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=kb-48|0;kb=k;if(Bf(v[b>>2],v[b+4>>2])>>>0>c>>>0){while(1){i=m&65535;if(i>>>0<=c>>>0){g=bg(v[b>>2],i);e=v[g>>2];if(Pb(e,v[g+4>>2])){n=k+24|0;e=Fb(e);o=Fb(v[bg(v[b>>2],i)+4>>2]);f=ZP(k,d);l=kb-16|0;kb=l;v[l+8>>2]=e;while(1){if(Pb(e,o)){j=kb-16|0;kb=j;if(!(w[e+5|0]|w[e+3|0]!=4)){g=j+8|0;Db(g,v[f>>2],x[f+14>>1]);Ze(g,0);t[e+3|0]=0}h=w[e+2|0];if(!(w[e+4|0]|(h|0)!=11)){g=j+8|0;Db(g,v[f>>2],x[f+14>>1]);Ze(g,0);t[e+2|0]=0;h=0}a:{b:{if(!w[e|0]){Db(j+8|0,v[f>>2],x[f+14>>1]);if(Cb(v[v[j+8>>2]>>2],v[j+12>>2])){break b}h=w[e+2|0]}i=w[e+3|0];g=j+8|0;Db(g,v[f>>2],x[f+14>>1]);Ze(g,(i|0)==4|(h|0)==11);h=w[e+3|0];break a}h=w[e+3|0];g=w[e+2|0];if(!(h|(g|0)==11)){t[e+5|0]=0;h=4;t[e+3|0]=4;break a}if(g|(h|0)==4){break a}t[e+4|0]=0;t[e+2|0]=11}c:{d:{e:{if(!(!w[f+16|0]|h)){t[e+3|0]=17;i=0;h=125;break e}i=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(w[e+5|0]){break c}i=1;h=6}t[e+5|0]=h}t[f+16|0]=i}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];kb=j+16|0;e=v[Ck(l+8|0)>>2];continue}break}XP(n,f);kb=l+16|0;We(n);We(f)}m=m+1|0;continue}break}}XP(a,d);kb=k+48|0}function d4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=kb-2144|0;kb=b;Ub(b+96|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[23588]=0;b=Q(55,b+80|0,10403)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break b}g=v[c>>2];d=v[c+12>>2];c=v[c+8>>2];v[b+72>>2]=c;v[b+76>>2]=d;e=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=e;v[b+68>>2]=f;v[b+64>>2]=g;e=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=e;h=fJ(b+16|0);if(h){v[b+48>>2]=c;v[b+52>>2]=d;c=v[b+52>>2];v[b+8>>2]=v[b+48>>2];v[b+12>>2]=c;v[b+44>>2]=f;v[b+40>>2]=g;c=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=c;c=aJ(b)}else{c=0}v[b+56>>2]=c;v[b+60>>2]=0;d=0;c=2048;while(1){if(c){e=ob[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=a;a=hc(b+32|0,b+96|0,d);a=bt(c,v[a>>2],v[a+4>>2],h?b+56|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[23588]=0;b=Q(55,b+80|0,8017)|0;c=v[23588];v[23588]=0;if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break b}c=P()|0;O()|0;ca(a|0);break b}kb=b+2144|0;return a|0}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}function Bd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb+-64|0;kb=d;v[a+480180>>2]=b;b=xq(a);wq(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;ct(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>x[a+480192>>1]){v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;wy(a,4);e=kb+-64|0;kb=e;b=a+484344|0;et(b);f=yk(v[b>>2],v[b+4>>2]);c=_x(e+8|0,b);v[23588]=0;U(814,b|0,f|0,c|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){hl(c);kb=e- -64|0;break a}a=P()|0;O()|0;hl(c);T(a|0);L()}jP(a+484360|0);$f(a+1298308|0);nA(a+1298320|0);$f(a+1298332|0);c=Ub(d,0,64);b=$M(c);d=Jb(a+1298344|0,b);Jb(d+12|0,b+12|0);Jb(d+24|0,b+24|0);Jb(d+36|0,b+36|0);Jb(d+48|0,b+48|0);v[d+60>>2]=v[b+60>>2];Cy(b);Lc(a+1298408|0);Lc(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}kb=c- -64|0;return}c=((c<<2)+a|0)+900380|0;e=v[c>>2];if(e){Nb(du(e))}v[c>>2]=0;b=b+1|0;continue}}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;h=kb-16|0;kb=h;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+72>>2];b=v[a+68>>2];o=b;p=b>>31;b=v[a+64>>2];q=b;r=b>>31;b=v[a+60>>2];s=b;t=b>>31;w=v[a+8>>2];x=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(q,r,e,e>>31);g=nb;f=Yb(f,-16777216,16776704);i=Oka(o,p,f,f>>31);e=i+e|0;f=nb+g|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=(v[h+12>>2]<<1)+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(u[e+4>>1],u[g+10>>1])+B(u[e+2>>1],u[g+8>>1])|0)+B(u[e+6>>1],u[g+12>>1])|0)+B(u[e+8>>1],u[g+14>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+2>>1])+B(u[e-6>>1],u[g>>1])|0)+B(u[e-2>>1],u[g+4>>1])|0)+B(u[e>>1],u[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;i=Oka(e,e>>31,s,t);e=y+i|0;f=nb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Rb(h+8|0,w,x);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;kb=h+16|0}function oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=kb-16|0;kb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+32>>2];p=v[a+28>>2];q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];t=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(t,w,e,e>>31);k=nb;C=e;e=(v[h+12>>2]<<1)+n|0;g=v[h+8>>2]>>>21&2040;l=(((B(u[e>>1],u[g+39714>>1])+B(u[e-2>>1],u[g+39712>>1])|0)+B(u[e+2>>1],u[g+39716>>1])|0)+B(u[e+4>>1],u[g+39718>>1])|0)/16384<<8;e=l;m=Oka(e,e>>31,x,y);g=C+m|0;e=nb+k|0;e=g>>>0<m>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);k=Oka(r,s,f,f>>31);g=k+g|0;f=nb+e|0;f=g>>>0<k>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;j=j+p|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+o|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Rb(h+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;kb=h+16|0}function Oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;h=kb-16|0;kb=h;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+72>>2];b=v[a+68>>2];o=b;p=b>>31;b=v[a+64>>2];q=b;r=b>>31;b=v[a+60>>2];s=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(q,r,e,e>>31);g=nb;f=Yb(f,-16777216,16776704);i=Oka(o,p,f,f>>31);e=i+e|0;f=nb+g|0;f=e>>>0<i>>>0?f+1|0:f;z=e;e=v[h+12>>2]+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(t[e+2|0],u[g+10>>1])+B(t[e+1|0],u[g+8>>1])|0)+B(t[e+3|0],u[g+12>>1])|0)+B(t[e+4|0],u[g+14>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+2>>1])+B(t[e-3|0],u[g>>1])|0)+B(t[e-1|0],u[g+4>>1])|0)+B(t[e|0],u[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;i=Oka(e,e>>31,s,w);e=z+i|0;f=nb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Rb(h+8|0,x,y);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;kb=h+16|0}function Sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=kb-16|0;kb=f;u[f+12>>1]=c;u[f+14>>1]=b;u[f+10>>1]=d;h=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(h>>>0<=b>>>0){break a}if(!c|tj(a)>>>0>=h>>>0){break a}Ff(f+12|0,h-b&65535);p=f,q=El(v[a>>2],v[a+4>>2]),u[p+8>>1]=q;g=x[f+12>>1];DS(a,g+x[le(f+14|0,f+8|0)>>1]|0);c=v[a>>2];e=a;if(Rc(c,v[a+4>>2])>>>0<b>>>0){vg(e,b);c=v[e>>2]}a=Fb(c);c=kb-16|0;kb=c;v[c+8>>2]=a;a=v[mP(c+8|0,b)>>2];kb=c+16|0;a=v[fc(f,a)>>2];i=f+10|0;l=kb-32|0;kb=l;b=a;a=v[e>>2];d=(zo(b,Fb(a))<<1)+a|0;a=g;b:{if(!a){break b}b=v[Gb(e)>>2];g=v[e+4>>2];if(a>>>0<=b-g>>1>>>0){b=a;c=g-d>>1;if(c>>>0<a>>>0){Ho(e,a-c|0,i);b=c;if((d|0)==(g|0)){break b}}m=kb-16|0;kb=m;c=g;o=v[e+4>>2];g=(o-((a<<1)+d|0)|0)+d|0;n=$h(m,e,c-g>>1);j=v[n+4>>2];k=g;while(1){if(c>>>0<=k>>>0){lc(n);Bq(d,g,o);kb=m+16|0}else{Ni(j,x[k>>1]);j=j+2|0;v[n+4>>2]=j;k=k+2|0;continue}break}au(d,b,((d>>>0<=i>>>0?y[e+4>>2]>i>>>0?a:0:0)<<1)+i|0);break b}b=Gb(e);b=Nj(l+8|0,Oj(e,Rc(v[e>>2],g)+a|0),d-v[e>>2]>>1,b);KC(b,a,i);d=kP(e,b,d);Oi(b)}Fb(d);kb=l+32|0;if(Rc(v[e>>2],v[e+4>>2])>>>0<=h>>>0){break a}vg(e,h)}kb=f+16|0}function gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;nd(b,32);uo(b);f=b,g=qe((w[a+50|0]|w[a+51|0]<<8)<<16>>16)>>>2|0,u[f+32>>1]=g;if((qe((w[a+32|0]|w[a+33|0]<<8)<<16>>16)|0)>0){u[b+34>>1]=x[b+34>>1]|32;c=qe((w[a+32|0]|w[a+33|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;f=b,g=Ec(Rka(d,d>>>0<2047?c+1|0:c,4095,0),nb),u[f+28>>1]=g}c=cc(w[a+38|0]|w[a+39|0]<<8|(w[a+40|0]<<16|w[a+41|0]<<24));v[b>>2]=c;d=cc(w[a+42|0]|w[a+43|0]<<8|(w[a+44|0]<<16|w[a+45|0]<<24));v[b+4>>2]=d;e=cc(w[a+42|0]|w[a+43|0]<<8|(w[a+44|0]<<16|w[a+45|0]<<24))+cc(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))|0;v[b+8>>2]=e;if((Ib(w[a+34|0]|w[a+35|0]<<8)|0)==16){v[b+8>>2]=e>>>1;v[b+4>>2]=d>>>1;v[b>>2]=c>>>1}a:{b:{if(cc(w[a+42|0]|w[a+43|0]<<8|(w[a+44|0]<<16|w[a+45|0]<<24))){c=x[b+34>>1];break b}c=x[b+34>>1];if(cc(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))>>>0>=3){break b}c=c&-3;break a}c=c|2}u[b+34>>1]=c;f=b,g=c&65531|Ib(w[a+30|0]|w[a+31|0]<<8)<<1&4,u[f+34>>1]=g;f=b,g=Ib(w[a+36|0]|w[a+37|0]<<8)<<1,v[f+24>>2]=g;c=qe((w[a+52|0]|w[a+53|0]<<8)<<16>>16);if(c){Bl(b,+(c|0)/96);c=qe((w[a+52|0]|w[a+53|0]<<8)<<16>>16)}t[b+37|0]=c<<4}function h9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=kb-16|0;kb=h;if(!w[a+4242|0]){Nx(a);a:{if(!w[a+4240|0]){break a}e=FM(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;Ss(a)}f=a+4256|0;b:{if(w[a+4244|0]){if(A[f>>3]>1){v[f>>2]=0;v[f+4>>2]=1072693248}break b}i=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Mx(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=Di(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=A[a+4280>>3]*e+A[a+4272>>3]*(1-e)}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];fO(h+8|0,1);g=lj(a);f:{if(!g){break f}f=v[a+4236>>2];if(w[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|tk(A[h+8>>3]*127)<<16,j=v[v[g>>2]+68>>2],ob[j](k|0,l|0)|0;break f}ob[v[v[g>>2]+44>>2]](g,f,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4264>>3]*+(d>>>0)+A[a+4256>>3]}g=a;a=v[a+44>>2];si(g,b,c,Kc(a,0),Kc(a,1),d);kb=h+16|0}function SS(a,b,c){var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;t[d+15|0]=c;a:{if(b>>>0>=22){t[d+14|0]=0;ee(a,0,d+14|0);break a}e=w[b+26672|0];b:{c:{switch(b-8|0){case 0:t[d+15|0]=c<<1;break b;case 4:t[d+15|0]=c+1>>>1;break b;case 5:t[d+15|0]=B(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:t[d+13|0]=c&15;t[d+12|0]=14;f=d,g=w[Xb(d+13|0,d+12|0)|0]<<4|15,t[f+15|0]=g;e=29;break b;case 1:t[d+11|0]=c&15;t[d+10|0]=14;f=d,g=w[Xb(d+11|0,d+10|0)|0]|240,t[f+15|0]=g;e=29;break b;case 3:t[d+15|0]=c&15|48;break b;case 4:t[d+15|0]=c<<4^128;e=35;break b;case 5:t[d+15|0]=c&15|176;break b;case 6:t[d+15|0]=c&15|64;break b;case 8:e=15;t[d+15|0]=c&15;break b;case 9:t[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:t[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;t[d+15|0]=(b>>>0<15?b:15)<<4;break b}if(c>>>0<=239){t[d+15|0]=c<<2&48|15;break b}t[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;t[d+15|0]=b>>>0<15?b:15;break b}if(c>>>0>239){break b}t[d+15|0]=c>>>2&3|240}ee(a,e,d+15|0)}kb=d+16|0}function pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;g=kb-16|0;kb=g;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(r,s,e,e>>31);h=nb;f=Yb(f,-16777216,16776704);k=Oka(p,q,f,f>>31);e=k+e|0;f=nb+h|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=v[g+12>>2]+l|0;h=v[g+8>>2]>>>21&2040;h=(((B(t[e|0],u[h+39714>>1])+B(t[e-1|0],u[h+39712>>1])|0)+B(t[e+1|0],u[h+39716>>1])|0)+B(t[e+2|0],u[h+39718>>1])<<8)/16384<<8;e=h;k=Oka(e,e>>31,w,x);e=A+k|0;f=nb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;j=j+n|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+m|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Rb(g+8|0,y,z);e=f-(h&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;kb=g+16|0}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=kb-16|0;kb=e;o=v[a+16>>2];p=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){j=v[a+8>>2];k=v[a+12>>2];f=v[a>>2];g=v[a+4>>2];i=0;break a}j=v[a+8>>2];k=v[a+12>>2];m=lg(j,k,l);n=nb;b=v[a+76>>2];f=v[a>>2];g=v[a+4>>2];Qf(f,g,lf(j,k,d),nb);i=b>>>0<nb>>>0?d:0}h=a+112|0;q=v[a+24>>2];r=v[a+20>>2];v[e>>2]=f;v[e+4>>2]=g;b:while(1){if(d){b=v[e+4>>2];f=v[e>>2];v[e+8>>2]=f;v[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Rb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){g=(v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31;Sd(h,(u[(g<<1|2)+f>>1]+u[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Rd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}f=v[c>>2];b=jg(h,p);v[c>>2]=f+B(b,r);v[c+4>>2]=v[c+4>>2]+B(b,q);Rb(e,j,k);c=c+8|0;continue b}else{g=(v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31;Sd(h,(u[(g<<1|2)+f>>1]+u[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Rd(h,4);Rb(e+8|0,m,n);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;kb=e+16|0}function R9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=kb-16|0;kb=j;c=rf(a,c);ne(j,v[a+36>>2]);a:{b:{if(!c){Sc(j,a+32|0,5);d=-1;if(!Cb(v[v[j>>2]>>2],v[j+4>>2])){break b}break a}d=v[c+16>>2]}e=v[a+36>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=kb-16|0;kb=d;v[d+8>>2]=0;Ep(e,d+8|0);z[b>>2]=z[d+8>>2];kb=d+16|0;break c}f=kb-16|0;kb=f;v[f+12>>2]=d;v[f+8>>2]=4;h=v[Kb(f+12|0,f+8|0)>>2];k=kb-16|0;kb=k;dG(k+8|0,e);d=v[k+12>>2];if(Ar(-1,2147483647,h,0)^1){i=Ar(h,0,0,-2147483648)^1}else{i=0}if(i){d:{e=kb-48|0;kb=e;i=d+v[v[d>>2]-12>>2]|0;g=v[i+16>>2]&-3;Tl(i,g);e:{f:{if(Qd(w[gm(e+40|0,d,1)|0])){i=v[(d+v[v[d>>2]-12>>2]|0)+24>>2];v[23588]=0;Ok(107,e+24|0,i,h,0);h=v[23588];v[23588]=0;g:{if((h|0)!=1){g=jE(e+24|0,Yg(e+8|0,-1,-1))?g|4:g;break g}h=V(0)|0;O()|0;_(h|0)|0;g=g|1;em(d+v[v[d>>2]-12>>2]|0,g);if(v[(d+v[v[d>>2]-12>>2]|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break f}T(a|0);L()}$()}Li(d+v[v[d>>2]-12>>2]|0,g)}kb=e+48|0;break d}V(0)|0;O()|0;Vb()}L()}}kb=k+16|0;v[b>>2]=0;kb=f+16|0}f=c}Ye(a,f);kb=j+16|0}function IG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=kb-16|0;kb=k;f=w[a|0];a:{if(!f){g=a;break a}g=a;b:{while(1){if(!Wk(f<<24>>24)){break b}f=w[g+1|0];g=g+1|0;if(f){continue}break}break a}c:{f=f&255;switch(f-43|0){case 0:case 2:break c;default:break a}}m=(f|0)==45?-1:0;g=g+1|0}d:{if(!((c|16)!=16|w[g|0]!=48)){n=1;if((w[g+1|0]&223)==88){g=g+2|0;l=16;break d}g=g+1|0;l=c?c:8;break d}l=c?c:10}c=0;while(1){e:{f=-48;i=t[g|0];f:{if((i-48&255)>>>0<10){break f}f=-87;if((i-97&255)>>>0<26){break f}f=-55;if((i-65&255)>>>0>25){break e}}i=f+i|0;if((i|0)>=(l|0)){break e}vf(k,l,0,0,0,j,h,0,0);f=1;g:{if(v[k+8>>2]|v[k+12>>2]){break g}o=Oka(j,h,l,0);p=nb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break g}h=p;f=i+o|0;h=f>>>0<i>>>0?h+1|0:h;j=f;n=1;f=c}g=g+1|0;c=f;continue}break}if(b){v[b>>2]=n?g:a}h:{i:{j:{if(c){v[116064]=68;a=d&1;m=a?0:m;j=d;h=e;break j}if((e|0)==(h|0)&d>>>0>j>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|m)){v[116064]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=j>>>0|e>>>0>h>>>0){break i}v[116064]=68;break h}a=m;b=a^j;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}kb=k+16|0;nb=e;return d}function u3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=kb+-64|0;kb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;If(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+8>>2];e=v[a+4>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=kb-32|0;kb=a;a:{b:{c:{d:{g=v[b+4>>2];if(g>>>0>=e>>>0){if(y[b+20>>2]<e>>>0){break d}if(d>>>0>y[b+8>>2]){break c}h=v[b+28>>2];if(d>>>0>v[b+24>>2]-h>>>0){break b}k=v[b+16>>2];l=v[b>>2];e:while(1){if((d|0)==(f|0)){break a}m=f+h|0;n=B(f,g);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{A[a+24>>3]=A[(c+n<<3)+l>>3];v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;o=m<<1;p=(c<<2)+k|0;i=xe(A[Hg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){j=~~i;break f}j=-2147483648}q=v[p>>2]+o|0,r=ed(j),u[q>>1]=r;c=c+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}kb=a+32|0;kb=b- -64|0}function ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=kb-16|0;kb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];t=u[e+2>>1];w=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)+B(u[e+4>>1],q)|0)+B(u[e+8>>1],p)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;kb=f+16|0}function l3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=kb+-64|0;kb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;If(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+8>>2];e=v[a+4>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=kb-32|0;kb=a;a:{b:{c:{d:{g=v[b+4>>2];if(g>>>0>=e>>>0){h=v[b+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>y[b+8>>2]){break c}i=v[b+28>>2];if(d>>>0>v[b+24>>2]-i>>>0){break b}l=v[b+16>>2];m=v[b>>2];e:while(1){if((d|0)==(f|0)){break a}n=B(f,g);o=B(f+i|0,h);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{A[a+24>>3]=A[(c+n<<3)+m>>3];v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;p=(c+o<<1)+l|0;j=xe(A[Hg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(j)<2147483648){k=~~j;break f}k=-2147483648}q=p,r=ed(k),u[q>>1]=r;c=c+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}kb=a+32|0;kb=b- -64|0}function S8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=kb+-64|0;kb=b;g=Tb(a);v[23588]=0;Y(909,g|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){a=44576;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==44888){kb=b- -64|0;return g|0}k:{h=at(44);if(h){d=v[a>>2];e=v[a+4>>2];v[23588]=0;e=Q(55,b+32|0,e|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break k}v[23588]=0;R(910,b+48|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break j}c=v[a+8>>2];v[23588]=0;c=Q(55,b|0,c|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break i}v[23588]=0;R(910,b+16|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break h}v[23588]=0;d=fa(911,h|0,d|0,b+48|0,b+16|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break g}bc(b+16|0);zb(c);bc(b+48|0);zb(e);v[b+60>>2]=d;v[23588]=0;R(912,g|0,b+60|0);e=v[23588];v[23588]=0;if((e|0)==1){break b}v[d+32>>2]=v[a+12>>2];v[d+36>>2]=v[a+16>>2];t[d+40|0]=w[a+20|0];t[d+41|0]=w[d+41|0]&253|w[a+21|0]<<1}a=a+24|0;continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;bc(b+16|0)}zb(c)}bc(b+48|0)}zb(e)}Nb(h);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}wc(g);T(a|0);L()}function Wja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=kb-1072|0;kb=d;v[d+1068>>2]=c;o=d,p=Me(b),t[o+8|0]=p;t[d+4|0]=1;c=d+8|0;g=w[kf(c,d+4|0)|0];f=wB(c,b);l=Eq(f);v[23588]=0;c=S(202,b|0)|0;e=v[23588];v[23588]=0;a:{if((e|0)!=1){v[d+4>>2]=c;v[d>>2]=536870911;xc(d+1068|0,v[Kb(d+4|0,d)>>2]<<3);v[23588]=0;m=v[d+1068>>2];k=Q(335,a|0,m|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;c=8;h=Q(164,f|0,8)|0;a=v[23588];v[23588]=0;b:{if((a|0)!=1){c:{o=Lb(v[k>>2],0),p=h,t[o|0]=p;i=1;a=g;while(1){c=c&255;n=c>>>0>9?c:9;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}v[23588]=0;j=Q(164,f|0,c|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Lb(v[k>>2],i),p=h,t[o|0]=p;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=Eq(f);v[23588]=0;Q(155,b|0,((a-l|0)+3&-4)+l|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}}c=P()|0;O()|0;ic(k);break a}Bb(f);kb=d+1072|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}Bb(f);T(c|0);L()}function b$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=kb-448|0;kb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=1158;b=te(a+24|0,a+32|0,a+20|0);h=a+16|0;gd(h,e);v[23588]=0;h=S(1136,h|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[23588]=0;c=qa(1166,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(ff(g)){vd(v[g>>2],0);Gd(g,0);break d}vd(g,0);de(g,0)}if(w[a+15|0]){v[23588]=0;c=Q(1154,h|0,45)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[23588]=0;R(49,g|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}}v[23588]=0;d=Q(1154,h|0,48)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}e=v[a+20>>2];h=e-4|0;c=v[b>>2];while(1){if(!((d|0)!=v[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}v[23588]=0;W(1171,g|0,c|0,e|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break c}break a}v[23588]=0;c=Q(1142,a+440|0,a+432|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+440>>2];ac(a+16|0);Xc(b);kb=a+448|0;return c|0}}}c=P()|0;O()|0;ac(a+16|0);Xc(b);T(c|0);L()}function Jn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=kb-80|0;kb=c;g=Tb(a);a=v[b+24>>2];a:{b:{if(sj(v[a+484360>>2],v[a+484364>>2])){c:{d:{e:while(1){if(sj(v[a+484360>>2],v[a+484364>>2])>>>0<=f>>>0){break d}d=wM(cS(c+40|0,1),f&255,0,0);v[23588]=0;e=v[d+12>>2];v[c+16>>2]=v[d+8>>2];v[c+20>>2]=e;e=v[d+20>>2];v[c+24>>2]=v[d+16>>2];v[c+28>>2]=e;e=v[d+4>>2];v[c+8>>2]=v[d>>2];v[c+12>>2]=e;X(1046,c- -64|0,a|0,0,c+8|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}j=c,k=Fb(v[c+64>>2]),v[j+32>>2]=k;d=Fb(v[c+68>>2]);while(1){a=v[c+32>>2];if(!Pb(a,d)){f=f+1|0;Ei(c- -64|0);a=v[b+24>>2];continue e}h=A[a>>3];e=v[a+16>>2];i=x[a+24>>1];a=c+40|0;v[a+16>>2]=f;v[a+12>>2]=i;v[a+8>>2]=e;A[a>>3]=h;v[23588]=0;R(1061,g|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){Az(c+32|0);continue}break}break}a=P()|0;O()|0;Ei(c- -64|0);break b}kb=c+80|0;return}a=P()|0;O()|0;break b}b=ba(8)|0;v[23588]=0;d=Q(55,c+40|0,7270)|0;a=v[23588];v[23588]=0;if((a|0)!=1){a=sc(b,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(d);break b}a=P()|0;O()|0;ca(b|0)}Xf(g);T(a|0)}L()}function jba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=kb-16|0;kb=i;v[i+8>>2]=b;o=xf(a);while(1){if(Ig(b,c)){b=v[fc(i,o)>>2];j=wd(v[i+8>>2]);m=kb-16|0;kb=m;n=0;k=kb-16|0;kb=k;h=kb-32|0;kb=h;f=h+28|0;d=h+24|0;e=kb-16|0;kb=e;a:{b:{if(!pc(b,v[fc(e+8|0,Zf(a))>>2])){g=w[j|0];l=w[wd(b)|0];if(!Sn(g,l)){break b}}v[e+8>>2]=b;g=fc(e,Fb(v[a>>2]));c:{d=v[e+8>>2];if(!pc(d,v[g>>2])){d=v[jz(e+8|0)>>2];l=w[wd(d)|0];g=w[j|0];if(!Sn(l,g)){break c}}if(!v[b>>2]){v[f>>2]=b;break a}v[f>>2]=d;b=d+4|0;break a}b=Jy(a,f,g);break a}if(Sn(l,g)){d:{d=hz(b);if(!pc(d,v[fc(e+8|0,Zf(a))>>2])){g=w[j|0];if(!Sn(g,w[wd(d)|0])){break d}}if(!v[b+4>>2]){v[f>>2]=b;b=b+4|0;break a}v[f>>2]=d;b=d;break a}b=Jy(a,f,g);break a}v[f>>2]=b;v[d>>2]=b;b=d}kb=e+16|0;d=b;b=v[b>>2];if(!b){b=kb-16|0;kb=b;e=jc(a);f=h+8|0;e=mh(f,tc(24),nh(b+8|0,e));mN(v[e>>2]+16|0,v[j>>2],v[j+4>>2]);p=jc(e),q=1,t[p+4|0]=q;kb=b+16|0;Kg(a,v[h+28>>2],d,v[h+8>>2]);b=ce(f);rk(f);n=1}Jg(k+8|0,v[fc(h+8|0,b)>>2],n);kb=h+32|0;kb=k+16|0;fc(m+8|0,v[k+8>>2]);kb=m+16|0;b=v[Lg(i+8|0)>>2];continue}else{kb=i+16|0}break}}function qS(a,b,c,d,e){var f=0,g=0;f=kb-16|0;kb=f;a:{if((d&255)>>>0<=4){while(1){d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!of(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!of(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){d=of(a,f+13|0);if(d){g=w[f+13|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!d){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!of(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){d=of(a,f+11|0);if(d){g=w[f+11|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!d){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}kb=f+16|0}function NV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=kb-32|0;kb=g;t[g+12|0]=0;m=Pm(g+16|0,d,g+12|0);f=v[m>>2];v[g+12>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=w[a|0];if(!(!i|(k|0)!=(e&255))){v[g+8>>2]=w[a+1|0];i=a+2|0;j=Kb(g+8|0,g+12|0);b:{k=b-2|0;if(!k){break b}j=v[j>>2];if(!(j&255)){break b}i=w[i|0];while(1){if(!(j&255)){break a}t[f|0]=i;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;j=j-1|0;continue}}t[f|0]=e;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;t[f|0]=k;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=v[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=t[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;t[c|0]=k;e=e-1|0;c=c+1|0;continue}break}ic(m);kb=g+32|0;return}n=w[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;t[l|0]=w[l|0]|B(f&n,257)>>>(h-j&7);l=b+1|0;b=d>>>0>l>>>0?l:0;j=j+1|0;h=(d>>>0<=l>>>0)+h|0;f=(f<<8|f)>>>1&255;continue}}}function maa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=kb-32|0;kb=j;e=b;b=v[a>>2];f=B(Zs(e,Fb(b)),6)+b|0;a:{if(!c){break a}b=v[Gb(a)>>2];g=v[a+4>>2];if((b-g|0)/6>>>0>=c>>>0){b=c;e=(g-f|0)/6|0;if(e>>>0<c>>>0){NA(a,c-e|0,d);b=e;if((f|0)==(g|0)){break a}}k=kb-16|0;kb=k;m=v[a+4>>2];h=B((m-(B(c,6)+f|0)|0)/6|0,6)+f|0;l=Gq(k,a,(g-h|0)/6|0);i=v[l+4>>2];e=h;while(1){if(e>>>0>=g>>>0){lc(l);if((f|0)!=(h|0)){e=h-f|0;hj(m+B((e|0)/-6|0,6)|0,f,e)}kb=k+16|0}else{iu(i,e);i=i+6|0;v[l+4>>2]=i;e=e+6|0;continue}break}e=f;a=B(e>>>0<=d>>>0?y[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[e|0]=c;t[e+1|0]=c>>>8;t[e+2|0]=c>>>16;t[e+3|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[e+4|0]=c;t[e+5|0]=c>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Gb(a);e=jT(j+8|0,IA(a,qk(v[a>>2],g)+c|0),(f-v[a>>2]|0)/6|0,b);iT(e,c,d);b=v[e+4>>2];d=e+4|0;gT(v[a>>2],f,d);h=v[a+4>>2];c=e+8|0;while(1){if((f|0)!=(h|0)){iu(v[c>>2],f);v[c>>2]=v[c>>2]+6;f=f+6|0;continue}break}qc(a,d);qc(a+4|0,c);qc(Gb(a),Cc(e));v[e>>2]=v[e+4>>2];f=b;hT(e)}Fb(f);kb=j+32|0}function jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=kb-16|0;kb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)|0)+B(t[e+2|0],q)|0)+B(t[e+4|0],p)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;kb=f+16|0}function E8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=0,x=0,y=0,A=C(0);i=v[a+44>>2];h=Kc(i,0);i=Kc(i,1);j=v[a+56>>2];n=Kc(j,0);j=Kc(j,1);k=a+4208|0;g=vc(v[k>>2],v[a+4212>>2]);o=B(v[v[a+16>>2]+1074404>>2],w[a+4233|0]);e=o<<1;if(g>>>0<e>>>0){dk(k,e)}l=w[a+4232|0];a:{if(l){e=v[a+4220>>2];k=v[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=z[i>>2];e=e>>>0<o>>>0?e:0;g=e-o|0;g=((g|0)<0?e:g)<<1;x=Eb(k,g);f=z[Eb(k,g|1)>>2];s=z[h>>2];t=z[x>>2];p=C(s+t);z[n>>2]=p;q=C(r+f);z[j>>2]=q;f=C(0);m=C(0);b:{c:{switch(u|0){case 0:f=z[a+4224>>2];m=C(q*f);f=C(p*f);break b;case 1:case 2:f=z[a+4224>>2];m=C(p*f);f=C(q*f);break b;case 3:break c;default:break b}}f=C(C(C(C(s+r)*C(.5))+t)*z[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;i=i+4|0;h=h+4|0;g=e<<1;y=Eb(k,g),A=C(D(f))<C(10000000195414814e-40)?C(0):f,z[y>>2]=A;y=Eb(k,g|1),A=C(D(m))<C(10000000195414814e-40)?C(0):m,z[y>>2]=A;e=e+1|0;v[a+4220>>2]=e;l=l+1|0;continue}}e=h;h=d<<2;qh(e,e+h|0,n);qh(i,i+h|0,j)}h=a;a=v[a+56>>2];si(h,b,c,Kc(a,0),Kc(a,1),d)}function RA(a,b,c,d){t[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:t[a+3|0]=c?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(d){break a}t[a+5|0]=B(c>>>4|0,10)+(c&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=d?32:31;return;case 29:t[a+3|0]=d?33:0;return;case 27:t[a+3|0]=d?34:0;return;case 30:t[a+3|0]=d?35:0;return;case 31:t[a+3|0]=d?36:0;return;case 50:t[a+3|0]=d?25:0;return;case 51:t[a+3|0]=d?30:0;return;default:break b}}t[a+3|0]=0}}function j8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),t=0,u=0,w=0,x=0,y=0,A=C(0);a:{j=v[a+4272>>2];if(!j){break a}if(!ai(a+44|0)){break a}f=v[a+44>>2];l=Kc(f,0);m=Kc(f,1);u=v[a+4252>>2]-1|0;i=v[a+4268>>2];k=v[a+4256>>2];n=d;f=v[a+56>>2];q=Kc(f,0);o=q;r=Kc(f,1);p=r;while(1){if(n){e=z[m>>2];f=i<<1;h=Eb(k,f);g=z[l>>2];z[h>>2]=g;y=Eb(k,f|1),A=e,z[y>>2]=A;s=z[a+4276>>2];e=C(C(D(TK(C(C(C(D(g))+C(D(e)))*C(536870912)),31,5)))*C(4.656612873077393e-10));e=C(C(C(s-e)*z[(e>=s?4236:4240)+a>>2])+e);z[a+4276>>2]=e;g=z[a+4244>>2];e=C(C(C(C(g-(e<g?g:e))*z[a+4248>>2])+C(.9999998807907104))*C(2147483648));b:{if(e<C(4294967296)&e>=C(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=z[Eb(k,t)>>2];h=f<<5;w=h;x=h|-2147483648;h=f>>>0<67108864;e=C(z[a+4232>>2]*C(C((h?w:x)>>>(h?31:32-(f>>>26|0)|0)>>>0)*C(4.656612873077393e-10)));z[o>>2]=g*e;y=p,A=C(z[Eb(k,t|1)>>2]*e),z[y>>2]=A;i=((i?0:j)+i|0)-1|0;v[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{si(a,b,c,q,r,d)}break}}}function XX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;f=Tb(a);a=0;a:{b:{c:{d:{e:{while(1){if((Uv(b,c,a)|0)==-1){break b}e=Uv(b,c,a);v[23588]=0;X(122,d|0,b|0,a|0,e-a|0);e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;R(123,d+16|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break e}v[23588]=0;R(124,f|0,d+16|0);e=v[23588];v[23588]=0;if((e|0)==1){break d}Ab(d+16|0);Ab(d);a=Uv(b,c,a)+Gk(v[c+4>>2],w[c+11|0])|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ab(d+16|0)}Ab(d);break a}f:{g:{h:{i:{j:{k:{if(pc(v[f>>2],v[f+4>>2])){v[23588]=0;X(122,d+16|0,b|0,a|0,-1);c=v[23588];v[23588]=0;if((c|0)==1){break j}c=Gk(v[d+20>>2],w[d+27|0]);Ab(d+16|0);if(!c){break k}}v[23588]=0;X(122,d|0,b|0,a|0,-1);a=v[23588];v[23588]=0;if((a|0)==1){break i}v[23588]=0;R(123,d+16|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}v[23588]=0;R(124,f|0,d+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}Ab(d+16|0);Ab(d)}kb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ab(d+16|0)}Ab(d)}Sl(f);T(a|0);L()}function Eia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=kb-48|0;kb=d;i=a+484344|0;j=a+480280|0;k=a+906300|0;while(1){a:{if(Qb(v[b>>2],v[b+8>>2],9)){e=d+44|0;oo(b,e);c=Cg(b);b:{if(!Sb(e,13951,4)){break b}if(!Sb(d+44|0,13603,4)){break b}if(!Sb(d+44|0,13779,4)){break b}if(!Sb(d+44|0,13784,4)){break b}if(Qb(v[b>>2],v[b+8>>2],c)){break a}}zg(b,8)}kb=d+48|0;return l|0}ae(d,b,c);e=kc(d+24|0,d);Bb(d);c=j;c:{d:{e:{if(!Sb(d+44|0,13469,4)){while(1){if((c|0)==(i|0)){break c}v[23588]=0;f=S(157,e|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break e}t[c+8|0]=f;c=c+32|0;continue}}if(w[d+44|0]!=70){break d}f=w[d+45|0];h=(f|0)==88;f:{if(!h){if((f-48&255)>>>0>9){break d}c=t[d+46|0];if((c|0)>47){break f}break d}c=t[d+46|0];if((c|0)<48){break d}}if(c>>>0>57){break d}g=t[d+47|0];if((g|0)<48|(g|0)>57){break d}c=(g+(h?-16:B(f,100)+48|0)|0)+B(c,10)&255;if(c>>>0>249){break c}v[23588]=0;R(439,e|0,Md(k,c)|0);c=v[23588];v[23588]=0;if((c|0)!=1){break c}}a=P()|0;O()|0;Bb(e);T(a|0);L()}if(Sb(d+44|0,13485,4)){break c}v[a+1074308>>2]=0;l=1}Bb(e);continue}}function UM(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=kb-32|0;kb=g;b=At(g);d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);c=(f<<5)+a|0;e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;t[c+4|0]=d;t[c+5|0]=d>>>8;t[c+6|0]=d>>>16;t[c+7|0]=d>>>24;d=w[b+28|0]|w[b+29|0]<<8|(w[b+30|0]<<16|w[b+31|0]<<24);e=w[b+24|0]|w[b+25|0]<<8|(w[b+26|0]<<16|w[b+27|0]<<24);t[c+24|0]=e;t[c+25|0]=e>>>8;t[c+26|0]=e>>>16;t[c+27|0]=e>>>24;t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24);e=w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24);t[c+16|0]=e;t[c+17|0]=e>>>8;t[c+18|0]=e>>>16;t[c+19|0]=e>>>24;t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);b=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c+8|0]=b;t[c+9|0]=b>>>8;t[c+10|0]=b>>>16;t[c+11|0]=b>>>24;t[c+12|0]=d;t[c+13|0]=d>>>8;t[c+14|0]=d>>>16;t[c+15|0]=d>>>24;kb=g+32|0;f=f+1|0;continue}break}}function jI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0;a:{if(w[b+21|0]){p=B(d,g);j=v[e>>2];l=v[f>>2];m=v[b>>2];b:{while(1){if((h|0)>0){if(v[a+1396>>2]<=9){al(a)}g=v[a+1392>>2];k=u[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=w[k+v[b+8>>2]|0];v[a+1392>>2]=i>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;k=(g|0)>=0?k:-1;break c}k=im(a,b)}if((k|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((k|0)<0){if(!w[a+1376|0]){b=0;if(v[a+1384>>2]){break b}}ec(a,21);return 0}g=0;n=B(d,l);m=((m+n|0)+j|0)>(p|0)?(p-n|0)+j|0:m;n=(m|0)>0?m:0;k=B(k,v[b>>2]);o=C(0);d:{if(w[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=C(o+z[v[b+28>>2]+(g+k<<2)>>2]);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=o+z[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+C(z[v[b+28>>2]+(g+k<<2)>>2]+C(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}break}v[e>>2]=j;v[f>>2]=l;b=1}return b}ec(a,21);return 0}aa(7512,13110,1887,6554);L()}function Fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0;g=kb-16|0;kb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];u=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(r,s,e,e>>31);i=nb;f=Yb(f,-16777216,16776704);h=Oka(p,q,f,f>>31);e=h+e|0;f=nb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=v[g+12>>2]+l|0;e=t[h|0];z=i;i=((B(t[h+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=Oka(e,e>>31,u,w);e=z+h|0;f=nb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;k=k+n|0;v[c>>2]=B(e,k>>12)+v[c>>2];j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Rb(g+8|0,x,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=j>>12;kb=g+16|0}function ZN(a,b){var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=Oka(c,c>>31,5e4,0);e=nb;b=v[Zc(d+12|0,d+8|0)>>2];c=Ic(Pka(c,e,b,b>>31),nb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=Oka(c,c>>31,1e4,0);e=nb;b=v[Zc(d+12|0,d+8|0)>>2];c=Ic(Pka(c,e,b,b>>31),nb);break a;case 1:break b}}f=60/(+y[b+44>>2]/1e4*(+(Oka(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(nb>>>0)*4294967296))*+y[a+24620>>2];c:{d:{c=v[a+484344>>2];e=x[b+70>>1];if(!ye(c,v[a+484348>>2],e)){break d}c=Zb(c,e);if(!Pb(v[c+24>>2],v[c+28>>2])){break d}c=c+24|0;break c}c=a+480248|0}e=v[c>>2];c=v[c+4>>2];if(!pc(e,c)){f=f*+y[Eb(e,y[b+48>>2]%(vc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(D(f)<2147483648){c=~~f;break e}c=-2147483648}f=A[b+8>>3]+(f-+(c>>>0));A[b+8>>3]=f;if(f>=1){A[b+8>>3]=f+-1;c=c+1|0;break a}if(!(A[a+1074384>>3]<=-1)){break a}A[b+8>>3]=f+1;c=c-1|0}b=Oka(v[a+480244>>2],0,c,0)+32768|0;a=nb;a=b>>>0<32768?a+1|0:a;a=Ec((a&65535)<<16|b>>>16,a>>>16|0);kb=d+16|0;return a?a:1}function Y9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=C(0);h=u[d>>1];j=u[d+2>>1];a:{if((h|0)>(j|0)){break a}k=v[b>>2];g=vc(k,v[b+4>>2]);if(!g){break a}i=u[e>>1];if((i|0)<(h|0)|(i|0)>(j|0)|(g-1&65535)>>>0>(j-i&65535)>>>0|y[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(g|0)){break b}i=Eb(k,f);f=f+1|0;if(!(z[i>>2]<C(0))){continue}break}return 0}i=(f|0)!=(g|0);f=0;if(i){break a}l=z[c>>2];if(l<=C(0)){break a}u[a+28>>1]=h;u[a>>1]=1;m=a,n=PL(g),u[m+30>>1]=n;z[a+32>>2]=D(l);dk(a+4|0,(j-h|0)+1|0);qh(Fb(v[b>>2]),Fb(v[b+4>>2]),zm(Fb(v[a+4>>2]),u[e>>1]-u[d>>1]|0));c=v[a+4>>2];g=u[a+30>>1];h=u[a+28>>1];b=u[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;j=Eb(c,b+g|0);m=Eb(c,b),o=C(z[j>>2]/z[a+32>>2]),z[m>>2]=o;b=u[e>>1];continue}else{c=u[a+30>>1];e=u[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=v[a+4>>2];d=u[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=Eb(b,f-h|0);m=Eb(b,f-e|0),o=C(z[a+32>>2]*z[g>>2]),z[m>>2]=o;f=f+1|0;continue}else{Fp(a)}break}}break}f=1}return f|0}function h$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=kb-160|0;kb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=1158;b=te(a+24|0,a+32|0,a+20|0);h=a+16|0;gd(h,e);v[23588]=0;h=S(19,h|0)|0;i=v[23588];v[23588]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[23588]=0;c=qa(1159,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}$f(g);if(w[a+15|0]){v[23588]=0;c=Q(20,h|0,45)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[23588]=0;R(47,g|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}}v[23588]=0;d=Q(20,h|0,48)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}e=v[a+20>>2];h=e-1|0;c=v[b>>2];d=d&255;while(1){if(!((d|0)!=w[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}v[23588]=0;W(1165,g|0,c|0,e|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break c}break a}v[23588]=0;c=Q(1126,a+152|0,a+144|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];ac(a+16|0);Xc(b);kb=a+160|0;return c|0}}}c=P()|0;O()|0;ac(a+16|0);Xc(b);T(c|0);L()}function Eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;g=kb-16|0;kb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(r,s,e,e>>31);i=nb;f=Yb(f,-16777216,16776704);h=Oka(p,q,f,f>>31);e=h+e|0;f=nb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(v[g+12>>2]<<1)+l|0;e=u[h>>1];z=i;i=e+((B(u[h+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=Oka(e,e>>31,t,w);e=z+h|0;f=nb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;k=k+n|0;v[c>>2]=B(e,k>>12)+v[c>>2];j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Rb(g+8|0,x,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=j>>12;kb=g+16|0}function Yy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-16|0;kb=e;f=a+1074312|0;Db(e+8|0,f,77);a:{if(j=Cb(v[v[e+8>>2]>>2],v[e+12>>2]),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{if(d){g=w[c+841|0];if(!g){break c}d=g-1|0;t[c+841|0]=d;if(d&255){break b}Db(e+8|0,f,16);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=2){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[c+764>>2]=a;break a}Db(e+8|0,f,17);d:{if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480180>>2]&3){break d}g=b+616|0;i=x[a+480188>>1];while(1){if((h&65535)>>>0>=i>>>0){break d}if(w[g+841|0]?(c|0)!=(g|0):0){break a}g=g+872|0;h=h+1|0;continue}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;e:{if((d|0)==-1){break e}f:{if(v[b+60>>2]==-1){break f}Db(e+8|0,f,68);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}v[b+60>>2]=d}v[b+64>>2]=d;Db(e+8|0,f,103);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}u[b+68>>1]=65535}if(v[a+480180>>2]!=2){break a}d=x[a+480188>>1];a=0;while(1){if((a|0)==(d|0)){break a}f=B(a,872)+b|0;v[f+1380>>2]=v[c+764>>2];t[f+1457|0]=w[c+841|0];a=a+1|0;continue}}kb=e+16|0}function eI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-208|0;kb=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;f=4;e=2;while(1){g=b;b=(b+f|0)+4|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;f=g;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){f=0;e=1;h=0;b=1;g=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){dx(a,c,b,d+16|0);os(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){ns(a,c,e,v[d+12>>2],b,0,d+16|0);break d}dx(a,c,b,d+16|0)}if((b|0)==1){ms(d+8|0,1);b=0;break c}ms(d+8|0,g);b=1}g=v[d+8>>2];e=g|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}h=g>>>0>1;f=v[d+12>>2];g=(f|0)!=0}ns(a,c,e,f,b,0,d+16|0);if(!(g?1:(b|0)!=1|h)){break a}while(1){e:{if((b|0)<=1){g=YH(e,f);os(d+8|0,g);f=v[d+12>>2];e=v[d+8>>2];b=b+g|0;break e}e=d+8|0;ms(e,2);v[d+8>>2]=v[d+8>>2]^7;os(e,1);f=a-4|0;h=d+16|0;g=b-2|0;ns(f-v[h+(g<<2)>>2]|0,c,v[d+8>>2],v[d+12>>2],b-1|0,1,h);ms(e,1);e=v[d+8>>2]|1;v[d+8>>2]=e;b=f;f=v[d+12>>2];ns(b,c,e,f,g,1,h);b=g}a=a-4|0;if((b|0)!=1|(e|0)!=1|f){continue}break}}kb=d+208|0}function j6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23588]=0;Y(977,a|0);e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[23588]=0;Y(953,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break e}e=0;v[23588]=0;Y(978,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break e}a=Ub(c,0,d);if(!w[b|0]){break b}if(wi(b,7226)|(d|0)!=8){break d}v[a+4>>2]=979;v[a>>2]=980;break c}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12196,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();return 0}if(!(wi(b,11161)|(d|0)!=64)){v[a+60>>2]=981;v[a+56>>2]=982;v[a+52>>2]=983;v[a+48>>2]=984;v[a+44>>2]=985;v[a+40>>2]=986;v[a+36>>2]=987;v[a+32>>2]=988;v[a+28>>2]=989;v[a+24>>2]=990;v[a+20>>2]=991;v[a+16>>2]=992;v[a+12>>2]=993;v[a+8>>2]=994;v[a+4>>2]=995;v[a>>2]=996;break c}if(!(wi(b,15157)|(d|0)!=24)){v[a+20>>2]=997;v[a+16>>2]=998;v[a+12>>2]=999;v[a+8>>2]=1e3;v[a+4>>2]=1001;v[a>>2]=1002;break c}if(wi(b,14958)|(d|0)!=4){break b}v[a>>2]=1003}e=1}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function dR(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb-80|0;kb=c;v[c+72>>2]=0;v[c+76>>2]=0;b=c- -64|0;v[b>>2]=0;v[b+4>>2]=0;v[c+56>>2]=0;v[c+60>>2]=0;v[c+48>>2]=0;v[c+52>>2]=0;Gz(a,Hz(a),c+48|0);b=rc(c+40|0,14144);hf(ze(a,0),v[b>>2],v[b+4>>2]);b=rc(c+32|0,14248);hf(ze(a,1),v[b>>2],v[b+4>>2]);b=rc(c+24|0,5499);hf(ze(a,3),v[b>>2],v[b+4>>2]);b=rc(c+16|0,15671);hf(ze(a,4),v[b>>2],v[b+4>>2]);b=rc(c+8|0,9225);hf(ze(a,8),v[b>>2],v[b+4>>2]);e=ze(a+288|0,0);b=kb-16|0;kb=b;d=e;e=rc(b+8|0,4935);hf(d,v[e>>2],v[e+4>>2]);kb=b+16|0;e=a+800|0;b=0;a=kb-80|0;kb=a;a:{b:{while(1){if((b|0)==128){break a}v[a+76>>2]=b<<3;c:{d:{if(b>>>0<=15){Ku(a+32|0,4087);v[23588]=0;R(287,a+16|0,a+76|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}v[23588]=0;U(288,a+48|0,a+32|0,a+16|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=a+48|0;Ge(a- -64|0,d);hf(ze(e,b),v[a+64>>2],v[a+68>>2]);zb(d);zb(a+16|0);$b(a+32|0);break d}b=P()|0;O()|0;zb(a+16|0);break b}d=rc(a+8|0,21619);hf(ze(e,b),v[d>>2],v[a+12>>2])}b=b+1|0;continue}break}b=P()|0;O()|0}$b(a+32|0);T(b|0);L()}kb=a+80|0;kb=c+80|0}function fo(a,b,c,d){var e=0;e=kb-16|0;kb=e;t[a+841|0]=0;v[a+708>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;v[a+800>>2]=0;v[a+696>>2]=0;v[a+668>>2]=0;u[a+804>>1]=0;v[a+88>>2]=v[a+88>>2]|6144;Db(e+8|0,b+1074312|0,23);if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&224;jo(a+788|0);v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;t[a+845|0]=0;t[a+838|0]=0;t[a+821|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+836>>1]=32512;t[a+819|0]=0;t[a+820|0]=0;u[a+842>>1]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|d;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0;kb=e+16|0}function Uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=kb-16|0;kb=g;o=v[a+16>>2];l=Tf(1,2);b=nb;p=b;Rb(a,l,b);f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+32>>2];r=v[a+28>>2];s=v[a+72>>2];b=v[a+68>>2];t=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){b=e;if(d){m=u[(v[g+12>>2]<<1)+o>>1]<<8;e=m;e=Oka(e,e>>31,z,A);k=nb;h=e;e=Yb(b,-16777216,16776704);n=Oka(x,y,e,e>>31);h=h+n|0;e=nb+k|0;e=h>>>0<n>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);k=Oka(t,w,f,f>>31);h=k+h|0;f=nb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;j=j+r|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+q|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Rb(g+8|0,C,D);e=f-(s&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;mg(a,l,p);kb=g+16|0}function oO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=kb-32|0;kb=f;n=lz(v[a+24>>2],w[a+32|0]);o=tj(n);a:{while(1){b:{u[b>>1]=m;d=m&65535;if(d>>>0>=o>>>0){break b}c:{if(!Hq(n,d)){break c}d=v[a>>2];h=yd(d,v[a+4>>2]);e=x[b>>1];if(h>>>0<=e>>>0){v[c>>2]=0;break a}k=Nd(d,e);vl(f+16|0,v[k>>2]);Dm(f+8|0,v[k>>2],v[k+4>>2]);i=f+24|0;d=v[f+16>>2];g=v[f+20>>2];e=ul(v[f+8>>2],v[f+12>>2],d,g);j=kb-16|0;kb=j;v[j+12>>2]=e;d:{if(g){h=32-g|0;v[j+8>>2]=h;l=h;h=v[Kb(j+8|0,j+12|0)>>2];l=-1<<g&-1>>>l-h&v[d>>2];if(l){hc(i,d,Nka(l));break d}if((e|0)==(h|0)){v[i>>2]=d;v[i+4>>2]=g;OP(i,e);break d}e=e-h|0;d=d+4|0}while(1){if(e>>>0>=32){g=v[d>>2];if(g){hc(i,d,Nka(g));break d}else{e=e-32|0;v[j+12>>2]=e;d=d+4|0;continue}}break}if(!e){hc(i,d,0);break d}g=v[d>>2]&-1>>>32-e;if(!g){hc(i,d,e);break d}hc(i,d,Nka(g))}kb=j+16|0;Dm(f,v[k>>2],v[k+4>>2]);if(!(v[f+24>>2]==v[f>>2]&v[f+28>>2]==v[f+4>>2])){break c}v[c>>2]=0;break a}m=x[b>>1]+1|0;continue}break}u[b>>1]=65535;v[c>>2]=-1}kb=f+32|0;return(m&65535)>>>0<o>>>0|0}function W8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0;c=kb-32|0;kb=c;a:{d=v[a+20>>2];b:{if(!d){break b}v[d+148>>2]=-1;h=c,i=ob[v[v[a>>2]+40>>2]](a)|0,v[h+16>>2]=i;v[c+8>>2]=1073741822;f=v[Kb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=v[a+20>>2];d=0;v[23588]=0;R(285,e+4|0,b+4|0);b=v[23588];v[23588]=0;c:{d:{if((b|0)!=1){b=v[a+20>>2];se(c+8|0,v[b+4>>2],v[b+8>>2]);v[c>>2]=0;v[c+4>>2]=0;e=v[c+12>>2];b=c+16|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=e;e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;e=kb-16|0;kb=e;v[e+8>>2]=0;kL(b,e+8|0);kb=e+16|0;b=v[v[a>>2]+184>>2];v[23588]=0;R(b|0,a|0,-1);b=v[23588];v[23588]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=v[v[a>>2]+188>>2];v[23588]=0;Y(d|0,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){break b}break d}b=v[v[a>>2]+48>>2];v[23588]=0;g=C(ab(b|0,a|0,d|0));b=v[23588];v[23588]=0;if((b|0)!=1){z[c+8>>2]=g;d=d+1|0;kL(c+16|0,c+8|0);continue}break}d=V(92948)|0;break c}d=V(92948)|0;break c}d=V(92948)|0}if((O()|0)!=(ea(92948)|0)){break a}_(d|0)|0;Lc(v[a+20>>2]+4|0);$()}kb=c+32|0;return}T(d|0);L()}function Vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=kb-16|0;kb=g;o=v[a+16>>2];l=Tf(1,2);b=nb;p=b;Rb(a,l,b);f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+32>>2];r=v[a+28>>2];s=v[a+72>>2];b=v[a+68>>2];u=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){b=e;if(d){m=t[v[g+12>>2]+o|0]<<16;e=m;e=Oka(e,e>>31,z,A);k=nb;h=e;e=Yb(b,-16777216,16776704);n=Oka(x,y,e,e>>31);h=h+n|0;e=nb+k|0;e=h>>>0<n>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);k=Oka(u,w,f,f>>31);h=k+h|0;f=nb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;j=j+r|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+q|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Rb(g+8|0,C,D);e=f-(s&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;mg(a,l,p);kb=g+16|0}function Cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=kb-32|0;kb=h;e=b;b=v[a>>2];b=(zo(e,Fb(b))<<1)+b|0;a:{b:{f=v[a+4>>2];if(f>>>0<y[Gb(a)>>2]){if((b|0)!=(f|0)){break b}d=kb-16|0;kb=d;a=$h(d,a,1);Kj(v[a+4>>2],w[c|0]|w[c+1|0]<<8);v[a+4>>2]=v[a+4>>2]+2;lc(a);kb=d+16|0;break a}d=Gb(a);d=Nj(h+8|0,Oj(a,Rc(v[a>>2],f)+1|0),b-v[a>>2]>>1,d);v[23588]=0;R(292,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){c=v[d+4>>2];f=d+4|0;eq(v[a>>2],b,f);g=v[a+4>>2];e=d+8|0;while(1){if((b|0)!=(g|0)){Kj(v[e>>2],w[b|0]|w[b+1|0]<<8);v[e>>2]=v[e>>2]+2;b=b+2|0;continue}break}qc(a,f);qc(a+4|0,e);qc(Gb(a),Cc(d));v[d>>2]=v[d+4>>2];b=c;Oi(d);break a}a=P()|0;O()|0;Oi(d);T(a|0);L()}i=kb-16|0;kb=i;j=v[a+4>>2];e=(j-(b+2|0)|0)+b|0;k=$h(i,a,f-e>>1);g=v[k+4>>2];d=e;while(1){if(d>>>0>=f>>>0){lc(k);while(1){if((b|0)!=(e|0)){e=e-2|0;j=pV(j-2|0,e);continue}break}kb=i+16|0}else{Kj(g,w[d|0]|w[d+1|0]<<8);g=g+2|0;v[k+4>>2]=g;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&y[a+4>>2]>c>>>0)<<1)+c|0;c=w[a|0];t[b+1|0]=w[a+1|0];t[b|0]=c}Fb(b);kb=h+32|0}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=kb-16|0;kb=e;p=v[a+16>>2];q=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){k=v[a+8>>2];m=v[a+12>>2];f=v[a>>2];b=v[a+4>>2];h=0;break a}b=v[a+12>>2];m=b;k=v[a+8>>2];n=lg(k,b,l);o=nb;h=v[a+76>>2];f=v[a>>2];b=v[a+4>>2];Qf(f,b,lf(k,m,d),nb);h=h>>>0<nb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[e>>2]=f;v[e+4>>2]=b;b:while(1){if(d){d=d-1|0;v[e+8>>2]=f;v[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=(b<<1)+p|0;b=l;while(1)if((b|0)<=0){Rb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Sd(g,u[f+(v[e+12>>2]<<1)>>1]/4<<16>>16);Rd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;f=jg(g,q);v[c>>2]=B(j>>12,f)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(f,i>>12);Rb(e,k,m);c=c+8|0;f=v[e>>2];b=v[e+4>>2];continue b}else{Sd(g,u[f+(v[e+12>>2]<<1)>>1]/4<<16>>16);Rd(g,4);Rb(e+8|0,n,o);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;kb=e+16|0}function gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-16|0;kb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){e=(v[f+12>>2]<<1)+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;k=k+n|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;kb=f+16|0}function yP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0;i=kb-16|0;kb=i;if(wj(v[a+656>>2])){e=w[a+797|0];g=$c(e);f=w[a+799|0];Db(i+8|0,d+1074312|0,34);d=g?e:f;a:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break a}e=d&255;if(!e|e>>>0>120){break a}d=w[Lb(v[a+656>>2]+108|0,e-1|0)|0]}l=C(C(v[a+704>>2])*b);e=v[v[a+656>>2]+44>>2];f=((d&255)+c<<16)-3997696>>16;b:{c:{c=v[a+852>>2]+u[a+772>>1]|0;if(c){h=v[e+36>>2];if(h){break c}}b=rm(e,c+f<<16>>16);break b}k=h+1|0;j=Wx(c,k);d=Pn(c,k);b=C(1);g=u[e+28>>1];c=f+j<<16>>16;d:{if((g|0)>(c|0)){break d}f=v[e+4>>2];if((c|0)>(vc(f,v[e+8>>2])+g<<16)-65536>>16){break d}if(!d){b=z[Eb(f,c-g|0)>>2];break b}e:{f:{g:{switch(x[e>>1]-1|0){case 2:h=v[e+16>>2];if(!vc(h,v[e+20>>2])){break f}b=z[Eb(h,d-1|0)>>2];break e;case 0:break g;default:break f}}j=v[e+16>>2];if(!vc(j,v[e+20>>2])){break f}b=z[Eb(j,(d+B(h,Pn(c,x[e+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=ue(C(rm(e,(c<<16)+65536>>16)/rm(e,c)),C(C(d|0)/C(k|0)))}b=C(b*z[Eb(f,c-g|0)>>2])}}m=a,n=kk(C(C(l*b)*C(16))),v[m+700>>2]=n}kb=i+16|0}function raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;nd(c,0);u[d+14>>1]=w[a+36|0]|w[a+37|0]<<8;u[d+12>>1]=32767;g=c,h=(x[Wc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,u[g+28>>1]=h;u[d+10>>1]=w[a+38|0]|w[a+39|0]<<8;u[d+8>>1]=32767;g=c,h=(x[Wc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,u[g+30>>1]=h;u[c+32>>1]=64;v[c>>2]=w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24);v[c+4>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[c+8>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[c+24>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);e=w[b+166|0];if(e>>>0<=4){t[c+38|0]=w[e+42714|0]}e=w[b+167|0]|w[b+168|0]<<8;t[c+39|0]=e;f=(w[b+171|0]|w[b+172|0]<<8)>>>4|0;t[c+41|0]=f;b=(w[b+169|0]|w[b+170|0]<<8)>>>2|0;t[c+40|0]=b;if((b|f)&255){t[c+39|0]=e^-1}b=w[a+40|0]|w[a+41|0]<<8;if(b&4){u[c+34>>1]=x[c+34>>1]|1;b=w[a+40|0]|w[a+41|0]<<8}if(b&8){u[c+34>>1]=x[c+34>>1]|2;b=w[a+40|0]|w[a+41|0]<<8}if(b&16){u[c+34>>1]=x[c+34>>1]|4;b=w[a+40|0]|w[a+41|0]<<8}if(b&32){u[c+34>>1]=x[c+34>>1]|32}kb=d+16|0}function rJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=kb+-64|0;kb=c;f=v[a>>2];a=v[f>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;If(c+48|0,c+32|0,g);a=v[f+4>>2];f=v[a+8>>2];g=v[a+4>>2];e=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=e;e=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=e;v[c+8>>2]=v[a+8>>2];e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;a:{b:{c:{d:{e=v[c+4>>2];if(g>>>0<=e>>>0){if(g>>>0>y[c+20>>2]){break d}if(f>>>0>y[c+8>>2]){break c}j=v[c+28>>2];if(f>>>0>v[c+24>>2]-j>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=h+j|0;o=B(e,h);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=Eb(v[b>>2],a);i=d;d=v[(a+o<<2)+m>>2]+(v[d>>2]>>1)|0;p=d;d=xs(k)+d&-4096;v[i>>2]=p-d;i=v[(a<<2)+l>>2]+(n<<1)|0;d=ld(d|2048,12);d=(d|0)<32767?d:32767;u[i>>1]=(d|0)>-32768?d:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}kb=c- -64|0}function jJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=kb+-64|0;kb=c;f=v[a>>2];a=v[f>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;If(c+48|0,c+32|0,g);a=v[f+4>>2];f=v[a+8>>2];g=v[a+4>>2];e=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=e;e=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=e;v[c+8>>2]=v[a+8>>2];e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;a:{b:{c:{d:{e=v[c+4>>2];if(g>>>0<=e>>>0){i=v[c+20>>2];if(g>>>0>i>>>0){break d}if(f>>>0>y[c+8>>2]){break c}j=v[c+28>>2];if(f>>>0>v[c+24>>2]-j>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=B(e,h);o=B(h+j|0,i);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=Eb(v[b>>2],a);p=d;d=v[(a+n<<2)+m>>2]+(v[d>>2]>>1)|0;q=d;d=xs(k)+d&-4096;v[p>>2]=q-d;d=ld(d|2048,12);d=(d|0)<32767?d:32767;u[(a+o<<1)+l>>1]=(d|0)>-32768?d:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}kb=c- -64|0}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-16|0;kb=e;d=Hh(b,c);n=e,o=Ib(w[a|0]|w[a+1|0]<<8),u[n+14>>1]=o;u[e+12>>1]=64;Rg(d,x[Wc(e+14|0,e+12|0)>>1]);n=d,o=Ib(w[a+14|0]|w[a+15|0]<<8),t[n+13|0]=o;n=d,o=Ib(w[a+16|0]|w[a+17|0]<<8),t[n+14|0]=o;n=d,o=Ib(w[a+20|0]|w[a+21|0]<<8),t[n+15|0]=o;n=d,o=Ib(w[a+22|0]|w[a+23|0]<<8),t[n+16|0]=o;h=v[d>>2];j=v[d+4>>2];b=w[d+12|0]&-2|pc(h,j)^1;t[d+12|0]=b;b=Ib(w[a+12|0]|w[a+13|0]<<8)>>>3&2|b&-3;t[d+12|0]=b;n=d,o=Ib(w[a+12|0]|w[a+13|0]<<8)>>>3&4|b&251,t[n+12|0]=o;b=4096;a:{b:{switch(c-1|0){case 0:i=-128;b=127;break a;case 1:break b;default:break a}}i=-1616;b=1616}b=b-i|0;l=b;c=b>>>1&32767;b=0;while(1){if($d(h,j)>>>0<=b>>>0){kb=e+16|0}else{d=Eb(h,b);u[d>>1]=k;m=d;g=(b<<2)+a|0;f=qe((w[g+28|0]|w[g+29|0]<<8)<<16>>16)+i|0;d=f>>31;d=d<<6|f>>>26;f=c+(f<<6)|0;d=f>>>0<c>>>0?d+1|0:d;n=m,o=tg(Ic(Pka(f,d,l,0),nb)),t[n+2|0]=o;n=e,o=Ib(w[g+26|0]|w[g+27|0]<<8),u[n+10>>1]=o;u[e+8>>1]=1;b=b+1|0;k=x[le(e+10|0,e+8|0)>>1]+k|0;continue}break}}function iI(a,b,c,d,e){var f=C(0),g=0,h=C(0),i=0,j=C(0),k=C(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=z[b>>2];j=z[c>>2];k=z[d>>2];z[c>>2]=j+k;g=c-4|0;f=z[g>>2];z[g>>2]=f+z[b>>2];j=C(j-k);f=C(f-h);z[d>>2]=C(j*z[e>>2])-C(z[e+4>>2]*f);z[b>>2]=C(f*z[e>>2])+C(j*z[e+4>>2]);b=d-12|0;j=z[b>>2];g=c-8|0;f=z[g>>2];i=g;g=d-8|0;k=z[g>>2];z[i>>2]=f+k;i=c-12|0;h=z[i>>2];z[i>>2]=h+z[b>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+32>>2])-C(z[e+36>>2]*h);z[b>>2]=C(h*z[e+32>>2])+C(f*z[e+36>>2]);b=d-20|0;j=z[b>>2];g=c-16|0;f=z[g>>2];i=g;g=d-16|0;k=z[g>>2];z[i>>2]=f+k;i=c-20|0;h=z[i>>2];z[i>>2]=h+z[b>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+64>>2])-C(z[e+68>>2]*h);z[b>>2]=C(h*z[e+64>>2])+C(f*z[e+68>>2]);b=d-28|0;j=z[b>>2];g=c-24|0;f=z[g>>2];i=g;g=d-24|0;k=z[g>>2];z[i>>2]=f+k;i=c-28|0;h=z[i>>2];z[i>>2]=h+z[b>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+96>>2])-C(z[e+100>>2]*h);z[b>>2]=C(h*z[e+96>>2])+C(f*z[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}aa(15760,13110,2423,9171);L()}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;h=kb-16|0;kb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(r,s,e,e>>31);i=nb;z=e;e=(v[h+12>>2]<<1)+n|0;g=v[h+8>>2]>>>21&2040;j=(((B(u[e>>1],u[g+39714>>1])+B(u[e-2>>1],u[g+39712>>1])|0)+B(u[e+2>>1],u[g+39716>>1])|0)+B(u[e+4>>1],u[g+39718>>1])|0)/16384<<8;e=j;k=Oka(e,e>>31,t,w);g=z+k|0;e=nb+i|0;e=g>>>0<k>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);i=Oka(p,q,f,f>>31);g=i+g|0;f=nb+e|0;f=g>>>0<i>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Rb(h+8|0,x,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;kb=h+16|0}function I7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;e=kb-160|0;kb=e;d=e+24|0;f=d+56|0;c=Ns(f);v[d>>2]=77956;v[c>>2]=77976;v[d+56>>2]=78016;v[d>>2]=77996;h=f;f=d+4|0;Kn(h,f);v[d>>2]=77956;v[c>>2]=77976;c=Is(f);v[c>>2]=77440;Mb(c+32|0);v[c+44>>2]=0;v[c+48>>2]=16;c=v[v[d>>2]-12>>2];v[23588]=0;f=ga(62)|0;h=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}v[23588]=0;U(63,e+16|0,c+d|0,f|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}ac(e+16|0);c=kb-16|0;kb=c;v[c+8>>2]=17;kb=c+16|0;mm(v[v[d>>2]-12>>2]+d|0,v[c+8>>2]);i=A[b>>3];v[23588]=0;b=bb(64,d|0,+i)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(65,e|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}v[23588]=0;R(61,g|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}zb(e);zp(b);kb=e+160|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(e)}zp(d);T(a|0);L()}v[23588]=0;R(58,a|0,g|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(g);kb=g+16|0;return}a=P()|0;O()|0;zb(g);T(a|0);L()}function hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-16|0;kb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){e=v[f+12>>2]+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;k=k+n|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;kb=f+16|0}function bK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-32|0;kb=d;a:{b:{c:{d:{e:{f:{g:{f=a+36|0;e=v[f>>2];c=v[a+40>>2];h:{if(Pb(e,c)){Hc(d+24|0);break h}c=d+8|0;Jn(c,a);v[23588]=0;c=S(1012,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}v[d+24>>2]=c;Xf(d+8|0);c=v[a+40>>2];e=v[a+36>>2]}e=(h=f,i=v[d+24>>2],j=Pb(e,c),j?h:i);if((b|0)==-1){f=v[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=v[e>>2];if((Ri(f,v[e+4>>2])|0)>(b|0)){break e}}b=ba(8)|0;v[23588]=0;c=Q(55,d+8|0,10887)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}a=P()|0;O()|0;zb(c);break d}a=P()|0;O()|0;Xf(d+8|0);break c}a=P()|0;O()|0;ca(b|0);break d}v[a+8>>2]=b;b=v[a+24>>2];v[b+480208>>2]=v[b+480208>>2]&-4194305|g;Gj(b+484360|0,w[mf(f,c)+16|0]);b=mf(v[e>>2],c);c=v[b+8>>2];b=v[b+12>>2];v[23588]=0;+ya(1043,a|0,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break a}a=P()|0;O()|0}bl(d+24|0)}T(a|0)}L()}v[a+16>>2]=0;v[a+20>>2]=0;bl(d+24|0);kb=d+32|0}function Gz(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;t[a+4|0]=d;t[a+5|0]=d>>>8;t[a+6|0]=d>>>16;t[a+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[a+24|0]=e;t[a+25|0]=e>>>8;t[a+26|0]=e>>>16;t[a+27|0]=e>>>24;t[a+28|0]=d;t[a+29|0]=d>>>8;t[a+30|0]=d>>>16;t[a+31|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[a+16|0]=e;t[a+17|0]=e>>>8;t[a+18|0]=e>>>16;t[a+19|0]=e>>>24;t[a+20|0]=d;t[a+21|0]=d>>>8;t[a+22|0]=d>>>16;t[a+23|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+8|0]=e;t[a+9|0]=e>>>8;t[a+10|0]=e>>>16;t[a+11|0]=e>>>24;t[a+12|0]=d;t[a+13|0]=d>>>8;t[a+14|0]=d>>>16;t[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function Fc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=v[b>>2];e=kb-48|0;kb=e;f=v[b+4>>2];b=w[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Mb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){t[e+32|0]=0;a=xi(c,c+d|0,e+32|0);v[23588]=0;W(53,f|0,c|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((b-3&255)>>>0>1){break h}v[23588]=0;b=W(53,f|0,c|0,c+d|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break g}c=ie(b);d=zh(b);g=ie(b);a=kb-32|0;kb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=g;while(1){if(zi(a+24|0,a+16|0)){c=a+8|0;d=a+24|0;g=t[v[d>>2]];t[v[c>>2]]=g?g:32;He(d);He(c);continue}break}kb=a+32|0;v[23588]=0;c=Q(54,e+16|0,b|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break f}v[23588]=0;d=Q(55,e|0,17790)|0;a=v[23588];v[23588]=0;if((a|0)==1){break e}v[23588]=0;U(56,e+32|0,c|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}a=e+32|0;Bc(b,a);zb(a);zb(d);zb(c)}kb=e+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(d)}zb(c)}zb(f);T(a|0);L()}}function b0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-32|0;kb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=ob[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}gd(g,d);v[23588]=0;b=S(1136,g|0)|0;a=v[23588];v[23588]=0;d:{e:{f:{g:{if((a|0)!=1){ac(g);gd(g,d);v[23588]=0;a=S(1137,g|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}ac(g);v[23588]=0;R(1138,g|0,a|0);d=v[23588];v[23588]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23588]=0;R(1139,g|12,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}v[23588]=0;d=g+24|0;a=ua(1140,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Gc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;ac(g);break d}b=P()|0;O()|0;ac(g);break d}b=P()|0;O()|0;Gc(g);break d}b=P()|0;O()|0;while(1){d=Gc(d-12|0);if((g|0)!=(d|0)){continue}break}}T(b|0);L()}t[f|0]=0}kb=g+32|0;return b|0}function p0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-32|0;kb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=ob[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}gd(g,d);v[23588]=0;b=S(19,g|0)|0;a=v[23588];v[23588]=0;d:{e:{f:{g:{if((a|0)!=1){ac(g);gd(g,d);v[23588]=0;a=S(1119,g|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break g}ac(g);v[23588]=0;R(1120,g|0,a|0);d=v[23588];v[23588]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23588]=0;R(1121,g|12,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break f}v[23588]=0;d=g+24|0;a=ua(1122,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=zb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;ac(g);break d}b=P()|0;O()|0;ac(g);break d}b=P()|0;O()|0;zb(g);break d}b=P()|0;O()|0;while(1){d=zb(d-12|0);if((g|0)!=(d|0)){continue}break}}T(b|0);L()}t[f|0]=0}kb=g+32|0;return b|0}function Fka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-144|0;kb=f;v[23588]=0;l=S(271,a|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){m=c+480192|0;while(1){a:{if((j&65535)>>>0>=l>>>0){Bb(a);kb=f+144|0;return}v[23588]=0;R(290,a|0,f+8|0);e=v[23588];v[23588]=0;if((e|0)!=1){b:{e=Ib(x[f+8>>1]);if(!e|e>>>0>x[m>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Hh(e,b);g=w[f+11|0];c:{if(!g){break c}h=w[f+10|0];if(h&1){t[e+12|0]=w[e+12|0]|1}if(h&2){t[e+12|0]=w[e+12|0]|4}if(!(h&4)){break c}t[e+12|0]=w[e+12|0]|2}t[f+4|0]=g;t[f+7|0]=31;h=w[Xb(f+4|0,f+7|0)|0];v[23588]=0;h=h+1&255;R(291,e|0,h|0);g=v[23588];v[23588]=0;if((g|0)==1){break a}t[e+13|0]=w[f+13|0];t[e+14|0]=w[f+14|0];g=w[f+12|0];t[e+15|0]=g;t[e+16|0]=g;g=v[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;n=Ib(x[i+8>>1]);k=Eb(g,e);u[k>>1]=n;i=Ib(x[i+10>>1]);u[f+4>>1]=d?i+128>>>2|0:i;Ff(f+4|0,64);t[k+2|0]=w[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=P()|0;O()|0;Bb(a);T(b|0);L()}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=kb-16|0;kb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;w=v[a+8>>2];x=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(p,q,e,e>>31);h=nb;f=Yb(f,-16777216,16776704);i=Oka(n,o,f,f>>31);e=i+e|0;f=nb+h|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=v[g+12>>2]+l|0;h=v[g+8>>2]>>>21&2040;h=(((B(t[e|0],u[h+39714>>1])+B(t[e-1|0],u[h+39712>>1])|0)+B(t[e+1|0],u[h+39716>>1])|0)+B(t[e+2|0],u[h+39718>>1])<<8)/16384<<8;e=h;i=Oka(e,e>>31,r,s);e=y+i|0;f=nb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Rb(g+8|0,w,x);e=f-(h&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;kb=g+16|0}function Ty(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;h=B(c,872)+b|0;a:{if(d){Db(g+8|0,a+1074312|0,90);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){t[(B(c,872)+b|0)+1427|0]=d}t[(B(c,872)+b|0)+1428|0]=d;break a}d=w[h+1428|0]}f=v[a+480180>>2];if(!e){i=gt(f)}h=h+616|0;b:{c:{if((f|0)!=268435456){if((f|0)!=16777216){break c}f=v[(B(c,872)+b|0)+1272>>2];if(!f|!v[f+44>>2]){break c}a=d&255;if(!(a>>>0<240|e)){uN(b,c,240-a|0);break b}if(!(a>>>0<224|e)){tN(h,224-a|0);break b}sN(h,0-a|0);break b}v[(B(c,872)+b|0)+1324>>2]=65535}e=d&255;d:{if(!(e>>>0>223&i)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}Qy(a,h,f);break b}if(v[a+480180>>2]==524288){break d}Py(a,h,f);break b}if(v[a+480180>>2]!=524288){break b}}f:{if(!(t[(B(c,872)+b|0)+1467|0]&1)){break f}if(v[a+1074416>>2]==1){Db(g+8|0,a+1074312|0,6);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break f}}d=v[a+480180>>2];if(d&32832){break f}if(!(v[a+480208>>2]&2)|(d|0)!=8){break b}}gk(a,h,(B(c,872)+b|0)+1316|0,0-(e<<2)|0,0)}kb=g+16|0}function ni(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;o(+a);b=j(1)|0;e=j(0)|0;f=b>>>20&2047;a:{if(f-969>>>0>=63){if(f>>>0<=968){return a+1}b:{if(f>>>0<1033){break b}c=0;if(!e&(b|0)==-1048576){break a}if((f|0)==2047){return a+1}if((b|0)>0|(b|0)>=0){return Jr(3105036184601418e216)}if(b>>>0<3230714880){break b}return Jr(12882297539194267e-247)}b=b<<1|e>>>31;e=e<<1;f=(b|0)==-2129002496&(e|0)!=0|b>>>0>2165964800?0:f}c=A[177];g=c+a;a=a-(g-c);c=a*a;h=c*c*(a*A[182]+A[181]);c=c*(a*A[180]+A[179]);a=a*A[178];o(+g);j(1)|0;e=j(0)|0;d=e<<4&2032;a=h+(c+(a+A[d+1464>>3]));d=d+1472|0;i=v[d>>2];b=v[d+4>>2];d=i;i=0;d=d+i|0;b=(e<<13)+b|0;b=d>>>0<i>>>0?b+1|0:b;if(!f){c:{if(!(e&-2147483648)){l(0,d|0);l(1,b+-1048576|0);c=+n();a=c*a+c;a=a+a;break c}e=kb-16|0;l(0,d|0);l(1,b+1071644672|0);c=+n();g=c*a;a=g+c;if(a<1){b=e;v[b+8>>2]=0;v[b+12>>2]=1048576;A[b+8>>3]=A[b+8>>3]*22250738585072014e-324;h=a+1;a=h+(g+(c-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,b|0);c=+n();c=c*a+c}return c}function _j(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=kb-32|0;kb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;gd(b,d);c=0;v[23588]=0;j=S(19,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){ac(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(dj(i+24|0,i+16|0)){break b}c:{if((xn(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=xn(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=xn(j,t[g+2|0])}l=i,m=ob[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}b=v[j+8>>2];if(vh(b,1,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(vh(b,1,t[g|0])){continue}}break}while(1){if(!pp(i+24|0,i+16|0)){break c}b=Zk(v[i+24>>2]);if(!vh(v[j+8>>2],1,b)){break c}fm(i+24|0);continue}}if((Bw(j,Zk(v[i+24>>2]))|0)==(Bw(j,t[g|0])|0)){g=g+1|0;fm(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(dj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}kb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;ac(i+8|0);T(a|0);L()}function YA(a,b,c){var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;t[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}t[d+15|0]=239;break b}t[d+15|0]=254;break b}if(c>>>0>=16){t[d+15|0]=c|15;break b}t[d+15|0]=c|240;break b;case 1:t[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){t[d+15|0]=c>>>4|240;break b}t[d+15|0]=c|224;break b;case 8:t[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:t[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=tg(c<<1),t[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:t[d+15|0]=119;break b;case 1:t[d+15|0]=119;break b;case 2:t[d+15|0]=121;break b;case 3:break g;default:break b}}t[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}t[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=w[b+26608|0]}ee(e,a,d+15|0);kb=d+16|0}function jH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;p=a;i=kb-1040|0;kb=i;q=v[116064];a:{b:{a=i+16|0;l=x[((b>>>0>149?0:b)<<1)+91840>>1]+90016|0;c=v[v[116090]+20>>2];if(c){j=v[c+4>>2];c=v[c>>2];e=v[c>>2]+1794895138|0;h=dm(v[c+8>>2],e);f=dm(v[c+12>>2],e);d=dm(v[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}r=d>>>2|0;s=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+s<<2)|0;o=dm(v[d>>2],e);d=dm(v[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|w[c+(d+o|0)|0]){break c}d=wi(l,c+d|0);if(!d){f=c+(r+n<<2)|0;h=dm(v[f>>2],e);e=dm(v[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=w[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=yg(g);d:{if(c>>>0>=1024){uc(a,g,1023);t[a+1023|0]=0;g=68;break d}uc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21619}break a}wa();L()}if(!w[a|0]){v[i>>2]=b;a=i+16|0;Gw(a,1024,12927,i)}v[116064]=q;Nc(p,a);kb=i+1040|0}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=kb-16|0;kb=e;p=v[a+16>>2];q=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){k=v[a+8>>2];m=v[a+12>>2];f=v[a>>2];b=v[a+4>>2];h=0;break a}b=v[a+12>>2];m=b;k=v[a+8>>2];n=lg(k,b,l);o=nb;h=v[a+76>>2];f=v[a>>2];b=v[a+4>>2];Qf(f,b,lf(k,m,d),nb);h=h>>>0<nb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[e>>2]=f;v[e+4>>2]=b;b:while(1){if(d){d=d-1|0;v[e+8>>2]=f;v[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=b+p|0;b=l;while(1)if((b|0)<=0){Rb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Sd(g,t[f+v[e+12>>2]|0]<<6);Rd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;f=jg(g,q);v[c>>2]=B(j>>12,f)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(f,i>>12);Rb(e,k,m);c=c+8|0;f=v[e>>2];b=v[e+4>>2];continue b}else{Sd(g,t[f+v[e+12>>2]|0]<<6);Rd(g,4);Rb(e+8|0,n,o);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;kb=e+16|0}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;e=kb-16|0;kb=e;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){f=v[e+8>>2];o=((((v[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=u[b+14>>1];q=u[b+12>>1];r=u[b+10>>1];s=u[b+8>>1];t=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+o|0;v[(f<<2)+e>>2]=(((((B(u[b+8>>1],r)+B(u[b+4>>1],s)|0)+B(u[b+12>>1],q)|0)+B(u[b+16>>1],p)|0)/2|0)+((((B(u[b-8>>1],x)+B(u[b-12>>1],y)|0)+B(u[b-4>>1],w)|0)+B(u[b>>1],t)|0)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;v[c>>2]=v[c>>2]+B(v[e>>2],h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g>>12);Rb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;kb=e+16|0}function Hw(a,b,c,d){var e=0,f=0,g=0,h=0;g=kb-32|0;kb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(a|(b|0)!=134217728){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Lf(g+16|0,a,b,c,e,h-15233|0);Fm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(b|(a|0)!=134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}kb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function Uy(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;h=B(c,872)+b|0;a:{if(d){Db(g+8|0,a+1074312|0,90);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){t[(B(c,872)+b|0)+1428|0]=d}t[(B(c,872)+b|0)+1427|0]=d;break a}d=w[h+1427|0]}f=v[a+480180>>2];if(!e){i=gt(f)}h=h+616|0;b:{c:{if((f|0)!=268435456){if((f|0)!=16777216){break c}f=v[(B(c,872)+b|0)+1272>>2];if(!f|!v[f+44>>2]){break c}a=d&255;if(!(a>>>0<240|e)){uN(b,c,a-240|0);break b}if(!(a>>>0<224|e)){tN(h,a-224|0);break b}sN(h,a);break b}v[(B(c,872)+b|0)+1324>>2]=1}e=d&255;d:{if(!(e>>>0>223&i)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}Ry(a,h,f);break b}if(v[a+480180>>2]==524288){break d}Sy(a,h,f);break b}if(v[a+480180>>2]!=524288){break b}}f:{if(!(t[(B(c,872)+b|0)+1467|0]&1)){break f}if(v[a+1074416>>2]==1){Db(g+8|0,a+1074312|0,6);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break f}}d=v[a+480180>>2];if(d&32832){break f}if(!(v[a+480208>>2]&2)|(d|0)!=8){break b}}gk(a,h,(B(c,872)+b|0)+1316|0,e<<2,0)}kb=g+16|0}function Nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;nd(b,32);g=b,h=cc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24)),v[g>>2]=h;f=cc(w[a+10|0]|w[a+11|0]<<8|(w[a+12|0]<<16|w[a+13|0]<<24));v[b+4>>2]=f;g=b,h=cc(w[a+14|0]|w[a+15|0]<<8|(w[a+16|0]<<16|w[a+17|0]<<24))+f|0,v[g+8>>2]=h;if(!(d?0:c)){c=cc(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))}v[b+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Ib(w[a+42|0]|w[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}Bl(b,+(c|0)*.0006510416666666666);t[e+15|0]=w[a+9|0];t[e+14|0]=64;g=b,h=w[Xb(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}kb=e+16|0}function Zj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=kb-32|0;kb=i;v[i+16>>2]=c;v[i+24>>2]=b;c=i+8|0;gd(c,d);b=0;v[23588]=0;j=S(1136,c|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){ac(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if($j(i+24|0,i+16|0)){break b}c:{if((vn(j,v[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}d:{e:{c=vn(j,v[b>>2]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=vn(j,v[g+8>>2])}l=i,m=ob[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,c,k)|0,v[l+24>>2]=m;g=b+8|0;break c}if(Xk(j,1,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(Xk(j,1,v[g>>2])){continue}}break}while(1){if(!ds(i+24|0,i+16|0)){break c}if(!Xk(j,1,Yk(v[i+24>>2]))){break c}Cn(i+24|0);continue}}if((Kl(j,Yk(v[i+24>>2]))|0)==(Kl(j,v[g>>2])|0)){g=g+4|0;Cn(i+24|0);break c}v[e>>2]=4}b=v[e>>2];continue}break}v[e>>2]=4}if($j(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}kb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;ac(i+8|0);T(a|0);L()}function Fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fu(c,d);d=b&63;if(e>>>0>d>>>0){c=US(c,d);d=0;g=kb-16|0;kb=g;t[a+12|0]=0;Lc(a);e=kb-32|0;kb=e;a:{b:{if(Vh(a)>>>0<=14){if(th(1073741823)>>>0<=14){break b}f=Gb(a);f=Vf(e+8|0,15,vc(v[a>>2],v[a+4>>2]),f);Ed(a,f);Uf(f)}kb=e+32|0;break a}cd();L()}h=0-w[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=w[e+1|0];if(!f){break c}t[g+7|0]=64;h=f+(h<<16>>16)|0;f=Al(g+8|0,h&65535,w[Xb(e+2|0,g+7|0)|0]);d:{if(y[a+4>>2]<y[Gb(a)>>2]){PS(a,f);break d}i=kb-32|0;kb=i;e=Gb(a);e=Vf(i+8|0,qg(a,vc(v[a>>2],v[a+4>>2])+1|0),vc(v[a>>2],v[a+4>>2]),e);Im(v[e+8>>2],x[f>>1]|x[f+2>>1]<<16);v[e+8>>2]=v[e+8>>2]+4;Ed(a,e);Uf(e);kb=i+32|0}d=d+1|0;continue}break}d=w[c+32|0];t[a+14|0]=d>>>4;t[a+13|0]=d&15;c=w[c+31|0];d=c&15;t[a+15|0]=d;t[a+16|0]=d;if(c&16){t[a+12|0]=w[a+12|0]|4}if(c&32){t[a+12|0]=w[a+12|0]|2}kb=g+16|0}e:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break e}c=w[a+12|0]&-2|pc(v[a>>2],v[a+4>>2])^1;a=a+12|0}t[a|0]=c}function Yja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=kb-32|0;kb=h;e=b;b=v[a>>2];b=so(e,Fb(b))+b|0;e=EU(c,d);a:{if((e|0)<=0){break a}f=v[Gb(a)>>2];g=v[a+4>>2];if((f-g|0)>=(e|0)){v[h+8>>2]=d;j=g-b|0;if((j|0)<(e|0)){v[h+8>>2]=c;fB(h+8|0,j);f=v[h+8>>2];l=kb-16|0;kb=l;i=Pk(l,a,e-j|0);k=kb-16|0;kb=k;v[k+8>>2]=f;while(1){if(Pb(f,d)){xd(v[i+4>>2],w[f|0]);f=He(k+8|0);v[i+4>>2]=v[i+4>>2]+1;f=v[f>>2];continue}break}kb=k+16|0;lc(i);kb=l+16|0;if((j|0)<=0){break a}}f=kb-16|0;kb=f;j=v[a+4>>2];d=(j-(b+e|0)|0)+b|0;i=Pk(f,a,g-d|0);e=v[i+4>>2];a=d;while(1){if(a>>>0>=g>>>0){lc(i);Bq(b,d,j);kb=f+16|0}else{xd(e,w[a|0]);e=e+1|0;v[i+4>>2]=e;a=a+1|0;continue}break}qh(c,v[h+8>>2],b);break a}f=Gb(a);g=Zl(h+8|0,Xl(a,fd(v[a>>2],g)+e|0),b-v[a>>2]|0,f);e=kb-32|0;kb=e;v[e+24>>2]=c;c=Xv(e+8|0,g+8|0,EU(c,d));d=v[c>>2];while(1){if(v[c+4>>2]!=(d|0)){xd(d,w[v[e+24>>2]]);d=v[c>>2]+1|0;v[c>>2]=d;He(e+24|0);continue}break}Ud(c);kb=e+32|0;b=DU(a,g,b);Yl(g)}Fb(b);kb=h+32|0}function sp(a,b,c,d,e,f){var g=C(0),h=0,i=C(0),j=0,k=C(0),l=C(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=z[f>>2];k=z[c>>2];l=z[d>>2];z[c>>2]=k+l;h=c-4|0;g=z[h>>2];z[h>>2]=g+z[f>>2];k=C(k-l);g=C(g-i);z[d>>2]=C(k*z[e>>2])-C(z[e+4>>2]*g);z[f>>2]=C(g*z[e>>2])+C(k*z[e+4>>2]);f=d-12|0;k=z[f>>2];h=c-8|0;g=z[h>>2];j=h;h=d-8|0;l=z[h>>2];z[j>>2]=g+l;j=c-12|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=b+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=d-20|0;k=z[f>>2];h=c-16|0;g=z[h>>2];j=h;h=d-16|0;l=z[h>>2];z[j>>2]=g+l;j=c-20|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=b+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=d-28|0;k=z[f>>2];h=c-24|0;g=z[h>>2];j=h;h=d-24|0;l=z[h>>2];z[j>>2]=g+l;j=c-28|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=b+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function r3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=kb+-64|0;kb=c;f=v[a>>2];a=v[f>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;If(c+48|0,c+32|0,g);a=v[f+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a:{b:{c:{d:{d=v[c+4>>2];if(g>>>0<=d>>>0){if(g>>>0>y[c+20>>2]){break d}if(f>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(f>>>0>v[c+24>>2]-h>>>0){break b}i=b+12|0;j=v[c+16>>2];k=v[c>>2];b=0;e:while(1){if((b|0)==(f|0)){break a}l=b+h|0;m=B(b,d);a=0;while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{e=v[(a+m<<2)+k>>2];n=ws(i);o=v[(a<<2)+j>>2]+(l<<1)|0;e=ld((ld(n,21)+e|0)+2048|0,12);e=(e|0)<32767?e:32767;u[o>>1]=(e|0)>-32768?e:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}kb=c- -64|0}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=kb-2608|0;kb=f;d=wB(f,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[23588]=0;Y(318,d|0);a=v[23588];v[23588]=0;a:{b:{if((a|0)!=1){if((u[d+1068>>1]|u[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}v[23588]=0;j=Q(164,d|0,1)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=0;d:{while(1){v[23588]=0;k=Q(164,d|0,1)|0;e=v[23588];v[23588]=0;if((e|0)==1){break d}a=u[(d+B(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+B(a,6)|0;h=w[e+1072|0];if(u[e+1068>>1]<0){break e}if(u[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;t[b+g|0]=i;g=g+1|0;continue}break}a=V(30480)|0;break b}a=V(30480)|0;break b}a=V(30480)|0}if((O()|0)==(ea(30480)|0)){_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0}Bb(d);T(a|0);L()}a=Eq(d);Bb(d);kb=f+2608|0;return a|0}function HX(a){a=a|0;var b=0,c=0,d=0,e=0;b=kb+-64|0;kb=b;e=Mb(a);v[23588]=0;a=ga(126)|0;c=v[23588];v[23588]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}v[23588]=0;c=Q(1,b+32|0,8923)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}v[23588]=0;a=ga(126)|0;d=v[23588];v[23588]=0;e:{f:{g:{h:{if((d|0)==1){break h}v[23588]=0;v[b+12>>2]=a;R(132,b+16|0,b+12|0);a=v[23588];v[23588]=0;if((a|0)==1){break h}v[23588]=0;U(2,b+48|0,c|0,b+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break g}d=b+48|0;a=Jb(e,d);Ab(d);Ab(b+16|0);Ab(c);v[23588]=0;c=ga(128)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}if(!c){break e}v[23588]=0;Q(133,a|0,17464)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break e}break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ab(b+16|0)}Ab(c);break a}v[23588]=0;c=ga(127)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}if(!c){break d}v[23588]=0;Q(133,a|0,16766)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}}kb=b- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ab(e);T(a|0);L()}function O1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=kb-32|0;kb=h;f=pf(h+16|0,1,0);a:{b:{while(1){j=h+8|0;d=Ac(f);m=d;n=Hb(f)+d|0;i=x[b>>1];d=0;c:{if((c|0)==10){Bx(j,m,n,i);break c}e=i;k=B(c,c);l=B(k,c);o=B(k,k);d:{while(1){e=e&65535;g=d|1;if(e>>>0<c>>>0){break d}g=d|2;if(e>>>0<k>>>0){break d}g=d|3;if(e>>>0<l>>>0){break d}if(e>>>0<o>>>0){g=d+4|0}else{d=d+4|0;e=(e>>>0)/(o>>>0)|0;continue}break}}d=g;if((d|0)>(n-m|0)){v[j+4>>2]=61;v[j>>2]=n;break c}l=d+m|0;e=l;while(1){d=i&65535;i=(d|0)/(c|0)|0;e=e-1|0;t[e|0]=w[(d-B(c,i)|0)+4898|0];if(i&65535){continue}break}v[j+4>>2]=0;v[j>>2]=l}if(!v[h+12>>2]){break b}d=dh(Hb(f));v[23588]=0;R(59,f|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break a}c=v[h+8>>2];b=Ac(f);v[23588]=0;R(60,f|0,c-b|0);b=v[23588];v[23588]=0;e:{if((b|0)!=1){v[23588]=0;R(72,a|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){break e}break a}break a}zb(f);kb=h+32|0;return}a=P()|0;O()|0;zb(f);T(a|0);L()}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;e=kb-16|0;kb=e;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){f=v[e+8>>2];o=(((v[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=u[b+14>>1];q=u[b+12>>1];r=u[b+10>>1];s=u[b+8>>1];w=u[b+6>>1];x=u[b+4>>1];y=u[b+2>>1];z=u[b>>1];f=0;while(1){if((f|0)!=2){b=f+o|0;v[(f<<2)+e>>2]=(((((B(t[b+4|0],r)+B(t[b+2|0],s)|0)+B(t[b+6|0],q)|0)+B(t[b+8|0],p)<<8)/2|0)+((((B(t[b-4|0],y)+B(t[b-6|0],z)|0)+B(t[b-2|0],x)|0)+B(t[b|0],w)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;v[c>>2]=v[c>>2]+B(v[e>>2],h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g>>12);Rb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;kb=e+16|0}function i3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=kb+-64|0;kb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;If(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a:{b:{c:{d:{d=v[c+4>>2];if(f>>>0<=d>>>0){h=v[c+20>>2];if(f>>>0>h>>>0){break d}if(e>>>0>y[c+8>>2]){break c}i=v[c+28>>2];if(e>>>0>v[c+24>>2]-i>>>0){break b}j=b+12|0;k=v[c+16>>2];l=v[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}m=B(b,d);n=B(b+i|0,h);a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=ld((v[(a+m<<2)+l>>2]+ld(ws(j),21)|0)+2048|0,12);g=(g|0)<32767?g:32767;u[(a+n<<1)+k>>1]=(g|0)>-32768?g:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}kb=c- -64|0}function MF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=kb-16|0;kb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<=0){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];kb=a+16|0;return c|0}function ay(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=kb-16|0;kb=d;f=w[a+2|0];if(!(!f|(f|0)==255)){v[d+12>>2]=f+1;v[d+8>>2]=10;Rg(b,v[td(d+12|0,d+8|0)>>2]);i=w[a+3|0];t[b+15|0]=i;t[b+16|0]=i;j=w[a+4|0];t[b+13|0]=j;l=w[a+5|0];t[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=v[b>>2];k=$d(c,v[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=w[b+12|0]&-2|t[a|0]&1;t[b+12|0]=c;if(w[a|0]&2){break d}c=c&251;break c}}else{m=Eb(c,e);h=(e<<2)+a|0;g=(w[h+6|0]|w[h+7|0]<<8)>>>4|0;u[m>>1]=g;e:{if(e){n=x[Eb(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=Eb(c,e),q=g,u[p>>1]=q}v[d+12>>2]=(((w[h+8|0]|w[h+9|0]<<8)<<16>>16)+o|0)/(f|0);v[d+8>>2]=0;v[d+4>>2]=64;p=m,q=v[Jj(d+12|0,d+8|0,d+4|0)>>2],t[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}t[b+12|0]=c;if(j>>>0<=l>>>0?w[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}t[b+12|0]=a}kb=d+16|0}function Qx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);d=kb-48|0;kb=d;a:{b=v[a+20>>2];b:{if(!b){break b}e=v[b+4>>2];b=v[b+8>>2];if(fd(e,b)>>>0<4){break b}se(d+16|0,e,b);b=fe(d+8|0);e=GU(d+24|0,v[d+16>>2],v[d+20>>2],v[b>>2],v[b+4>>2]);v[23588]=0;b=S(157,e|0)|0;f=v[23588];v[23588]=0;c:{if((f|0)!=1){if(b){break c}b=v[v[a>>2]+40>>2];v[23588]=0;f=S(b|0,a|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}b=v[a+20>>2];if(fd(v[b+4>>2],v[b+8>>2])-4>>>0<f<<2>>>0){break c}c=v[v[a>>2]+176>>2];b=0;v[23588]=0;R(c|0,a|0,-1);c=v[23588];v[23588]=0;if((c|0)==1){break a}while(1){if((b|0)==(f|0)){b=v[v[a>>2]+180>>2];v[23588]=0;Y(b|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break a}v[23588]=0;g=C(Ca(461,e|0));c=v[23588];v[23588]=0;d:{if((c|0)==1){break d}c=v[v[a>>2]+44>>2];v[23588]=0;Ba(c|0,a|0,b|0,C(qm(g)?g:C(0)));c=v[23588];v[23588]=0;if((c|0)==1){break d}b=b+1|0;continue}break}break a}break a}Bb(e)}kb=d+48|0;return}a=P()|0;O()|0;Bb(e);T(a|0);L()}function l7(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=kb-32|0;kb=d;v[23588]=0;g=Q(13,d+24|0,a|0)|0;c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=d+16|0;gd(c,v[v[a>>2]-12>>2]+a|0);v[23588]=0;c=S(68,c|0)|0;e=v[23588];v[23588]=0;e:{f:{if((e|0)!=1){ac(d+16|0);e=Sm(d+8|0,a);f=v[v[a>>2]-12>>2];v[23588]=0;f=a+f|0;h=S(14,f|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break f}e=v[e>>2];v[23588]=0;c=Va(69,c|0,e|0,f|0,h|0,+b)|0;e=v[23588];v[23588]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!$u(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[23588]=0;R(16,a+c|0,5);c=v[23588];v[23588]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;ac(d+16|0);break e}c=V(0)|0;O()|0}zk(g);break c}zk(g);break b}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[23588]=0;Y(17,a+c|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}$()}kb=d+32|0;return a|0}a=P()|0;O()|0;v[23588]=0;Z(18);d=v[23588];v[23588]=0;if((d|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function CJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;v[a+4>>2]=b;v[a>>2]=94392;e=(b>>>0)/48|0;d=((0-b|0)!=(B(e,-48)|0))+e|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){g=-1<<c}else{g=(1<<c)-1&-1>>>32-c|-1<<c}c=0;v[a+24>>2]=c;f=f?g&65536:0;v[a+28>>2]=f;g=0-c|0;h=Rka(c,f,d,0);c=65536-(f+((c|0)!=0)|0)|0;f=nb;if((c|0)==(f|0)&g>>>0>h>>>0|c>>>0>f>>>0){d=d+1|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}v[a+24>>2]=0;v[a+28>>2]=f?c&65536:0}v[a+16>>2]=d-((b>>>0)%(d>>>0)|0);b=e>>>0<63;d=63-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+48>>2]=b?c:-1;v[a+52>>2]=b?d:-1;d=64-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+40>>2]=e?c:0;v[a+44>>2]=e?d:0;c=e+1|0;e=c&31;if((c&63)>>>0>=32){d=-1<<e}else{d=(1<<e)-1&-1>>>32-e|-1<<e}v[a+32>>2]=0;v[a+36>>2]=b?d&65536:0;return a}function Pf(a,b,c){t[a+5|0]=c;a:{b:{switch(b|0){case 0:if(!c){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;t[a+5|0]=B(c>>>4|0,10)+(c&15);return;case 14:t[a+3|0]=19;return;case 15:if(c>>>0<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 37:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function Tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=kb-48|0;kb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;c=f+44|0;oo(b,c);a:{if(!LP(c)){break a}d=w[f+46|0];g=w[f+47|0];e=w[f+45|0];t[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e>>>1^-1)&3;g=g>>>0<192;u[a+2>>1]=x[(B(c,6)+(e<<1)|0)+27368>>1]<<g;i=B(B(w[(e+B(c,3)|0)+27144|0],x[((B(c,90)+B(e,30)|0)+(d>>>3&30)|0)+27152>>1]),1e3);d=d>>>1|0;d=B(((i>>>0)/x[(B(h,6)+(d&6)|0)+27344>>1]|0)+(d&1)|0,e?1:4);u[a>>1]=d;e=w[(g|c<<1)+27380|0];if(e+8>>>0>(d&65535)>>>0){break a}c=kb-32|0;kb=c;v[c+28>>2]=e+4;v[c+8>>2]=36;g=v[b>>2];h=v[b+8>>2];d=v[Kb(c+28|0,c+8|0)>>2];if(!Qb(g,h,d)){d=df(b)}h=c+8|0;fr(h,f);g=hc(c+16|0,v[c+8>>2],d);nc(c,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);fr(h,f);Ub(v[c+8>>2]+d|0,0,36-d|0);_b(b,v[c+28>>2]);kb=c+32|0;b=2;c=e>>>0>2?e:2;while(1){if((b|0)!=(c|0)){d=b+f|0;b=b+1|0;if(!w[d|0]){continue}break a}break}b=e+f|0;if(Sb(b,9526,4)){b=Sb(b,11048,4)}else{b=0}t[a+5|0]=!b}kb=f+48|0;return a|0}function sx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=kb+-64|0;kb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;If(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(d>>>0>v[c+24>>2]-g>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=B(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{l=xe(ng(A[(a+k<<3)+i>>3])*134217728);m=v[(a<<2)+h>>2]+(j<<2)|0,n=C(+(Jm(l)|0)*7.450580596923828e-9),z[m>>2]=n;a=a+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}kb=c- -64|0}function xq(a){var b=0,c=0,d=0,e=0,f=0;e=kb-16|0;kb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(x[a+480192>>1]){break a}c=Fb(v[a+484344>>2]);v[e+8>>2]=c;a=Fb(v[a+484348>>2]);while(1){if(!Pb(c,a)){d=1;break a}if(!(!Pb(v[c>>2],v[c+4>>2])|v[c+12>>2]==64)){break a}c=v[MM(e+8|0)>>2];continue}}d=16777216;break a}d=32;f=x[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(t[b+480281|0]&1){break a}c=c+1|0;if(x[b+480286>>1]==64){continue}break}break a}d=2}kb=e+16|0;return d}function rx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=kb+-64|0;kb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;If(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){g=v[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=B(b,f);l=B(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=(a+l<<2)+i|0,n=C(+(Jm(xe(ng(A[(a+k<<3)+j>>3])*134217728))|0)*7.450580596923828e-9),z[m>>2]=n;a=a+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}kb=c- -64|0}function s3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=kb+-64|0;kb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;If(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{g=v[c+4>>2];if(g>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=b+h|0;l=B(b,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=v[(a<<2)+i>>2]+(k<<1)|0;f=ld(v[(a+l<<2)+j>>2]+2048|0,12);f=(f|0)<32767?f:32767;u[m>>1]=(f|0)>-32768?f:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}kb=c- -64|0}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=kb-16|0;kb=e;n=v[a+16>>2];o=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);k=v[a+128>>2];a:{if(!k){i=v[a+8>>2];j=v[a+12>>2];g=v[a>>2];b=v[a+4>>2];h=0;break a}i=v[a+8>>2];j=v[a+12>>2];l=lg(i,j,k);m=nb;h=v[a+76>>2];g=v[a>>2];b=v[a+4>>2];Qf(g,b,lf(i,j,d),nb);h=h>>>0<nb>>>0?d:0}f=a+112|0;p=v[a+24>>2];q=v[a+20>>2];v[e>>2]=g;v[e+4>>2]=b;b:while(1){if(d){b=v[e+4>>2];v[e+8>>2]=v[e>>2];v[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(b<<1)+n|0;b=k;while(1)if((b|0)<=0){Rb(f,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Sd(f,u[(v[e+12>>2]<<1)+g>>1]/4<<16>>16);Rd(f,b);v[f>>2]=v[f>>2];v[f+4>>2]=0}g=v[c>>2];b=jg(f,o);v[c>>2]=g+B(b,q);v[c+4>>2]=v[c+4>>2]+B(b,p);Rb(e,i,j);c=c+8|0;continue b}else{Sd(f,u[(v[e+12>>2]<<1)+g>>1]/4<<16>>16);Rd(f,4);Rb(e+8|0,l,m);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;kb=e+16|0}function D9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=Qj(d,v[a+4>>2]);if(c>>>0<b>>>0){g=kb-32|0;kb=g;e=b-c|0;b=v[Gb(a)>>2];c=v[a+4>>2];a:{if(e>>>0<=b-c>>11>>>0){b=kb-16|0;kb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){lc(b);kb=b+16|0}else{xL(a);a=a+2048|0;v[b+4>>2]=a;continue}break}break a}h=Gb(a);i=g+8|0;b=a;f=Qj(v[a>>2],c)+e|0;c=kb-16|0;kb=c;v[c+12>>2]=f;d=kb-16|0;kb=d;v[d+12>>2]=2097151;v[d+8>>2]=2147483647;a=v[Kb(d+12|0,d+8|0)>>2];kb=d+16|0;b:{if(a>>>0>=f>>>0){d=Sx(b);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;break b}cd();L()}d=zL(i,a,Qj(v[b>>2],v[b+4>>2]),h);c=d;a=kb-16|0;kb=a;v[a>>2]=v[c+8>>2];f=v[c+8>>2];v[a+8>>2]=c+8;v[a+4>>2]=f+(e<<11);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){xL(c);c=v[a>>2]+2048|0;v[a>>2]=c;continue}break}Ud(a);kb=a+16|0;Ed(b,d);yL(d)}kb=g+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<11)|0)}}function Jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;g=kb-16|0;kb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;u=v[a+8>>2];w=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(p,q,e,e>>31);i=nb;f=Yb(f,-16777216,16776704);h=Oka(n,o,f,f>>31);e=h+e|0;f=nb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=v[g+12>>2]+l|0;e=t[h|0];x=i;i=((B(t[h+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=Oka(e,e>>31,r,s);e=x+h|0;f=nb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Rb(g+8|0,u,w);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;kb=g+16|0}function j3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=kb+-64|0;kb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;If(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{g=v[c+4>>2];if(g>>>0>=e>>>0){h=v[c+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}i=v[c+28>>2];if(d>>>0>v[c+24>>2]-i>>>0){break b}j=v[c+16>>2];k=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=B(b,g);m=B(b+i|0,h);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=ld(v[(a+l<<2)+k>>2]+2048|0,12);f=(f|0)<32767?f:32767;u[(a+m<<1)+j>>1]=(f|0)>-32768?f:-32768;a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}kb=c- -64|0}function Fs(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;o(+a);e=j(1)|0;c=j(0)|0;a:{b:{d=e>>>20&2047;if(d-969>>>0<63){k=d;break b}if(d>>>0<=968){return a+1}if(d>>>0<1033){break b}b=0;if(!c&(e|0)==-1048576){break a}if((d|0)==2047){return a+1}if((e|0)<0){return Jr(12882297539194267e-247)}return Jr(3105036184601418e216)}b=A[170];f=A[169]*a+b;b=f-b;b=b*A[172]+(b*A[171]+a);a=b*b;g=a*a*(b*A[176]+A[175]);a=a*(b*A[174]+A[173]);o(+f);j(1)|0;h=j(0)|0;c=h<<4&2032;b=g+(a+(A[c+1464>>3]+b));d=c+1472|0;c=h<<13;e=0;i=v[d>>2]+e|0;c=c+v[d+4>>2]|0;c=e>>>0>i>>>0?c+1|0:c;d=i;if(!k){c:{if(!(h&-2147483648)){l(0,d|0);l(1,c-1058013184|0);a=+n();a=(a*b+a)*5486124068793689e288;break c}e=kb-16|0;l(0,d|0);l(1,c+1071644672|0);g=+n();f=g*b;a=f+g;if(a<1){v[e+8>>2]=0;v[e+12>>2]=1048576;A[e+8>>3]=A[e+8>>3]*22250738585072014e-324;b=a+1;a=b+(f+(g-a)+(a+(1-b)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);a=+n();b=a*b+a}return b}function YP(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;t[e+15|0]=c;f=b&15;b=w[f+27072|0];a:{b:{switch(f|0){case 0:b=c?d>>>0<51?0:b:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;t[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}t[e+15|0]=0;b=25;break a;case 7:b=d>>>0<52?0:b;break a;case 10:c=c&240;if(!c){break a}t[e+15|0]=c;break a;case 11:t[e+15|0]=B(c&15,17);break a;case 12:t[e+15|0]=c>>>2;break a;case 13:t[e+15|0]=B(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:t[e+15|0]=c|240;b=2;break a;case 1:t[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}t[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;t[e+15|0]=c&15;break a;case 9:t[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}t[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}ee(a,b,e+15|0);kb=e+16|0}function kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;nd(b,32);uo(b);f=b,g=Ib(w[a+40|0]|w[a+41|0]<<8)>>>2|0,u[f+32>>1]=g;c=x[b+34>>1];if((qe((w[a+38|0]|w[a+39|0]<<8)<<16>>16)|0)>0){c=c|32;u[b+34>>1]=c;d=qe((w[a+38|0]|w[a+39|0]<<8)<<16>>16);e=(d<<8&-256)+2047|0;d=d>>>24|0;f=b,g=Ec(Rka(e,e>>>0<2047?d+1|0:d,4095,0),nb),u[f+28>>1]=g}f=b,g=cc(w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24)),v[f>>2]=g;f=b,g=cc(w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24)),v[f+4>>2]=g;f=b,g=cc(w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24))+cc(w[a+66|0]|w[a+67|0]<<8|(w[a+68|0]<<16|w[a+69|0]<<24))|0,v[f+8>>2]=g;c=c&-3|((Ib(w[a+44|0]|w[a+45|0]<<8)|0)!=0)<<1;u[b+34>>1]=c;f=b,g=c&65531|Ib(w[a+44|0]|w[a+45|0]<<8)<<1&4,u[f+34>>1]=g;f=b,g=cc(w[a+54|0]|w[a+55|0]<<8|(w[a+56|0]<<16|w[a+57|0]<<24))<<1,v[f+24>>2]=g;c=qe((w[a+42|0]|w[a+43|0]<<8)<<16>>16);if(c){Bl(b,+(c|0)/96);c=qe((w[a+42|0]|w[a+43|0]<<8)<<16>>16)}t[b+37|0]=c<<4}function Ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=kb-16|0;kb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;t=v[a+8>>2];w=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Oka(p,q,e,e>>31);i=nb;f=Yb(f,-16777216,16776704);h=Oka(n,o,f,f>>31);e=h+e|0;f=nb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(v[g+12>>2]<<1)+l|0;e=u[h>>1];x=i;i=e+((B(u[h+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=Oka(e,e>>31,r,s);e=x+h|0;f=nb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Rb(g+8|0,t,w);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;kb=g+16|0}function X7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0),u=C(0),x=C(0),y=C(0),A=0,B=0,E=0,F=0,G=0,H=C(0);g=kb-16|0;kb=g;m=v[a+4240>>2];a:{if(!m){break a}if(!ai(a+44|0)){break a}n=z[a+4220>>2];e=v[a+44>>2];F=g,G=Kc(e,0),v[F+8>>2]=G;F=g,G=Kc(e,1),v[F+12>>2]=G;e=v[a+56>>2];o=Kc(e,0);v[g>>2]=o;p=Kc(e,1);v[g+4>>2]=p;y=C(C(1)-n);q=v[a+4208>>2];A=w[a+4264|0];e=d;b:while(1){if(e){k=v[a+4244>>2];B=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;v[a+4244>>2]=(f|0)==(m|0)?0:f;e=e-1|0;continue b}else{h=(A?1-l|0:f)&255;j=v[((h<<2)+a|0)+4248>>2];E=v[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=v[s>>2];v[s>>2]=i+4;j=k-j|0;t=z[Eb(q,h+((j>>31&E)+j<<1)|0)>>2];u=z[i>>2];x=C(C(t*z[a+4224>>2])+C(u*z[a+4260>>2]));F=Eb(q,f+B|0),H=C(D(x))<C(10000000195414814e-40)?C(0):x,z[F>>2]=H;h=g+r|0;i=v[h>>2];v[h>>2]=i+4;z[i>>2]=C(u*y)+C(n*t);l=l+1|0;f=f+1|0;continue}}break}si(a,b,c,o,p,d)}kb=g+16|0}function SW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=kb-32|0;kb=j;d=an(j+8|0,a);c=kb-48|0;kb=c;k=-1;a:{if(!lD(d,c+8|0)){break a}k=0;if(!qD(c+8|0)){break a}l=yg(13017);if(l){o=v[d+12>>2];b:{if(!xl(d,w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24))){break b}while(1){c:{if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))>>>0>n>>>0){if(fg(d,5)){break c}}g=m&1;break b}g=0;h=1;d:{if((w[c+12|0]|w[c+13|0]<<8)>>>0>=64){f=Oq(d);a=f&63;e:{if(!(f&64)){break e}e=6;while(1){i=Oq(d);a=(i&127)<<e|a;if(!(i&128)){break e}i=e>>>0<25;e=e+7|0;if(i){continue}break}}e=f>>>7|0;f=e?-2147483648:a;if(((e?(a|0)>=0?0-a|0:f:f)|0)<=0){break d}}while(1){e=Oq(d);if(e){f=g>>>0>=l>>>0;a=f&h;if(!((h^1)&1|f)){a=(Qp(e<<24>>24)&255)==w[g+13017|0]}h=a;g=g+1|0;continue}break}id(d,4);m=(g|0)==(l|0)?h&1?1:m:m}n=n+1|0;continue}}xl(d,o)}if(!g){break a}k=Be(d,b,pD(c+8|0),0)}kb=c+48|0;kb=j+32|0;return k|0}function yw(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=kb-16|0;kb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Hb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Hb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=xi(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+82976|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=g&95;if((a|0)!=w[c|0]){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Hb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}kb=m+16|0;return a}function Yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=kb-16|0;kb=g;m=v[a+16>>2];j=Tf(1,2);b=nb;n=b;Rb(a,j,b);f=v[a+48>>2];o=v[a+24>>2];p=v[a+20>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];t=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){k=u[(v[g+12>>2]<<1)+m>>1]<<8;e=k;e=Oka(e,e>>31,x,y);i=nb;h=e;e=Yb(b,-16777216,16776704);l=Oka(t,w,e,e>>31);h=h+l|0;e=nb+i|0;e=h>>>0<l>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);i=Oka(r,s,f,f>>31);h=i+h|0;f=nb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,p)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,o);Rb(g+8|0,z,A);e=f-(q&k)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;mg(a,j,n);kb=g+16|0}function L6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-80|0;kb=e;v[e+72>>2]=c;a=eg(a,e+72|0);c=Hc(a+4|0);h=Hc(a+24|0);i=Hc(a+32|0);j=Tb(a+36|0);v[a+56>>2]=3;k=Tb(a+68|0);v[23588]=0;R(947,a|0,d|0);f=v[23588];v[23588]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];g=v[b+4>>2];l=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=l;v[e+32>>2]=f;v[e+36>>2]=g;b=fe(e+24|0);f=v[b+4>>2];b=v[b>>2];g=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=g;v[23588]=0;g=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=g;X(936,e+48|0,e+8|0,b|0,f|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}v[23588]=0;U(948,a|0,e+48|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}Bb(e+48|0);v[23588]=0;Y(949,a|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}Ee(e+72|0);kb=e+80|0;return a|0}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;Bb(e+48|0);break a}d=P()|0;O()|0}Xe(k);Xf(j);Bs(i);kj(h);jj(c);Ee(a);Ee(e+72|0);T(d|0);L()}function Xha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=kb-32|0;kb=e;b=kb-32|0;kb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;c=tc(64);v[23588]=0;d=S(835,c|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{if((f|0)!=1){c=Mf(b+8|0,d);d=v[c>>2];v[23588]=0;R(836,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=v[c>>2];v[23588]=0;a=W(837,a|0,b+22|0,b+16|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}d:{if(!a){Hc(b+24|0);break d}a=v[c>>2];v[23588]=0;R(838,a|0,15);a=v[23588];v[23588]=0;if((a|0)==1){break c}eg(b+24|0,c)}sg(c);kb=b+32|0;b=v[b+24>>2];break a}a=P()|0;O()|0;Nb(c);break b}a=P()|0;O()|0;sg(c)}T(a|0);L()}v[e+24>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}v[23588]=0;c=Q(1,e+8|0,(a<<2)+32176|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;U(486,b|0,a|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}Ab(c);a=a+1|0;continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ab(c)}sg(e+24|0);T(a|0);L()}kb=e+32|0;return b|0}function Fp(a){a=a|0;var b=0,c=0,d=C(0),e=C(0),f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=C(0);b=v[a+36>>2];if(!b){Lc(a+16|0);return}a:{b:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Lc(c);return}dk(c,b);b=u[a+28>>1];d=C(rm(a,(b<<16)+65536>>16)/rm(a,b));c=v[a+36>>2]+1|0;d=ue(d,C(C(1)/C(c>>>0)));a=v[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}e=ue(d,C(b>>>0));n=Eb(a,b-1|0),o=e,z[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;f=x[a+30>>1];if(f>>>0>1e3/(b>>>0)>>>0){Lc(c);return}dk(c,B(b,f));h=x[a+30>>1];j=Pn(u[a+28>>1],h);i=v[a+36>>2];d=C(C(1)/C(i+1>>>0));c=0;c:while(1){if((c&65535)>>>0>=f>>>0){break a}b=Pn(c+j<<16>>16,h)<<16;e=rm(a,b+65536>>16);b=b>>16;e=ue(C(e/rm(a,b)),d);k=B(b,v[a+36>>2]);l=v[a+16>>2];b=1;while(1){g=b&65535;if(i>>>0<g>>>0){c=c+1|0;continue c}else{m=ue(e,C(g>>>0));n=Eb(l,(g+k|0)-1|0),o=m,z[n>>2]=o;b=b+1|0;continue}}};case 0:Lc(a+16|0);return;default:break b}}Lc(a+16|0);v[a+36>>2]=0}}function Zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=kb-16|0;kb=g;m=v[a+16>>2];j=Tf(1,2);b=nb;n=b;Rb(a,j,b);f=v[a+48>>2];o=v[a+24>>2];p=v[a+20>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];u=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){k=t[v[g+12>>2]+m|0]<<16;e=k;e=Oka(e,e>>31,x,y);i=nb;h=e;e=Yb(b,-16777216,16776704);l=Oka(u,w,e,e>>31);h=h+l|0;e=nb+i|0;e=h>>>0<l>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);i=Oka(r,s,f,f>>31);h=i+h|0;f=nb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Yc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,p)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,o);Rb(g+8|0,z,A);e=f-(q&k)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;mg(a,j,n);kb=g+16|0}function kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=(v[f+12>>2]<<1)+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;kb=f+16|0}function Xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-16|0;kb=e;u[e+12>>1]=0;v[e+8>>2]=0;j=8;n=B(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){u[e+6>>1]=0;qS(a,e+15|0,e+12|0,j,e+6|0);g=x[e+6>>1];f=x[e+12>>1];c=j;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!of(a,e+5|0)){break c}f=w[e+5|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}u[e+12>>1]=f;break b}l=l+1|0;continue a}u[e+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+x[e+8>>1]|0;u[e+6>>1]=f;u[i>>1]=f;v[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=v[e+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}v[e+8>>2]=c}k=f;continue}}break}kb=e+16|0}function y9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=0,s=0,t=0,u=C(0),w=C(0),x=C(0),y=C(0),A=0,B=0,E=0,F=C(0);r=v[a+4220>>2];if(r){f=v[a+44>>2];k=Kc(f,0);l=Kc(f,1);g=v[a+56>>2];s=Kc(g,0);j=v[a+4208>>2];A=v[a+4228>>2];f=d;t=Kc(g,1);m=t;g=s;while(1){if(f){h=v[a+4224>>2];e=h-A|0;e=(v[a+4220>>2]&e>>31)+e<<1;B=Eb(j,e);n=z[Eb(j,e|1)>>2];u=z[a+4244>>2];o=z[B>>2];w=z[a+4252>>2];p=z[l>>2];x=z[a+4248>>2];q=z[k>>2];y=z[a+4256>>2];i=C(C(n*u)+C(C(o*w)+C(C(p*x)+C(q*y))));e=h<<1;E=Eb(j,e),F=C(D(i))<C(10000000195414814e-40)?C(0):i,z[E>>2]=F;i=C(C(o*u)+C(C(n*w)+C(C(q*x)+C(p*y))));E=Eb(j,e|1),F=C(D(i))<C(10000000195414814e-40)?C(0):i,z[E>>2]=F;h=h+1|0;v[a+4224>>2]=(h|0)==(r|0)?0:h;z[g>>2]=C(q*z[a+4240>>2])+C(o*z[a+4236>>2]);z[m>>2]=C(p*z[a+4240>>2])+C(n*z[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{si(a,b,c,s,t,d)}break}}}function YG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-32|0;kb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Pe(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=su(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(mH(v[a+36>>2],d,i,f,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=su(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((_r(zf(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break a}}d=zf(t[c+23|0]);v[a+48>>2]=d;break a}d=zf(t[c+23|0]);break a}d=-1}kb=c+32|0;return d}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=kb-16|0;kb=e;n=v[a+16>>2];o=kg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);k=v[a+128>>2];a:{if(!k){i=v[a+8>>2];j=v[a+12>>2];g=v[a>>2];b=v[a+4>>2];h=0;break a}i=v[a+8>>2];j=v[a+12>>2];l=lg(i,j,k);m=nb;h=v[a+76>>2];g=v[a>>2];b=v[a+4>>2];Qf(g,b,lf(i,j,d),nb);h=h>>>0<nb>>>0?d:0}f=a+112|0;p=v[a+24>>2];q=v[a+20>>2];v[e>>2]=g;v[e+4>>2]=b;b:while(1){if(d){b=v[e+4>>2];v[e+8>>2]=v[e>>2];v[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=b+n|0;b=k;while(1)if((b|0)<=0){Rb(f,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Sd(f,t[v[e+12>>2]+g|0]<<6);Rd(f,b);v[f>>2]=v[f>>2];v[f+4>>2]=0}g=v[c>>2];b=jg(f,o);v[c>>2]=g+B(b,q);v[c+4>>2]=v[c+4>>2]+B(b,p);Rb(e,i,j);c=c+8|0;continue b}else{Sd(f,t[v[e+12>>2]+g|0]<<6);Rd(f,4);Rb(e+8|0,l,m);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;kb=e+16|0}function Wu(a){var b=0,c=0,d=0,e=0;c=kb-16|0;kb=c;a:{if(w[a+3|0]!=19){break a}t[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=w[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}t[a+3|0]=0;break a}t[a+3|0]=2;t[a+5|0]=b|240;break a}t[a+3|0]=3;t[a+5|0]=b|240;break a}t[a+5|0]=b&15|16;break a}t[a+5|0]=b&3|48;break a}t[a+5|0]=b&15|32;break a}t[a+5|0]=b&15|176;break a}t[a+5|0]=b&3|64;break a}t[a+3|0]=15;t[a+5|0]=b&15;break a}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;break a}t[a+3|0]=0;break a}b=b&15;if(b){t[a+3|0]=11;v[c+12>>2]=b;v[c+8>>2]=14;d=a,e=w[td(c+12|0,c+8|0)|0]|240,t[d+5|0]=e;break a}t[a+3|0]=0;break a}if((b|0)!=192){break a}t[a|0]=254;t[a+3|0]=0;break a}if((b|0)!=208){break a}t[a+3|0]=0}kb=c+16|0}function HF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=t[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((w[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function _G(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-32|0;kb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Pe(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=su(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(mH(v[a+36>>2],d,i,f,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=su(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((_r(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break a}}d=v[c+20>>2];v[a+48>>2]=d;break a}d=v[c+20>>2];break a}d=-1}kb=c+32|0;return d}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=v[f+12>>2]+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;kb=f+16|0}function us(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=kb+-64|0;kb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;If(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){g=v[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=B(b,f);l=B(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[(a+l<<2)+i>>2]=C(v[(a+k<<2)+j>>2])*C(7.450580596923828e-9);a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}kb=c- -64|0}function tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=kb-144|0;kb=g;Do(a);a:{b:{if(!fg(a,64)){break b}c:{d:{if(!xl(a,60)){break d}if(!$Q(a,14094)){break d}c=15;d=450;break c}Do(a);if(!fg(a,128)){break b}b=0;if(!xl(a,124)){break a}if(!$Q(a,15357)){break a}c=31;d=930}Do(a);b=0;e:{while(1){if((b&65535)>>>0>=c>>>0){break e}b=b+1|0;if(ZQ(a)>>>0<=131072){continue}break}b=0;break a}id(a,4);if(!fg(a,2)){break b}b=0;e=kb-16|0;kb=e;c=kb-16|0;kb=c;Xm(c+8|0,e+8|0);f=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);h=v[c+4>>2];if((f|0)==(h|0)){id(a,v[c+12>>2])}kb=c+16|0;if((f|0)==(h|0)){i=Ib(x[e+8>>1])}kb=e+16|0;if(i>>>0<178){break a}b=-1;if(!fg(a,d)){break a}id(a,d);d=kb-16|0;kb=d;e=g+8|0;_R(d+8|0,e);c=v[d+12>>2];md(d,a,v[d+8>>2],v[d+12>>2]);f=v[d+4>>2];if((f|0)==(c|0)){id(a,v[d+12>>2])}kb=d+16|0;a=(c|0)==(f|0);if(!a){eA(e)}if(!a){break a}b=_Q(w[g+8|0]);break a}b=-1}kb=g+144|0;return b|0}function KF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=t[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];b=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=w[a+3|0];h=w[a+2|0];b=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function Qu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=kb-560|0;kb=f;u[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=v[e>>2];b:{if(b){c=wP(f,c);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);e=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=e;t[b+8|0]=e>>>8;t[b+9|0]=e>>>16;t[b+10|0]=e>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;sy(b+48|0,c+48|0);sy(b+68|0,c+68|0);sy(b+88|0,c+88|0);uc(b+108|0,c+108|0,448);d=b;du(c);break b}b=at(556);if(!b){v[e>>2]=0;break a}d=wP(b,c);v[e>>2]=d}g=a,h=x[le(a+480192|0,f+558|0)>>1],u[g+480192>>1]=h}kb=f+560|0;return d|0}function M8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=kb-16|0;kb=c;d=Mb(a);while(1){b:{c:{d:{if(Hb(g)>>>0>f>>>0){b=v[Ai(g,f)>>2];if(b>>>0>=2097152){v[23588]=0;R(919,d|0,63);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;t[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=w[c+10|0]|64}else{a=w[c+10|0]}v[23588]=0;R(919,d|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}kb=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=w[j|0];v[23588]=0;R(919,d|0,(a|i)<<24>>24);h=v[23588];v[23588]=0;a=e;break e}v[23588]=0;a=a-1|0;R(919,d|0,t[a+(c+10|0)|0]|-128);h=v[23588];v[23588]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;O()|0;Ab(d);T(a|0);L()}}function vs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=kb+-64|0;kb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;If(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(d>>>0>v[c+24>>2]-g>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=B(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[v[(a<<2)+h>>2]+(j<<2)>>2]=C(v[(a+k<<2)+i>>2])*C(7.450580596923828e-9);a=a+1|0;continue}}}aa(7192,9005,33,8718);L()}aa(7157,9005,34,8718);L()}aa(5900,9005,35,8718);L()}aa(5870,9005,36,8718);L()}kb=c- -64|0}function Kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;d=v[b>>2];e=mk(d,v[b+4>>2]);a:{if(e>>>0<c>>>0){i=kb-32|0;kb=i;f=c-e|0;e=v[Gb(b)>>2];d=v[b+4>>2];b:{if(f>>>0<=e-d>>4>>>0){h=kb-16|0;kb=h;d=Ft(h,b,f);e=v[d+4>>2];f=v[d+8>>2];while(1){if((e|0)==(f|0)){lc(d);kb=h+16|0}else{Eu(e);e=e+16|0;v[d+4>>2]=e;continue}break}break b}e=Gb(b);e=gQ(i+8|0,hQ(b,mk(v[b>>2],d)+f|0),mk(v[b>>2],v[b+4>>2]),e);d=kb-16|0;kb=d;v[d>>2]=v[e+8>>2];h=v[e+8>>2];v[d+8>>2]=e+8;v[d+4>>2]=h+(f<<4);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){Eu(f);f=v[d>>2]+16|0;v[d>>2]=f;continue}break}Ud(d);kb=d+16|0;Ed(b,e);d=v[e+4>>2];f=v[e+8>>2];while(1){if((d|0)!=(f|0)){f=f-16|0;v[e+8>>2]=f;continue}break}d=v[e>>2];if(d){$o(e);Nb(d)}}kb=i+32|0;break a}if(c>>>0<e>>>0){Od(b,d+(c<<4)|0)}}if(Qb(v[a>>2],v[a+8>>2],c<<4)){c=v[b>>2];gc(g+8|0,c,mk(c,v[b+4>>2])<<4);ud(g,a,v[g+8>>2],v[g+12>>2])}kb=g+16|0}function Qba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;l=kb-16|0;kb=l;d=v[fc(l+8|0,Fb(v[a+4>>2]))>>2];i=kb-32|0;kb=i;e=d;d=v[a>>2];h=(zo(e,Fb(d))<<1)+d|0;g=fz(b,c);a:{if((g|0)<=0){break a}e=v[Gb(a)>>2];d=v[a+4>>2];if((g|0)<=e-d>>1){f=d-h|0;j=f>>1;b:{if((j|0)>=(g|0)){e=c;break b}v[i+8>>2]=b;v[i+8>>2]=v[i+8>>2]+(j<<1);e=v[i+8>>2];fP(a,e,c,g-j|0);if((f|0)<=0){break a}}m=kb-16|0;kb=m;j=v[a+4>>2];f=(j-((g<<1)+h|0)|0)+h|0;g=$h(m,a,d-f>>1);k=v[g+4>>2];c=f;while(1){if(c>>>0>=d>>>0){lc(g);Bq(h,f,j);kb=m+16|0}else{Ni(k,x[c>>1]);k=k+2|0;v[g+4>>2]=k;c=c+2|0;continue}break}$n(b,e,h);break a}f=Gb(a);f=Nj(i+8|0,Oj(a,Rc(v[a>>2],d)+g|0),h-v[a>>2]>>1,f);d=kb-16|0;kb=d;e=Oo(d,f+8|0,fz(b,c));c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){Ni(c,x[b>>1]);c=v[e>>2]+2|0;v[e>>2]=c;b=b+2|0;continue}break}Ud(e);kb=d+16|0;h=kP(a,f,h);Oi(f)}Fb(h);kb=i+32|0;kb=l+16|0;return a|0}function mca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-16|0;kb=e;v[e+12>>2]=1;a:{if(lo(a)){c=v[a>>2];j=rg(c,v[a+4>>2]);v[e+8>>2]=j;k=v[Kb(e+12|0,e+8|0)>>2];while(1){if(k){k=k-1|0;if((b|0)!=(c|0)){f=Fb(v[b>>2]);g=Fb(v[b+4>>2]);d=kb-16|0;kb=d;h=HB(f,g);b:{if(h>>>0<=Ym(c)>>>0){v[d+8>>2]=g;l=v[c>>2];i=Rc(l,v[c+4>>2]);m=i>>>0>=h>>>0;if(m){i=g}else{v[d+8>>2]=f;mP(d+8|0,i);i=v[d+8>>2]}f=Qi(f,i,l);if(!m){oP(c,v[d+8>>2],g,h-Rc(v[c>>2],v[c+4>>2])|0);break b}Od(c,f);break b}nP(c);iq(c,Oj(c,h));oP(c,f,g,h)}kb=d+16|0;Zo(c+12|0,b+12|0);u[c+28>>1]=x[b+28>>1]}c=c+32|0;continue}break}if(!j){yz(a,1-j|0,b);break a}gP(a,v[a>>2]+32|0);break a}if(v[a>>2]){iP(a);c=v[a>>2];lo(a);Nb(c);n=Gb(a),o=0,v[n>>2]=o;v[a>>2]=0;v[a+4>>2]=0}c=dq(a,1);if(th(134217727)>>>0<c>>>0){cd();L()}d=aQ(c);v[a>>2]=d;v[a+4>>2]=d;n=Gb(a),o=d+(c<<5)|0,v[n>>2]=o;yz(a,1,b)}kb=e+16|0}function pF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=kb-32|0;kb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;Lf(g+16|0,a,b,c,e,f-16129|0);Fm(g,a,b,c,e,16257-f|0);b=v[g+8>>2];e=(v[g+12>>2]&33554431)<<7|b>>>25;h=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;f=v[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}kb=g+32|0;return l(2,d&-2147483648|e),q()}function bm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;v[a+4>>2]=0;if(Qd(w[gm(d+8|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;b=S(104,b|0)|0;c=v[23588];v[23588]=0;d:{if((c|0)!=1){if(!pc(b,-1)){break d}break b}break c}v[a+4>>2]=v[a+4>>2]+1;continue}}if(v[a+4>>2]>=(b|0)){break a}e:{while(1){c=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;c=S(104,c|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break e}if(pc(c,-1)){break b}c=v[a+4>>2]+1|0;v[a+4>>2]=c;if((b|0)>(c|0)){continue}break}c=0;break a}}b=V(0)|0;O()|0;_(b|0)|0;c=1;em(v[v[a>>2]-12>>2]+a|0,1);f:{g:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break f}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break g}T(a|0);L()}$();break a}V(0)|0;O()|0;Vb()}L()}c=2}Li(v[v[a>>2]-12>>2]+a|0,c)}kb=d+16|0;return a|0}function baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=v[a>>2];d=yk(e,v[a+4>>2]);if(d>>>0<b>>>0){h=kb-32|0;kb=h;a:{b:{e=b-d|0;b=v[Gb(a)>>2];f=v[a+4>>2];c:{if(e>>>0<=(b-f|0)/52>>>0){Zx(a,e,c);break c}d=Gb(a);f=TL(a,yk(v[a>>2],f)+e|0);g=yk(v[a>>2],v[a+4>>2]);b=h+8|0;pg(b+12|0,d);if(f){d=SL(f)}else{d=0}v[b>>2]=d;g=d+B(g,52)|0;v[b+8>>2]=g;v[b+4>>2]=g;i=Cc(b),j=d+B(f,52)|0,v[i>>2]=j;v[23588]=0;U(879,b|0,e|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}f=v[a>>2];c=v[a+4>>2];e=b+4|0;while(1){if((c|0)!=(f|0)){c=c-52|0;d=wl(v[e>>2]-52|0,c);v[d+20>>2]=v[c+20>>2];g=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=g;CQ(d+24|0,c+24|0);ad(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];v[e>>2]=v[e>>2]-52;continue}break}qc(a,e);qc(a+4|0,b+8|0);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2];RL(b)}kb=h+32|0;break a}a=P()|0;O()|0;RL(b);T(a|0);L()}return}if(b>>>0<d>>>0){UL(a,e+B(b,52)|0)}}function Uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-16|0;kb=e;u[e+12>>1]=0;v[e+8>>2]=0;n=B(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){t[e+7|0]=0;pS(a,e+15|0,e+12|0,e+7|0);g=w[e+7|0];f=x[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!of(a,e+6|0)){break c}f=w[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}u[e+12>>1]=f;break b}l=l+1|0;continue a}u[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+w[e+8|0]|0;t[e+7|0]=f;t[i|0]=f;v[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=v[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}v[e+8>>2]=c}j=f;continue}}break}kb=e+16|0}function Tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=kb-16|0;kb=e;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){f=v[e+8>>2];m=((((v[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=u[b+14>>1];o=u[b+12>>1];p=u[b+10>>1];q=u[b+8>>1];r=u[b+6>>1];s=u[b+4>>1];t=u[b+2>>1];w=u[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+m|0;v[(f<<2)+e>>2]=(((((B(u[b+8>>1],p)+B(u[b+4>>1],q)|0)+B(u[b+12>>1],o)|0)+B(u[b+16>>1],n)|0)/2|0)+((((B(u[b-8>>1],t)+B(u[b-12>>1],w)|0)+B(u[b-4>>1],s)|0)+B(u[b>>1],r)|0)/2|0)|0)/16384;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g);Rb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;kb=e+16|0}function ON(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=kb-16|0;kb=c;d=Mb(a);while(1){b:{c:{d:{if(Hb(g)>>>0>f>>>0){b=v[Ai(g,f)>>2];if(b>>>0>=2097152){v[23588]=0;R(51,d|0,63);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;t[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=w[c+10|0]|64}else{a=w[c+10|0]}v[23588]=0;R(51,d|0,a&255);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}kb=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=w[j|0];v[23588]=0;R(51,d|0,a|i&255);h=v[23588];v[23588]=0;a=e;break e}v[23588]=0;a=a-1|0;R(51,d|0,w[a+(c+10|0)|0]|128);h=v[23588];v[23588]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;O()|0;Ab(d);T(a|0);L()}}function m7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0),x=C(0);h=kb-16|0;kb=h;if(ai(a+44|0)){f=v[a+44>>2];g=Kc(f,0);v[h+8>>2]=g;f=Kc(f,1);v[h+12>>2]=f;j=v[a+56>>2];m=Kc(j,0);v[h>>2]=m;j=Kc(j,1);v[h+4>>2]=j;a:{if(z[Eb(a+4208|0,2)>>2]!=C(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=v[e>>2];v[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=z[n>>2];l=z[i>>2];r=z[a+4236>>2];s=z[a+4232>>2];t=z[a+4228>>2];u=z[a+4220>>2];w=z[a+4224>>2];i=e+4240|0;o=z[i>>2];z[n>>2]=o;z[i>>2]=l;i=e+4264|0;x=z[i>>2];e=e+4256|0;p=z[e>>2];z[i>>2]=p;l=C(C(C(C(t*q)+C(C(u*l)+C(w*o)))-C(s*p))-C(r*x));z[e>>2]=l;k=h+k|0;e=v[k>>2];v[k>>2]=e+4;z[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;uc(m,e,g);uc(j,f,g);f=v[a+56>>2];m=Kc(f,0);j=Kc(f,1)}si(a,b,c,m,j,d)}kb=h+16|0}function jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=yd(d,v[a+4>>2]);if(c>>>0<b>>>0){f=kb-32|0;kb=f;c=b-c|0;b=v[Gb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=kb-16|0;kb=d;b=Qt(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){lc(b);kb=d+16|0}else{EQ(a);a=a+12|0;v[b+4>>2]=a;continue}break}break a}b=Gb(a);b=Ik(f+8|0,kn(a,yd(v[a>>2],d)+c|0),yd(v[a>>2],v[a+4>>2]),b);e=kb-16|0;kb=e;d=DQ(e,b+8|0,c);c=v[d>>2];while(1){if(v[d+4>>2]!=(c|0)){EQ(c);c=v[d>>2]+12|0;v[d>>2]=c;continue}break}Ud(d);kb=e+16|0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;CQ(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}qc(a,d);qc(a+4|0,b+8|0);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2];a=v[b+4>>2];while(1){c=v[b+8>>2];if((c|0)!=(a|0)){c=c-12|0;v[b+8>>2]=c;FQ(c);continue}break}a=v[b>>2];if(a){$o(b);Nb(a)}}kb=f+32|0;return}if(b>>>0<c>>>0){GQ(a,d+B(b,12)|0)}}function uba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;b=v[a+4>>2];if(Qd(w[b+223884|0])){dO(b+223860|0);b=v[a+4>>2]}v[a+24>>2]=0;v[a+28>>2]=0;v[b>>2]=0;c=v[a>>2];v[b+40>>2]=v[c+480196>>2];v[b+44>>2]=v[c+480204>>2];v[b+80>>2]=v[c+480200>>2];c=x[c+480188>>1];v[f+8>>2]=0;v[f+12>>2]=0;d=f+8|0;u[d+4>>1]=65280;v[d>>2]=0;e=kb-16|0;kb=e;v[e+12>>2]=c;b=a+8|0;a:{if(hn(b)>>>0>=c>>>0){g=v[b>>2];h=Vg(g,v[b+4>>2]);v[e+8>>2]=h;i=v[Kb(e+12|0,e+8|0)>>2];while(1){if(i){v[g>>2]=v[d>>2];u[g+4>>1]=x[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){nN(b,c-h|0,d);break a}Od(b,v[b>>2]+(c<<3)|0);break a}wO(b);mz(b,or(b,c));nN(b,c,d)}kb=e+16|0;b=0;while(1){c=v[a>>2];if(x[c+480188>>1]<=b>>>0){kb=f+16|0}else{d=B(b,872);fo((d+v[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+v[a+4>>2]|0;u[c+1432>>1]=0;t[c+1418|0]=0;t[c+1415|0]=0;t[c+1413|0]=0;b=b+1|0;continue}break}}function uw(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break a}f=0;t[b|0]=0;a=v[e>>2];v[e>>2]=a+1;t[a|0]=46;if(!Hb(h)){break b}a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Hb(h)){break c}if(!w[b|0]){break a}f=0;a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;v[k>>2]=0;return 0}f=-1;a=ww(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=w[(a>>2)+82976|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=v[e>>2];if((a|0)!=(d|0)){f=-1;if((w[a-1|0]&95)!=(w[c|0]&127)){break b}}v[e>>2]=a+1;t[a|0]=g;return 0}t[c|0]=80;break d}d=g&95;if((d|0)!=w[c|0]){break d}t[c|0]=d|128;if(!w[b|0]){break d}t[b|0]=0;if(!Hb(h)){break d}b=v[j>>2];if((b-i|0)>159){break d}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c}b=v[e>>2];v[e>>2]=b+1;t[b|0]=g;f=0;if((a|0)>84){break b}v[k>>2]=v[k>>2]+1}return f}return-1}function f3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=kb+-64|0;kb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;If(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){g=v[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=B(b,f);l=B(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[(a+l<<2)+i>>2]=A[(a+k<<3)+j>>3];a=a+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}kb=c- -64|0}function DP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;b=v[a>>2];fc(g+8|0,b);a:{b:{c:{d:{e:{if(Fd(v[b+16>>2])){while(1){if(c>>>0>31){break e}v[23588]=0;d=ga(43)|0;e=v[23588];v[23588]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=V(93532)|0;if((O()|0)!=(ea(93532)|0)){break c}_(c|0)|0;t[b+20|0]=0;v[23588]=0;Y(31,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}$();break e}t[b+20|0]=0}if(!w[b+20|0]){d=v[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=v[d+2496>>2];e=d+(b<<2)|0;i=v[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=v[d+(h<<2)>>2];b=i^(b&2147483647|v[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;v[e>>2]=b;v[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}kb=g+16|0;break a}c=P()|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break b}}T(c|0);L()}V(0)|0;O()|0;Vb();L()}return v[a+28>>2]&f}function jA(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=kb-32|0;kb=i;aS(a,b);h=kb-16|0;kb=h;nd(c,1);g=Ib(w[b+22|0]|w[b+23|0]<<8)<<1;v[c>>2]=g;t[c+37|0]=w[b+24|0]<<4;t[h+15|0]=w[b+25|0];t[h+14|0]=64;l=c,m=w[Xb(h+15|0,h+14|0)|0]<<2,u[l+30>>1]=m;f=Ib(w[b+26|0]|w[b+27|0]<<8);a=f<<1;k=Ib(w[b+28|0]|w[b+29|0]<<8);j=k<<1;a=k>>>0>=2?a+j>>>0<=g>>>0?a:f+j>>>0>g>>>0?a:f:a;a:{b:{switch(g|0){case 2:v[c>>2]=0;break a;case 0:break a;default:break b}}v[c+4>>2]=a;f=a+j|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}u[c+34>>1]=x[c+34>>1]|2}kb=h+16|0;Il(i,3,b);a=i+16|0;Fc(a,i);c=Dc(d,a);zb(a);a=0;while(1){if((a|0)!=32){d=a+c|0;if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}a=a+1|0;continue}break}a=mA(b);kb=i+32|0;return a}function YE(a,b,c,d,e,f,g,h){var i=0,j=0,k=C(0);i=kb-96|0;kb=i;qy(v[a+24>>2]);t[v[a+24>>2]+1298420|0]=v[a+52>>2]!=0;v[i+92>>2]=f;v[i+88>>2]=e;v[i+84>>2]=d;v[i+80>>2]=c;a:{d=i+80|0;c=0;while(1){b:{if((c|0)!=4){if(v[(c<<2)+d>>2]){break b}}else{c=4}break a}c=c+1|0;continue}}v[i+40>>2]=b;v[i+36>>2]=c;v[i+32>>2]=d;e=v[a+32>>2];k=z[a+48>>2];v[i+8>>2]=b;c=v[i+36>>2];v[i>>2]=v[i+32>>2];v[i+4>>2]=c;d=kb-16|0;kb=d;v[d+8>>2]=v[i+8>>2];c=v[i+4>>2];v[d>>2]=v[i>>2];v[d+4>>2]=c;c=wJ(i+48|0);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=h;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=k;v[c>>2]=g;kb=d+16|0;while(1){if(b){d=v[a+24>>2];v[i+24>>2]=b;v[i+28>>2]=0;v[i+16>>2]=134217727;v[i+20>>2]=0;d=zJ(d,v[Zq(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|j)){a=v[a+24>>2];v[a+480208>>2]=v[a+480208>>2]&-513}kb=i+96|0;return j}function RX(){var a=0,b=0,c=0,d=0;c=kb-32|0;kb=c;a:{a=Nc(c+16|0,14930);if(!Hb(a)){break a}b:{if((Eg(a,14600)|0)!=-1){b=Eg(a,14600);v[23588]=0;X(130,c|0,a|0,b+1|0,-1);b=v[23588];v[23588]=0;if((b|0)==1){break b}Bc(a,c);zb(c)}if((Eg(a,16764)|0)!=-1){b=Eg(a,16764);v[23588]=0;X(130,c|0,a|0,b+1|0,-1);b=v[23588];v[23588]=0;if((b|0)==1){break b}Bc(a,c);zb(c)}if((Eg(a,13813)|0)!=-1){b=Eg(a,13813);v[23588]=0;X(130,c|0,a|0,0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}Bc(a,c);zb(c)}if((Eg(a,13662)|0)!=-1){b=Eg(a,13662);v[23588]=0;X(130,c|0,a|0,0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}Bc(a,c);zb(c)}if((Eg(a,13705)|0)!=-1){b=Eg(a,13705);v[23588]=0;X(130,c|0,a|0,0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}Bc(a,c);zb(c)}v[23588]=0;b=S(131,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;zb(a);T(c|0);L()}zb(a);kb=c+32|0;return b|0}function o3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=kb+-64|0;kb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;If(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(d>>>0>v[c+24>>2]-g>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=B(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[v[(a<<2)+h>>2]+(j<<2)>>2]=A[(a+k<<3)+i>>3];a=a+1|0;continue}}}aa(7192,9005,77,8685);L()}aa(7157,9005,78,8685);L()}aa(5900,9005,79,8685);L()}aa(5870,9005,80,8685);L()}kb=c- -64|0}function im(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;al(a);a:{b:{c:{f=v[b+32>>2];d:{if(!f){e=v[b+2084>>2];if(e){break d}break b}c=v[b+4>>2];if((c|0)<9){break c}e=v[b+2084>>2];if(!e){break c}}h=v[a+1392>>2];j=hm(h);d=v[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=y[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}v[a+1392>>2]=h>>>b;b=d-b|0}v[a+1396>>2]=b;return c}if(w[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=w[v[b+8>>2]+d|0];if((c|0)==255){break f}g=v[a+1392>>2];if(v[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=v[a+1396>>2];if((e|0)>=(c|0)){v[a+1392>>2]=g>>>c;v[a+1396>>2]=e-w[v[b+8>>2]+d|0];return d}v[a+1396>>2]=0;break b}d=d+1|0;continue}break}ec(a,21);v[a+1396>>2]=0}return-1}aa(11298,13110,1705,5448);L()}function MW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-96|0;kb=d;zc(b);Xo(a);a:{if(!xv(b,d+56|0)){break a}if(!kD(d+56|0)){break a}b:{if(!c){break b}if(!Qb(v[b>>2],v[b+8>>2],cc(v[d+60>>2])-28|0)){break a}Mv(a);g=d,h=Lv(),v[g+32>>2]=h;e=d+32|0;Kv(Uj(v[a+4>>2])+32|0,e);sr(e);c=v[Uj(v[a+4>>2])+32>>2];v[23588]=0;R(191,e|0,b|0);b=v[23588];v[23588]=0;c:{if((b|0)==1){break c}b=v[d+32>>2];e=v[d+60>>2];f=v[d+68>>2];v[23588]=0;b=fa(192,b|0,cc(e)-28|0,c|0,cc(f)|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}e=0;if(!b){break a}se(d+16|0,v[c>>2],v[c+4>>2]);$g(d+24|0,v[d+16>>2],v[d+20>>2]);b=fe(d+8|0);b=qr(d+32|0,v[d+24>>2],v[d+28>>2],v[b>>2],v[b+4>>2]);hd(Uj(v[a+4>>2])+12|0,b);Bb(b);break b}a=Ea(92948,26056)|0;b=O()|0;d:{if((ea(92948)|0)==(b|0)){break d}if((ea(26056)|0)==(b|0)){break d}T(a|0);L()}_(a|0)|0;$();e=0;break a}e=1}kb=d+96|0;return e|0}function Fw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=v[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;e=w[b|0];if((e|0)!=61){b=c+1|0;if(e){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;c:{if(w[g+a|0]){break c}f=v[117002];if(!f){break c}b=v[f>>2];if(!b){break c}while(1){d:{c=a;e=b;i=0;h=g;d=0;e:{if(!g){break e}d=w[c|0];f:{if(!d){break f}while(1){g:{j=w[e|0];if(!j){break g}h=h-1|0;if(!h|(d|0)!=(j|0)){break g}e=e+1|0;d=w[c+1|0];c=c+1|0;if(d){continue}break f}break}i=d}d=(i&255)-w[e|0]|0}if(!d){b=b+g|0;if(w[b|0]==61){break d}}b=v[f+4>>2];f=f+4|0;if(b){continue}break c}break}k=b+1|0}return k}function Uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;e=kb-16|0;kb=e;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){f=v[e+8>>2];m=(((v[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=u[b+14>>1];o=u[b+12>>1];p=u[b+10>>1];q=u[b+8>>1];r=u[b+6>>1];s=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];f=0;while(1){if((f|0)!=2){b=f+m|0;v[(f<<2)+e>>2]=(((((B(t[b+4|0],p)+B(t[b+2|0],q)|0)+B(t[b+6|0],o)|0)+B(t[b+8|0],n)<<8)/2|0)+((((B(t[b-4|0],w)+B(t[b-6|0],x)|0)+B(t[b-2|0],s)|0)+B(t[b|0],r)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g);Rb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;kb=e+16|0}function tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=kb-32|0;kb=g;d=kb-16|0;kb=d;c=a+33|0;v[b>>2]=w[c+206|0]|w[c+207|0]<<8;eM(c,b+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);eM(c,b+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);f=b+236|0;while(1){if((e|0)==96){if(w[c+208|0]){t[b+31|0]=w[c+209|0]+1;f=w[b+31|0];a:{b:{if(!f){e=1;break b}e=16;if(f>>>0<17){break a}}t[b+31|0]=e}u[d+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[d+12>>1]=127;i=b,j=w[Wc(d+14|0,d+12|0)|0]+1|0,t[i+30|0]=j}t[b+33|0]=w[c+212|0];kb=d+16|0}else{i=dc(f,e+12|0),j=w[c+e|0],u[i>>1]=j;e=e+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){f=dc(e,h+12|0);d=w[c+h|0];u[f>>1]=d>>>0<(w[a+27|0]|w[a+28|0]<<8)>>>0?d:0;h=h+1|0;continue}break}Il(g,3,a+4|0);c=g+16|0;Fc(c,g);Dc(b+492|0,c);zb(c);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}kb=g+32|0}function qQ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;f=kb-16|0;kb=f;n=v[a+20>>2];g=x[a+34>>1]&65;v[f+8>>2]=g;v[f>>2]=g^65;g=b;i=a+24|0;o=d+1298224|0;e=d+1074992|0;j=oj(d);p=a+4|0;q=a+12|0;r=a+8|0;s=a+16|0;t=d+480180|0;while(1){if((e|0)!=(o|0)){if(v[e+104>>2]==(a|0)){if(v[e+16>>2]){v[e+16>>2]=g}if(y[e+4>>2]>c>>>0){v[e>>2]=0;v[e+4>>2]=0}b=a;if(v[e+76>>2]){xc(e+76|0,c);b=v[e+104>>2]}d=v[e+88>>2];b=gD(d,b);h=v[(b?q:p)>>2];v[e+84>>2]=v[(b?s:r)>>2];v[e+80>>2]=h;b=d|v[f+8>>2];v[e+88>>2]=b;v[e+88>>2]=b&(v[f>>2]^-1);b=e+704|0;h=v[a+24>>2];a:{if(!v[e+704>>2]|!h){break a}if(Km(v[t>>2])){break a}d=v[(j?b:i)>>2];k=Oka(v[(j?i:b)>>2],0,v[e+700>>2],0);l=k+(d>>>1|0)|0;m=nb;u=e,w=Ec(Rka(l,k>>>0>l>>>0?m+1|0:m,d,0),nb),v[u+700>>2]=w}v[b>>2]=h}e=e+872|0;continue}break}v[a>>2]=c;v[a+20>>2]=g;Cz(n);kb=f+16|0}function aD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=kb-32|0;kb=c;v[23588]=0;e=Q(13,c+24|0,467480)|0;d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!w[e|0]){break e}f=Sm(c+8|0,467480);d=v[v[116870]-12>>2]+467480|0;g=v[d+4>>2];v[23588]=0;h=S(14,d|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break d}f=v[f>>2];v[23588]=0;b=a+b|0;a=ka(15,f|0,a|0,((g&176)==32?b:a)|0,b|0,d|0,h|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}v[c+16>>2]=a;if(!$u(c+16|0)){break e}a=v[v[116870]-12>>2];v[23588]=0;R(16,a+467480|0,5);a=v[23588];v[23588]=0;if((a|0)!=1){break e}break d}zk(e);break b}a=V(0)|0;O()|0;zk(e);break c}a=V(0)|0;O()|0}_(a|0)|0;a=v[v[116870]-12>>2];v[23588]=0;Y(17,a+467480|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}kb=c+32|0;return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){V(0)|0;O()|0;Vb();L()}T(a|0);L()}function TB(a){var b=0,c=0,d=0,e=0,f=0,g=0;if((w[a|0]-16&255)>>>0>=241){e=a+1954|0;c=a+1698|0;a:{b:{while(1){if((c|0)==(e|0)){c=0;e=0;while(1){b=32;if((c|0)==32){break a}d=B(c,13)+a|0;if(w[d+14|0]){break b}b=(c<<4)+a|0;if(w[b+418|0]|w[b+419|0]<<8|(w[b+420|0]<<16|w[b+421|0]<<24)){break b}f=w[b+422|0]|w[b+423|0]<<8|(w[b+424|0]<<16|w[b+425|0]<<24);if(w[d+942|0]|f>>>0>1048575){break b}d=B(c,11)+a|0;g=d+1346|0;if(w[g|0]>15|w[d+1351|0]>3|w[d+1356|0]>3){break b}c:{d:{if(f){d=w[b+430|0]|w[b+431|0]<<8|(w[b+432|0]<<16|w[b+433|0]<<24);if(d>>>0<=1048574&(d>>>0<(w[b+426|0]|w[b+427|0]<<8|(w[b+428|0]<<16|w[b+429|0]<<24))>>>0|d>>>0>f>>>0)){break b}b=1;if(e){break c}break d}b=1;if(e){break c}if(Sb(g,26253,11)){break d}b=0;break c}b=1}e=b;c=c+1|0;continue}}b=t[c|0];c=c+1|0;if((b|0)>=-1){continue}break}return 0}b=c}a=b>>>0>31&e}else{a=0}return a}function Naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-32|0;kb=d;e=Mb(d+16|0);a:{b:{c:{if(c>>>0<64){break c}v[23588]=0;c=S(189,b|0)|0;f=v[23588];v[23588]=0;d:{if((f|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[23588]=0;Q(55,a|0,21619)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}break a}v[23588]=0;c=S(202,b|0)|0;f=v[23588];v[23588]=0;if((f|0)!=1){g=d,h=Fi(c),v[g+8>>2]=h;c=v[td(d+12|0,d+8|0)>>2];v[23588]=0;R(46,e|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{v[23588]=0;c=S(206,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break f}if(!c){break e}v[23588]=0;W(847,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[23588];v[23588]=0;if((c|0)!=1){continue}}break}break a}v[23588]=0;Q(188,b|0,4)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}ad(a,e)}zb(e);kb=d+32|0;return}a=P()|0;O()|0;zb(e);T(a|0);L()}function Np(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=kb-16|0;kb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;f=Oka(b,d,5e4,0);e=nb;b=v[Zc(c+8|0,c)>>2];b=Ic(Pka(f,e,b,b>>31),nb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=Oka(v[a+1074420>>2],0,Oka(v[a+1074408>>2],0,v[a+1074416>>2],0),nb),v[g>>2]=h;v[c+4>>2]=nb;b=Oka(b,0,6e5,0);d=c+8|0;e=b;f=nb;b=nv(v[d>>2],v[d+4>>2],v[c>>2],v[c+4>>2])?c:d;b=Rka(e,f,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];f=Oka(b,d,1e4,0);e=nb;b=v[Zc(c+8|0,c)>>2];b=Ic(Pka(f,e,b,b>>31),nb);v[a+1074404>>2]=b}e=a+1074404|0;a=v[a+480244>>2];b=Oka(a,a>>31,b,b>>31)+32768|0;a=nb;a=Ic(Pka(b,b>>>0<32768?a+1|0:a,65536,0),nb);v[e>>2]=a?a:1;kb=c+16|0}function mK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;c=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){e=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|c)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(e>>>0>2146435071){break a}b=1072693248;k=-1023;if((e|0)!=1072693248){b=e;break b}if(c){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;c=j(0)|0;k=-1077}l(0,c|0);c=b+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function DK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=C(0);d=a+4208|0;j=C(C(z[Eb(d,2)>>2]*C(2999.9990234375))+C(.0010000000474974513));l=C(z[Eb(d,3)>>2]*C(.9980000257492065));f=-3e3/+C(j*C(y[v[a+16>>2]+24620>>2]));h=a+4272|0;c=bk(10,f*+y[Eb(h,4)>>2]);d=a+4232|0;o=Eb(d,0),p=C(c),z[o>>2]=p;c=bk(10,f*+y[Eb(h,5)>>2]);o=Eb(d,1),p=C(c),z[o>>2]=p;m=f*(1/+C(l+C(.0010000000474974513))+-1);c=0;while(1){if((e|0)==4){e=a+4208|0;f=bk(10,+BK(z[Eb(e,0)>>2])*.05);b=4/K(c)*f;c=bk(10,+BK(z[Eb(e,1)>>2])*.1);z[a+4228>>2]=b*K(c);z[a+4224>>2]=f*K(1-c)}else{g=Eb(h,e);k=e>>>1|0;n=v[Eb(h,k+4|0)>>2];g=v[g>>2];i=bk(10,m*+(n+g>>>0));b=bk(10,f*+(g>>>0));j=z[Eb(d,k)>>2];g=e<<1;i=(1-i)*.5;o=Eb(d,g+2|0),p=C(b*(1-i)),z[o>>2]=p;o=Eb(d,g+3|0),p=C(b*i),z[o>>2]=p;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;e=e+1|0;continue}break}}function on(a,b,c,d){var e=0,f=0;f=kb-16|0;kb=f;v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=v[a+24>>2];v[23588]=0;R(d|0,f|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break i}d=v[f>>2];e=yd(d,v[f+4>>2]);if(e>>>0<2147483647){break h}d=ba(8)|0;v[23588]=0;b=Q(1007,d|0,7389)|0;e=v[23588];v[23588]=0;if((e|0)==1){break g}v[23588]=0;U(119,b|0,93308,168);b=v[23588];v[23588]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=gg(21619);break j}b=gg(Mc(Nd(d,b)))}Xe(f);break d}b=V(0)|0;O()|0;ca(d|0)}Xe(f)}_(b|0)|0;b=0;v[23588]=0;X(939,c|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break c}$()}kb=f+16|0;return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Vb()}L()}T(a|0);L()}function y6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-32|0;kb=e;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[23588]=0;Y(953,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}v[23588]=0;Y(953,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break g}f=v[a+24>>2];v[23588]=0;d=Q(55,e+16|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break g}v[23588]=0;c=Q(55,e|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break f}v[23588]=0;X(968,f|0,d|0,c|0,1);b=v[23588];v[23588]=0;if((b|0)==1){break e}zb(c);zb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;zb(c)}zb(d)}_(b|0)|0;b=0;v[23588]=0;X(939,6412,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}kb=e+32|0;return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function rI(a,b,c,d){var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=kb-96|0;kb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=z[g+4>>2];f=z[g+8>>2];z[i+4>>2]=h+f;k=d<<1;z[(8-k<<2)+e>>2]=h-f;h=z[g+16>>2];f=z[g+12>>2];z[(7-k<<2)+e>>2]=h-f;z[i+8>>2]=-C(h+f);d=d+1|0;continue}break}qI(e+48|0);qI(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=z[i>>2];f=z[d+(e+48|0)>>2];l=z[d+71168>>2];m=z[d+71204>>2];n=z[d+e>>2];z[i>>2]=C(f*l)-C(m*n);i=a+d|0;d=c+d|0;f=C(C(f*m)+C(n*l));z[i>>2]=C(h*z[d>>2])-C(z[d+36>>2]*f);z[(17-g<<2)+a>>2]=C(h*z[d+36>>2])+C(f*z[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}kb=e+96|0}function cU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!w[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=w[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?(w[d-1|0]==13&(i|0)==10)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&w[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}$f(a);yt(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=t[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Yp(a,e);c=c+1|0;continue}break}}function PV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;nd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Sq(a+4|0,a);d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d;c=Sq(a+8|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=f;c=(w[a+15|0]|w[a+16|0]<<8)<<1;v[b+24>>2]=c;c=w[a+15|0]|w[a+16|0]<<8?c:16726;v[b+24>>2]=c;g=b,h=(B(Yu(t[a+17|0],w[a+14|0]<<28>>24),c)>>>0)/8363|0,v[g+24>>2]=h;t[e+15|0]=w[a+18|0];t[e+14|0]=127;g=b,h=(((w[Xb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[g+30>>1]=h;c=w[a+14|0];if(c>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=c&240}c=w[a+19|0];if(c&4){u[b+34>>1]=x[b+34>>1]|1;c=w[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=x[b+34>>1];d=f|2;u[b+34>>1]=d;c=w[a+19|0];if(c&16){d=f|6;u[b+34>>1]=d;c=w[a+19|0]}if(!(c&64)){break a}u[b+34>>1]=d|128}kb=e+16|0}function j4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb+-64|0;kb=e;a:{b:{if((b|0)>=0){d=v[a+24>>2];if(tj(Wb(v[d+484360>>2],w[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=v[a+24>>2];g=v[f+484344>>2];i=v[f+484348>>2];h=x[dc(v[Wb(v[f+484360>>2],w[f+484376|0])>>2],b)>>1];if(!Rm(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<v[Zb(g,h)+12>>2]){break c}}a=a+16|0;break a}u[f+1074448>>1]=b;c=f;f=b&65535;EM(c,f);c=v[a+24>>2];v[c+1074392>>2]=-2;v[c+1074428>>2]=d;g=w[a+64|0];b=e+24|0;u[b+4>>1]=0;t[b+6|0]=255;v[b+16>>2]=2;v[b>>2]=0;v[b+8>>2]=d;u[b+12>>1]=f;d=v[b+20>>2];v[e+16>>2]=v[b+16>>2];v[e+20>>2]=d;d=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=d;d=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=d;b=e+48|0;_t(b,c,g?7:1,e);j=a,k=A[xM(v[e+52>>2])>>3],A[j+16>>3]=k;Ei(b);a=a+16|0}kb=e- -64|0;return+A[a>>3]}function eM(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=kb-16|0;kb=k;t[k+15|0]=c;t[k+14|0]=12;Rg(b,w[Xb(k+15|0,k+14|0)|0]);c=0;l=v[b>>2];m=v[b+4>>2];p=$d(l,m);while(1){if((c|0)==(p|0)){c=0;t[b+12|0]=0;a:{if(!(d&1)){break a}if(pc(l,m)){break a}c=1;t[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;t[b+12|0]=c}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=c|2}t[b+14|0]=g;t[b+13|0]=f}kb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=Eb(l,c);i=(c<<2)+a|0;u[j>>1]=w[i+96|0]|w[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=Eb(l,c);i=(c<<2)+a|0;u[j>>1]=w[i+144|0]|w[i+145|0]<<8;i=i+146|0}t[j+2|0]=w[i|0]}e:{if(!c){break e}i=Eb(l,c);j=x[i>>1];n=Eb(l,c-1|0);o=x[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;u[i>>1]=j;if(j>>>0>=x[n>>1]){break e}u[i>>1]=j+256}c=c+1|0;continue}break}}function DN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-16|0;kb=e;h=-1;a:{if(!my(a,b,2)){break a}f=v[b+656>>2];g=a+1074312|0;Db(e+8|0,g,31);b:{if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}Db(e+8|0,g,31);g=d-Cb(v[v[e+8>>2]>>2],v[e+12>>2])|0;i=v[a+480180>>2];d=(i|0)==4096;j=f+88|0;f=d?64:(i|0)==16384?192:512;d=aq(j,g,f,d?255:64)-(f>>>1|0)|0;if(w[b+746|0]&16){h=Wp(a,b,!(v[b+88>>2]&32768),d);break a}if(wj(v[b+656>>2])){if((d|0)==u[b+772>>1]){break a}k=b,l=ed(d),u[k+772>>1]=l;t[b+851|0]=w[b+851|0]|64;break a}a=oj(a);v[e+8>>2]=d;c:{if((d|0)<0){v[e+8>>2]=0-d;bi(e+8|0,255);a=(v[e+8>>2]<<2)+(a?38160:37136)|0;break c}bi(e+8|0,255);a=(v[e+8>>2]<<2)+(a?37136:38160)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];k=c,l=Ic(Pka(Oka(b,d,a,a>>31),nb,65536,0),nb),v[k>>2]=l}kb=e+16|0;return h}function vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;nd(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;v[c>>2]=w[a+40|0]|w[a+41|0]<<8|(w[a+42|0]<<16|w[a+43|0]<<24);v[c+4>>2]=w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24);v[c+8>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[c+24>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);d=w[b+151|0];if(d>>>0<=4){t[c+38|0]=w[d+42714|0]}d=w[b+152|0]|w[b+153|0]<<8;t[c+39|0]=d;e=(w[b+156|0]|w[b+157|0]<<8)>>>4|0;t[c+41|0]=e;b=(w[b+154|0]|w[b+155|0]<<8)>>>2|0;t[c+40|0]=b;if((b|e)&255){t[c+39|0]=d^-1}b=w[a+38|0]|w[a+39|0]<<8;if(b&4){u[c+34>>1]=x[c+34>>1]|1;b=w[a+38|0]|w[a+39|0]<<8}if(b&8){u[c+34>>1]=x[c+34>>1]|2;b=w[a+38|0]|w[a+39|0]<<8}if(b&16){u[c+34>>1]=x[c+34>>1]|4;b=w[a+38|0]|w[a+39|0]<<8}if(b&32){u[c+34>>1]=x[c+34>>1]|32}}function uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=kb-16|0;kb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){f=v[b+8>>2];n=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;o=u[e+39718>>1];p=u[e+39716>>1];q=u[e+39714>>1];r=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;v[(e<<2)+b>>2]=(((B(u[f>>1],q)+B(u[f-4>>1],r)|0)+B(u[f+4>>1],p)|0)+B(u[f+8>>1],o)|0)/16384;e=e+1|0;continue}break}h=h+k|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=g+j|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;kb=b+16|0}function hba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=kb-880|0;kb=b;c=Ub(a,0,76);v[c+84>>2]=0;v[c+88>>2]=0;v[c+80>>2]=256;u[c+76>>1]=65535;v[c+92>>2]=0;v[c+96>>2]=0;t[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=jQ(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Tb(d);g=Ly(c+223860|0);f=b+8|0;Ub(f,0,108);Nz(b+120|0,48e3);Ub(b+664|0,0,72);t[b+754|0]=0;u[b+752>>1]=65535;t[b+746|0]=0;u[b+744>>1]=65535;t[b+738|0]=0;u[b+736>>1]=65535;v[b+748>>2]=0;v[b+740>>2]=0;Ub(b+756|0,0,103);v[b+868>>2]=0;v[b+872>>2]=0;t[b+875|0]=0;t[b+876|0]=0;t[b+877|0]=0;t[b+878|0]=0;v[b+860>>2]=0;v[b+864>>2]=0;t[b+859|0]=w[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=Sp(e,f)+872|0;continue}break}v[23588]=0;R(538,d|0,32);a=v[23588];v[23588]=0;if((a|0)!=1){kb=b+880|0;return c|0}a=P()|0;O()|0;Tp(g);ic(d);T(a|0);L()}function Hy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=x[a+480188>>1];h=d>>>0>256?d:256;f=v[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=B(c,872)+a|0;if(!v[e+1075068>>2]){if(!qj(v[e+1075648>>2])|w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!Fd(f)){break a}if(!kN(f,c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){c=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=B(d,872)+a|0;if(!(v[b+1075688>>2]?0:v[b+1075068>>2])){c=(v[b+1075680>>2]|v[b+1075672>>2]<<9)>>>(v[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=v[(B(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=v[(B(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function mI(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=v[a+32>>2];a:{b:{b=v[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=v[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=w[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(y[a+40>>2]<c>>>0){ec(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=v[a+40>>2];if(e>>>0<=c+26>>>0){ec(a,1);break a}if(Sb(c,93872,4)){ec(a,21);break a}if(w[c+4|0]){ec(a,21);break a}d:{if(d){if(!v[a+992>>2]|!(t[c+5|0]&1)){break d}ec(a,21);break a}if(t[c+5|0]&1){break d}ec(a,21);break a}b=0;f=c+27|0;d=w[c+26|0];c=f+d|0;if(e>>>0<c>>>0){ec(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=w[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}ec(a,1)}return 0}function fF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-48|0;kb=d;v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;a:{b:{c:{if((e|0)!=1){e=Mb(d+32|0);v[23588]=0;Y(c|0,d+16|0);c=v[23588];v[23588]=0;d:{e:{if((c|0)!=1){h=d,i=Fb(v[d+16>>2]),v[h+8>>2]=i;f=1;while(1){g=Fb(v[d+20>>2]);c=v[d+8>>2];if(!Pb(c,g)){c=gg(Mc(e));Xe(d+16|0);zb(e);break b}if(!f){v[23588]=0;Q(941,e|0,14575)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}c=v[d+8>>2]}v[23588]=0;Q(800,e|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break e}mq(d+8|0);f=0;continue}}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Xe(d+16|0)}zb(e);break c}c=V(0)|0;O()|0}_(c|0)|0;c=0;v[23588]=0;X(939,b|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}kb=d+48|0;return c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){V(0)|0;O()|0;Vb();L()}T(a|0);L()}function B7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=ti(a,b,c,d);v[b+4260>>2]=0;v[b>>2]=46748;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Tb(d)+24|0;if((d|0)!=(c|0)){continue}break}t[b+5046|0]=1;u[b+5044>>1]=0;a=b+4208|0;f=Eb(a,0),g=1063675494,v[f>>2]=g;f=Eb(a,1),g=1065185444,v[f>>2]=g;f=Eb(a,2),g=0,v[f>>2]=g;f=Eb(a,3),g=1032805417,v[f>>2]=g;f=Eb(a,4),g=1053079357,v[f>>2]=g;f=Eb(a,5),g=1059859440,v[f>>2]=g;f=Eb(a,6),g=1047457519,v[f>>2]=g;f=Eb(a,7),g=1062836634,v[f>>2]=g;f=Eb(a,8),g=1038174126,v[f>>2]=g;f=Eb(a,9),g=1065353216,v[f>>2]=g;f=Eb(a,10),g=1065353216,v[f>>2]=g;f=Eb(a,11),g=1048525618,v[f>>2]=g;f=Eb(a,12),g=1059760811,v[f>>2]=g;v[23588]=0;R(897,b+44|0,2);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;while(1){c=wc(c-24|0);if((e|0)!=(c|0)){continue}break}Jf(b);T(a|0);L()}return b|0}function sG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=kb-32|0;kb=h;a:{b:{c:{if((b|0)!=(c|0)){j=v[116064];v[116064]=0;g=kb-16|0;kb=g;Hd();e=kb-16|0;kb=e;f=kb-16|0;kb=f;Ew(f,b,h+28|0,2);k=v[f>>2];i=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=i;kb=f+16|0;i=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=i;v[g+4>>2]=f;kb=e+16|0;f=v[g>>2];e=v[g+4>>2];b=v[g+12>>2];v[h+16>>2]=v[g+8>>2];v[h+20>>2]=b;v[h+8>>2]=f;v[h+12>>2]=e;kb=g+16|0;i=v[h+16>>2];f=v[h+20>>2];g=v[h+8>>2];e=v[h+12>>2];b=v[116064];if(!b){break c}if(v[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[116064]=j;if(v[h+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;i=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=i;v[a+12>>2]=f;kb=h+32|0}function eia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;c=rf(a,c);ne(e,v[a+36>>2]);h=a;a:{if(!c){Sc(e,a+32|0,5);d=0;if(Cb(v[v[e>>2]>>2],v[e+4>>2])){break a}}d=kb-32|0;kb=d;f=v[a+36>>2];Wf(f,d+30|0);b:{c:{d:{e:{a=x[d+30>>1];if(a>>>0>=4001){i=v[b+12>>2];a=kb-16|0;kb=a;g=yc(a,15896);ad(d,g);Ab(g);kb=a+16|0;v[23588]=0;U(478,d+16|0,d|0,d+30|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}a=v[i+1298464>>2];v[23588]=0;U(376,a|0,2,d+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}Ab(d+16|0);bc(d);a=4e3}vg(yj(v[b>>2],0),a);b=yj(v[b>>2],0);j=d,k=Fb(v[b>>2]),v[j+16>>2]=k;b=Fb(v[b+4>>2]);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Ab(d+16|0)}bc(d);T(b|0);L()}while(1){a=v[d+16>>2];if(Pb(a,b)){Wf(f,d);u[a>>1]=x[d>>1];Se(d+16|0);continue}break}kb=d+32|0;d=c}Ye(h,d);kb=e+16|0}function U9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=kb-16|0;kb=f;j=rf(a,c);ne(f,v[a+36>>2]);k=a;a:{if(!j){Sc(f,a+32|0,5);c=0;if(Cb(v[v[f>>2]>>2],v[f+4>>2])){break a}}e=kb-48|0;kb=e;h=v[a+36>>2];Kk(h,e+40|0);c=v[e+44>>2];if(!c&y[e+40>>2]>=257|c){v[e+40>>2]=256;v[e+44>>2]=0}l=v[e+40>>2];m=v[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=l>>>0){break b}Wf(h,e+38|0);g=Mb(e+24|0);v[23588]=0;Q(485,h|0,g|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;U(11,e+8|0,d|0,g|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}v[23588]=0;a=Q(888,b|0,e+38|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break d}i=a;a=e+8|0;Jb(i,a);Ab(a);zb(g);c=c+1|0;continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;Ab(e+8|0)}zb(g);T(c|0);L()}kb=e+48|0;c=j}Ye(k,c);kb=f+16|0}function vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=kb-16|0;kb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){f=v[b+8>>2];n=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;o=u[e+39718>>1];p=u[e+39716>>1];q=u[e+39714>>1];r=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=e+n|0;v[(e<<2)+b>>2]=(((B(t[f|0],q)+B(t[f-2|0],r)|0)+B(t[f+2|0],p)|0)+B(t[f+4|0],o)<<8)/16384;e=e+1|0;continue}break}h=h+k|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=g+j|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;kb=b+16|0}function uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=kb-432|0;kb=d;zc(b);xA(b,d+376|0,d+296|0,d+8|0);k=d,l=tg((m=w[d+427|0]+1|0,n=1,o=cc(v[d+408>>2]),o?m:n)),t[k+4|0]=l;i=w[Xb(26800,d+4|0)|0];t[d+7|0]=i;u[d+4>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Ib(x[d+8>>1])<<16>>16;if(!((e|0)<0|w[d+291|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=cc(v[d+296>>2]);if(e>>>0<g>>>0){if(dd(b,g)){break c}}t[d+7|0]=h+1;break b}}else{d:{if(!dd(b,cc(v[d+392>>2])+(f<<2)|0)){break d}if(!dd(b,Co(b))){break d}e:{if(!c){j=Me(b);break e}j=Hj(b)}u[d+2>>1]=j;k=d,l=x[le(d+4|0,d+2|0)>>1],u[k+4>>1]=l}f=f+1|0;continue}break}g=cc(v[d+296>>2]);xA(b,d+376|0,d+296|0,d+8|0);h=h+1|0;continue}break}rv(a);break a}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}kb=d+432|0}
function qv(a,b,c,d){var e=0,f=0,g=0,h=0;g=kb-16|0;kb=g;a:{if(!c){break a}if(d){b=hc(g+8|0,a,b);a=kb-16|0;kb=a;v[a+12>>2]=c;d=v[b+4>>2];b:{if(!d){d=v[b>>2];break b}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];h=e;e=v[Kb(a+8|0,a+12|0)>>2];v[c>>2]=-1<<d&-1>>>h-e|v[c>>2];f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Ub(e,255,d);e=c&31;v[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+v[b>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]|-1>>>32-e}kb=a+16|0;break a}b=hc(g,a,b);a=kb-16|0;kb=a;v[a+12>>2]=c;d=v[b+4>>2];c:{if(!d){d=v[b>>2];break c}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];f=v[c>>2];h=e;e=v[Kb(a+8|0,a+12|0)>>2];v[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Ub(e,0,d);e=c&31;v[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+v[b>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-e^-1)}kb=a+16|0}kb=g+16|0}function yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=kb-48|0;kb=g;h=a+8|0;c=v[a+8>>2];j=Cc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;e=v[a+4>>2];d=v[a>>2];if(e>>>0>d>>>0){a=e;d=((a-d>>1)+1|0)/-2<<1;e=a+d|0;while(1){if((a|0)!=(c|0)){e=pV(e,a)+2|0;a=a+2|0;continue}break}c=e;v[h>>2]=c;v[i>>2]=d+v[i>>2];break a}v[g+24>>2]=c-d;v[g+44>>2]=1;e=g+24|0;c=v[Zc(e,g+44|0)>>2];c=Nj(e,c,c>>>2|0,v[a+16>>2]);d=fc(g+16|0,v[a+4>>2]);f=v[fc(g+8|0,v[a+8>>2])>>2];e=kb-32|0;kb=e;d=v[d>>2];v[e+24>>2]=d;d=Oo(e+8|0,c+8|0,HB(d,f));f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){k=f;f=v[e+24>>2];Kj(k,w[f|0]|w[f+1|0]<<8);f=v[d>>2]+2|0;v[d>>2]=f;Se(e+24|0);continue}break}Ud(d);kb=e+32|0;qc(a,c);qc(i,c+4|0);qc(h,c+8|0);qc(j,Cc(c));Oi(c);c=v[a+8>>2]}Kj(c,w[b|0]|w[b+1|0]<<8);v[h>>2]=v[h>>2]+2;kb=g+48|0}function Hd(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(w[468292]){return v[117072]}c=kb-32|0;kb=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=OG(a,d?14249:21619)}else{d=v[a<<2>>2]}v[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!NG(0)){b=89968;if(!Sb(c+8|0,89968,24)){break a}b=89992;if(!Sb(c+8|0,89992,24)){break a}a=0;if(!w[468064]){while(1){f=(a<<2)+468016|0,g=OG(a,21619),v[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}t[468064]=1;v[117010]=v[117004]}b=468016;if(!Sb(c+8|0,468016,24)){break a}b=468040;if(!Sb(c+8|0,468040,24)){break a}b=Pd(24);if(!b){break b}}a=v[c+12>>2];v[b>>2]=v[c+8>>2];v[b+4>>2]=a;a=v[c+28>>2];v[b+16>>2]=v[c+24>>2];v[b+20>>2]=a;a=v[c+20>>2];v[b+8>>2]=v[c+16>>2];v[b+12>>2]=a;break a}b=0}kb=c+32|0;t[468292]=1;v[117072]=b;return b}function Rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-16|0;kb=f;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){b=(v[f+12>>2]<<1)+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(u[b+4>>1],u[e+10>>1])+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/2|0)+((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)/2|0)|0)/16384|0;h=h+l|0;v[c>>2]=v[c>>2]+B(b,h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Rb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;kb=f+16|0}function wq(a,b){var c=0;c=kb-16|0;kb=c;a=ir(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(Ob(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:vy(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;_f(a,107);break a;case 3:vy(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;_f(a,4);break a;case 2:break b;case 0:break c}}Ob(a,88,1);break a}vy(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}kb=c+16|0}function uK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=kb-48|0;kb=j;k=v[a+4>>2];l=v[a>>2];a=v[a+8>>2];v[j+32>>2]=b;v[j+44>>2]=a;v[j+36>>2]=l;v[j+40>>2]=k;v[23588]=0;a=Q(932,(d?d:933)|0,e|0)|0;b=v[23588];v[23588]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+16>>2]=a;a=v[eg(j+24|0,j+16|0)>>2];b=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=b;v[23588]=0;b=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=b;c=+Aa(934,j|0,+c,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}Ee(j+16|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Ee(j+16|0)}_(a|0)|0;v[23588]=0;ia(935,15024,d|0,e|0,f|0,g|0,h|0,i|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();c=0}kb=j+48|0;return+c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Q8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{c=kb-16|0;kb=c;e=Mb(a);g=c,h=Pi(b),v[g+8>>2]=h;g=c,h=hr(b),v[g>>2]=h;a=0;b:{while(1){c:{if(!zi(c+8|0,c)){if(!a){break c}v[23588]=0;R(49,e|0,65533);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}b=w[v[c+8>>2]];d:{e:{if(!a){if(!(b&128)){a=0;v[23588]=0;R(49,e|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}break b}if((b&224)==192){d=b&31;a=1;break d}if((b&240)==224){d=b&15;a=2;break d}d=65533;if((b&248)!=240){break e}d=b&7;a=3;break d}if((b&192)!=128){d=0;v[23588]=0;R(49,e|0,65533);f=v[23588];v[23588]=0;a=0;if((f|0)==1){break b}}d=b&63|d<<6;a=a-1|0;if(a){break d}}a=0;v[23588]=0;R(49,e|0,d|0);b=v[23588];v[23588]=0;d=0;if((b|0)==1){break b}}He(c+8|0);continue}break}kb=c+16|0;break a}a=P()|0;O()|0;Gc(e);T(a|0);L()}}function E9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((Qj(v[a>>2],v[a+4>>2])|0)==2){if((Qj(v[a+12>>2],v[a+16>>2])|0)==(b|0)){break b}}v[23588]=0;R(899,a|0,2);c=v[23588];v[23588]=0;c:{if((c|0)==1){break c}v[23588]=0;R(899,a+12|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}v[23588]=0;R(900,a+24|0,2);c=v[23588];v[23588]=0;if((c|0)==1){break c}v[23588]=0;R(900,a+36|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=er(v[c+12>>2],a);f=Eb(v[c+36>>2],a),g=d,v[f>>2]=g;a=a+1|0;continue}}else{e=er(v[a>>2],d);f=Eb(v[a+24>>2],d),g=e,v[f>>2]=g;d=d+1|0;continue}}b=V(92948)|0;if((O()|0)!=(ea(92948)|0)){break a}_(b|0)|0;Lc(a);BL(a);b=a+12|0;Lc(b);BL(b);b=a+24|0;Lc(b);AL(b);a=a+36|0;Lc(a);AL(a);$()}return}T(b|0);L()}function V8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=kb-4112|0;kb=c;h=ob[v[v[a>>2]+120>>2]](a)|0;if(!h){ob[v[v[a>>2]+124>>2]](a)}v[c+12>>2]=0;f=kb-16|0;kb=f;while(1){d=v[a+44>>2];if(Qj(d,v[a+48>>2])>>>0<=e>>>0){kb=f+16|0}else{v[f+12>>2]=0;d=er(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){z[d>>2]=z[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){v[c+8>>2]=b;xc(c+8|0,512);e=c+16|0;zy(e);d=v[c+8>>2];ob[v[v[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[g>>2]);i=c,j=z[Jx(c+12|0,c+4|0)>>2],z[i+12>>2]=j;z[c+4>>2]=D(z[g+2048>>2]);i=c,j=z[Jx(c+12|0,c+4|0)>>2],z[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){ob[v[v[a>>2]+128>>2]](a)}kb=c+4112|0;return C(z[c+12>>2])}function K3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=kb-32|0;kb=d;j=d,k=VJ(),v[j+24>>2]=k;g=a+24|0;c=d+24|0;TJ(g,ce(c));kj(c);u[a+28>>1]=0;QP();f=kb-16|0;kb=f;e=tc(144);v[23588]=0;h=Q(1063,e|0,4)|0;i=v[23588];v[23588]=0;a:{if((i|0)!=1){e=v[Mf(f+8|0,h)>>2];kb=f+16|0;break a}a=P()|0;O()|0;Nb(e);T(a|0);L()}v[d+24>>2]=e;SJ(a+32|0,ce(c));Bs(c);j=d,k=UJ(v[a>>2]),v[j+24>>2]=k;RJ(a+4|0,ce(c));jj(c);In(v[g>>2],v[a+4>>2]);t[a+64|0]=1;v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;j=d,k=Gi(v[b>>2]),v[j+24>>2]=k;e=xf(b);b:{while(1){b=v[d+24>>2];if(!Ig(b,e)){break b}c=wd(b);b=yh(d+8|0,c);v[23588]=0;X(968,a|0,b|0,c+12|0,0);c=v[23588];v[23588]=0;if((c|0)!=1){zb(b);Lg(d+24|0);continue}break}a=P()|0;O()|0;zb(b);T(a|0);L()}kb=d+32|0}function CL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;a:{if(vc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!Zg(v[v[b>>2]-12>>2]+b|0)){break a}d=kb-16|0;kb=d;f=tc(64);v[23588]=0;g=S(835,f|0)|0;h=v[23588];v[23588]=0;b:{c:{if((h|0)!=1){f=Mf(d,g);g=v[f>>2];v[23588]=0;g=W(894,g|0,b|0,c|0)|0;h=v[23588];v[23588]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}Hc(d+8|0);break d}a=P()|0;O()|0;sg(f);break c}eg(d+8|0,f)}sg(f);kb=d+16|0;d=v[d+8>>2];break b}a=P()|0;O()|0;Nb(f)}T(a|0);L()}v[e+8>>2]=d;f:{g:{if(!Fd(d)){v[23588]=0;b=Q(893,b|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break g}v[e>>2]=b;rT(e+8|0,ce(e));sg(e);d=v[e+8>>2]}if(!Fd(d)){break f}v[23588]=0;R(487,a|0,e+8|0);a=v[23588];v[23588]=0;i=d;if((a|0)!=1){break f}}a=P()|0;O()|0;sg(e+8|0);T(a|0);L()}sg(e+8|0)}kb=e+16|0;return i}function BV(a,b,c){var d=0,e=0;e=kb-16|0;kb=e;t[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{d=w[b+26288|0];switch(d-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break f}}g:{if(d-6>>>0<2){break g}if((d|0)==31){break b}if((d|0)==11){break g}if((d|0)!=1){break a}d=(c|0)!=0;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}t[e+15|0]=b;break a}if(c>>>0<=64){t[e+15|0]=c<<1;d=23;break a}t[e+15|0]=128;d=23;break a}d=19;h:{switch((c&240)-48>>>4|0){case 0:t[e+15|0]=159;d=20;break a;case 1:t[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}t[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break h;default:break a}}t[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}t[e+15|0]=(b<<5|c<<24>>>27)^128;d=31}ee(a,d,e+15|0);kb=e+16|0}function sd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=v[a+112>>2];d=v[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=v[a+4>>2];e=v[a+44>>2];b=f-e|0;h=b;g=b+v[a+120>>2]|0;b=v[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=Lw(a);if((h|0)>=0){break a}f=v[a+4>>2];e=v[a+44>>2]}v[a+112>>2]=-1;v[a+116>>2]=-1;v[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=v[a+4>>2];e=v[a+8>>2];c=v[a+112>>2];g=v[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}v[a+104>>2]=e;c=v[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){t[f-1|0]=h}return h}function Sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-16|0;kb=f;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){b=v[f+12>>2]+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(t[b+2|0],u[e+10>>1])+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/2|0)+((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])<<8)/2|0)|0)/16384|0;h=h+l|0;v[c>>2]=v[c>>2]+B(b,h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Rb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;kb=f+16|0}function Vn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b+88>>2];d=c|2048;v[b+88>>2]=d;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){d=c|6144;v[b+88>>2]=d}a:{if(!v[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=v[b+104>>2];if(!c){break b}e=x[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;v[b+88>>2]=d;e=v[c>>2];v[b+76>>2]=e;g=v[c+4>>2];v[b+80>>2]=g;c=v[c+8>>2];v[b+84>>2]=c;if(c>>>0<e>>>0){v[b+76>>2]=c;h=c}else{h=e}e=v[b+4>>2];if(h>>>0>=e>>>0){break b}v[b>>2]=0;v[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;v[b+88>>2]=d;v[b+76>>2]=v[c>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=d|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}i=b,j=ed(aq(f+48|0,v[b+724>>2],256,64)),u[i+728>>1]=j;i=b,j=x[Eb(v[f+48>>2],w[f+65|0])>>1],v[i+724>>2]=j}}function c8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=0;h=kb-16|0;kb=h;if(ai(a+44|0)){g=v[a+44>>2];r=h,s=Kc(g,0),v[r+8>>2]=s;r=h,s=Kc(g,1),v[r+12>>2]=s;g=v[a+56>>2];l=Kc(g,0);v[h>>2]=l;m=Kc(g,1);v[h+4>>2]=m;p=w[a+4273|0];q=w[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=v[i>>2];v[i>>2]=e+4;f=C(z[e>>2]*z[a+4240>>2]);e=a+j|0;i=e+4228|0;f=C(f+C(z[i>>2]*z[a+4236>>2]));z[i>>2]=f;f=TK(C(f*C(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=z[e>>2];o=z[a+4264>>2];f=C(C(C(f*z[a+4260>>2])-C(z[a+4268>>2]*z[i>>2]))-C(n*o));z[e>>2]=f;z[i>>2]=n+C(f*o);e=h+j|0;j=v[e>>2];v[e>>2]=j+4;z[j>>2]=f*C(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{si(a,b,c,l,m,d)}break}}kb=h+16|0}function QW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=kb-16|0;kb=g;dd(b,w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24));h=Tb(a);a=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);v[23588]=0;R(184,h|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))>>>0<=a>>>0){break b}e=v[b+8>>2];f=v[b>>2];v[23588]=0;e=W(156,f|0,e|0,4)|0;f=v[23588];v[23588]=0;if((f|0)==1){break a}if(!e){break b}e=w[c+4|0]|w[c+5|0]<<8;v[23588]=0;e=Q(185,b|0,e|0)|0;f=v[23588];v[23588]=0;c:{if((f|0)!=1){v[g+12>>2]=e;if(yd(v[d>>2],v[d+4>>2])>>>0<=e>>>0){break c}v[23588]=0;R(186,h|0,g+12|0);e=v[23588];v[23588]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}kb=g+16|0;return}}a=P()|0;O()|0;wc(h);T(a|0);L()}function Cp(a){var b=C(0),c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=gi(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=C(-gi(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=hi(f+1.5707963267948966);break a}b=hi(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=gi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=hi(-4.71238898038469-+a);break a}b=hi(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(ax(a,c+8|0)&3){case 0:b=gi(A[c+8>>3]);break a;case 1:b=hi(-A[c+8>>3]);break a;case 2:b=C(-gi(A[c+8>>3]));break a;default:break b}}b=hi(A[c+8>>3])}a=b;kb=c+16|0;return a}function s1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;v[c+28>>2]=0;if(Qd(w[gm(c+24|0,a,0)|0])){d=c+16|0;gd(d,v[v[a>>2]-12>>2]+a|0);v[23588]=0;d=S(1097,d|0)|0;e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){e=Sm(c+8|0,a);f=Hc(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[23588]=0;ma(1100,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[23588];v[23588]=0;if((d|0)!=1){break b}}b=V(0)|0;O()|0;ac(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;em(v[v[a>>2]-12>>2]+a|0,b);c:{d:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break d}T(a|0);L()}$();break a}V(0)|0;O()|0;Vb()}L()}ac(c+16|0);v[b>>2]=v[c+20>>2]}Li(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}kb=c+32|0;return a|0}function oL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=kb-16|0;kb=c;e=v[b+4220>>2];f=v[b+4224>>2];g=v[b+4228>>2];h=v[b+4232>>2];i=v[b+4240>>2];j=v[b+4236>>2];l=w[b+4244|0];k=b+4208|0;Si(k,33);d=v[k>>2];t[d+32|0]=l;t[d+24|0]=j;t[d+25|0]=j>>>8;t[d+26|0]=j>>>16;t[d+27|0]=j>>>24;t[d+28|0]=i;t[d+29|0]=i>>>8;t[d+30|0]=i>>>16;t[d+31|0]=i>>>24;t[d+16|0]=g;t[d+17|0]=g>>>8;t[d+18|0]=g>>>16;t[d+19|0]=g>>>24;t[d+20|0]=h;t[d+21|0]=h>>>8;t[d+22|0]=h>>>16;t[d+23|0]=h>>>24;t[d+8|0]=e;t[d+9|0]=e>>>8;t[d+10|0]=e>>>16;t[d+11|0]=e>>>24;t[d+12|0]=f;t[d+13|0]=f>>>8;t[d+14|0]=f>>>16;t[d+15|0]=f>>>24;t[d|0]=76;t[d+1|0]=70;t[d+2|0]=79;t[d+3|0]=32;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;se(c+8|0,v[k>>2],v[b+4212>>2]);hc(a,v[c+8>>2],v[c+12>>2]);kb=c+16|0}function WK(a){var b=0,c=0,d=0,e=0;b=kb-16|0;kb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=hi(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=C(-gi(d+1.5707963267948966));break a}a=gi(d+-1.5707963267948966);break a}a=hi(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=gi(d+4.71238898038469);break a}a=C(-gi(d+-4.71238898038469));break a}a=hi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(ax(a,b+8|0)&3){case 0:a=hi(A[b+8>>3]);break a;case 1:a=gi(A[b+8>>3]);break a;case 2:a=hi(-A[b+8>>3]);break a;default:break b}}a=C(-gi(A[b+8>>3]))}kb=b+16|0;return a}function qI(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);f=z[a>>2];i=z[a+24>>2];c=C(f-i);d=z[a+16>>2];b=z[a+32>>2];g=z[a+8>>2];e=C(d+C(b-g));z[a+16>>2]=c+e;j=C(c-C(e*C(.5)));c=z[a+4>>2];e=z[a+20>>2];h=z[a+28>>2];k=C(C(C(c-e)-h)*C(.8660253882408142));z[a+4>>2]=j+k;l=C(C(d-b)*C(.1736481785774231));f=C(f+C(i*C(.5)));i=C(C(g+b)*C(.7660444378852844));m=C(l+C(f-i));n=C(C(c+e)*C(.9848077297210693));b=C(z[a+12>>2]*C(.8660253882408142));c=C(C(c+h)*C(.6427876353263855));o=C(C(n-b)-c);z[a+12>>2]=m+o;z[a+20>>2]=m-o;z[a+28>>2]=j-k;d=C(C(g+d)*C(.9396926164627075));g=C(C(f+d)-l);e=C(C(e-h)*C(.3420201539993286));h=C(C(e-b)-n);z[a+32>>2]=g+h;d=C(C(f-d)+i);b=C(C(b+e)-c);z[a+24>>2]=d+b;z[a+8>>2]=d-b;z[a>>2]=g-h}function xN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{f=kb-16|0;kb=f;e=Mb(a);d=Pi(b);v[f+8>>2]=d;g=hr(b);a=0;b:{while(1){c:{if(!Pb(d,g)){if(!a){break c}v[23588]=0;R(49,e|0,65533);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break b}b=w[d|0];d:{e:{if(!a){if(!(b&128)){a=0;v[23588]=0;R(49,e|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}break b}if((b&224)==192){c=b&31;a=1;break d}if((b&240)==224){c=b&15;a=2;break d}c=65533;if((b&248)!=240){break e}c=b&7;a=3;break d}if((b&192)!=128){c=0;v[23588]=0;R(49,e|0,65533);d=v[23588];v[23588]=0;a=0;if((d|0)==1){break b}}c=b&63|c<<6;a=a-1|0;if(a){break d}}a=0;v[23588]=0;R(49,e|0,c|0);b=v[23588];v[23588]=0;c=0;if((b|0)==1){break b}}d=v[He(f+8|0)>>2];continue}break}kb=f+16|0;break a}a=P()|0;O()|0;Gc(e);T(a|0);L()}}function Wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-16|0;kb=e;t[e+15|0]=0;u[e+12>>1]=0;j=8;n=B(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){u[e+10>>1]=0;qS(a,e+15|0,e+12|0,j,e+10|0);i=x[e+10>>1];f=x[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!of(a,e+9|0)){break c}f=w[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}u[e+12>>1]=f;break b}k=k+1|0;continue a}u[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;t[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;u[e+10>>1]=l;u[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}kb=e+16|0}function V_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-16|0;kb=k;a:{if(a){a=_F(c);b:{if(b){Sk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rk(k,a);break b}Mr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Wi(i,k);Gc(k);l=e,m=aj(a),v[l>>2]=m;l=f,m=bj(a),v[l>>2]=m;ch(k,a);Bc(g,k);zb(k);Ph(k,a);Wi(h,k);Gc(k);a=Qk(a);break a}a=ZF(c);c:{if(b){Sk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rk(k,a);break c}Mr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Wi(i,k);Gc(k);l=e,m=aj(a),v[l>>2]=m;l=f,m=bj(a),v[l>>2]=m;ch(k,a);Bc(g,k);zb(k);Ph(k,a);Wi(h,k);Gc(k);a=Qk(a)}v[j>>2]=a;kb=k+16|0}function TX(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb-192|0;kb=c;b=c+16|0;pi(b,a);v[23588]=0;R(88,c+32|0,b|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23588]=0;a=Q(89,c+48|0,c+32|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}zb(c+32|0);zb(c+16|0);b=v[v[a>>2]-12>>2];v[23588]=0;d=ga(62)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}v[23588]=0;U(63,c+8|0,a+b|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}ac(c+8|0);b=a+v[v[a>>2]-12>>2]|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;v[23588]=0;b=Q(95,a|0,c+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}a=_k(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=v[c+32>>2];sf(b);kb=c+192|0;a=a?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;zb(c+32|0)}zb(c+16|0);break b}b=P()|0;O()|0;sf(a)}T(b|0);L()}return a|0}function Z_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-16|0;kb=k;a:{if(a){a=bG(c);b:{if(b){Sk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rk(k,a);break b}Mr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Bc(i,k);zb(k);l=e,m=aj(a),t[l|0]=m;l=f,m=bj(a),t[l|0]=m;ch(k,a);Bc(g,k);zb(k);Ph(k,a);Bc(h,k);zb(k);a=Qk(a);break a}a=aG(c);c:{if(b){Sk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rk(k,a);break c}Mr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Bc(i,k);zb(k);l=e,m=aj(a),t[l|0]=m;l=f,m=bj(a),t[l|0]=m;ch(k,a);Bc(g,k);zb(k);Ph(k,a);Bc(h,k);zb(k);a=Qk(a)}v[j>>2]=a;kb=k+16|0}function dp(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-32|0;kb=d;v[d+28>>2]=0;a:{b:{c:{if(Qd(w[gm(d+24|0,a,0)|0])){f=d+16|0;gd(f,v[v[a>>2]-12>>2]+a|0);v[23588]=0;f=S(1097,f|0)|0;e=v[23588];v[23588]=0;d:{e:{if((e|0)==1){break e}e=Sm(d+8|0,a);g=Hc(d);h=v[v[a>>2]-12>>2];g=v[g>>2];e=v[e>>2];v[23588]=0;ma(c|0,f|0,e|0,g|0,a+h|0,d+28|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break e}ac(d+16|0);break d}b=V(0)|0;O()|0;ac(d+16|0);_(b|0)|0;b=v[d+28>>2]|1;v[d+28>>2]=b;em(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break c}T(a|0);L()}$()}Li(v[v[a>>2]-12>>2]+a|0,v[d+28>>2])}kb=d+32|0;break a}V(0)|0;O()|0;Vb()}L()}return a}function ZR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=t[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=B(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=t[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=w[e+45|0];if(w[e+44|0]|c>>>0>64){break a}b=Ib(w[e+42|0]|w[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=w[a+470|0];if(d>>>0>128){break a}b=w[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=dA(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Lr(w[a|0],w[c|0])?c:a;continue}}a=w[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function Ey(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}f=v[a+480180>>2];d=f&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=v[a+480208>>2]&4096;if(!d){break h}if(!a){break b}a=0-(d>>>2|0)|0;break d}a=v[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(f&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}Db(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break d}a=(a|0)/4<<24>>24}c=a;if(!c){break b}}a=v[b+692>>2];u[b+784>>1]=0;g=b,h=Yb(a+c|0,0,256),v[g+692>>2]=h}kb=e+16|0}function aq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=kb-16|0;kb=h;f=v[a>>2];e=v[a+4>>2];i=$d(f,e)-1|0;while(1){a:{b:{if($d(f,e)-1>>>0<=g>>>0){g=i;break b}if(x[Pc(f,e,g)>>1]<(b|0)){break a}e=v[a+4>>2];f=v[a>>2]}i=x[Pc(f,e,g)>>1];f=0;v[h+12>>2]=0;c:{if((b|0)>=(i|0)){j=h,k=(w[Pc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break c}e=0;if(g){e=g-1|0;f=(w[Pc(v[a>>2],v[a+4>>2],e)+2|0]<<16)/(d|0)|0;v[h+12>>2]=f;e=x[Pc(v[a>>2],v[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=i>>>0){break c}a=((w[Pc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0)-f|0;d=a;g=a>>31;a=b-e|0;b=Oka(d,g,a,a>>31);a=i-e|0;j=h,k=Ic(Pka(b,nb,a,a>>31),nb)+f|0,v[j+12>>2]=k}pe(h+12|0,0,65536);kb=h+16|0;return(B(v[h+12>>2],c)+32768|0)/65536|0}g=g+1|0;e=v[a+4>>2];f=v[a>>2];continue}}function Qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-48|0;kb=e;g=Mc(b);d=Hb(b);i=Mc(c);h=Hb(c);d=d+g|0;f=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(Dp(i,h,w[d|0])){continue}break}f=d-g|0}b:{c:{if((f|0)!=-1){k=e,l=ie(b),v[k+16>>2]=l;k=e,l=Gp(e+16|0,f),v[k+24>>2]=l;k=e,l=Gp(e+24|0,1),v[k+32>>2]=l;c=mj(e+40|0,e+32|0);k=e,l=zh(b),v[k>>2]=l;d=mj(e+8|0,e);OL(b,v[c>>2],v[d>>2]);break c}if(!Hb(b)){break c}g=Mc(b);d=Hb(b);i=Mc(c);h=Hb(c);if(!d|!h){c=-1}else{c=g;f=d+c|0;h=h+i|0;while(1){d:{d=i;e:{if((c|0)!=(f|0)){while(1){if((d|0)==(h|0)){break e}j=t[d|0];d=d+1|0;if(!pc(t[c|0],j)){continue}break}}else{c=f}break d}c=c+1|0;continue}break}c=(c|0)==(f|0)?-1:c-g|0}if(c){break c}Mb(a);break b}ad(a,b)}kb=e+48|0}function Ap(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;g=-1077}b=b+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function yC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;e=v[b>>2];d=Rc(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=kb-32|0;kb=i;d=c-d|0;f=v[Gb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=kb-16|0;kb=f;e=$h(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){lc(e);kb=f+16|0}else{Go(d);d=d+2|0;v[e+4>>2]=d;continue}break}break b}f=Gb(b);e=Nj(i+8|0,Oj(b,Rc(v[b>>2],e)+d|0),Rc(v[b>>2],v[b+4>>2]),f);h=kb-16|0;kb=h;d=Oo(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){Go(f);f=v[d>>2]+2|0;v[d>>2]=f;continue}break}Ud(d);kb=h+16|0;Ed(b,e);Oi(e)}kb=i+32|0;break a}if(c>>>0<d>>>0){Od(b,e+(c<<1)|0)}}c=Qb(v[a>>2],v[a+8>>2],c<<1);if(c){d=v[b>>2];gc(g+8|0,d,Rc(d,v[b+4>>2])<<1);ud(g,a,v[g+8>>2],v[g+12>>2])}kb=g+16|0;return c|0}function el(a,b,c){var d=0,e=0,f=0,g=0;e=kb-48|0;kb=e;d=v[a+24>>2];g=v[d+24620>>2];a:{if(!((g|0)==(b|0)&v[d+24624>>2]==(c|0))){f=e+8|0;uc(f,d+24604|0,40);v[e+28>>2]=c;v[e+24>>2]=b;c=v[e+44>>2];Cs(f,v[e+40>>2]);co(f,c);ry(d,f);if((b|0)==(g|0)){break a}c=v[a+24>>2]+906300|0;d=fk(c);while(1){if((c|0)!=(d|0)){b=v[c>>2];b:{if(!b){break b}if(!(ob[v[v[b>>2]+120>>2]](b)|0)){break b}ob[v[v[b>>2]+112>>2]](b,0);ob[v[v[b>>2]+100>>2]](b);ob[v[v[b>>2]+128>>2]](b)}c=c+160|0;continue}break}c=v[a+24>>2]+906300|0;d=fk(c);while(1){if((c|0)!=(d|0)){b=v[c>>2];c:{if(!b){break c}if(ob[v[v[b>>2]+120>>2]](b)|0){break c}ob[v[v[b>>2]+112>>2]](b,1);ob[v[v[b>>2]+124>>2]](b)}c=c+160|0;continue}break}break a}if(w[a+29|0]){break a}vM(d,1)}t[a+29|0]=1;kb=e+48|0}function pca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=kb-48|0;kb=g;h=a+8|0;c=v[a+8>>2];j=Cc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;d=v[a+4>>2];e=v[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Qi(d,c,a+d|0);v[h>>2]=c;v[i>>2]=a+v[i>>2];break a}v[g+24>>2]=c-e>>1;v[g+44>>2]=1;d=g+24|0;c=v[Zc(d,g+44|0)>>2];c=Vf(d,c,c>>>2|0,v[a+16>>2]);e=fc(g+16|0,v[a+4>>2]);f=v[fc(g+8|0,v[a+8>>2])>>2];d=kb-32|0;kb=d;e=v[e>>2];v[d+24>>2]=e;e=Wm(d+8|0,c+8|0,cu(f,e));f=v[e>>2];while(1){if(v[e+4>>2]!=(f|0)){k=f;f=v[d+24>>2];Im(k,x[f>>1]|x[f+2>>1]<<16);f=v[e>>2]+4|0;v[e>>2]=f;Le(d+24|0);continue}break}Ud(e);kb=d+32|0;qc(a,c);qc(i,c+4|0);qc(h,c+8|0);qc(j,Cc(c));Uf(c);c=v[a+8>>2]}Im(c,x[b>>1]|x[b+2>>1]<<16);v[h>>2]=v[h>>2]+4;kb=g+48|0}function Vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-16|0;kb=e;t[e+15|0]=0;u[e+12>>1]=0;n=B(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){t[e+11|0]=0;pS(a,e+15|0,e+12|0,e+11|0);i=w[e+11|0];f=x[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!of(a,e+10|0)){break c}f=w[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}u[e+12>>1]=f;break b}k=k+1|0;continue a}u[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;t[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;t[e+11|0]=l;t[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}kb=e+16|0}function C3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-80|0;kb=d;a=v[a+4>>2];Wv(d+16|0,b);v[23588]=0;b=Q(1,d|0,17734)|0;e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[23588]=0;U(2,d+32|0,d+16|0,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break h}v[23588]=0;U(477,d+48|0,d+32|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break g}v[23588]=0;R(1015,d- -64|0,d+48|0);c=v[23588];v[23588]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[23588]=0;R(c|0,a|0,d- -64|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}zb(d- -64|0);Ab(d+48|0);Ab(d+32|0);Ab(b);Ab(d+16|0);kb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;zb(d- -64|0)}Ab(d+48|0)}Ab(d+32|0)}Ab(b)}Ab(d+16|0);T(a|0);L()}function zE(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=kb-32|0;kb=h;f=pf(h+16|0,1,0);a:{b:{while(1){j=h+8|0;e=Ac(f);g=e;i=Hb(f)+e|0;e=w[b|0];c:{if((c|0)==10){cK(j,g,i,e);break c}k=c>>>0>e>>>0?1:B(c,c)>>>0>e>>>0?2:3;if((k|0)>(i-g|0)){v[j+4>>2]=61;v[j>>2]=i;break c}i=g+k|0;g=i;while(1){k=e&255;e=(k|0)/(c|0)|0;g=g-1|0;t[g|0]=w[(k-B(c,e)|0)+4898|0];if(e&255){continue}break}v[j+4>>2]=0;v[j>>2]=i}if(!v[h+12>>2]){break b}e=dh(Hb(f));v[23588]=0;R(59,f|0,e|0);e=v[23588];v[23588]=0;if((e|0)!=1){continue}break}break a}b=v[h+8>>2];c=Ac(f);v[23588]=0;R(60,f|0,b-c|0);b=v[23588];v[23588]=0;d:{if((b|0)!=1){v[23588]=0;R(d|0,a|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){break d}break a}break a}zb(f);kb=h+32|0;return}a=P()|0;O()|0;zb(f);T(a|0);L()}function LM(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:Jp(a,C(1));ek(a,C(3.725290298461914e-9));Ip(a,C(268435456));Hp(a,0);break b;case 1:Jp(a,C(32));ek(a,C(4.656612873077393e-10));Ip(a,C(2147483648));Hp(a,0);break b;case 2:Jp(a,C(2));ek(a,C(7.450580596923828e-9));Ip(a,C(134217728));Hp(a,1);break b;default:Jp(a,C(1));ek(a,C(7.450580596923828e-9));Ip(a,C(134217728));Hp(a,1);jy(a,0);iy(a,1);hy(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}Jp(a,C(.75));ek(a,C(7.450580596923828e-9));Ip(a,C(134217728));Hp(a,1);jy(a,0);b=(b|0)==4;iy(a,b?2:3);hy(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}jy(a,1);iy(a,0);hy(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function eS(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=v[b>>2];while(1){if((i|0)==128){vg(b,c);c=v[a+8>>2];d=c+d|0;i=x[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(Wg(v[a>>2])&-2)){break c}dd(a,c+(f<<10)|0);if(!iA(a,16,1)){break b}u[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((Wg(v[a>>2])|0)!=(d+B(f,i)|0)){break a}}dd(a,c+B(f,x[e>>1])|0);h=iA(a,64,1)?h:k}dd(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(B(c,x[e>>1])<<8)|0)==(Wg(v[a>>2])|0)){break d}}if(c>>>0>=255){hA(b,254,65534);hA(b,255,65535)}l=h}a=l&65535}else{j=x[dc(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function Wn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=kb-16|0;kb=g;if(e){v[e>>2]=0}a:{h=v[a+484344>>2];if(!ye(h,v[a+484348>>2],b)){break a}i=Zb(h,b);k=v[i+48>>2];b=jd(v[i>>2],v[k+12>>2],c,d);f=w[b+5|0];b:{c:{d:{e:{j=w[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}v[g+12>>2]=1;h=0;if((j|0)!=17){break b}h=v[a+480180>>2]==4;break b}v[g+12>>2]=2;h=0}v[g+8>>2]=v[i+12>>2]+(c^-1);d=0;c=v[Kb(g+8|0,g+12|0)>>2];a=c;while(1){f:{if(a){b=B(Qg(v[k+12>>2]),6)+b|0;if(w[b+3|0]==34){break f}c=d}f=(j-37&255)>>>0<254?f:c?f:f<<8;if(!e){break a}v[e>>2]=c;break a}i=f<<8;f=w[b+5|0]|(h?f>>>0<256?i+-8192|0:i:i);d=d+1|0;a=a-1|0;continue}}kb=g+16|0;return f}function OH(a,b,c,d){a:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 6:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 8:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 9:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 16:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 17:ob[d|0](a,c);default:return;case 1:case 4:case 14:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function Cea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb+-64|0;kb=c;a:{d=v[a+4>>2];b:{if(d>>>0<b>>>0){f=fe(c+56|0);e=b-d|0;g=Dt(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){Dm(c+40|0,v[a>>2],d);hc(f,v[c+40>>2],v[c+44>>2]);v[a+4>>2]=v[a+4>>2]+e;break c}d=ho(c+40|0);v[23588]=0;b=Q(728,a|0,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}v[23588]=0;R(729,d|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[d+4>>2]=v[a+4>>2]+e;vl(c+24|0,v[a>>2]);Dm(c+16|0,v[a>>2],v[a+4>>2]);vl(c+8|0,v[d>>2]);oR(c+32|0,v[c+24>>2],v[c+28>>2],v[c+16>>2],v[c+20>>2],v[c+8>>2],v[c+12>>2]);hc(f,v[c+32>>2],v[c+36>>2]);Mt(a,d);We(d)}a=hc(c,v[f>>2],v[f+4>>2]);qv(v[a>>2],v[a+4>>2],e,0);break b}v[a+4>>2]=b}kb=c- -64|0;return}a=P()|0;O()|0;We(d);T(a|0);L()}function nL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=kb-80|0;kb=c;d=v[b>>2];e=v[b+4>>2];b=fe(c+48|0);b=qr(c+56|0,d,e,v[b>>2],v[b+4>>2]);v[23588]=0;d=S(202,b|0)|0;e=v[23588];v[23588]=0;a:{if((e|0)==1){break a}v[23588]=0;d=W(905,b|0,c+8|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Sb(c+8|0,17588,4)|v[c+12>>2]){break b}f=a,g=Yd(z[c+16>>2],C(0)),z[f+4220>>2]=g;f=a,g=Yd(z[c+20>>2],C(0)),z[f+4224>>2]=g;f=a,g=Yd(z[c+24>>2],C(0)),z[f+4228>>2]=g;d=v[c+28>>2];if(d>>>0<=5){v[a+4232>>2]=d}v[a+4236>>2]=v[c+32>>2];t[a+4240|0]=w[c+36|0]!=0;t[a+4241|0]=w[c+37|0]!=0;t[a+4242|0]=w[c+38|0]!=0;t[a+4243|0]=w[c+39|0]!=0;t[a+4244|0]=w[c+40|0]!=0;Ts(a)}Bb(b);kb=c+80|0;return}a=P()|0;O()|0;Bb(b);T(a|0);L()}function Nea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;e=v[b>>2];d=rg(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=kb-32|0;kb=i;d=c-d|0;f=v[Gb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=kb-16|0;kb=f;e=Lz(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){lc(e);kb=f+16|0}else{bQ(d);d=d+32|0;v[e+4>>2]=d;continue}break}break b}f=Gb(b);e=Et(i+8|0,dq(b,rg(v[b>>2],e)+d|0),rg(v[b>>2],v[b+4>>2]),f);h=kb-16|0;kb=h;d=cQ(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){bQ(f);f=v[d>>2]+32|0;v[d>>2]=f;continue}break}Ud(d);kb=h+16|0;Ed(b,e);dQ(e)}kb=i+32|0;break a}if(c>>>0<d>>>0){Od(b,e+(c<<5)|0)}}if(Qb(v[a>>2],v[a+8>>2],c<<5)){c=v[b>>2];gc(g+8|0,c,rg(c,v[b+4>>2])<<5);ud(g,a,v[g+8>>2],v[g+12>>2])}kb=g+16|0}function I6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=kb-48|0;kb=f;v[f+40>>2]=d;d=eg(a,f+40|0);g=Hc(d+4|0);h=Hc(d+24|0);i=Hc(d+32|0);j=Tb(d+36|0);v[d+56>>2]=3;k=Tb(d+68|0);v[23588]=0;R(947,d|0,e|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{if((a|0)!=1){gc(f+8|0,b,c);a=fe(f);b=v[a+4>>2];c=v[a>>2];v[23588]=0;Ia(951,f+16|0,v[f+8>>2],v[f+12>>2],c|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}v[23588]=0;U(948,d|0,f+16|0,e|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Bb(f+16|0);v[23588]=0;Y(949,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){break a}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bb(f+16|0)}Xe(k);Xf(j);Bs(i);kj(h);jj(g);Ee(d);Ee(f+40|0);T(e|0);L()}Ee(f+40|0);kb=f+48|0;return d|0}function SX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=kb-16|0;kb=h;f=pd(b);d=zd(v[b+4>>2],w[b+11|0]);i=pd(c);g=zd(v[c+4>>2],w[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(ou(i,g,w[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=fc(h+8|0,Rf(Rf(Pi(b),e),1));d=fc(h,hr(b));oD(b,v[c>>2],v[d>>2]);break c}if(!Gk(v[b+4>>2],w[b+11|0])){break c}f=pd(b);d=zd(v[b+4>>2],w[b+11|0]);i=pd(c);g=zd(v[c+4>>2],w[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=w[d|0];d=d+1|0;if(!pc(w[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Mb(a);break b}ad(a,b)}kb=h+16|0}function R6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=kb-48|0;kb=b;c=Mb(b+32|0);v[23588]=0;Y(940,b+16|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=Fb(v[b+16>>2]),v[f+8>>2]=g;d=1;while(1){e=Fb(v[b+20>>2]);a=v[b+8>>2];if(!Pb(a,e)){a=gg(Mc(c));Xe(b+16|0);zb(c);break b}if(!d){v[23588]=0;Q(941,c|0,14575)|0;a=v[23588];v[23588]=0;if((a|0)==1){break d}a=v[b+8>>2]}v[23588]=0;Q(800,c|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break d}mq(b+8|0);d=0;continue}}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Xe(b+16|0)}zb(c);_(a|0)|0;a=0;v[23588]=0;X(939,6988,0,0,0);c=v[23588];v[23588]=0;if((c|0)==1){break a}$()}kb=b+48|0;return a|0}b=P()|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){V(0)|0;O()|0;Vb();L()}T(b|0);L()}function laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=kb-32|0;kb=f;c=Qg(v[v[a+48>>2]+12>>2]);a:{if(!b){break a}c=B(b,c);b:{if(v[a+12>>2]!=(b|0)){break b}if((qk(v[a>>2],v[a+4>>2])|0)!=(c|0)){break b}b=kb-16|0;kb=b;d=Fb(v[a>>2]);a=Fb(v[a+4>>2]);Fj(b+8|0);e=Zs(a,d);c=kb-16|0;kb=c;v[c+8>>2]=d;while(1){if((e|0)>0){a=v[c+8>>2];d=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8;t[a+4|0]=d;t[a+5|0]=d>>>8;e=e-1|0;Ck(c+8|0);continue}break}kb=c+16|0;kb=b+16|0;break a}e=f+8|0;Fj(e);c=yT(f+16|0,c,e);XL(a);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];e=Gb(c);g=Gb(a),h=v[e>>2],v[g>>2]=h;v[e>>2]=0;v[c>>2]=0;v[c+4>>2]=0;vk(c);v[a+12>>2]=b}kb=f+32|0}function VG(a,b,c,d,e,f){var g=0;g=kb-80|0;kb=g;a:{if((f|0)>=16384){Jd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Jd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Jd(g- -64|0,b,c,d,e,0,0,0,7471104);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Jd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)>-48920?f:-48920)+32538|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Jd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;kb=g+80|0}function ti(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=44312;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=Tb(a+44|0);g=Tb(b+12|0);e=Tb(b+24|0);f=Tb(b+36|0);v[23588]=0;R(897,b|0,0);d=v[23588];v[23588]=0;if((d|0)==1){a=P()|0;O()|0;wc(f);wc(e);Rs(g);Rs(b);T(a|0);L()}u[a+4204>>1]=0;v[a+4196>>2]=1065353216;v[a+4200>>2]=0;d=v[a+16>>2];v[d+946300>>2]=v[d+946300>>2]+1;v[v[a+20>>2]>>2]=a;v[23588]=0;e=S(898,a+92|0)|0;d=v[23588];v[23588]=0;a:{if((d|0)!=1){f=a+4200|0;v[c>>2]=e;c=v[a+16>>2]+906300|0;d=w[a+4200|0];b=v[a+20>>2];while(1){if((Md(c,d)|0)==(b|0)|d>>>0>248){break a}d=d+1|0;t[f|0]=d;continue}}a=P()|0;O()|0;lL(b);T(a|0);L()}return a}function ax(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;g=(p(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;A[b>>3]=d;g=d<-.7853981852531433;if(D(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,i-(c<<23)|0),q());c=TH(e+8|0,e,c,1,0);d=A[e>>3];if((g|0)<0){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}kb=e+16|0;return c}function Kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=kb-16|0;kb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){e=v[b+8>>2];o=e>>>18|0;p=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){h=(e<<1)+p|0;i=u[h>>1];v[(e<<2)+b>>2]=i+((B(u[h+4>>1]-i|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Rb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;kb=b+16|0}function _0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=v[b+44>>2];i=v[b+24>>2];if(h>>>0<i>>>0){v[b+44>>2]=i;h=i}l=-1;m=-1;n=f&24;a:{if(!n|(e|0)==1&(n|0)==24){break a}if(h){g=h-Ac(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=i-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=o;k=g}d=d+k|0;c=c+j|0;d=j>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>o>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!i){break a}}if(d){d=v[b+8>>2];Bn(b,d,d+e|0,h)}if(f&16){Pw(b,v[b+20>>2],v[b+28>>2]);cs(b,e)}l=e;m=c}Yg(a,l,m)}function XE(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0;g=kb-80|0;kb=g;qy(v[a+24>>2]);t[v[a+24>>2]+1298420|0]=v[a+52>>2]!=0;v[g+40>>2]=b;v[g+36>>2]=c;v[g+32>>2]=d;i=z[a+48>>2];j=v[a+32>>2];v[g+8>>2]=b;c=v[g+36>>2];v[g>>2]=v[g+32>>2];v[g+4>>2]=c;d=kb-16|0;kb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;c=wJ(g+48|0);v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=f;f=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=f;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=i;v[c>>2]=e;kb=d+16|0;while(1){if(b){d=v[a+24>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;d=zJ(d,v[Zq(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|h)){a=v[a+24>>2];v[a+480208>>2]=v[a+480208>>2]&-513}kb=g+80|0;return h}function WR(a,b){var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(!Qb(v[a>>2],v[a+8>>2],1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){if(a){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}fA(c+8|0,b);ud(c+16|0,a,v[c+8>>2],v[c+12>>2])}kb=c+32|0}function zn(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0,n=0;l=kb-16|0;kb=l;t[l+15|0]=a;a:{b:{c:{k=v[d>>2];if((k|0)!=(c|0)){break c}m=43;n=a&255;if((n|0)!=w[j+24|0]){m=45;if(w[j+25|0]!=(n|0)){break c}}v[d>>2]=c+1;t[c|0]=m;break b}if(!(!Hb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=xi(j,j+26|0,l+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[f+82976|0];break a}v[d>>2]=k+1;t[k|0]=w[f+82976|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}kb=l+16|0;return a}function JI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;a:{b:{c:{d:{e:{if((b|0)>=0){g=a;a=v[a+32>>2];if((Qg(a)|0)>(b|0)){break e}}a=ba(8)|0;v[23588]=0;b=Q(55,f|0,10656)|0;c=v[23588];v[23588]=0;if((c|0)==1){break d}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}d=(a+(b<<5)|0)+480280|0;c=c?134218752:0;v[d>>2]=c|v[d>>2]&-134218753;d=(a+B(b,872)|0)+1075080|0;v[d>>2]=c|v[d>>2]&-134218753;a=x[a+480188>>1];d=a>>>0>256?a:256;b=b+1|0;g=v[g+32>>2];while(1){if((a|0)==(d|0)){break a}e=g+B(a,872)|0;if((b|0)==x[e+1075778>>1]){e=e+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;continue}}c=P()|0;O()|0;ca(a|0)}T(c|0)}L()}kb=f+16|0}function Lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=kb-16|0;kb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){e=v[b+8>>2];o=e>>>10&4194048;p=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){h=e+p|0;i=t[h|0];v[(e<<2)+b>>2]=((B(t[h+2|0]-i|0,o)|0)/16384|0)+(i<<8);e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Rb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;kb=b+16|0}function ica(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;h=rf(a,c);ne(e,v[a+36>>2]);i=a;a:{if(!h){Sc(e,a+32|0,5);c=0;if(Cb(v[v[e>>2]>>2],v[e+4>>2])){break a}}f=v[a+36>>2];a=kb-16|0;kb=a;v[a+12>>2]=0;zG(f,a+12|0,1);c=v[a+12>>2];d=c>>>2&3;t[a+11|0]=d;if(d){t[a+4|0]=3;d=w[Xb(a+4|0,a+11|0)|0];t[a+4|0]=0;t[a|0]=0;t[a+10|0]=0;b:{if(!d){break b}ii(f,a+4|0);if((d|0)==1){break b}ii(f,a);if(d>>>0<3){break b}ii(f,a+10|0);g=w[a+10|0]<<24}c=c&255|w[a+4|0]<<8|w[a|0]<<16|g;v[a+12>>2]=c}d=c>>>4|0;v[a+4>>2]=d;v[a>>2]=1e6;Ix(b,v[Kb(a+4|0,a)>>2]);c=0;while(1){g=Hb(b);if(g>>>0<=c>>>0){if((d|0)!=(g|0)){bm(f,d-g|0)}kb=a+16|0}else{Vk(f,Tc(b,c),1);c=c+1|0;continue}break}c=h}Ye(i,c);kb=e+16|0}function yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=u[e+39718>>1];n=u[e+39716>>1];o=u[e+39714>>1];p=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;v[(e<<2)+b>>2]=(((B(u[f>>1],o)+B(u[f-4>>1],p)|0)+B(u[f+4>>1],n)|0)+B(u[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;kb=b+16|0}function xh(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=0;f=GK(a);h=a+4208|0;c=C(C(z[Eb(h,4)>>2]*C(1.899999976158142))+C(.10000000149011612));g=z[a+4268>>2];d=ue(C(10),C(C(C(C(C(v[((b<<2)+a|0)+4292>>2])/g)*C(-60))/C(C(z[Eb(h,3)>>2]*C(19.899999618530273))+C(.10000000149011612)))/C(20)));c=C(C(ue(d,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-Cp(c>C(1)?C(3.1415927410125732):C(f*C(C(6.2831854820251465)/g)))));a:{if(c==C(0)){break a}if(!qm(c)){break a}g=C(c+c);f=C(C(-2)-g);c=C(C(f*f)+C(C(c*c)*C(-4)));if(c>C(0)){e=C(K(c))}c=C(C(e-f)/g);if(C(D(c))>C(1)){c=C(C(C(-f)-e)/g)}e=Kf(c)}b=(b<<3)+a|0;z[b+4404>>2]=e;z[b+4400>>2]=d;c=z[a+4272>>2];c=C(c*c);e=C(C(1)-c);d=C(d*d);return C(C(C(e*C(d/C(C(1)-C(c*d))))*e)+c)}function Hfa(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb-192|0;kb=c;b=c+16|0;pi(b,a);v[23588]=0;R(88,c+32|0,b|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23588]=0;a=Q(89,c+48|0,c+32|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}zb(c+32|0);zb(c+16|0);b=v[v[a>>2]-12>>2];v[23588]=0;d=ga(62)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}v[23588]=0;U(63,c+8|0,a+b|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}ac(c+8|0);v[23588]=0;b=Q(90,a|0,c+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}a=_k(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>1];sf(b);kb=c+192|0;a=(a?0:d)&65535;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;zb(c+32|0)}zb(c+16|0);break b}b=P()|0;O()|0;sf(a)}T(b|0);L()}return a|0}function zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-32|0;kb=d;nd(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;e=d+16|0;i=c,j=w[Xb(e,d)|0]<<2,u[i+30>>1]=j;v[c+24>>2]=(w[b+14|0]|w[b+15|0]<<8)<<1;uk(d,2,b+1|0);Fc(e,d);Ce(c+43|0,e);zb(e);e=_c(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}g=w[b+22|0]|w[b+23|0]<<8|(w[b+24|0]<<16|w[b+25|0]<<24);v[c>>2]=g;f=w[b+26|0]|w[b+27|0]<<8|(w[b+28|0]<<16|w[b+29|0]<<24);v[c+4>>2]=f;a=w[b+30|0]|w[b+31|0]<<8|(w[b+32|0]<<16|w[b+33|0]<<24);h=a-(a>>>0>f>>>0)|0;v[c+8>>2]=h;a=w[b|0];if(a&4){u[c+34>>1]=x[c+34>>1]|2;a=w[b|0]}if(a&8){u[c+34>>1]=x[c+34>>1]|4;a=w[b|0]}if(!(a&16)){break a}xd(e,16);dg(e,9);v[c+8>>2]=h>>>1;v[c+4>>2]=f>>>1;v[c>>2]=g>>>1}kb=d+32|0}function oA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-16|0;kb=e;d=w[a|0];if(d&1){t[b+12|0]=w[b+12|0]|1;d=w[a|0]}if(d&2){t[b+12|0]=w[b+12|0]|4;d=w[a|0]}if(d&4){t[b+12|0]=w[b+12|0]|2;d=w[a|0]}if(d&16){t[b+12|0]=w[b+12|0]|16;d=w[a|0]}if(d&32){t[b+12|0]=w[b+12|0]|8}t[e+15|0]=w[a+1|0];t[e+14|0]=25;Rg(b,w[Xb(e+15|0,e+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];g=v[b>>2];i=$d(g,v[b+4>>2]);b=0;while(1){if((b|0)!=(i|0)){h=Eb(g,b);f=(b<<2)+a|0;d=w[f+6|0]|w[f+7|0]<<8;u[h>>1]=d;a:{if(!b){break a}j=d;d=x[Eb(g,b-1|0)>>1];if(j>>>0>=d>>>0){break a}u[h>>1]=d+1}k=h,l=Yb((w[f+8|0]|w[f+9|0]<<8)<<16>>16>>c,0,64),t[k+2|0]=l;b=b+1|0;continue}break}kb=e+16|0}function OG(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=Fw(13815);if(w[b|0]?b:0){break a}b=Fw(B(a,12)+79584|0);if(w[b|0]?b:0){break a}b=Fw(14099);if(w[b|0]?b:0){break a}b=14715}b:{while(1){d=w[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14715;c:{d:{c=w[b|0];e:{f:{if(!(w[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!w[e+1|0]){break e}}if(!wi(e,14715)){break e}if(wi(e,13432)){break d}}if(!a){c=79656;if(w[e+1|0]==46){break c}}return 0}c=v[117003];if(c){while(1){if(!wi(e,c+8|0)){break c}c=v[c+32>>2];if(c){continue}break}}c=Pd(36);if(c){v[c+4>>2]=20;v[c>>2]=79552;b=c+8|0;uc(b,e,d);t[b+d|0]=0;v[c+32>>2]=v[117003];v[117003]=c}c=a|c?c:79656}return c}function Dga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=kb-528|0;kb=b;e=-1;a:{if(!fg(a,1468)){break a}xl(a,1464);c=b+524|0;mS(a,c);if(!oe(c,26889)){e=0;if(!oe(b+524|0,15497)){break a}}xl(a,20);c=1;while(1){if((c&65535)>>>0<=31){if(jS(a,b)){c=c+1|0;d=mA(b)+d|0;continue}else{e=-1;break a}}break}e=0;if(d>>>0>40){break a}d=b+520|0;c=kb-16|0;kb=c;b:{if(!fg(a,2)){t[c|0]=0;qC(d,c);break b}Xm(c+8|0,d);lA(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0;if(w[b+520|0]>128){break a}d=Oc(b+520|0);c=kb-16|0;kb=c;c:{if(!fg(a,512)){VR(b);break c}Mu(c+8|0,b);lA(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0;c=0;e=1;a=w[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=w[d|0]){continue}break}e=0}kb=b+528|0;return e|0}function Yj(a,b){var c=0,d=0,e=0,f=0;c=kb+-64|0;kb=c;d=v[v[a>>2]-12>>2]+a|0;e=v[d+16>>2]&-3;Tl(d,e);a:{b:{if(Qd(w[gm(c+56|0,a,1)|0])){d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;U(108,c+40|0,d|0,c+8|0);b=v[23588];v[23588]=0;c:{if((b|0)!=1){b=jE(c+40|0,Yg(c+24|0,-1,-1))?e|4:e;break c}b=V(0)|0;O()|0;_(b|0)|0;b=e|1;em(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}$()}Li(v[v[a>>2]-12>>2]+a|0,b)}kb=c- -64|0;return a}V(0)|0;O()|0;Vb()}L()}function _da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=kb-16|0;kb=b;i=v[a+16>>2];h=Tf(1,2);e=nb;j=e;Rb(a,h,e);f=v[a+40>>2];g=v[a+36>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){d=d-1|0;o=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+i|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+o>>1];e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Rb(b+8|0,m,n);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;mg(a,h,j);kb=b+16|0}function PX(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb-192|0;kb=c;b=c+16|0;pi(b,a);v[23588]=0;R(88,c+32|0,b|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23588]=0;a=Q(89,c+48|0,c+32|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}zb(c+32|0);zb(c+16|0);b=v[v[a>>2]-12>>2];v[23588]=0;d=ga(62)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}v[23588]=0;U(63,c+8|0,a+b|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}ac(c+8|0);v[23588]=0;b=Q(93,a|0,c+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}a=_k(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=v[c+32>>2];sf(b);kb=c+192|0;a=a?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;zb(c+32|0)}zb(c+16|0);break b}b=P()|0;O()|0;sf(a)}T(b|0);L()}return a|0}function _V(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;nd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Sq(a+4|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=f;c=Sq(a+8|0,a);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=c;t[e+15|0]=127;t[e+14|0]=w[a+15|0];g=b,h=(((w[Xb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[g+30>>1]=h;d=w[a+12|0];if(d>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=d&240}d=(w[a+13|0]|w[a+14|0]<<8)<<1;v[b+24>>2]=d;d=w[a+13|0]|w[a+14|0]<<8?d:16726;v[b+24>>2]=d;g=b,h=(B(Yu(0,w[a+12|0]<<28>>24),d)>>>0)/8363|0,v[g+24>>2]=h;if(c>>>0>f>>>0){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}kb=e+16|0}function sH(a){a=a|0;var b=0,c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[23588]=0;c=Q(1104,d+8|0,a|0)|0;b=v[23588];v[23588]=0;c:{if((b|0)!=1){d:{if(!Qd(w[c|0])){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;b=S(1105,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[23588]=0;Y(1106,a+b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;rH(c);break c}rH(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[23588]=0;Y(17,a+c|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}$()}kb=d+16|0;return a|0}a=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-32|0;kb=d;e=Tb(a);a=0;c=v[b+24>>2];c=ut(v[c+484344>>2],v[c+484348>>2]);v[23588]=0;R(181,e|0,c|0);c=v[23588];v[23588]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=v[b+24>>2];f=v[c+484344>>2];if(ut(f,v[c+484348>>2])>>>0<=a>>>0){break b}v[23588]=0;R(1022,d|0,Zb(f,a)|0);c=v[23588];v[23588]=0;if((c|0)!=1){c=v[b+24>>2];v[23588]=0;U(1009,d+16|0,c|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(183,e|0,d+16|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}a=a+1|0;zb(d+16|0);zb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(d+16|0)}zb(d);break a}kb=d+32|0;return}a=P()|0;O()|0}Xe(e);T(a|0);L()}function a3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-80|0;kb=e;v[e+76>>2]=d;v[e+72>>2]=c;v[23588]=0;c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;c=S(1079,e+8|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){a:{b:{if(c){v[23588]=0;R(1080,e+48|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){d=e+56|0;Dv(d,v[e+48>>2],v[e+52>>2]);b=Dg(e- -64|0,d);c=Dg(e+40|0,e+72|0);break b}break a}v[23588]=0;R(1081,e+48|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}d=e+56|0;Dv(d,v[e+48>>2],v[e+52>>2]);b=Dg(e+32|0,d);c=Dg(e+24|0,e+72|0)}ID(a,v[b>>2],v[b+4>>2],v[c>>2],v[c+4>>2]);me(d);me(e+48|0);me(e+72|0);kb=e+80|0;return}}a=P()|0;O()|0;me(e+72|0);T(a|0);L()}function Ky(a,b,c){var d=0,e=0,f=0,g=0;d=kb+-64|0;kb=d;e=v[a>>2];f=v[e-4>>2];g=v[e-8>>2];v[d+28>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+40>>2]=0;v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+56>>2]=0;e=0;t[d+59|0]=0;t[d+60|0]=0;t[d+61|0]=0;t[d+62|0]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;a=a+g|0;a:{if(_g(f,c,0)){v[d+56>>2]=1;ob[v[v[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=v[d+32>>2]==1?a:0;break a}ob[v[v[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:e=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}e=v[d+24>>2]}kb=d- -64|0;return e}function ph(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=kb+-64|0;kb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=v[a>>2];e=v[a+4>>2];if(ye(d,e,b)){break b}c:{d:{if(yk(d,e)>>>0<=b>>>0){d=_x(f+8|0,a);v[23588]=0;U(201,a|0,b+1|0,d|0);e=v[23588];v[23588]=0;if((e|0)==1){break d}hl(d);d=v[a>>2]}v[23588]=0;R(211,bg(d,b)|0,c|0);c=v[23588];v[23588]=0;e:{if((c|0)!=1){c=bg(v[a>>2],b);v[c+16>>2]=0;v[c+20>>2]=0;c=v[a>>2];v[23588]=0;Y(212,bg(c,b)|0);c=v[23588];v[23588]=0;if((c|0)!=1){break e}}b=V(92948)|0;a=O()|0;break c}a=bg(v[a>>2],b);g=Pb(v[a>>2],v[a+4>>2]);break b}b=V(92948)|0;a=O()|0;hl(d)}if((ea(92948)|0)!=(a|0)){break a}_(b|0)|0;$()}kb=f- -64|0;return g|0}T(b|0);L()}function _fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb+-64|0;kb=c;i=c,j=df(a)>>>5|0,u[i+32>>1]=j;u[c+16>>1]=3999;h=b+480190|0;d=x[Wc(c+32|0,c+16|0)>>1];u[h>>1]=d;g=1;while(1){f=g&65535;if(f>>>0<=d>>>0){d=Hi(b,f);e=c+32|0;Yt(a,e);nd(d,0);Dj(c,2,e);e=c+16|0;Fc(e,c);Dc(((f<<5)+b|0)+946304|0,e);zb(e);v[d+24>>2]=8287;i=c,j=Ib(x[c+60>>1]),u[i+16>>1]=j;u[c>>1]=64;i=d,j=x[Wc(e,c)>>1]<<2,u[i+30>>1]=j;i=d,j=cc(v[c+52>>2])&-2,v[i>>2]=j;e=Ib(x[c+62>>1]);i=Eb(d+68|0,0),j=e,v[i>>2]=j;e=Ib(x[c+56>>1]);f=Ib(x[c+58>>1]);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>y[d>>2]){break a}v[d+16>>2]=f;v[d+12>>2]=e<<1;u[d+34>>1]=x[d+34>>1]|8}g=g+1|0;d=x[h>>1];continue}break}kb=c- -64|0}function zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=u[e+39718>>1];n=u[e+39716>>1];o=u[e+39714>>1];p=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;v[(e<<2)+b>>2]=(((B(t[f|0],o)+B(t[f-2|0],p)|0)+B(t[f+2|0],n)|0)+B(t[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;kb=b+16|0}function ar(a){a=a|0;var b=0,c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[23588]=0;c=Q(13,d+8|0,a|0)|0;b=v[23588];v[23588]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;b=S(22,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[23588]=0;R(16,a+b|0,1);b=v[23588];v[23588]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;zk(c);break c}zk(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[23588]=0;Y(17,a+c|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}$()}kb=d+16|0;return a|0}a=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=kb-16|0;kb=g;nd(b,4);u[b+30>>1]=w[a+12|0]<<2;Ff(b+30|0,256);e=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=e;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=f;c=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);v[b+4>>2]=c;d=(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+c|0;v[b+8>>2]=d;e=w[a+14|0];if(e&16){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;f=f>>>1|0;v[b>>2]=f;e=w[a+14|0]}if(e&32){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;v[b>>2]=f>>>1;e=w[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){u[b+34>>1]=34;u[b+34>>1]=w[a+14|0]&2?38:34}a=Nc(g,21619);Ce(b+43|0,a);zb(a);kb=g+16|0}function jF(a,b,c,d){var e=0,f=0,g=0;f=kb-32|0;kb=f;v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}v[23588]=0;Y(953,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break f}g=v[a+24>>2];v[23588]=0;e=Q(55,f|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break e}v[23588]=0;U(d|0,f+16|0,g|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break d}a=f+16|0;b=gg(Mc(a));zb(a);zb(e);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;zb(e)}_(b|0)|0;b=0;v[23588]=0;X(939,c|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}kb=f+32|0;return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function H1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-32|0;kb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!bx(ib(v[a+60>>2],b|0,i|0,d+12|0)|0)){g=v[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}h=v[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;v[e>>2]=h+v[e>>2];b=(j?12:4)+b|0;v[b>>2]=v[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((i|0)==2){break a}a=c-v[b+4>>2]|0}kb=d+32|0;return a|0}function ML(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=C(0),k=0,l=C(0);g=kb-16|0;kb=g;e=u[d>>1];f=u[d+2>>1];if(!(!x[b>>1]|(e|0)>(f|0)|(!(z[c>>2]>C(0))|(f-e|0)>32766))){u[a>>1]=3;f=a+4|0;Lc(f);u[a+28>>1]=65472;v[g+12>>2]=1065353216;QL(f,g+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Lc(a+16|0);h=u[d>>1];u[a+28>>1]=h;e=kb-16|0;kb=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[Wc(e+14|0,e+12|0)>>1];kb=e+16|0;u[a+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=ue(i,C(C(1)/C(b|0)));dk(f,(u[d+2>>1]-h|0)+1|0);b=v[a+4>>2];c=u[a+28>>1];e=u[d+2>>1];d=u[d>>1];while(1){if((d|0)>(e|0)){Fp(a)}else{j=ue(i,C(d|0));k=Eb(b,d-c|0),l=j,z[k>>2]=l;d=d+1|0;continue}break}h=1}kb=g+16|0;return h|0}function sX(){var a=0,b=0,c=0,d=0;a=_C(v[v[116870]-12>>2]+467480|0,10);c=kb-16|0;kb=c;v[23588]=0;b=Q(13,c+8|0,467480)|0;d=v[23588];v[23588]=0;a:{b:{c:{d:{if((d|0)!=1){e:{if(!w[b|0]){break e}d=Sm(c,467480);v[23588]=0;a=Q(21,d|0,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){if(!$u(a)){break e}a=v[v[116870]-12>>2];v[23588]=0;R(16,a+467480|0,1);a=v[23588];v[23588]=0;if((a|0)!=1){break e}}a=V(0)|0;O()|0;zk(b);break d}zk(b);break c}a=V(0)|0;O()|0}_(a|0)|0;b=v[v[116870]-12>>2];v[23588]=0;Y(17,b+467480|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}$()}kb=c+16|0;break a}c=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(c|0);L()}V(0)|0;O()|0;Vb();L()}ar(467480)}function Zn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}e=v[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(e&69206029){break b}g=d&240;f=d&15;if((f|0)==15){if(g){Yn(a,b,(d&240)>>>4|0,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((g|0)!=240){break b}if(f){Xn(a,b,f,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(!(t[b+851|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&255;d=d&15;d:{if(d){if(a&240?e&16777248:0){break c}c=c-(d<<2)|0;break d}c=(a>>>2&60)+c|0}if((e|0)!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}h=b,i=Yb(c,0,256),v[h+688>>2]=i}function $da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=kb-16|0;kb=b;i=v[a+16>>2];h=Tf(1,2);e=nb;j=e;Rb(a,h,e);f=v[a+40>>2];g=v[a+36>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){d=d-1|0;o=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+i|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+o|0]<<8;e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Rb(b+8|0,m,n);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;mg(a,h,j);kb=b+16|0}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){b=(v[f+12>>2]<<1)+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(u[b+4>>1],u[e+10>>1])+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/2|0)+((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(b,h);v[c+4>>2]=v[c+4>>2]+B(b,g);Rb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;kb=f+16|0}function vH(a){var b=0,c=0,d=0,e=0,f=0;c=kb-192|0;kb=c;b=c+16|0;pi(b,a);v[23588]=0;R(88,c+32|0,b|0);a=v[23588];v[23588]=0;a:{b:{c:{d:{if((a|0)!=1){v[23588]=0;a=Q(89,c+48|0,c+32|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break d}zb(c+32|0);zb(c+16|0);b=v[v[a>>2]-12>>2];v[23588]=0;d=ga(62)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;U(63,c+8|0,a+b|0,d|0);b=v[23588];v[23588]=0;if((b|0)==1){break b}ac(c+8|0);v[23588]=0;b=Q(94,a|0,c+32|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}a=_k(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);f=A[c+32>>3];sf(b);kb=c+192|0;return a?0:f}b=P()|0;O()|0;break c}b=P()|0;O()|0;zb(c+32|0)}zb(c+16|0);break a}b=P()|0;O()|0;sf(a)}T(b|0);L()}function Uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;i=e,j=Aj(b),v[i>>2]=j;d=kb-16|0;kb=d;g=a;c=Td(a);a:{if(c){f=jc(g);while(1){a=c;c=a+13|0;if(Jt(b,c)){f=a;c=v[a>>2];if(c){continue}break a}if(!Jt(c,b)){break a}f=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=jc(g);f=a}v[d+12>>2]=a;b=v[f>>2];if(!b){c=kb-16|0;kb=c;a=jc(g);h=mh(d,tc(20),nh(c+8|0,a));b=v[h>>2];a=v[e>>2];a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+17|0]=0;t[b+13|0]=a;t[b+14|0]=a>>>8;t[b+15|0]=a>>>16;t[b+16|0]=a>>>24;i=jc(h),j=1,t[i+4|0]=j;kb=c+16|0;Kg(g,v[d+12>>2],f,v[d>>2]);b=ce(d);rk(d);h=1}Jg(e+8|0,v[fc(d,b)>>2],h);kb=d+16|0;kb=e+16|0;return v[e+8>>2]+17|0}function uz(a,b,c){var d=0,e=0,f=0,g=0;d=Mb(a);a=Hb(b);v[23588]=0;R(46,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){a:{while(1){if(Hb(b)>>>0>e>>>0){f=v[Ai(b,e)>>2];g=f&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}else{v[23588]=0;R(47,d|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[23588]=0;R(47,d|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}v[23588]=0;R(47,d|0,63);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;zb(d);T(a|0);L()}function _ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-32|0;kb=d;v[d+28>>2]=0;pk(a,d+28|0);a:{b:{i=v[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Mb(d+16|0);v[23588]=0;u[d+14>>1]=0;e=W(483,a|0,g|0,255)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}if(!e){break d}v[23588]=0;R(472,a|0,d+14|0);e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;U(11,d|0,c|0,g|0);e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;e=Q(484,b|0,d+14|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break e}Jb(e,d);Ab(d);zb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;Ab(d);break a}zb(g)}kb=d+32|0;return}f=P()|0;O()|0}zb(g);T(f|0);L()}function Gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-32|0;kb=e;v[e+24>>2]=b;j=e,k=ie(a),v[j+8>>2]=k;f=On(e+24|0,e+8|0);a:{b:{h=Sh(c,d);if(!h){break b}if(!_s(a,c)){b=Hb(a);g=bd(a);c:{if(g-b>>>0>=h>>>0){g=Ac(a);if((b|0)==(f|0)){break c}i=f+g|0;Xh(i+h|0,i,b-f|0);break c}sm(a,g,(b+h|0)-g|0,b,f,0,h);g=v[a>>2]}b=b+h|0;Rh(a,b);t[e+8|0]=0;je(b+g|0,e+8|0);b=f+g|0;while(1){if((c|0)==(d|0)){break b}je(b,c);c=c+1|0;b=b+1|0;continue}}d=Uh(e+8|0,c,d);c=Mc(d);f=Hb(d);v[23588]=0;c=fa(356,a|0,b|0,c|0,c+f|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){zb(d);break a}a=P()|0;O()|0;zb(d);T(a|0);L()}j=e,k=ie(a),v[j+8>>2]=k;c=Gp(e+8|0,f)}kb=e+32|0;return c|0}function u6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)==1){break c}v[23588]=0;Y(953,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}v[23588]=0;Y(953,c|0);f=v[23588];v[23588]=0;d=1;if((f|0)==1){break c}f=v[a+24>>2];b=rc(e+8|0,b);c=rc(e,c);g=v[c+4>>2];c=v[c>>2];h=v[b+4>>2];b=v[b>>2];v[23588]=0;mF(974,f,b,h,c,g);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5510,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}kb=e+16|0;return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-32|0;kb=d;u[d+30>>1]=0;Wf(a,d+30|0);a:{b:{i=x[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Mb(d+16|0);v[23588]=0;u[d+14>>1]=0;e=Q(485,a|0,g|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break b}if(!e){break d}v[23588]=0;R(472,a|0,d+14|0);e=v[23588];v[23588]=0;if((e|0)==1){break b}v[23588]=0;U(11,d|0,c|0,g|0);e=v[23588];v[23588]=0;if((e|0)!=1){v[23588]=0;e=Q(484,b|0,d+14|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break e}Jb(e,d);Ab(d);zb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;Ab(d);break a}zb(g)}kb=d+32|0;return}f=P()|0;O()|0}zb(g);T(f|0);L()}function XN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=kb-112|0;kb=g;v[g+108>>2]=0;e=Wn(a,e&65535,d,c,g+108|0);f=w[b+790|0];if(!v[g+108>>2]){d=(f|0)==15;c=d&!w[b+792|0];e=e<<8;a:{if(e){v[b+664>>2]=e;break a}e=0;if(d){break a}e=v[b+664>>2]}h=c?0:w[b+836|0]<<16}if((f|0)==15){c=w[b+792|0];b:{if(!c){c=v[b+76>>2];v[g>>2]=1;f=v[Zc(g,g+108|0)>>2]<<3;d=Oka(c,0,e,0);e=(256<<f>>>1|0)+d|0;c=nb;c=d>>>0>e>>>0?c+1|0:c;d=f+8|0;f=d&31;if((d&63)>>>0>=32){d=0;c=c>>>f|0}else{d=c>>>f|0;c=((1<<f)-1&c)<<32-f|e>>>f}e=Ec(c,d);break b}cB(g);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}e=v[Eb(c+68|0,w[b+792|0]-1|0)>>2]+e|0}v[b+664>>2]=e}_n(a,b,e+h|0);kb=g+112|0}function GL(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=kb-48|0;kb=e;d=Mb(e+32|0);v[23588]=0;R(889,b|0,e+24|0);f=v[23588];v[23588]=0;if((f|0)!=1){b:{g=v[e+28>>2];f=v[e+24>>2];$f(d);v[23588]=0;f=!g&f>>>0<255?f:255;R(60,d|0,f|0);g=v[23588];v[23588]=0;if((g|0)==1){break b}c:{while(1){if((f|0)==(h|0)){b=rV(Mc(d),Hb(d));if((b|0)==-1){break c}v[23588]=0;R(60,d|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break c}break b}g=Tc(d,h);v[23588]=0;Q(890,b|0,g|0)|0;g=v[23588];v[23588]=0;if((g|0)!=1){h=h+1|0;continue}break}break b}v[23588]=0;U(11,e+8|0,a|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}a=e+8|0;Jb(c,a);Ab(a);zb(d);kb=e+48|0;break a}}a=P()|0;O()|0;zb(d);T(a|0);L()}}function uy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-16|0;kb=e;b=v[a>>2];if(!pc(b,v[a+4>>2])){b=Fb(b);v[e+8>>2]=b;c=Fb(v[a+4>>2]);while(1){if(Pb(b,c)){Qo(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=d;b=f>>>0<g>>>0?b+1|0:b;d=b;b=v[Le(e+8|0)>>2];continue}else{c=v[a>>2];b=vc(c,v[a+4>>2]);l=e,m=Fb(c),v[l>>2]=m;d=Rka(f,d,b,0);h=d;g=((nb&1)<<31|d>>>1)&2147483647;f=b<<24;d=0;i=Fb(v[a+4>>2]);while(1){b=v[e>>2];if(Pb(b,i)){j=b;c=v[b>>2];b=c>>>8|0;c=g+(c<<24)|0;b=b+k|0;b=Ec(Rka(c,c>>>0<g>>>0?b+1|0:b,h,k),nb);v[j>>2]=b;c=f;f=c-b|0;d=d-(b>>>0>c>>>0)|0;Le(e);continue}else{d=v[a>>2];if(!vc(d,v[a+4>>2])){gv();L()}v[d>>2]=f+v[d>>2]}break}}break}}kb=e+16|0}function Ht(a,b){var c=0,d=0,e=0;c=kb-48|0;kb=c;d=c+24|0;kQ(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);kQ(c,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);a=v[d>>2];b=w[a|0]|w[a+1|0]<<8;a=v[c>>2];b=Gt(b,w[a|0]|w[a+1|0]<<8);a:{if(!xj(b)){break a}a=v[d+4>>2];b=w[a|0]|w[a+1|0]<<8;a=v[c+4>>2];b=Gt(b,w[a|0]|w[a+1|0]<<8);if(!xj(b)){break a}a=v[d+8>>2];b=w[a|0]|w[a+1|0]<<8;a=v[c+8>>2];b=Gt(b,w[a|0]|w[a+1|0]<<8);if(!xj(b)){break a}a=v[c+12>>2];e=(w[a|0]|w[a+1|0]<<8)<<16>>16;a=v[d+12>>2];b=qe((w[a|0]|w[a+1|0]<<8)<<16>>16);a=qe(e);b=(a|0)==(b|0)?0:(b|0)<(a|0)?-1:1;if(!xj(b)){break a}a=v[d+16>>2];b=w[a|0]|w[a+1|0]<<8;a=v[c+16>>2];b=Gt(b,w[a|0]|w[a+1|0]<<8)}a=gf(b);kb=c+48|0;return a}function Wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){b=v[f+12>>2]+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(t[b+2|0],u[e+10>>1])+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/2|0)+((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(b,h);v[c+4>>2]=v[c+4>>2]+B(b,g);Rb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;kb=f+16|0}function LI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=kb-16|0;kb=d;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Qg(a)|0)>(b|0)){break d}}a=ba(8)|0;v[23588]=0;d=Q(55,d|0,10656)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}a=sc(a,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(d);break b}if(c<0|c>1){a=ba(8)|0;v[23588]=0;d=Q(55,d|0,11672)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=sc(a,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=(a+B(b,872)|0)+1075740|0,f=zl(c*64),v[e>>2]=f;kb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function m5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-32|0;kb=e;f=Tb(a);a=b;b=x[v[b+24>>2]+480192>>1];v[23588]=0;R(181,f|0,b|0);c=v[23588];v[23588]=0;b=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=b&65535;c=v[a+24>>2];if(d>>>0>x[c+480192>>1]){break b}c=BM(c,d);v[23588]=0;c=Q(55,e|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){d=v[a+24>>2];v[23588]=0;U(1009,e+16|0,d|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;R(183,f|0,e+16|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}zb(e+16|0);zb(c);b=b+1|0;continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;break c}b=P()|0;O()|0;zb(e+16|0)}zb(c);break a}kb=e+32|0;return}b=P()|0;O()|0}Xe(f);T(b|0);L()}function Iv(a,b,c,d){var e=0,f=0,g=0;e=kb-48|0;kb=e;v[e+44>>2]=d;a:{f=v[b>>2];b:{if(!(ob[v[v[f>>2]+36>>2]](f,c,d)|0)){Jh(a);break b}Ql(e+24|0,v[b>>2],v[b+4>>2]);b=v[b>>2];d=v[v[b>>2]+24>>2];v[23588]=0;b=S(d|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[e+20>>2]=b-c;d=v[e+24>>2];f=v[e+28>>2];g=v[Kb(e+44|0,e+20|0)>>2];b=kb-16|0;kb=b;v[b+12>>2]=f;v[b+8>>2]=d;d=Ql(b,d,f);f=v[d+4>>2];d=v[d>>2];v[23588]=0;da(172,e+32|0,d|0,f|0,c|0,g|0);c=v[23588];v[23588]=0;c:{if((c|0)!=1){me(b+8|0);kb=b+16|0;break c}a=P()|0;O()|0;me(b+8|0);T(a|0);L()}b=fe(e+8|0);ID(a,v[e+32>>2],v[e+36>>2],v[b>>2],v[b+4>>2])}kb=e+48|0;return}a=P()|0;O()|0;me(e+24|0);T(a|0);L()}function wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=kb-16|0;kb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[h+39714>>1])+B(u[e-2>>1],u[h+39712>>1])|0)+B(u[e+2>>1],u[h+39716>>1])|0)+B(u[e+4>>1],u[h+39718>>1])|0)/16384|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;kb=b+16|0}function yn(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;a:{b:{k=v[d>>2];if((k|0)!=(c|0)){break b}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break b}}v[d>>2]=c+1;t[c|0]=l;break a}c:{if(!(!Hb(g)|(a|0)!=(f|0))){g=0;a=v[i>>2];if((a-h|0)>159){break c}b=v[e>>2];v[i>>2]=a+4;v[a>>2]=b;break a}g=-1;f=ww(j,j+104|0,a)-j|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break c}v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[a+82976|0];return 0}v[d>>2]=k+1;t[k|0]=w[a+82976|0];v[e>>2]=v[e>>2]+1;g=0}return g}v[e>>2]=0;return 0}function EN(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{b:{c:{if(t[b+851|0]&1){f=w[b+848|0];g=c&240;if(g){f=f&15|g;t[b+848|0]=f}c=c&15;if(c){f=c|f&-16;t[b+848|0]=f}t[b+849|0]=(f&240)>>>4;if(v[a+480180>>2]!=32768){break a}break c}if(v[a+480180>>2]==32768){break c}c=w[b+849|0]-1|0;t[b+849|0]=c;if(c&255){break a}f=w[b+848|0];break b}f=w[b+848|0];if((f&240)==16){break b}if(!(w[a+480209|0]&16)){break a}}t[b+849|0]=(f&240)>>>4;c=f&15;c=d?c:0-c|0;d=v[b+656>>2];d:{if(wj(d)){v[b+852>>2]=v[b+852>>2]+B(c,v[v[d+44>>2]+36>>2]);break d}h=b,i=fh(a,ht(a,v[b+700>>2],u[b+772>>1],v[b+704>>2])+c|0,u[b+772>>1],v[b+704>>2]),v[h+700>>2]=i}if(!e){break a}v[b>>2]=0;v[b+4>>2]=0}}function Cia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=kb-48|0;kb=c;d=a;a:{if(hu(v[d>>2],v[d+8>>2])){v[g>>2]=0;break a}dT(c+16|0,c+32|0);nc(c+24|0,v[d>>2],v[d+8>>2],v[c+16>>2],v[c+20>>2]);h=v[c+28>>2];i=w[c+32|0];f=i&127;v[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(B(h,7)+a|0)+B(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=w[(c+32|0)+e|0];f=i&127|f<<7;v[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}_b(d,h);dT(c+8|0,c+32|0);nc(c+24|0,v[d>>2],v[d+8>>2],v[c+8>>2],v[c+12>>2]);h=v[c+28>>2];f=v[g>>2];e=0;a=b;continue}break}_b(d,e);if(a>>>0<33){break a}v[g>>2]=-1}kb=c+48|0}function Q4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-32|0;kb=e;f=Tb(a);a=b;b=x[v[b+24>>2]+480190>>1];v[23588]=0;R(181,f|0,b|0);d=v[23588];v[23588]=0;b=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=b&65535;d=v[a+24>>2];if(c>>>0>x[d+480190>>1]){break b}v[23588]=0;d=Q(55,e|0,CM(d,c)|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){c=v[a+24>>2];v[23588]=0;U(1009,e+16|0,c|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(183,f|0,e+16|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}zb(e+16|0);zb(d);b=b+1|0;continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;break c}b=P()|0;O()|0;zb(e+16|0)}zb(d);break a}kb=e+32|0;return}b=P()|0;O()|0}Xe(f);T(b|0);L()}function vm(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;f=a+1074312|0;Db(e+8|0,f,84);a:{if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){Db(e+8|0,f,10);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;Db(e+8|0,f,10);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}t[b+831|0]=0;u[b+778>>1]=0}kb=e+16|0}function rz(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;i=pl(a,b);a:{if((i|0)==255){break a}if(jk(v[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=Oka(1<<20-f,0,c,0)+24858e3|0;h=nb;c=Ec(Rka(c,c>>>0<24858e3?h+1|0:h,49716e3,0),nb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Wc(g+14|0,g+12|0)>>1]}h=zt(i);e=Lb(a+8|0,i);t[e|0]=(f<<10|c)>>>8|(d?0:32);hh(v[a>>2],v[a+4>>2],b,h|160,c&255);hh(v[a>>2],v[a+4>>2],b,h|176,w[e|0]);t[a+534|0]=1}kb=g+16|0}function Eba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-80|0;kb=d;e=Af(d+48|0);v[23588]=0;g=Q(797,b|0,e|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(798,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}break a}g=v[e+4>>2];v[23588]=0;U(190,d|0,b|0,g|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}f=kc(d+24|0,d);hd(e+8|0,f);Bb(f);Bb(d);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}v[23588]=0;Q(188,b|0,2-c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break d}break a}xk(a,e)}Ad(e);kb=d+80|0;return}a=P()|0;O()|0;Ad(e);T(a|0);L()}function $0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=kb-16|0;kb=g;a:{b:{if(!pc(b,-1)){i=v[a+8>>2];j=v[a+12>>2];d=v[a+24>>2];if((d|0)==v[a+28>>2]){e=-1;if(!(w[a+48|0]&16)){break a}h=v[a+20>>2];k=v[a+44>>2];v[23588]=0;c=a+32|0;R(47,c|0,0);f=v[23588];v[23588]=0;if((f|0)==1){break b}f=bd(c);v[23588]=0;R(60,c|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break b}e=Ac(c);Pw(a,e,Hb(c)+e|0);cs(a,d-h|0);v[a+44>>2]=v[a+20>>2]+(k-h|0);d=v[a+24>>2]}v[g+12>>2]=d+1;d=v[Zc(g+12|0,a+44|0)>>2];v[a+44>>2]=d;if(w[a+48|0]&8){c=Ac(a+32|0);Bn(a,c,c+(j-i|0)|0,d)}e=yH(a,qp(b));break a}e=Ow(b);break a}a=V(0)|0;O()|0;_(a|0)|0;$()}kb=g+16|0;return e|0}function B1(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kb-32|0;kb=e;if($H(1,e+16|0)){js(v[116064],12631);L()}c=is(e+8|0,v[e+16>>2]);g=is(e,v[e+20>>2]);d=kb-32|0;kb=d;b=kb-16|0;kb=b;a=kb-16|0;kb=a;h=a,i=Oka(v[c>>2],v[c+4>>2],1e9,0),v[h>>2]=i;v[a+4>>2]=nb;c=sl(a+8|0,a);f=v[c+4>>2];c=v[c>>2];kb=a+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=a;kb=b+16|0;f=v[d+8>>2];c=v[d+12>>2];a=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=a;a=d;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=sl(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];kb=d+32|0;a=Zr(e+24|0,a,b);b=v[a+4>>2];a=v[a>>2];kb=e+32|0;nb=b;return a|0}function xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=kb-16|0;kb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[h+39714>>1])+B(t[e-1|0],u[h+39712>>1])|0)+B(t[e+1|0],u[h+39716>>1])|0)+B(t[e+2|0],u[h+39718>>1])<<8)/16384|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;kb=b+16|0}function ql(a,b,c){var d=0,e=0,f=0;d=Mb(a);a=Hb(b);v[23588]=0;R(46,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){a:{while(1){if(Hb(b)>>>0>e>>>0){f=v[Ai(b,e)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if(v[(a<<2)+c>>2]==(f|0)){v[23588]=0;R(47,d|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[23588]=0;R(47,d|0,a<<24>>24);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}v[23588]=0;R(47,d|0,63);a=v[23588];v[23588]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;zb(d);T(a|0);L()}function OX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-32|0;kb=c;a:{b:{c:{d:{if(h=sh(v[b+4>>2],w[b+11|0]),i=1,j=v[b+12>>2],j?h:i){Mb(a);break d}e=Mb(c+16|0);d=zd(v[b+4>>2],w[b+11|0]);f=pr(14270);g=pd(b);v[23588]=0;X(102,e|0,g|0,d|0,d+f|0);d=v[23588];v[23588]=0;e:{if((d|0)!=1){v[23588]=0;W(103,e|0,14270,f|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;Ab(e);T(a|0);L()}v[23588]=0;R(132,c|0,b+12|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}v[23588]=0;U(2,a|0,c+16|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Ab(c);Ab(c+16|0)}kb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ab(c)}Ab(c+16|0);T(b|0);L()}function E2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-32|0;kb=e;h=Mb(a);f=Mb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480192>>1]){if(!(i&1)){break c}v[23588]=0;R(247,h|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}a=P()|0;O()|0;break a}c=BM(c,d);v[23588]=0;c=Q(55,e|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}d=Re(c);v[23588]=0;g=Q(800,f|0,c|0)|0;j=v[23588];v[23588]=0;d:{if((j|0)==1){break d}v[23588]=0;Q(941,g|0,21589)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}i=d^1|i;zb(c);a=a+1|0;continue}break}a=P()|0;O()|0;zb(c);break a}zb(f);kb=e+32|0;return}a=P()|0;O()|0}zb(f);zb(h);T(a|0);L()}function D2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-32|0;kb=e;h=Mb(a);f=Mb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480190>>1]){if(!(i&1)){break c}v[23588]=0;R(247,h|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}a=P()|0;O()|0;break a}v[23588]=0;c=Q(55,e|0,CM(c,d)|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}d=Re(c);v[23588]=0;g=Q(800,f|0,c|0)|0;j=v[23588];v[23588]=0;d:{if((j|0)==1){break d}v[23588]=0;Q(941,g|0,21589)|0;g=v[23588];v[23588]=0;if((g|0)==1){break d}i=d^1|i;zb(c);a=a+1|0;continue}break}a=P()|0;O()|0;zb(c);break a}zb(f);kb=e+32|0;return}a=P()|0;O()|0}zb(f);zb(h);T(a|0);L()}function Xr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=kb-16|0;kb=h;f=d?d:468004;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}if(!v[v[116090]>>2]){v[i>>2]=d&57343;e=1;break a}a=a-194|0;if(a>>>0>50){break c}d=v[(a<<2)+82768>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[116064]=25;e=-1;break a}v[f>>2]=d}kb=h+16|0;return e}function Gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-80|0;kb=d;e=Af(d+48|0);v[23588]=0;c=Q(793,b|0,e|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(794,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}break a}c=v[e+4>>2];v[23588]=0;c=cc(c);c=c?c:-1;U(190,d|0,b|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}f=kc(d+24|0,d);hd(e+8|0,f);Bb(f);Bb(d);d:{c=c&1;if(!c){break d}v[23588]=0;Q(188,b|0,2-c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break d}break a}xk(a,e)}Ad(e);kb=d+80|0;return}a=P()|0;O()|0;Ad(e);T(a|0);L()}function Bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=kb-48|0;kb=d;f=Mc(b);e=Hb(b);h=Mc(c);i=Hb(c);g=-1;a:{if(!e){break a}j=e+f|0;e=f;while(1){if((e|0)==(j|0)){break a}if(Dp(h,i,w[e|0])){e=e+1|0;continue}break}g=e-f|0}b:{c:{if((g|0)!=-1){k=d,l=ie(b),v[k+32>>2]=l;f=mj(d+40|0,d+32|0);k=d,l=ie(b),v[k+8>>2]=l;k=d,l=Gp(d+8|0,g),v[k+16>>2]=l;c=mj(d+24|0,d+16|0);OL(b,v[f>>2],v[c>>2]);break c}i=Hb(b);if(!i){break c}h=Mc(b);j=Hb(b);e=Mc(c);g=-1;f=Hb(c);if(f){c=h+j|0;d:{while(1){if((c|0)==(h|0)){break d}c=c-1|0;if(!Dp(e,f,w[c|0])){continue}break}g=c-h|0}}if((i-1|0)!=(g|0)){break c}Mb(a);break b}ad(a,b)}kb=d+48|0}function Qga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=kb-16|0;kb=c;a:{b:{d=v[b+8>>2];if((d|0)==v[a+8>>2]){e=v[b+4>>2];if((e|0)!=v[a+4>>2]){break b}v[c+12>>2]=d;v[c+8>>2]=d;d=v[Kb(c+12|0,c+8|0)>>2];v[c+12>>2]=e;v[c+8>>2]=e;h=v[Kb(c+12|0,c+8|0)>>2];i=v[a>>2];j=v[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=B(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k<<1)+i|0;f=Wh(C(Yd(z[v[(a<<2)+j>>2]+(b<<2)>>2],C(-1))*C(32768)));d:{if(C(D(f))<C(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=ed(g),u[m>>1]=n;a=a+1|0;continue}}}aa(17301,8943,27,9470);L()}aa(17251,8943,28,9470);L()}kb=c+16|0}function Hia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=v[a>>2];d=Fq(c,v[a+4>>2]);if(d>>>0<b>>>0){f=kb-32|0;kb=f;c=b-d|0;b=v[Gb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=(b-e|0)/40>>>0){d=kb-16|0;kb=d;b=VU(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){lc(b);kb=d+16|0}else{_S(a);a=a+40|0;v[b+4>>2]=a;continue}break}break a}b=Gb(a);d=SU(f+8|0,TU(a,Fq(v[a>>2],e)+c|0),Fq(v[a>>2],v[a+4>>2]),b);b=kb-16|0;kb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=B(c,40)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){_S(c);c=v[b>>2]+40|0;v[b>>2]=c;continue}break}Ud(b);kb=b+16|0;RU(a,d);QU(d)}kb=f+32|0;return}if(b>>>0<d>>>0){Od(a,c+B(b,40)|0)}}function AX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=kb-16|0;kb=g;e=pd(b);d=zd(v[b+4>>2],w[b+11|0]);i=pd(c);j=zd(v[c+4>>2],w[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(ou(i,j,w[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=fc(g+8|0,Pi(b));d=fc(g,Rf(Pi(b),f));oD(b,v[c>>2],v[d>>2]);break c}f=Gk(v[b+4>>2],w[b+11|0]);if(!f){break c}e=pd(b);i=zd(v[b+4>>2],w[b+11|0]);j=pd(c);d=-1;h=zd(v[c+4>>2],w[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!ou(j,h,w[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Mb(a);break b}ad(a,b)}kb=g+16|0}function FN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-16|0;kb=d;v[d+12>>2]=b;if(b>>>0<4294967280){a:{if(yl(a)>>>0>=b>>>0){break a}i=d,j=zd(v[a+4>>2],w[a+11|0]),v[i+8>>2]=j;e=Ng(v[Zc(d+12|0,d+8|0)>>2]);if((e|0)==(yl(a)|0)){break a}f=zd(v[a+4>>2],w[a+11|0]);b:{c:{if((e|0)==10){g=v[a>>2];h=1;b=a;c=f;break c}b=e+1|0;d:{if(yl(a)>>>0<e>>>0){b=tc(b);break d}v[23588]=0;b=S(52,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}c=w[a+11|0];h=gf(c);g=pd(a);c=zd(v[a+4>>2],c)}b=we(b,g,c+1|0);if(h){Nb(g)}if((e|0)!=10){cf(a,e+1|0);Gd(a,f);vd(a,b);break b}de(a,f)}}kb=d+16|0;return}jf();L()}function Pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=kb-16|0;kb=c;a:{b:{d=v[b+8>>2];if((d|0)==v[a+8>>2]){e=v[b+4>>2];if((e|0)!=v[a+4>>2]){break b}v[c+12>>2]=d;v[c+8>>2]=d;d=v[Kb(c+12|0,c+8|0)>>2];v[c+12>>2]=e;v[c+8>>2]=e;h=v[Kb(c+12|0,c+8|0)>>2];i=v[a>>2];j=v[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=B(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k|0)+i|0;f=Wh(C(Yd(z[v[(a<<2)+j>>2]+(b<<2)>>2],C(-1))*C(128)));d:{if(C(D(f))<C(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=oS(g),t[m|0]=n;a=a+1|0;continue}}}aa(17301,8943,27,9470);L()}aa(17251,8943,28,9470);L()}kb=c+16|0}function qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-80|0;kb=d;e=Af(d+48|0);v[23588]=0;g=Q(868,b|0,e|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(869,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}break a}g=v[e+4>>2];v[23588]=0;U(190,d|0,b|0,g|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}f=kc(d+24|0,d);hd(e+8|0,f);Bb(f);Bb(d);d:{if(!(g&1)|c>>>0<2){break d}v[23588]=0;Q(188,b|0,1)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break d}break a}xk(a,e)}Ad(e);kb=d+80|0;return}a=P()|0;O()|0;Ad(e);T(a|0);L()}function sv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;t[f+15|0]=d;t[b+12|0]=w[b+12|0]&240|w[a|0]&15;i=a+1|0;e=f+15|0;Rg(b,w[Xb(i,e)|0]);g=w[Xb(a+2|0,e)|0];t[b+13|0]=g;k=b,l=Dd(w[a+3|0],g,d),t[k+14|0]=l;e=w[Xb(a+4|0,e)|0];t[b+15|0]=e;k=b,l=Dd(w[a+5|0],e,d),t[k+16|0]=l;g=v[b>>2];b=0;while(1){t[f+14|0]=25;if(b>>>0<w[Xb(f+14|0,i)|0]){e=B(b,3)+a|0;h=Yb(w[e+6|0]+c<<24>>24,0,64);d=Eb(g,b);t[d+2|0]=h;e=w[e+7|0]|w[e+8|0]<<8;u[d>>1]=e;a:{if(!b){break a}h=Eb(g,b-1|0);j=x[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;u[d>>1]=e;if(x[h>>1]<=(e&65535)>>>0){break a}u[d>>1]=e+256}b=b+1|0;continue}break}kb=f+16|0}function qD(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Sb(a,3878,4)){break a}b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);if(b>>>0<36){break a}c=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);if(c>>>0<36){break a}d=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);if(d>>>0<36){break a}e=w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);if(B(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function ZU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if(!d){break a}i=w[e|0];if(!i){break a}g=d-6|0;j=(g&255)>>>0<6&35>>>g;l=d-2|0;m=0-c|0;while(1){if(!b){break a}k=(l&255)>>>0>2;h=B(m,6);c=a;a=h+c|0;f=w[a+3|0];b:{if(!(k|(f-2&255)>>>0>2)){g=1;if(w[(c+h|0)+5|0]<224){break b}break a}g=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}g=1}c:{if(k){break c}f=c+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=c+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}b=b-1|0;if(!g){continue}c=w[(c+h|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}t[e|0]=0}}function Iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-80|0;kb=d;e=Af(d+48|0);v[23588]=0;c=Q(789,b|0,e|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(790,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break b}}break a}c=v[e+4>>2];v[23588]=0;c=cc(c);U(190,d|0,b|0,c|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}f=kc(d+24|0,d);hd(e+8|0,f);Bb(f);Bb(d);d:{c=c&1;if(!c){break d}v[23588]=0;Q(188,b|0,2-c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break d}break a}xk(a,e)}Ad(e);kb=d+80|0;return}a=P()|0;O()|0;Ad(e);T(a|0);L()}function EY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(_g(a,v[b+8>>2],f)){ow(b,c,d,e);return}g=w[b+53|0];i=v[a+12>>2];t[b+53|0]=0;h=w[b+52|0];t[b+52|0]=0;m=a+16|0;kw(v[m>>2],v[a+20>>2],b,c,d,e,f);j=w[b+53|0];l=g|j;k=w[b+52|0];h=h|k;g=a+24|0;i=(i<<3)+m|0;a:{if(g>>>0>=i>>>0){break a}while(1){if(w[b+54|0]){break a}b:{if(k){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!j){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;kw(v[g>>2],v[g+4>>2],b,c,d,e,f);j=w[b+53|0];l=j|l;k=w[b+52|0];h=k|h;g=g+8|0;if(i>>>0>g>>>0){continue}break}}t[b+53|0]=(l&255)!=0;t[b+52|0]=(h&255)!=0}function KS(a){var b=0,c=0,d=0,e=0,f=0;b=kb-32|0;kb=b;e=b,f=cc(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[e>>2]=f;v[b+4>>2]=0;e=b,f=cc(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[e+8>>2]=f;v[b+12>>2]=0;c=cc(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24));v[b+16>>2]=c?c:52;v[b+20>>2]=0;e=b,f=cc(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+80|0,v[e+24>>2]=f;v[b+28>>2]=0;a=b;d=bf(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=nv(v[a>>2],v[a+4>>2],v[c>>2],v[c+4>>2])?c:a;continue}}kb=b+32|0;c=v[a>>2];b=c-52|0;nb=v[a+4>>2]-(c>>>0<52)|0;return b}function RH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=kb-208|0;kb=f;v[f+204>>2]=c;c=f+160|0;Ub(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((QH(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=v[a+76>>2]>=0;g=v[a>>2];if(v[a+72>>2]<=0){v[a>>2]=g&-33}b:{c:{d:{if(!v[a+48>>2]){v[a+48>>2]=80;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;h=v[a+44>>2];v[a+44>>2]=f;break d}if(v[a+16>>2]){break c}}c=-1;if(oC(a)){break b}}c=QH(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){ob[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=h;v[a+28>>2]=0;b=v[a+20>>2];v[a+16>>2]=0;v[a+20>>2]=0;c=b?c:-1}b=a;a=v[a>>2];v[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}kb=f+208|0;return e}function Paa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=kb-16|0;kb=h;f=c;e=kb-16|0;kb=e;g=b;d=Td(b);a:{if(d){c=jc(g);while(1){b=d;d=b+16|0;if(kM(f,d)){c=b;d=v[b>>2];if(d){continue}break a}if(!kM(d,f)){break a}c=b+4|0;d=v[b+4>>2];if(d){continue}break}break a}b=jc(g);c=b}v[e+12>>2]=b;b=v[c>>2];if(!b){b=kb-16|0;kb=b;d=jc(g);d=mh(e,tc(28),nh(b+8|0,d));i=v[d>>2];v[23588]=0;R(846,i+16|0,f|0);f=v[23588];v[23588]=0;b:{if((f|0)!=1){j=jc(d),k=1,t[j+4|0]=k;kb=b+16|0;break b}a=P()|0;O()|0;jM(d);T(a|0);L()}Kg(g,v[e+12>>2],c,v[e>>2]);b=ce(e);jM(e);i=1}c=h+8|0;Jg(c,v[fc(e,b)>>2],i);kb=e+16|0;uP(a,c);kb=h+16|0}function M6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;i=e,j=Aj(b),v[i>>2]=j;c=kb-16|0;kb=c;g=a;d=Td(a);a:{if(d){f=jc(g);while(1){a=d;d=a+16|0;if(pt(b,d)){f=a;d=v[a>>2];if(d){continue}break a}if(!pt(d,b)){break a}f=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=jc(g);f=a}v[c+12>>2]=a;b=v[f>>2];if(!b){a=kb-16|0;kb=a;b=jc(g);b=mh(c,tc(40),nh(a+8|0,b));Mb(ad(v[b>>2]+16|0,v[e>>2])+12|0);i=jc(b),j=1,t[i+4|0]=j;kb=a+16|0;Kg(g,v[c+12>>2],f,v[c>>2]);b=ce(c);a=v[c>>2];v[c>>2]=0;if(a){if(w[jc(c)+4|0]){xm(a+16|0)}Nb(a)}h=1}Jg(e+8|0,v[fc(c,b)>>2],h);kb=c+16|0;a=wd(v[e+8>>2]);kb=e+16|0;return a+12|0}function xP(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function XA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-16|0;kb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Rg(b,Dd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;f=((c|0)!=0)<<1;h=v[b>>2];j=$d(h,v[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){WA(b,32);kb=e+16|0}else{a=k+(d<<2)|0;u[e+12>>1]=w[a+160|0]|w[a+161|0]<<8;g=le(e+14|0,e+12|0);i=Eb(h,d);g=x[g>>1];u[i>>1]=g;u[e+14>>1]=g+1;t[e+11|0]=(c^w[a+162|0])>>>f;t[e+10|0]=64;l=i,m=w[Xb(e+11|0,e+10|0)|0],t[l+2|0]=m;d=d+1|0;continue}break}}function U$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=kb-48|0;kb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=ob[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;gd(a,c);v[23588]=0;a=S(1119,a|0)|0;b=v[23588];v[23588]=0;b:{if((b|0)!=1){ac(f+24|0);c:{if(e){Ph(f+24|0,a);break c}Oh(f+24|0,a)}g=f,h=ie(f+24|0),v[g+16>>2]=h;while(1){g=f,h=zh(f+24|0),v[g+8>>2]=h;if(!zi(f+16|0,f+8|0)){c=v[f+40>>2];zb(f+24|0);break a}a=t[v[f+16>>2]];v[23588]=0;Q(21,f+40|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){He(f+16|0);continue}break}c=P()|0;O()|0;zb(f+24|0);break b}c=P()|0;O()|0;ac(f+24|0)}T(c|0);L()}kb=f+48|0;return c|0}function RV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-208|0;kb=d;XB(c,a);WB(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=kb-16|0;kb=c;v[c+12>>2]=64;v[c+8>>2]=255;e=w[Kb(c+12|0,c+8|0)|0];kb=c+16|0;t[d+12|0]=e;Rg(b,w[Xb(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;e=v[b>>2];f=$d(e,v[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=w[d+18|0];c=Eb(e,0);break b}g=x[Eb(e,a-1|0)>>1];v[d+12>>2]=1;b=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[b+1|0]&1)<<8|w[b|0];h=Pe(d+12|0,d+8|0);c=Eb(e,a);u[c>>1]=x[h>>1]+g;b=w[b+2|0]}t[c+2|0]=b;a=a+1|0;continue}}kb=d+208|0}function J3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=kb+-64|0;kb=d;f=d+16|0;h=kb-16|0;kb=h;i=FP(h+8|0);while(1){if((j|0)==12){kb=h+16|0}else{g=kb+-64|0;kb=g;c=v[i+4>>2];e=v[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=AJ(CJ(g+8|0,32));break a}e=E(c);e=CJ(g+8|0,(c<<e+1?32:31)-e|0);while(1){k=AJ(e);if(c>>>0<=k>>>0){continue}break}c=v[i>>2]+k|0}kb=g- -64|0;l=Eb(f,j),m=c,v[l>>2]=m;j=j+1|0;continue}break}f=IP(d,f,KP(f));GP(a,f);Gm(f);kb=d- -64|0;d=wx(a+120|0,a,b);t[d+20|0]=1;v[23588]=0;R(1068,a|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){a=P()|0;O()|0;Hn(d);T(a|0);L()}return a|0}function fba(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){et(a+484344|0);$f(a+1298308|0);nA(a+1298320|0);$f(a+1298332|0);Lc(a+1298408|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){b=a+906300|0;c=fk(b);while(1){if((b|0)==(c|0)){break a}yV(b);b=b+160|0;continue}}d=v[b>>2];if(d){Nb(du(d))}v[b>>2]=0;b=b+4|0;continue}}}else{Em(c);c=c+104|0;continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0}else{v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;continue}break}}function aM(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=kb-16|0;kb=h;t[h+15|0]=b;t[h+14|0]=10;Rg(g,w[Xb(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;j=v[g>>2];k=$d(j,v[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=w[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=Eb(j,b);l=B(b,3)+f|0;i=(w[l|0]|w[l+1|0]<<8)>>>4|0;u[m>>1]=i;c:{if(b){n=x[Eb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=Eb(j,b),p=i,u[o>>1]=p}o=m,p=Dd(w[l+2|0],0,64),t[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}t[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;kb=h+16|0}function xU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=kb-16|0;kb=e;f=kb-32|0;kb=f;c=pf(f+16|0,1,0);b:{c:{d:{while(1){d=Ac(c);Gx(f+8|0,d,Hb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=dh(Hb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Ac(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;e:{if((b|0)!=1){v[23588]=0;R(72,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break e}break c}break c}zb(c);kb=f+32|0;break b}a=P()|0;O()|0;zb(c);T(a|0);L()}v[23588]=0;R(71,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(e);kb=e+16|0;break a}a=P()|0;O()|0;Ab(e);T(a|0);L()}}function _o(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=kb-16|0;kb=e;f=kb-32|0;kb=f;c=pf(f+16|0,1,0);b:{c:{d:{while(1){d=Ac(c);Kx(f+8|0,d,Hb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=dh(Hb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Ac(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;e:{if((b|0)!=1){v[23588]=0;R(72,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break e}break c}break c}zb(c);kb=f+32|0;break b}a=P()|0;O()|0;zb(c);T(a|0);L()}v[23588]=0;R(71,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(e);kb=e+16|0;break a}a=P()|0;O()|0;Ab(e);T(a|0);L()}}function FD(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];d=Vg(c,v[a+4>>2]);if(d>>>0<b>>>0){f=kb-32|0;kb=f;c=b-d|0;b=v[Gb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=kb-16|0;kb=d;b=lr(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){lc(b);kb=d+16|0}else{Tj(a);a=a+8|0;v[b+4>>2]=a;continue}break}break a}b=Gb(a);d=nr(f+8|0,or(a,Vg(v[a>>2],e)+c|0),Vg(v[a>>2],v[a+4>>2]),b);b=kb-16|0;kb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=(c<<3)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){Tj(c);c=v[b>>2]+8|0;v[b>>2]=c;continue}break}Ud(b);kb=b+16|0;Ed(a,d);mr(d)}kb=f+32|0;return}if(b>>>0<d>>>0){Od(a,c+(b<<3)|0)}}function uY(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-32|0;kb=k;m=v[c>>2];l=v[c+8>>2];c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=l;v[k+24>>2]=c;v[k+28>>2]=l;v[k+20>>2]=m;v[k+16>>2]=d;v[23588]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ma(1049,a|0,b|0,k|0)|0;b=v[23588];v[23588]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;ia(935,10365,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$();a=-255}kb=k+32|0;break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}return a|0}function Bp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-16|0;kb=e;f=kb-32|0;kb=f;c=pf(f+16|0,1,0);a:{b:{c:{while(1){d=Ac(c);Kx(f+8|0,d,Hb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break c}d=dh(Hb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=Ac(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;d:{if((b|0)!=1){v[23588]=0;R(61,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}break b}break b}zb(c);kb=f+32|0;break a}a=P()|0;O()|0;zb(c);T(a|0);L()}v[23588]=0;R(58,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(e);kb=e+16|0;return}a=P()|0;O()|0;zb(e);T(a|0);L()}function o9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-16|0;kb=e;f=kb-32|0;kb=f;c=pf(f+16|0,1,0);a:{b:{c:{while(1){d=Ac(c);Kx(f+8|0,d,Hb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break c}d=dh(Hb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=Ac(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;d:{if((b|0)!=1){v[23588]=0;R(61,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}break b}break b}zb(c);kb=f+32|0;break a}a=P()|0;O()|0;zb(c);T(a|0);L()}v[23588]=0;R(58,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(e);kb=e+16|0;return}a=P()|0;O()|0;zb(e);T(a|0);L()}function k2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=kb-16|0;kb=g;a:{if(!(c&1024)){break a}i=g,j=Pi(b),v[i+8>>2]=j;c=Gk(v[b+4>>2],w[b+11|0]);b:{if(!c){break b}if(w[pd(b)|0]!=43){if(w[pd(b)|0]!=45){break b}}d=d+1|0;xJ(g+8|0)}if(c>>>0>=d>>>0){break a}e=v[fc(g,v[g+8>>2])>>2];c=d-Gk(v[b+4>>2],w[b+11|0])|0;c:{e=so(e,Pi(b));d=zd(v[b+4>>2],w[b+11|0]);if(e>>>0<=d>>>0){if(c){f=yl(b);d:{if(c>>>0<=f-d>>>0){f=pd(b);if((d|0)==(e|0)){break d}h=e+f|0;Xh(c+h|0,h,d-e|0);break d}Oy(b,f,(c+d|0)-f|0,d,e,c);f=v[b>>2]}nI(e+f|0,c,48);c=c+d|0;tq(b,c);xd(c+f|0,0)}break c}sk();L()}Pi(b)}ad(a,b);kb=g+16|0}function ne(a,b){var c=0,d=0,e=0;c=kb-32|0;kb=c;a=Yg(a,-1,-1);a:{b:{if(Qd(w[gm(c+24|0,b,1)|0])){d=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23588]=0;Ok(107,c+8|0,d,0,0);d=v[23588];v[23588]=0;c:{if((d|0)!=1){d=v[c+12>>2];v[a>>2]=v[c+8>>2];v[a+4>>2]=d;d=v[c+20>>2];v[a+8>>2]=v[c+16>>2];v[a+12>>2]=d;break c}a=V(0)|0;O()|0;_(a|0)|0;e=1;em(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}$()}Li(v[v[b>>2]-12>>2]+b|0,e)}kb=c+32|0;return}V(0)|0;O()|0;Vb()}L()}function kL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-16|0;kb=e;Kh(e+8|0,b);f=kb-16|0;kb=f;$g(f+8|0,v[e+8>>2],v[e+12>>2]);c=v[f+12>>2];b=v[f+8>>2];g=kb-16|0;kb=g;k=g,l=Fb(a),v[k+8>>2]=l;h=b;a=c;b=kb-16|0;kb=b;i=v[g+8>>2];c=i;d=v[c+12>>2];c=v[c+8>>2];a:{if((d|0)<0){break a}j=v[i+4>>2];if(!d&j>>>0<c>>>0|d){break a}v[b+8>>2]=j-c;v[b+12>>2]=0-(d+(c>>>0>j>>>0)|0);v[b>>2]=a;v[b+4>>2]=0;d=VB(b+8|0,b);if((bz(v[d>>2],v[d+4>>2])|0)!=(a|0)){break a}Qi(h,a+h|0,c+v[i>>2]|0);c=v[g+8>>2];h=c;d=a+v[c+8>>2]|0;c=v[c+12>>2];v[h+8>>2]=d;v[h+12>>2]=a>>>0>d>>>0?c+1|0:c}kb=b+16|0;kb=g+16|0;kb=f+16|0;kb=e+16|0}function d$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-16|0;kb=k;a:{if(a){a=_F(b);Sk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rk(k,a);Wi(i,k);Gc(k);Oh(k,a);Wi(h,k);Gc(k);l=d,m=aj(a),v[l>>2]=m;l=e,m=bj(a),v[l>>2]=m;ch(k,a);Bc(f,k);zb(k);Ph(k,a);Wi(g,k);Gc(k);a=Qk(a);break a}a=ZF(b);Sk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rk(k,a);Wi(i,k);Gc(k);Oh(k,a);Wi(h,k);Gc(k);l=d,m=aj(a),v[l>>2]=m;l=e,m=bj(a),v[l>>2]=m;ch(k,a);Bc(f,k);zb(k);Ph(k,a);Wi(g,k);Gc(k);a=Qk(a)}v[j>>2]=a;kb=k+16|0}function Dfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;nd(b,0);_h(d,1,a);c=d+16|0;Fc(c,d);Ce(b+43|0,c);zb(c);v[b>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[b+4>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[b+8>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);v[b+24>>2]=w[a+62|0]|w[a+63|0]<<8;Bl(b,+((w[a+60|0]^8)-120|0)/192);t[d+16|0]=w[a+61|0];t[d|0]=64;f=b,g=w[Xb(c,d)|0]<<2,u[f+30>>1]=g;u[b+34>>1]=0;c=w[a+47|0];if(c&4){u[b+34>>1]=1;v[b>>2]=v[b>>2]>>>1;e=1;c=w[a+47|0]}if(c&32){e=e|4;u[b+34>>1]=e;c=w[a+47|0]}if(c<<24>>24<0){u[b+34>>1]=e|2}kb=d+32|0}function Wia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=kb-80|0;kb=d;e=Af(d+48|0);v[23588]=0;c=Q(400,b|0,e|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(401,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}break c}c=kb-16|0;kb=c;g=c,h=cc(v[e+4>>2]),v[g+12>>2]=h;v[c+8>>2]=8;f=v[Zc(c+12|0,c+8|0)>>2];kb=c+16|0;v[23588]=0;U(190,d|0,b|0,f-8|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Ad(e);T(a|0);L()}b=kc(d+24|0,d);hd(e+8|0,b);Bb(b);Bb(d);xk(a,e)}Ad(e);kb=d+80|0}function Wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){if(th(119304647)>>>0<b>>>0){cd();L()}b=B(b,36);c=tc(b);v[a>>2]=c;v[a+4>>2]=c;f=Gb(a),g=b+c|0,v[f>>2]=g;d=kb-16|0;kb=d;v[d>>2]=a;c=v[a+4>>2];v[d+4>>2]=c;v[d+8>>2]=b+c;b=v[d+4>>2];e=v[d+8>>2];while(1){if((b|0)==(e|0)){lc(d);kb=d+16|0}else{c=Ub(b,0,36);v[c>>2]=0;v[c+4>>2]=0;u[c+22>>1]=0;u[c+24>>1]=0;u[c+26>>1]=0;u[c+28>>1]=0;t[c+21|0]=64;t[c+19|0]=64;t[c+20|0]=100;t[c+15|0]=0;t[c+16|0]=0;t[c+17|0]=0;t[c+18|0]=0;v[c+8>>2]=0;v[c+12>>2]=0;u[c+30>>1]=0;u[c+32>>1]=0;b=b+36|0;v[d+4>>2]=b;continue}break}}return a|0}function _J(a,b){var c=0,d=0,e=0,f=0;a:{e=kb-16|0;kb=e;f=kb-32|0;kb=f;c=pf(f+16|0,1,0);b:{c:{d:{while(1){d=Ac(c);Bx(f+8|0,d,Hb(c)+d|0,x[b>>1]);if(!v[f+12>>2]){break d}d=dh(Hb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Ac(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;e:{if((b|0)!=1){v[23588]=0;R(72,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break e}break c}break c}zb(c);kb=f+32|0;break b}a=P()|0;O()|0;zb(c);T(a|0);L()}v[23588]=0;R(71,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(e);kb=e+16|0;break a}a=P()|0;O()|0;Ab(e);T(a|0);L()}}function rs(a,b,c){var d=0,e=0;d=a,e=ij(C(C(z[c+1792>>2]*C(75038))+C(C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489))+C(C(C(z[c+1280>>2]+z[c+2304>>2])*C(6574))+C(C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153))+C(C(C(z[c+768>>2]+z[c+2816>>2])*C(2037))+C(C(C(z[c+3072>>2]-z[c+512>>2])*C(459))+C(C(C(z[c+256>>2]+z[c+3328>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))))))))),u[d>>1]=e;d=(b<<5)+a|0,e=ij(C(C(z[c+8>>2]*C(-5))+C(C(z[c+520>>2]*C(146))+C(C(z[c+1032>>2]*C(-45))+C(C(z[c+1544>>2]*C(-9975))+C(C(z[c+2056>>2]*C(64019))+C(C(z[c+2568>>2]*C(9727))+C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))))))))),u[d>>1]=e}function k$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-16|0;kb=k;a:{if(a){a=bG(b);Sk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rk(k,a);Bc(i,k);zb(k);Oh(k,a);Bc(h,k);zb(k);l=d,m=aj(a),t[l|0]=m;l=e,m=bj(a),t[l|0]=m;ch(k,a);Bc(f,k);zb(k);Ph(k,a);Bc(g,k);zb(k);a=Qk(a);break a}a=aG(b);Sk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rk(k,a);Bc(i,k);zb(k);Oh(k,a);Bc(h,k);zb(k);l=d,m=aj(a),t[l|0]=m;l=e,m=bj(a),t[l|0]=m;ch(k,a);Bc(f,k);zb(k);Ph(k,a);Bc(g,k);zb(k);a=Qk(a)}v[j>>2]=a;kb=k+16|0}function eK(a,b){var c=0,d=0,e=0,f=0;a:{e=kb-16|0;kb=e;f=kb-32|0;kb=f;c=pf(f+16|0,1,0);b:{c:{d:{while(1){d=Ac(c);cK(f+8|0,d,Hb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break d}d=dh(Hb(c));v[23588]=0;R(59,c|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Ac(c);v[23588]=0;R(60,c|0,b-d|0);b=v[23588];v[23588]=0;e:{if((b|0)!=1){v[23588]=0;R(72,e|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break e}break c}break c}zb(c);kb=f+32|0;break b}a=P()|0;O()|0;zb(c);T(a|0);L()}v[23588]=0;R(71,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(e);kb=e+16|0;break a}a=P()|0;O()|0;Ab(e);T(a|0);L()}}function R3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=Ft(c,a,1);yx(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;lc(a);kb=c+16|0;return}e=kb-32|0;kb=e;c=Gb(a);c=gQ(e+8|0,hQ(a,mk(v[a>>2],v[a+4>>2])+1|0),mk(v[a>>2],v[a+4>>2]),c);yx(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-16|0;yx(v[b>>2]-16|0,d);v[b>>2]=v[b>>2]-16;continue}break}qc(a,b);qc(a+4|0,c+8|0);qc(Gb(a),Cc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;v[c+8>>2]=b;Ds(b);continue}break}a=v[c>>2];if(a){$o(c);Nb(a)}kb=e+32|0}function mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;i=e,j=Aj(b),v[i>>2]=j;f=x[b>>1];d=kb-16|0;kb=d;g=a;c=Td(a);a:{if(c){b=jc(g);while(1){a=c;c=x[a+14>>1];if(no(f,c)){b=a;c=v[a>>2];if(c){continue}break a}if(!no(c,f)){break a}b=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=jc(g);b=a}v[d+12>>2]=a;a=v[b>>2];if(!a){a=kb-16|0;kb=a;c=jc(g);f=mh(d,tc(20),nh(a+8|0,c));c=v[f>>2];h=x[v[e>>2]>>1];u[c+16>>1]=0;u[c+14>>1]=h;i=jc(f),j=1,t[i+4|0]=j;kb=a+16|0;Kg(g,v[d+12>>2],b,v[d>>2]);a=ce(d);rk(d);h=1}Jg(e+8|0,v[fc(d,a)>>2],h);kb=d+16|0;a=ro(v[e+8>>2]);kb=e+16|0;return a+2|0}function LN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=kb-16|0;kb=c;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}d=c+8|0;f=a+1074312|0;Db(d,f,21);e=a;a=w[b+821|0];a=oy(e,w[b+828|0],Cb(v[v[c+8>>2]>>2],v[c+12>>2])?a:a+16>>>2|0);Db(d,f,45);b:{if(!(!Cb(v[v[c+8>>2]>>2],v[c+12>>2])|w[b+828|0]!=3)){d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];e=d+1|0;break c}t[b+832|0]=a;e=1}t[b+821|0]=e;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}Db(c+8|0,f,47);if(!Cb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}t[b+831|0]=a}if(a){g=b,h=Yb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}kb=c+16|0}function bY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=kb+-64|0;kb=g;mn(g+16|0,c);v[23588]=0;c=g+28|0;R(113,c|0,d|0);d=v[23588];v[23588]=0;b:{c:{d:{if((d|0)==1){break d}v[23588]=0;c=g+40|0;R(113,c|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}v[23588]=0;c=g+52|0;R(113,c|0,f|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}Vv(g+8|0,g+16|0);v[23588]=0;X(114,a|0,b|0,v[g+8>>2],v[g+12>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}hE(g+16|0);kb=g- -64|0;break a}a=P()|0;O()|0;while(1){c=Ab(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=P()|0;O()|0;hE(g+16|0)}T(a|0);L()}}function TT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;i=e,j=Aj(b),v[i>>2]=j;f=v[b>>2];d=kb-16|0;kb=d;g=a;c=Td(a);a:{if(c){b=jc(g);while(1){a=c;c=v[a+16>>2];if(PT(f,c)){b=a;c=v[a>>2];if(c){continue}break a}if(!PT(c,f)){break a}b=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=jc(g);b=a}v[d+12>>2]=a;a=v[b>>2];if(!a){a=kb-16|0;kb=a;c=jc(g);f=mh(d,tc(24),nh(a+8|0,c));c=v[f>>2];h=v[v[e>>2]>>2];v[c+20>>2]=0;v[c+16>>2]=h;i=jc(f),j=1,t[i+4|0]=j;kb=a+16|0;Kg(g,v[d+12>>2],b,v[d>>2]);a=ce(d);rk(d);h=1}Jg(e+8|0,v[fc(d,a)>>2],h);kb=d+16|0;a=wd(v[e+8>>2]);kb=e+16|0;return a+4|0}function Hk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;f=a+36|0;c=v[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=v[a+20>>2];if(d>>>0>=y[a+24>>2]){tn(e,f,MD(f));ud(e+8|0,a,v[e>>2],v[e+4>>2]);c=v[e+12>>2];v[a+24>>2]=c;v[a+20>>2]=0;if(!c){break c}d=0;c=v[a+32>>2]}v[a+20>>2]=d+1;g=w[(a+d|0)+36|0];d=c+8|0;v[a+32>>2]=d;v[a+28>>2]=v[a+28>>2]|g<<c;c=d;continue}break}a=ba(8)|0;v[23588]=0;b=S(167,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break a}b=P()|0;O()|0;ca(a|0);T(b|0);L()}v[a+32>>2]=c-b;d=a;a=v[a+28>>2];v[d+28>>2]=a>>>b;kb=e+16|0;return a&(-1<<b^-1)}ha(b|0,30480,168);L()}function h_(a){a=a|0;if(w[468432]){return v[117107]}if(!w[469536]){a=469248;while(1){a=Mb(a)+12|0;if((a|0)!=469536){continue}break}t[469536]=1}rd(469248,89240);rd(469260,89272);rd(469272,89308);rd(469284,89332);rd(469296,89356);rd(469308,89372);rd(469320,89392);rd(469332,89412);rd(469344,89440);rd(469356,89480);rd(469368,89512);rd(469380,89548);rd(469392,89584);rd(469404,89600);rd(469416,89616);rd(469428,89632);rd(469440,89356);rd(469452,89648);rd(469464,89664);rd(469476,89680);rd(469488,89696);rd(469500,89712);rd(469512,89728);rd(469524,89744);t[468432]=1;v[117107]=469248;return 469248}function b7(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=kb-80|0;kb=d;v[d+72>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=f;v[d+32>>2]=c;v[d+36>>2]=e;a=fe(d+24|0);c=v[a+4>>2];a=v[a>>2];e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;v[23588]=0;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;X(936,d+48|0,d|0,a|0,c|0);a=v[23588];v[23588]=0;a:{b:{if((a|0)!=1){a=v[eg(d+16|0,d+72|0)>>2];v[23588]=0;b=+Aa(937,d+48|0,+b,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Bb(d+48|0);Ee(d+72|0);kb=d+80|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;Bb(d+48|0)}Ee(d+72|0);T(a|0);L()}function Oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=kb-16|0;kb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>18|0;n=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;g=u[f>>1];v[(e<<2)+b>>2]=g+((B(u[f+4>>1]-g|0,m)|0)/16384|0);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Rb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;kb=b+16|0}function H9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=Iz(c,a);Tx(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;lc(a);kb=c+16|0;return}e=kb-32|0;kb=e;c=Gb(a);c=Vf(e+8|0,qg(a,vc(v[a>>2],v[a+4>>2])+1|0),vc(v[a>>2],v[a+4>>2]),c);Tx(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-4|0;Tx(v[b>>2]-4|0,d);v[b>>2]=v[b>>2]-4;continue}break}qc(a,b);qc(a+4|0,c+8|0);qc(Gb(a),Cc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;v[c+8>>2]=b;sg(b);continue}break}a=v[c>>2];if(a){Kz(c);Nb(a)}kb=e+32|0}function A6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)==1){break c}v[23588]=0;Y(953,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=v[a+24>>2];b=rc(c+8|0,b);e=v[b+4>>2];b=v[b>>2];v[23588]=0;da(965,c+16|0,d|0,b|0,e|0,1);b=v[23588];v[23588]=0;if((b|0)==1){break c}a=c+16|0;b=gg(Mc(a));zb(a);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23588]=0;X(939,5538,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}kb=c+32|0;return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Kg(a,b,c,d){var e=0,f=0;v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=v[v[a>>2]>>2];if(b){v[a>>2]=b;d=v[c>>2]}f=v[jc(a)>>2];t[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=v[d+8>>2];if(w[c+12|0]){break a}b:{if(Ch(c)){b=v[c+8>>2];e=v[b+4>>2];if(!(!e|w[e+12|0])){break b}if(!Ch(d)){sq(c);c=v[c+8>>2]}t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;rq(b);break a}b=v[c+8>>2];e=v[b>>2];if(!(!e|w[e+12|0])){break b}if(Ch(d)){rq(c);c=v[c+8>>2]}t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;sq(b);break a}t[c+12|0]=1;d=b;t[d+12|0]=(d|0)==(f|0);t[e+12|0]=1;continue}break}a=Gb(a);v[a>>2]=v[a>>2]+1}function Hm(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function lI(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if($e(a)){ec(a,31);return 0}g=a,h=$e(a),t[g+1375|0]=h;d=gj(a);b=gj(a);gj(a);g=a,h=gj(a),v[g+1112>>2]=h;gj(a);c=$e(a);v[a+1116>>2]=c;if(!hx(a,a+1120|0,c)){ec(a,10);return 0}v[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){b=0;e=v[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}v[a- -64>>2]=d;v[a+60>>2]=(v[a+56>>2]+(c+e|0)|0)+27}v[a+1380>>2]=0;return 1}function gm(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=kb-32|0;kb=e;t[a|0]=0;a:{d=v[v[b>>2]-12>>2]+b|0;b:{if(Zg(d)){d=v[d+72>>2];if(d){ar(d)}c:{if(c){break c}c=v[v[b>>2]-12>>2]+b|0;if(!(v[c+4>>2]&4096)){break c}d=e+24|0;gd(d,c);v[23588]=0;f=S(19,d|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}ac(e+24|0);c=Sm(e+16|0,b);d=Hc(e+8|0);while(1){d:{if(!pp(c,d)){break d}g=Zk(v[c>>2]);if(!vh(v[f+8>>2],1,g)){break d}fm(c);continue}break}if(!dj(c,d)){break c}Li(v[v[b>>2]-12>>2]+b|0,6)}h=a,i=Zg(v[v[b>>2]-12>>2]+b|0),t[h|0]=i;break b}Li(d,4)}kb=e+32|0;return a}a=P()|0;O()|0;ac(e+24|0);T(a|0);L()}function vw(a,b,c,d,e){var f=0,g=0;f=kb-16|0;kb=f;g=f+8|0;gd(g,b);v[23588]=0;b=S(1136,g|0)|0;g=v[23588];v[23588]=0;a:{if((g|0)==1){break a}v[23588]=0;X(1148,b|0,82976,83008,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;b=S(1137,f+8|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;c=S(1149,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}v[d>>2]=c;v[23588]=0;c=S(1146,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[e>>2]=c;v[23588]=0;R(1147,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}ac(f+8|0);kb=f+16|0;return}a=P()|0;O()|0;ac(f+8|0);T(a|0);L()}function Pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=kb-16|0;kb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>10&4194048;n=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){f=e+n|0;g=t[f|0];v[(e<<2)+b>>2]=((B(t[f+2|0]-g|0,m)|0)/16384|0)+(g<<8);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Rb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;kb=b+16|0}function sY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=kb-16|0;kb=c;v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;a:{b:{c:{d:{if((e|0)==1){break d}v[23588]=0;Y(953,b|0);e=v[23588];v[23588]=0;if((e|0)==1){break d}e=v[a+24>>2];b=rc(c+8|0,b);g=v[b+4>>2];b=v[b>>2];v[23588]=0;mF(973,e,b,g,f,d);d=v[23588];v[23588]=0;b=1;if((d|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,8602,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$();b=0}kb=c+16|0;break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}return b|0}function K$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=kb-32|0;kb=f;v[f+24>>2]=b;a:{if(!(v[c+4>>2]&1)){c=ob[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+8|0;gd(a,c);v[23588]=0;a=S(1137,a|0)|0;b=v[23588];v[23588]=0;b:{if((b|0)!=1){ac(f+8|0);c:{if(e){Ph(f+8|0,a);break c}Oh(f+8|0,a)}g=f,h=ie(f+8|0),v[g>>2]=h;while(1){a=Uk(f+8|0);b=v[f>>2];if(!Pb(b,a)){c=v[f+24>>2];Gc(f+8|0);break a}a=v[b>>2];v[23588]=0;Q(1152,f+24|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){Le(f);continue}break}c=P()|0;O()|0;Gc(f+8|0);break b}c=P()|0;O()|0;ac(f+8|0)}T(c|0);L()}kb=f+32|0;return c|0}function Hha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-48|0;kb=e;d=v[a+8>>2];c=v[a>>2];v[23588]=0;d=W(156,c|0,d|0,1)|0;c=v[23588];v[23588]=0;a:{if((c|0)==1){break a}b:{if(!d){break b}v[23588]=0;Y(502,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break a}v[23588]=0;d=S(206,a|0)|0;c=v[23588];v[23588]=0;c:{if((c|0)!=1){while(1){if(!(d&255)){break b}v[23588]=0;c=Q(503,a|0,e+8|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break c}d:{if(!c){break d}c=w[e+8|0];if(c>>>0>63){break d}uc(US(v[b>>2],c),e+8|0,33)}d=d-1|0;continue}}break a}break a}Bb(a);kb=e+48|0;return}b=P()|0;O()|0;Bb(a);T(b|0);L()}function zw(a,b,c,d,e){var f=0,g=0;f=kb-16|0;kb=f;g=f+8|0;gd(g,b);v[23588]=0;b=S(19,g|0)|0;g=v[23588];v[23588]=0;a:{if((g|0)==1){break a}v[23588]=0;X(1134,b|0,82976,83008,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}v[23588]=0;b=S(1119,f+8|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;c=S(1135,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}t[d|0]=c;v[23588]=0;c=S(1132,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}t[e|0]=c;v[23588]=0;R(1133,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}ac(f+8|0);kb=f+16|0;return}a=P()|0;O()|0;ac(f+8|0);T(a|0);L()}function Rg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=vc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=kb-32|0;kb=e;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=kb-16|0;kb=c;b=Bh(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){lc(b);kb=c+16|0}else{rv(a);a=a+4|0;v[b+4>>2]=a;continue}break}break a}c=Gb(a);c=Vf(e+8|0,qg(a,vc(v[a>>2],d)+b|0),vc(v[a>>2],v[a+4>>2]),c);f=kb-16|0;kb=f;b=Wm(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){rv(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Ud(b);kb=f+16|0;Ed(a,c);Uf(c)}kb=e+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<2)|0)}}function pD(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;v[b+4>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+8>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);v[b+12>>2]=(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+((w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24))<<2);a=b+4|0;d=Eb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=qo(v[a>>2],v[c>>2])?c:a;continue}}kb=b+16|0;return v[a>>2]-36|0}function VZ(a){a=a|0;if(w[468424]){return v[117105]}if(!w[469232]){a=468944;while(1){a=Mb(a)+12|0;if((a|0)!=469232){continue}break}t[469232]=1}qd(468944,5037);qd(468956,5028);qd(468968,10796);qd(468980,10540);qd(468992,5264);qd(469004,11572);qd(469016,5121);qd(469028,5612);qd(469040,8846);qd(469052,8829);qd(469064,8837);qd(469076,8856);qd(469088,10023);qd(469100,13166);qd(469112,8919);qd(469124,7674);qd(469136,5264);qd(469148,9712);qd(469160,10428);qd(469172,10808);qd(469184,9209);qd(469196,6466);qd(469208,5495);qd(469220,13084);t[468424]=1;v[117105]=468944;return 468944}function Yt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;LR(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;t[b+31|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function tY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23588]=0;Y(953,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}e=v[a+24>>2];b=rc(d+8|0,b);c=v[b+4>>2];b=v[b>>2];v[23588]=0;b=nF(e,b,c,1);e=v[23588];v[23588]=0;c=nb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,8633,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$();b=0;c=0}kb=d+16|0;a=c;break a}b=P()|0;O()|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)!=1){T(b|0);L()}V(0)|0;O()|0;Vb();L()}ra(a|0);return b|0}function E0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-32|0;kb=c;a:{b:{c:{if(pc(b,-1)){break c}i=c,j=qp(b),t[i+23|0]=j;if(w[a+44|0]){d=-1;if((wk(c+23|0,1,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=as(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((wk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((wk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=Ow(b);break a}d=-1}kb=c+32|0;return d|0}function w6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)==1){break c}v[23588]=0;Y(953,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=v[a+24>>2];b=rc(e+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23588]=0;da(970,d|0,b|0,f|0,(c|0)!=0|0,1);c=v[23588];v[23588]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9955,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}kb=e+16|0;return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function iN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{if(v[a+480180>>2]!=1){break a}c=w[b+846|0];if(!c){break a}d=v[b+104>>2];if(!d){break a}if(!_d(v[d>>2],v[d+20>>2])){break a}f=x[d+34>>1];if(!(f&10)){break a}c=w[b+847|0]+w[(c&15)+33232|0]|0;t[b+847|0]=c;if(c<<24>>24>=0){break a}t[b+847|0]=0;h=f&2;c=v[(h?4:12)+d>>2];g=b;b=v[b+760>>2]+1|0;b=b>>>0<v[(h?8:16)+d>>2]-c>>>0?b:0;v[g+760>>2]=b;g=v[d+20>>2];c=b+c|0;b=Fk(f);gc(e+8|0,g+B(c,b)|0,b);b=v[e+8>>2];f=Lb(b,v[e+12>>2]);while(1){if((b|0)==(f|0)){uj(d,a)}else{t[b|0]=w[b|0]^-1;b=b+1|0;continue}break}}kb=e+16|0}
function eL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=ti(a,b,c,d);t[a+4260|0]=e;v[a>>2]=46284;c=Tb(a+4264|0);d=Tb(a+4276|0);v[a+4328>>2]=0;b=a+4320|0;v[b>>2]=0;v[b+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;b=a+4208|0;f=Eb(b,0),g=1056964608,v[f>>2]=g;f=Eb(b,1),g=1036831949,v[f>>2]=g;f=Eb(b,2),g=1038174126,v[f>>2]=g;f=Eb(b,3),g=1065353216,v[f>>2]=g;f=Eb(b,4),g=1061158912,v[f>>2]=g;f=Eb(b,5),g=1059082943,v[f>>2]=g;f=Eb(b,6),g=1061997773,v[f>>2]=g;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;wc(d);wc(c);Jf(a);T(b|0);L()}function cea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=kb-16|0;kb=b;g=v[a+16>>2];f=Tf(1,2);e=nb;h=e;Rb(a,f,e);i=v[a+24>>2];j=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){d=d-1|0;m=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+g|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+m>>1];e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],i);Rb(b+8|0,k,l);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;mg(a,f,h);kb=b+16|0}function Nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=kb-16|0;kb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){h=v[b+12>>2]+i|0;e=t[h|0];e=((B(t[h+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;kb=b+16|0}function A0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-32|0;kb=c;d=w[a+52|0];a:{if(pc(b,-1)){if(d){break a}b=v[a+48>>2];e=a,f=pc(b,-1)^1,t[e+52|0]=f;break a}b:{if(!d){break b}e=c,f=qp(v[a+48>>2]),t[e+19|0]=f;c:{d:{e:{d=c+20|0;switch(as(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((_r(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}kb=c+32|0;return b|0}function X6(a){a=a|0;var b=0;b=7976;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21619;break a}b=8009;break a}b=17519;break a;case 0:b=5014;break a;case 9:b=8032;break a;case 10:b=8046;break a;case 11:b=5391;break a;case 12:b=5411;break a;case 19:b=8058;break a;case 20:b=7990;break a;case 21:b=12750;break a;case 22:b=12073;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6022;break a}b=7943}return gg(b)|0}function Mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=kb-16|0;kb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){h=(v[b+12>>2]<<1)+i|0;e=u[h>>1];e=e+((B(u[h+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;kb=b+16|0}function Ufa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;f=kb-32|0;kb=f;a:{c=v[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=B(Qg(v[v[a+48>>2]+12>>2]),d?b-c|0:c-b|0);e=Fb(v[a+4>>2]);c:{if(d){e=fc(f+24|0,e);d=f+16|0;Fj(d);e=v[e>>2];v[23588]=0;X(636,a|0,e|0,c|0,d|0);c=v[23588];v[23588]=0;if((c|0)!=1){break c}a=V(92948)|0;if((O()|0)!=(ea(92948)|0)){break a}_(a|0)|0;$();break b}c=fc(f+8|0,hB(e,c));e=v[fc(f,Fb(v[a+4>>2]))>>2];d=v[c>>2];c=v[a>>2];c=B(Zs(d,Fb(c)),6)+c|0;if(Pb(d,e)){Od(a,YL(c+B(Zs(e,d),6)|0,v[a+4>>2],c))}Fb(c)}v[a+12>>2]=b}kb=f+32|0;return}T(a|0);L()}function v6(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=kb-16|0;kb=e;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{c:{if((d|0)==1){break c}v[23588]=0;Y(953,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break c}d=v[a+24>>2];b=rc(e+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23588]=0;$a(972,d|0,b|0,f|0,+c,1);d=v[23588];v[23588]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5929,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}kb=e+16|0;return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Rba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=kb-16|0;kb=d;v[d+12>>2]=b;if(b>>>0<1073741808){a:{if(un(a)>>>0>=b>>>0){break a}h=d,i=Hb(a),v[h+8>>2]=i;e=cm(v[Zc(d+12|0,d+8|0)>>2]);if((e|0)==(un(a)|0)){break a}f=1;c=un(a);g=Hb(a);b:{c:{if((e|0)==1){b=a;c=v[a>>2];break c}b=e+1|0;d:{if(c>>>0<e>>>0){b=Ci(b);break d}v[23588]=0;b=S(1226,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}f=ff(a);c=Ac(a)}mi(b,c,Hb(a)+1|0);if(f){Nb(c)}if((e|0)!=1){cf(a,e+1|0);Gd(a,g);vd(a,b);break b}de(a,g)}}kb=d+16|0;return}jf();L()}function Bo(a,b,c,d,e,f){var g=0;g=kb-16|0;kb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;d=0;a:{b:{while(1){c=d&255;if(c>>>0>3){break b}e=w[g+15|0];Pq(g+8|0,e,w[g+14|0],c>>>0>1);if(!(w[g+8|0]|!e)){d=d+1|0;Ji(g+15|0,g+13|0);Ji(g+14|0,g+12|0);continue}break}c=x[g+8>>1];t[b+2|0]=c;t[b+4|0]=c>>>8;c=w[g+13|0];t[b+5|0]=w[g+12|0];t[b+3|0]=c;t[g+7|0]=0;ee(a,0,g+7|0);break a}d=w[g+15|0];e=Ki(d);c=w[g+13|0];if(e>>>0>Ki(c)>>>0){Ji(g+15|0,g+13|0);Ji(g+14|0,g+12|0);d=w[g+15|0];c=w[g+13|0]}t[b+4|0]=0;t[b+2|0]=0;t[b+5|0]=w[g+12|0];t[b+3|0]=c;ee(a,d,g+14|0)}kb=g+16|0}function yt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=kb-16|0;kb=c;v[c+12>>2]=b;if(b>>>0<4294967280){a:{if(bd(a)>>>0>=b>>>0){break a}h=c,i=Hb(a),v[h+8>>2]=i;d=Ng(v[Zc(c+12|0,c+8|0)>>2]);if((d|0)==(bd(a)|0)){break a}f=Hb(a);b:{c:{if((d|0)==10){g=1;b=a;e=v[a>>2];break c}b=d+1|0;d:{if(bd(a)>>>0<d>>>0){b=tc(b);break d}v[23588]=0;b=S(1225,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}g=ff(a);e=Ac(a)}b=we(b,e,Hb(a)+1|0);if(g){Nb(e)}if((d|0)!=10){cf(a,d+1|0);Gd(a,f);vd(a,b);break b}de(a,f)}}kb=c+16|0;return}jf();L()}function u8(a){a=a|0;var b=0,c=0;c=kb-16|0;kb=c;b=v[v[a+16>>2]+24620>>2];b=Ic(Pka(Oka(b,b>>31,3840,0),nb,1e3,0),nb);v[a+4316>>2]=b;v[23588]=0;v[c+12>>2]=0;U(903,a+4264|0,b|0,c+12|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){d:{if(!w[a+4260|0]){break d}b=v[a+4316>>2];v[23588]=0;v[c+12>>2]=0;U(903,a+4276|0,b|0,c+12|0);b=v[23588];v[23588]=0;if((b|0)!=1){break d}b=V(92948)|0;break c}v[c+12>>2]=0;b=c+12|0;$K(a+4288|0,b);v[c+12>>2]=0;$K(a+4300|0,b);break b}b=V(92948)|0}if((O()|0)!=(ea(92948)|0)){break a}_(b|0)|0;v[a+4316>>2]=0;$()}kb=c+16|0;return}T(b|0);L()}function Vk(a,b,c){var d=0,e=0;e=kb-16|0;kb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!Qd(w[gm(e+8|0,a,1)|0])){break c}d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23588]=0;b=W(106,d|0,b|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;d=1;em(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23588]=0;Z(105);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)==1){break b}T(a|0);L()}$()}Li(v[v[a>>2]-12>>2]+a|0,d);kb=e+16|0;return a}V(0)|0;O()|0;Vb()}L()}function wP(a,b){var c=0,d=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;Ez(a+48|0);Ez(a+68|0);Ez(a+88|0);At(a+492|0);At(a+524|0);Mj(a,0,0);Lj(a,0,0);v[a+40>>2]=0;v[a+44>>2]=0;eu(a,b);b=a+108|0;d=dA(b);c=1;while(1){if((b|0)!=(d|0)){t[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function vr(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;a=Mb(a);a:{b:{c:{switch(b|0){case 0:v[23588]=0;b=Q(1,d|0,15826)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}Jb(a,b);Ab(b);break b;case 1:v[23588]=0;b=Q(1,d|0,15851)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Jb(a,b);Ab(b);break b}break a;case 2:v[23588]=0;b=Q(1,d|0,15799)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Jb(a,b);Ab(b);break b}break a;case 3:break c;default:break b}}v[23588]=0;b=Q(1,d|0,15773)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}Jb(a,b);Ab(b)}kb=d+16|0;return}b=P()|0;O()|0;Ab(a);T(b|0);L()}function L0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=kb-32|0;kb=c;a:{b:{c:{if(Dn(b)){break c}v[c+20>>2]=b;if(w[a+44|0]){d=-1;if((wk(c+20|0,4,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=as(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((wk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((wk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=Dn(b)?0:b;break a}d=-1}kb=c+32|0;return d|0}function D6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)==1){break c}v[23588]=0;Y(953,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}c=v[a+24>>2];b=rc(d+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23588]=0;e=+za(963,c|0,b|0,f|0,1);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5966,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}kb=d+16|0;return+e}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function ns(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=kb-240|0;kb=h;v[h+236>>2]=d;v[h+232>>2]=c;v[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-v[(e<<2)+g>>2]|0;if((ob[b|0](i,a)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=v[((e<<2)+g|0)-8>>2];l=j-4|0;if((ob[b|0](l,i)|0)>=0){break e}if((ob[b|0](l-f|0,i)|0)>=0){break e}}v[(k<<2)+h>>2]=i;c=YH(c,d);os(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=v[h+236>>2];c=v[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}XH(h,k);dx(i,b,e,g)}kb=h+240|0}function dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=kb-16|0;kb=b;g=v[a+16>>2];f=Tf(1,2);e=nb;h=e;Rb(a,f,e);i=v[a+24>>2];j=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){d=d-1|0;m=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+g|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+m|0]<<8;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],i);Rb(b+8|0,k,l);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;mg(a,f,h);kb=b+16|0}function F6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;a:{b:{c:{if((c|0)==1){break c}v[23588]=0;Y(953,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break c}c=v[a+24>>2];b=rc(d+8|0,b);e=v[b+4>>2];b=v[b>>2];v[23588]=0;b=fa(959,c|0,b|0,e|0,1)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9986,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}kb=d+16|0;return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function $H(a,b){var c=0,d=0,e=0;if(!w[464260]){d=Ga()|0;t[464260]=1;t[464261]=d}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!w[464261]){break c}e=+Fa();break a}v[116064]=28;return-1}e=+Pa()}c=e/1e3;e:{if(D(c)<0x8000000000000000){d=D(c)>=1?~~(c>0?F(H(c*2.3283064365386963e-10),4294967295):I((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;a=~~c>>>0;break e}d=-2147483648;a=0}v[b>>2]=a;c=(e-(+(Oka(a,d,1e3,0)>>>0)+ +(nb|0)*4294967296))*1e3*1e3;f:{if(D(c)<2147483648){a=~~c;break f}a=-2147483648}v[b+4>>2]=a;return 0}function IR(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break a}c=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(w[c|0]|w[c+1|0]<<8){break a}b=a+1096|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-5>>>0<4294967292){break a}if(!Xt(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|w[a+32|0]>15|w[a+33|0]>64){break a}b=Xt(a);a=a+34|0;if(b){continue}break}}return d}function H0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-32|0;kb=c;d=w[a+52|0];a:{if(Dn(b)){if(d){break a}b=v[a+48>>2];e=a,f=Dn(b)^1,t[e+52|0]=f;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch(as(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((_r(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}kb=c+32|0;return b|0}function QA(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=w[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!w[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=w[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=B(c>>>3|0,b);b=((d|0)==10)<<4}c=b+B(oq(w[a+1|0]),c)|0}return c}function dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-208|0;kb=e;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;UM(a+946304|0);f=a+906300|0;g=fk(f);d=e+48|0;Ub(d,0,160);d=WM(d);v[23588]=0;U(820,f|0,g|0,d|0);f=v[23588];v[23588]=0;a:{if((f|0)!=1){yy(d);d=ke(e+24|0,b);v[23588]=0;f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;v[e+16>>2]=v[d+16>>2];f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;a=W(821,a|0,e|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){a=P()|0;O()|0;break a}Bb(b);kb=e+208|0;return a|0}a=P()|0;O()|0;yy(d)}Bb(b);T(a|0);L()}function aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=kb-16|0;kb=b;j=v[a+16>>2];h=Tf(1,2);e=nb;k=e;Rb(a,h,e);e=v[a+40>>2];f=v[a+36>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){i=u[(v[b+12>>2]<<1)+j>>1];f=f+l|0;v[c>>2]=v[c>>2]+B(i,f>>12);e=e+g|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,i);Rb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+36>>2]=f;v[a+24>>2]=e>>12;mg(a,h,k);kb=b+16|0}function oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=kb-16|0;kb=g;h=x[c>>1];i=c;e=kb-16|0;kb=e;f=b;d=Td(b);a:{if(d){c=jc(f);while(1){b=d;d=x[b+14>>1];if(Ek(h,d)){c=b;d=v[b>>2];if(d){continue}break a}if(!Ek(d,h)){break a}c=b+4|0;d=v[b+4>>2];if(d){continue}break}break a}b=jc(f);c=b}v[e+12>>2]=b;b=v[c>>2];if(!b){b=kb-16|0;kb=b;d=jc(f);d=mh(e,tc(16),nh(b+8|0,d));Ni(v[d>>2]+14|0,x[i>>1]);k=jc(d),l=1,t[k+4|0]=l;kb=b+16|0;Kg(f,v[e+12>>2],c,v[e>>2]);b=ce(e);rk(e);j=1}c=g+8|0;Jg(c,v[fc(e,b)>>2],j);kb=e+16|0;uP(a,c);kb=g+16|0}function o5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=kb-32|0;kb=c;a:{f=a+36|0;b=v[f>>2];d=v[a+40>>2];b:{if(Pb(b,d)){Hc(c+24|0);break b}b=c+8|0;Jn(b,a);v[23588]=0;b=S(1012,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[c+24>>2]=b;Xf(c+8|0);d=v[a+40>>2];b=v[a+36>>2]}b=(g=f,h=v[c+24>>2],i=Pb(b,d),i?g:h);a=v[a+8>>2];c:{if((a|0)==-1){g=c,h=Fb(v[b>>2]),v[g+8>>2]=h;a=Fb(v[b+4>>2]);while(1){b=v[c+8>>2];if(!Pb(b,a)){break c}e=e+A[b>>3];Ux(c+8|0);continue}}e=A[mf(v[b>>2],a)>>3]}bl(c+24|0);kb=c+32|0;return+e}a=P()|0;O()|0;Xf(c+8|0);T(a|0);L()}function gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){c=kb-16|0;kb=c;v[c+12>>2]=477218588;v[c+8>>2]=2147483647;d=v[Kb(c+12|0,c+8|0)>>2];kb=c+16|0;if(b>>>0>d>>>0){cd();L()}b=B(b,9);c=tc(b);v[a>>2]=c;v[a+4>>2]=c;e=Gb(a),f=b+c|0,v[e>>2]=f;c=kb-16|0;kb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=b+d;b=v[c+4>>2];d=v[c+8>>2];while(1){if((b|0)==(d|0)){lc(c);kb=c+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[c+4>>2]=b;continue}break}}return a|0}function MC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-16|0;kb=f;v[f+8>>2]=e;v[f+12>>2]=d;$f(a);yt(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;v[f+4>>2]=i;g=v[Kb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=Ju(Ir(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){v[f+4>>2]=i-g;e=h+1|0;d=v[Kb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=t[Tc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=Tc(j,e),n=32,t[m|0]=n}e=e+1|0;continue}}break}kb=f+16|0}function Aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=kb-16|0;kb=f;g=x[Jl(v[a>>2],v[a+4>>2],b)>>1];a:{b:{if(!Hq(a,b)){break b}c=v[a+24>>2];d=Fb(v[c+484360>>2]);v[f+8>>2]=d;h=Fb(v[c+484364>>2]);while(1){if(!Pb(d,h)){break b}e=0;i=El(v[d>>2],v[d+4>>2]);c:{while(1){if((e|0)!=(i|0)){if(!(!((a|0)!=(d|0)|(b|0)!=(e|0))|x[dc(v[d>>2],e)>>1]!=(g|0))){c=PR(v[a+24>>2]+484344|0,g);if((c|0)!=65535){break c}}e=e+1|0;continue}break}d=v[Az(f+8|0)>>2];continue}break}j=Jl(v[a>>2],v[a+4>>2],b),k=c,u[j>>1]=k;break a}c=g}kb=f+16|0;return c&65535}function bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=kb-16|0;kb=b;j=v[a+16>>2];h=Tf(1,2);e=nb;k=e;Rb(a,h,e);e=v[a+40>>2];f=v[a+36>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){i=t[v[b+12>>2]+j|0]<<8;f=f+l|0;v[c>>2]=v[c>>2]+B(i,f>>12);e=e+g|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,i);Rb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+36>>2]=f;v[a+24>>2]=e>>12;mg(a,h,k);kb=b+16|0}function v5(a){a=a|0;var b=0,c=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){a=v[a+24>>2];b=v[a+24>>2];c=x[b+1074448>>1];a:{if(c>>>0>=tj(Wb(v[b+484360>>2],w[b+484376|0]))>>>0){a=x[v[a+24>>2]+1074446>>1];break a}a=v[a+24>>2];b=x[dc(v[Wb(v[a+484360>>2],w[a+484376|0])>>2],c)>>1];a=Rm(v[a+484344>>2],v[a+484348>>2],b)?b:-1}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9716,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Qn(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Db(e+8|0,a+1074312|0,3);if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){Db(e+8|0,a+1074312|0,3);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=B(b,872)+a|0;d=v[f+1075648>>2];a=Pp(a,v[f+1075080>>2],d);if(!a){break a}ob[v[v[a>>2]+84>>2]](a,c,(d?w[d+33|0]:13)<<24>>24,b)}kb=e+16|0}function HI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;a:{b:{c:{a=v[a+32>>2];e=Hs(a);d:{if(!e){if(Gs(a)>>>0<=b>>>0){break d}a=Hi(a,b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ba(8)|0;v[23588]=0;b=Q(55,d|0,6003)|0;c=v[23588];v[23588]=0;e:{if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break e}c=P()|0;O()|0;ca(a|0)}T(c|0);L()}a=v[(a+(b<<2)|0)+900384>>2];if(!a){break b}t[a+15|0]=w[a+15|0]&253|(c?2:0)}kb=d+16|0;return}L()}function kx(a,b,c){var d=0,e=0,f=C(0),g=C(0),h=C(0),i=C(0),j=0,k=C(0),l=C(0),m=C(0);e=kb-32|0;kb=e;g=z[a+24>>2];f=z[a+12>>2];h=z[a+48>>2];i=z[a+36>>2];pI(C(-z[a>>2]),C(g+f),C(h+i),e+20|0);pI(z[a+60>>2],C(h-i),C(g-f),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=z[j>>2];f=z[d+(e+20|0)>>2];h=z[d+71248>>2];i=z[d+71260>>2];k=z[d+(e+8|0)>>2];z[j>>2]=C(f*h)-C(i*k);j=b+d|0;l=z[(0-a<<2)+71256>>2];d=5-a<<2;m=z[d+71248>>2];f=C(C(f*i)+C(k*h));z[j>>2]=C(g*l)-C(m*f);z[b+d>>2]=C(g*m)+C(f*l);a=a+1|0;continue}break}kb=e+32|0}function eo(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0;d=x[a+24>>1];b=c+(d<<2)|0;v[a+40>>2]=((b&3)<<4)+27824;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+32>>1]=f;u[a+36>>1]=b?1:1<<e-12;u[a+34>>1]=-1<<f^-1;if((d|0)==15){u[a+36>>1]=4095}b=c+(x[a+26>>1]<<2)|0;v[a+52>>2]=((b&3)<<4)+27824;d=b>>>2|0;b=b>>>0<48;e=b?12-d|0:0;u[a+44>>1]=e;c=c+(x[a+30>>1]<<2)|0;v[a+64>>2]=((c&3)<<4)+27824;f=c>>>2|0;c=c>>>0<48;g=c?12-f|0:0;u[a+56>>1]=g;u[a+48>>1]=b?1:1<<d-12;u[a+60>>1]=c?1:1<<f-12;u[a+46>>1]=-1<<e^-1;u[a+58>>1]=-1<<g^-1}function Wd(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;v[b+4>>2]=1130;v[b>>2]=a;v[b+8>>2]=0;d=kb-16|0;kb=d;if(v[a>>2]!=-1){a:{c=fc(d,Mf(d+8|0,b));while(1){if(v[a>>2]==1){continue}break}b:{if(!v[a>>2]){vd(a,1);c=v[v[c>>2]>>2];v[23588]=0;Y(1131,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}v[a>>2]=-1}break a}b=V(0)|0;O()|0;_(b|0)|0;vd(a,0);v[23588]=0;Z(105);a=v[23588];v[23588]=0;c:{if((a|0)==1){a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){break c}V(0)|0;O()|0;Vb()}L()}T(a|0);L()}}kb=d+16|0;kb=b+16|0;return v[a+4>>2]-1|0}function Baa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=kb-32|0;kb=f;a=Tb(a);b:{c:{d:{e:{while(1){e=v[b+8>>2];g=v[b>>2];v[23588]=0;e=W(156,g|0,e|0,8)|0;g=v[23588];v[23588]=0;if((g|0)==1){break c}if(e){v[23588]=0;U(866,f|0,b|0,c|0);e=v[23588];v[23588]=0;if((e|0)==1){break e}v[23588]=0;R(867,a|0,f|0);e=v[23588];v[23588]=0;if((e|0)==1){break d}Ad(f);e=ZA(v[a+4>>2]);Zh(f,v[e>>2],v[e+4>>2]);if(v[f>>2]!=(d|0)){continue}}break}kb=f+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Ad(f);break b}b=P()|0;O()|0}Zd(a);T(b|0);L()}}function Ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[f+39714>>1])+B(u[e-2>>1],u[f+39712>>1])|0)+B(u[e+2>>1],u[f+39716>>1])|0)+B(u[e+4>>1],u[f+39718>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;kb=b+16|0}function qL(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;Nx(a);c=Yd(c,C(0));a:{switch(b|0){case 0:z[a+4220>>2]=c;return;case 1:z[a+4224>>2]=c;return;case 2:z[a+4228>>2]=c;Ts(a);return;case 3:t[a+4240|0]=c>=C(.5);Ts(a);return;case 4:b=kb-16|0;kb=b;e=b,f=Th(C(c*C(32))),v[e+12>>2]=f;v[b+8>>2]=0;v[b+4>>2]=5;d=v[Jj(b+12|0,b+8|0,b+4|0)>>2];kb=b+16|0;v[a+4232>>2]=d;return;case 5:t[a+4241|0]=c>=C(.5);return;case 6:t[a+4242|0]=c>=C(.5);return;case 7:t[a+4244|0]=c>=C(.5);return;case 8:if(c==C(0)){Mx(a)}A[a+4256>>3]=c;break;default:break a}}}function Iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-48|0;kb=d;c=d+24|0;Cj(c,b,1819307379);hd(a+40|0,c);Bb(c);Cj(c,b,1953721961);hd(a+60|0,c);Bb(c);Cj(c,b,543520099);hd(a+120|0,c);Bb(c);Cj(c,b,1414744396);v[23588]=0;c=Q(402,c|0,13719)|0;e=v[23588];v[23588]=0;a:{if((e|0)!=1){b:{if(c){v[23588]=0;U(770,d|0,d+24|0,2);c=v[23588];v[23588]=0;if((c|0)==1){break b}Ut(a+140|0,d);Zd(d)}v[23588]=0;U(771,d|0,b|0,1634890872);b=v[23588];v[23588]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;Bb(d+24|0);T(a|0);L()}hd(a+80|0,d);Bb(d);Bb(d+24|0);kb=d+48|0}function n$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=kb-416|0;kb=h;d=h+416|0;v[h+12>>2]=d;c=kb-144|0;kb=c;v[c+28>>2]=c+132;i=c+32|0;gG(v[a+8>>2],i,c+28|0,e,f,g);v[c+16>>2]=0;v[c+20>>2]=0;v[c+12>>2]=i;e=h+16|0;g=vc(e,v[h+12>>2]);f=kb-16|0;kb=f;i=ki(f+8|0,v[a+8>>2]);a=JG(e,c+12|0,g,c+16|0);ji(i);kb=f+16|0;if((a|0)==-1){Yr(12513);L()}v[h+12>>2]=(a<<2)+e;kb=c+144|0;c=v[h+12>>2];a=kb-16|0;kb=a;v[a+8>>2]=b;while(1){if((c|0)!=(e|0)){nH(a+8|0,v[e>>2]);e=e+4|0;continue}break}kb=a+16|0;kb=d;return v[a+8>>2]}function HW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=16384;d=v[Kb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=17;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=Hk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}dr(c+4|0,Hk(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}dr(c+4|0,d-e|0);break b}cD(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}cD(a,e,0,b)}d=v[a+1072>>2];continue}break}kb=c+16|0}function F5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;e=Tb(a);a=b;b=0;a:{b:{c:{d:{e:{while(1){d=v[a+24>>2];if(x[d+480188>>1]<=b>>>0){break a}v[23588]=0;R(1008,c|0,(d+(b<<5)|0)+480289|0);d=v[23588];v[23588]=0;if((d|0)!=1){d=v[a+24>>2];v[23588]=0;U(1009,c+16|0,d|0,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break e}v[23588]=0;R(183,e|0,c+16|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}b=b+1|0;zb(c+16|0);zb(c);continue}break}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;zb(c+16|0)}zb(c)}Xe(e);T(b|0);L()}kb=c+32|0}function JM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=16777216;h=e+12|0;d=v[a>>2];c=vc(d,v[a+4>>2]);a:{if(c>>>0<b>>>0){f=kb-32|0;kb=f;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){xC(a,b,h);break b}c=Gb(a);c=Vf(f+8|0,qg(a,vc(v[a>>2],d)+b|0),vc(v[a>>2],v[a+4>>2]),c);g=kb-16|0;kb=g;b=Wm(g,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){gq(d,v[h>>2]);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Ud(b);kb=g+16|0;Ed(a,c);Uf(c)}kb=f+32|0;break a}if(b>>>0<c>>>0){Od(a,d+(b<<2)|0)}}uy(a);kb=e+16|0}function Fy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-16|0;kb=d;g=lt(a,a+1074376|0,b,c);a:{if(!g){break a}h=a+1074312|0;Db(d+8|0,h,117);if(Cb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}e=B(b,872)+a|0;i=e+1075648|0;c=v[i>>2];if(!c|!w[c+33|0]){break a}f=a;a=e+1074992|0;e=Pp(f,v[a+88>>2],c);if(!e){break a}Db(d+8|0,h,34);f=!Cb(v[v[d+8>>2]>>2],v[d+12>>2]);c=tg(w[a+797|0]-u[a+770>>1]|0);b:{if(f|(c<<24)-16777216>>24<0){break b}a=v[a+656>>2];if(!a){break b}c=w[Lb(a+108|0,c-1|0)|0]}ob[v[v[e>>2]+88>>2]](e,g,c&255,t[v[i>>2]+33|0],b)}kb=d+16|0}function GW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=32768;d=v[Kb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=9;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=Hk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}dr(c+4|0,Hk(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}dr(c+4|0,d-e|0);break b}bD(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}bD(a,e,0,b)}d=v[a+1072>>2];continue}break}kb=c+16|0}function oja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=kb-32|0;kb=d;a=Tb(a);b:{c:{d:{e:{while(1){c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,8)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}if(c){v[23588]=0;R(398,d|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(399,a|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}Ad(d);c=ZA(v[a+4>>2]);Zh(d,v[c>>2],v[c+4>>2]);if((cc(v[d>>2])|0)!=1162757187){continue}}break}kb=d+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Ad(d);break b}b=P()|0;O()|0}Zd(a);T(b|0);L()}}function gka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;nd(b,0);g=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=g;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);v[b+12>>2]=e;f=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+16>>2]=f;c=w[a+12|0]|w[a+13|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;c=w[a+14|0];u[b+30>>1]=c?c+1|0:256;d=x[b+34>>1]&32767|!w[a+14|0]<<15;u[b+34>>1]=d;c=w[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;u[b+34>>1]=d;c=w[a+15|0]}if(c&2){v[b+16>>2]=f>>>1;v[b+12>>2]=e>>>1;v[b>>2]=g>>>1;u[b+34>>1]=d|1}}function cga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-80|0;kb=c;d=Af(c+48|0);v[23588]=0;e=Q(624,b|0,d|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(625,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}break c}e=v[d+4>>2];v[23588]=0;U(190,c|0,b|0,(e>>>0<9?0:e-8|0)|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Ad(d);T(a|0);L()}b=kc(c+24|0,c);hd(d+8|0,b);Bb(b);Bb(c);xk(a,d)}Ad(d);kb=c+80|0}function U4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0);v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{if((d|0)==1){break a}v[23588]=0;Y(1024,c|0);d=v[23588];v[23588]=0;if((d|0)==1){break a}d=v[a+24>>2];e=z[d+48>>2];d=v[d+24>>2];v[23588]=0;b=_a(1025,d|0,C(e),b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10303,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[f+39714>>1])+B(t[e-1|0],u[f+39712>>1])|0)+B(t[e+1|0],u[f+39716>>1])|0)+B(t[e+2|0],u[f+39718>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;kb=b+16|0}function Vi(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?E(c):E(d)+32|0;Lf(f,d,e,0,0,c+49|0);i=v[f>>2];h=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=i;v[a+4>>2]=h;v[a+8>>2]=c;v[a+12>>2]=g&-2147483648|d;kb=f+16|0}function zba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;f=Mb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(yd(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Nd(d,0);break e}v[23588]=0;Q(800,f|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}d=Nd(v[b>>2],a)}v[23588]=0;R(801,e|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;Q(800,f|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break d}a=a+1|0;zb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(e);break a}kb=e+16|0;return}a=P()|0;O()|0}zb(f);T(a|0);L()}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-80|0;kb=c;d=Af(c+48|0);v[23588]=0;e=Q(507,b|0,d|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(508,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}break c}e=x[d+2>>1]|x[d+4>>1]<<16;v[23588]=0;U(190,c|0,b|0,e|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Ad(d);T(a|0);L()}b=kc(c+24|0,c);hd(d+8|0,b);Bb(b);Bb(c);MS(a,d)}Ad(d);kb=c+80|0}function mW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-32|0;kb=d;nd(b,0);_h(d,1,a+33|0);e=d+16|0;Fc(e,d);Ce(b+43|0,e);zb(e);f=w[a+50|0]|w[a+51|0]<<8|(w[a+52|0]<<16|w[a+53|0]<<24);v[b>>2]=f;v[b+24>>2]=w[a+54|0]|w[a+55|0]<<8;t[d+16|0]=w[a+56|0];t[d|0]=64;h=b,i=w[Xb(e,d)|0]<<2,u[h+30>>1]=i;e=w[a+57|0]|w[a+58|0]<<8|(w[a+59|0]<<16|w[a+60|0]<<24);v[b+4>>2]=e;g=w[a+61|0]|w[a+62|0]<<8|(w[a+63|0]<<16|w[a+64|0]<<24);c=c?e?f:g:g;v[b+8>>2]=c;if(!(!w[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0)){u[b+34>>1]=x[b+34>>1]|2}kb=d+32|0}function oy(a,b,c){var d=0,e=0;e=kb-16|0;kb=e;Db(e+8|0,a+1074312|0,21);a:{if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+33440|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=pM(Un(a))+-64|0;break a}d=t[(c>>>1&31)+32128|0];if(x[a+480182>>1]&1032){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+33312|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+33376|0]}a=d;kb=e+16|0;return a}function QQ(a,b,c,d,e,f){b=w[(b&15)+27024|0];t[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=w[a+5|0];c=b&15;if(c){t[a+5|0]=c;return}t[a+5|0]=b&240;return;case 3:b=w[a+5|0];b=B(b&240,10)|b&15;t[a+5|0]=b;d=b&255;b=x[e>>1];if(!(d|(b|0)==65535)){t[a+5|0]=b;t[a+3|0]=12;u[e>>1]=65535}xc(f,c);return;case 1:u[e>>1]=w[a+5|0];v[f>>2]=63;t[a+3|0]=0;return;case 5:b=w[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|B(c,-10)+b;t[a+5|0]=b}if(b&255){break a}t[a+3|0]=0;return;case 7:break a;default:break b}}if(w[a+5|0]){break a}t[a+3|0]=0}}function Gga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=kb-608|0;kb=f;b=kb-16|0;kb=b;d=f+8|0;YR(b+8|0,d);c=v[b+12>>2];md(b,a,v[b+8>>2],v[b+12>>2]);e=v[b+4>>2];if((e|0)==(c|0)){id(a,v[b+12>>2])}kb=b+16|0;c=(c|0)==(e|0);if(!c){XR(d)}b=-1;a:{if(!c){break a}b=0;if(!ZR(f+8|0)){break a}b=-1;if(!fg(a,1024)){break a}b=0;d=kb-1024|0;kb=d;c=kb-16|0;kb=c;fA(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((e|0)==(g|0)){id(a,v[c+12>>2])}kb=c+16|0;if((e|0)==(g|0)){b=gA(d,0)>>>0<17}kb=d+1024|0}kb=f+608|0;return b|0}function Jba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=kb-16|0;kb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;jO(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;lc(c);kb=c+16|0;return}f=kb-32|0;kb=f;g=Gb(a);h=f+8|0;d=dz(v[a>>2],v[a+4>>2])+1|0;c=kb-16|0;kb=c;v[c+12>>2]=d;a:{e=th(613566756);if(d>>>0<=e>>>0){d=ez(a);if(d>>>0<e>>>1>>>0){v[c+8>>2]=d<<1;e=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;break a}cd();L()}c=mO(h,e,dz(v[a>>2],v[a+4>>2]),g);jO(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+7;lO(a,c);kO(c);kb=f+32|0}function U6(a){a=a|0;var b=0,c=0,d=0;b=kb-32|0;kb=b;a:{b:{if(!a){a=gg(21619);break b}v[23588]=0;c=Q(55,b|0,a|0)|0;a=v[23588];v[23588]=0;c:{d:{if((a|0)!=1){v[23588]=0;R(938,b+16|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break d}d=b+16|0;a=gg(Mc(d));zb(d);zb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;zb(c)}_(a|0)|0;a=0;v[23588]=0;X(939,10936,0,0,0);c=v[23588];v[23588]=0;if((c|0)==1){break a}$()}kb=b+32|0;return a|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function EX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;f=Mb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(yd(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Nd(d,0);break e}v[23588]=0;Q(98,f|0,c|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break b}d=Nd(v[b>>2],a)}v[23588]=0;R(153,e|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;Q(98,f|0,e|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break d}a=a+1|0;Ab(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(e);break a}kb=e+16|0;return}a=P()|0;O()|0}Ab(f);T(a|0);L()}function nu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=kb-16|0;kb=g;v[g+12>>2]=0;v[g+8>>2]=a;i=kb-16|0;kb=i;b=hc(i+8|0,v[g+8>>2],v[g+12>>2]);e=kb-16|0;kb=e;d=118;v[e+12>>2]=118;c=v[b+4>>2];a:{if(!c){c=v[b>>2];break a}f=32-c|0;v[e+8>>2]=f;d=v[b>>2];j=v[d>>2];h=f;f=v[Kb(e+8|0,e+12|0)>>2];v[d>>2]=(-1<<c&-1>>>h-f^-1)&j;j=v[e+12>>2];c=d+4|0;v[b>>2]=c;d=j-f|0}h=c;c=d>>>5<<2;Ub(h,0,c);f=d&31;v[e+12>>2]=f;if((d&-32)!=(d|0)){h=b;b=c+v[b>>2]|0;v[h>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-f^-1)}kb=e+16|0;kb=i+16|0;kb=g+16|0;return a}function Qfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=kb-32|0;kb=d;a=Tb(a);b:{c:{d:{e:{while(1){c=v[b+8>>2];e=v[b>>2];v[23588]=0;c=W(156,e|0,c|0,8)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}if(c){v[23588]=0;R(653,d|0,b|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}v[23588]=0;R(654,a|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break d}Ad(d);c=ZA(v[a+4>>2]);Zh(d,v[c>>2],v[c+4>>2]);if(v[d>>2]!=1413891155){continue}}break}kb=d+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Ad(d);break b}b=P()|0;O()|0}Zd(a);T(b|0);L()}}function d7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;t[a+4202|0]=1;c=kk(C(C(y[v[a+16>>2]+24620>>2])*C(.04500000178813934)));d=kk(C(C(c>>>0)*C(1.1892070770263672)));e=kk(C(C(d>>>0)*C(1.1892070770263672)));h=kk(C(C(e>>>0)*C(1.1892070770263672)));f=kk(C(C(c+e>>>0)*C(.11546666920185089)));g=kk(C(C(d+h>>>0)*C(.11546666920185089)));b=a+4272|0;i=Eb(b,0),j=c-f|0,v[i>>2]=j;i=Eb(b,1),j=e-f|0,v[i>>2]=j;i=Eb(b,2),j=d-g|0,v[i>>2]=j;i=Eb(b,3),j=h-g|0,v[i>>2]=j;i=Eb(b,4),j=f,v[i>>2]=j;i=Eb(b,5),j=g,v[i>>2]=j;DK(a);CK(a)}function eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;v[f+12>>2]=b;a:{if(dt(a)>>>0>=b>>>0){e=v[a>>2];g=yk(e,v[a+4>>2]);v[f+8>>2]=g;d=v[Kb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=WL(e,c)+52|0;continue}break}if(b>>>0>g>>>0){Zx(a,b-g|0,c);break a}UL(a,v[a>>2]+B(b,52)|0);break a}if(v[a>>2]){et(a);d=v[a>>2];dt(a);Nb(d);h=Gb(a),i=0,v[h>>2]=i;v[a>>2]=0;v[a+4>>2]=0}d=TL(a,b);if(th(82595524)>>>0<d>>>0){cd();L()}e=SL(d);v[a>>2]=e;v[a+4>>2]=e;h=Gb(a),i=e+B(d,52)|0,v[h>>2]=i;Zx(a,b,c)}kb=f+16|0}function Raa(a){a=a|0;var b=0,c=0;b=32224;a=Tb(a);a:{b:{while(1){c:{if((b|0)==32624){b=32624;break c}d:{c=v[a+4>>2];if(!pc(v[a>>2],c)){if(!wi(v[b+4>>2],v[Bj(c)>>2])){break d}}v[23588]=0;R(844,a|0,b+4|0);c=v[23588];v[23588]=0;if((c|0)!=1){break d}break b}b=b+8|0;continue}break}while(1){if((b|0)==32672){break a}e:{c=v[a+4>>2];f:{if(!pc(v[a>>2],c)){if(!wi(v[b+8>>2],v[Bj(c)>>2])){break f}}v[23588]=0;R(844,a|0,b+8|0);c=v[23588];v[23588]=0;if((c|0)==1){break e}}b=b+12|0;continue}break}}b=P()|0;O()|0;wc(a);T(b|0);L()}}function TJ(a,b){var c=0,d=0;c=v[a>>2];v[a>>2]=b;if(c){v[23588]=0;Y(813,c|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){a=v[c+4>>2];if(a){if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(d|0)){b=b-4|0;sg(b);continue}break}v[a+4>>2]=d;b=v[a>>2];Vh(a);Nb(b)}Nb(a)}v[c+4>>2]=0;_M(c+1298408|0);Cy(c+1298344|0);zb(c+1298332|0);Ab(c+1298320|0);zb(c+1298308|0);By(c+1298304|0);Ay(c+1298300|0);nt(c+1298264|0);Ny(c+1074376|0);ZM(c+906300|0);zz(c+484360|0);RM(c+484344|0);wc(c+480248|0);break a}V(0)|0;O()|0;Vb();L()}Nb(c)}}function Zba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=kb-48|0;kb=c;f=OO(a,1<<b-1);v[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=v[10465];d=c+16|0;v[d+8>>2]=v[10464];v[d+12>>2]=e;e=v[10463];v[d>>2]=v[10462];v[d+4>>2]=e;nz(d,h*+(b>>>0));JO(c+32|0,A[c+16>>3],A[c+24>>3]);d=Kd(v[f>>2],a);e=v[c+44>>2];v[d+8>>2]=v[c+40>>2];v[d+12>>2]=e;e=v[c+36>>2];v[d>>2]=v[c+32>>2];v[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=ol(c,1,0);dy(f,0,g,A[a>>3],A[a+8>>3]);kb=c+48|0;return f|0}function Vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=kb-16|0;kb=c;a=Tv(c,a);d=v[a+4>>2];v[23588]=0;R(488,d|0,b|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+12;lc(a);kb=c+16|0;break a}b=P()|0;O()|0;lc(a);T(b|0);L()}return}d=kb-32|0;kb=d;c=Gb(a);c=Ik(d+8|0,kn(a,yd(v[a>>2],v[a+4>>2])+1|0),yd(v[a>>2],v[a+4>>2]),c);e=v[c+8>>2];v[23588]=0;R(488,e|0,b|0);b=v[23588];v[23588]=0;b:{if((b|0)!=1){v[c+8>>2]=v[c+8>>2]+12;zr(a,c);Sv(c);kb=d+32|0;break b}a=P()|0;O()|0;Sv(c);T(a|0);L()}}function pP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;f=v[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=v[a>>2]+B(f,62)|0;d=b?1:-1;p=B(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=B(c,f);q=v[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{u[(b<<1)+h>>1]=x[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function eN(a,b,c){var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}e=v[a+480180>>2];b=e&1048580?(b&240?-16:15)&b:b;c=b&240;f=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=f>>>3&30;break d}g=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!g){break b}b=0-(b<<1)|0;break c}if(g){break b}if(c){if(b?e&59314208:0){break b}b=f>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;v[d+12>>2]=v[a>>2]+(b<<!(e&59314208));pe(d+12|0,0,256);v[a>>2]=v[d+12>>2]}kb=d+16|0}function KY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(_g(a,v[b+8>>2],e)){nw(b,c,d);return}a:{if(_g(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];ob[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];ob[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function GI(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;a:{b:{c:{a=v[a+32>>2];c=Hs(a);d:{if(!c){if(Gs(a)>>>0<=b>>>0){break d}c=(w[Hi(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ba(8)|0;v[23588]=0;b=Q(55,d|0,6003)|0;c=v[23588];v[23588]=0;e:{if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break e}c=P()|0;O()|0;ca(a|0)}T(c|0);L()}a=v[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(w[a+15|0]&2)>>>1|0}kb=d+16|0;return c|0}L()}function Gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-80|0;kb=c;d=Af(c+48|0);v[23588]=0;e=Q(659,b|0,d|0)|0;f=v[23588];v[23588]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(660,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}break c}e=v[d+4>>2];v[23588]=0;U(190,c|0,b|0,e|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Ad(d);T(a|0);L()}b=kc(c+24|0,c);hd(d+8|0,b);Bb(b);Bb(c);xk(a,d)}Ad(d);kb=c+80|0}function DG(a,b,c,d){var e=0,f=0,g=0;f=kb-16|0;kb=f;a:{b:{if((a|0)!=(b|0)){c:{g=v[116064];v[116064]=0;Hd();d=CG(a,f+12|0,d);e=nb;d:{a=v[116064];if(a){if(v[f+12>>2]!=(b|0)){break c}if((a|0)!=68){break d}v[c>>2]=4;a=2147483647;if(!!d&(e|0)>=0|(e|0)>0){break a}break b}v[116064]=g;if(v[f+12>>2]==(b|0)){break d}break c}if((e|0)<0&d>>>0<=2147483647|(e|0)<-1){v[c>>2]=4;break b}if((e|0)>=0&d>>>0>=2147483648|(e|0)>0){v[c>>2]=4;a=2147483647;break a}a=d;break a}}v[c>>2]=4;a=0;break a}a=-2147483648}kb=f+16|0;return a}function D5(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb-32|0;kb=c;e=Tb(a);Xd(c+24|0);a=0;b=v[c+28>>2];d=v[c+24>>2];v[23588]=0;R(181,e|0,YI(d,b)|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){b:{while(1){b=v[c+24>>2];if((YI(b,v[c+28>>2])|0)<=(a|0)){kb=c+32|0;return}b=v[b+(a<<3)>>2];v[23588]=0;b=Q(55,c+8|0,b|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){v[23588]=0;R(183,e|0,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break b}zb(b);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(b);break a}a=P()|0;O()|0}Xe(e);T(a|0);L()}function qga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;gc(c+8|0,b,26);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function BI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=kb-32|0;kb=d;A[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;d=Q(55,d+8|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(d);break b}a=v[a+32>>2];v[d+8>>2]=0;v[d+12>>2]=-1074790400;v[d>>2]=0;v[d+4>>2]=1072693248;e=(a+B(b,872)|0)+1075684|0,f=zl(A[Hg(d+24|0,d+8|0,d)>>3]*128+128),v[e>>2]=f;kb=d+32|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function ZC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=w[a+8|0];h=v[a>>2];e=v[a+4>>2];f=Mc(b);a=Hb(b);b=kb-16|0;kb=b;v[b+8>>2]=a;v[b+12>>2]=e;a=h;g=v[Kb(b+12|0,b+8|0)>>2];c=g;while(1){a:{if(!c){c=0;break a}i=w[f|0];t[a|0]=i;if(!i){break a}f=f+1|0;a=a+1|0;c=c-1|0;continue}break}b:{if((d-1&255)>>>0<=1){t[b+7|0]=0;pm(a,((a+e|0)-g|0)+c|0,b+7|0);break b}if((d-3&255)>>>0>1){break b}t[b+6|0]=32;pm(a,((a+e|0)-g|0)+c|0,b+6|0)}c:{switch(d-1|0){case 0:case 3:t[(v[b+12>>2]+h|0)-1|0]=0;break;default:break c}}kb=b+16|0}function T9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=kb-16|0;kb=e;f=rf(a,c);ne(e,v[a+36>>2]);h=a;a:{if(!f){Sc(e,a+32|0,5);c=0;if(Cb(v[v[e>>2]>>2],v[e+4>>2])){break a}}c=0;d=kb-32|0;kb=d;g=v[a+36>>2];Kk(g,d+24|0);i=d,j=Ec(v[d+24>>2],v[d+28>>2]),v[i+16>>2]=j;v[d+12>>2]=256;dk(b,v[Kb(d+16|0,d+12|0)>>2]);a=v[b>>2];while(1){if(vc(a,v[b+4>>2])>>>0<=c>>>0){kb=d+32|0}else{v[d+16>>2]=0;Ep(g,d+16|0);a=v[b>>2];i=Eb(a,c),k=z[d+16>>2],z[i>>2]=k;c=c+1|0;continue}break}c=f}Ye(h,c);kb=e+16|0}function a$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=kb-16|0;kb=h;d=Hb(a);e=un(a);g=$d(b,c);a:{if(!g){break a}b:{f=Ac(a);if(f>>>0<=b>>>0){f=(Hb(a)<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(e-d>>>0<g>>>0){YF(a,e,(d+g|0)-e|0,d,d)}e=Ac(a)+(d<<2)|0;while(1){if((b|0)==(c|0)){break b}vd(e,v[b>>2]);b=b+4|0;e=e+4|0;continue}}b=HG(h,b,c);c=Ac(b);d=Hb(b);v[23588]=0;W(1172,a|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){Gc(b);break a}a=P()|0;O()|0;Gc(b);T(a|0);L()}vd(e,0);Rh(a,d+g|0)}kb=h+16|0;return a|0}function Nq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!ff(a)){if(!ff(b)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return}d=Mc(b);b=Hb(b);c=kb-16|0;kb=c;a:{if(b>>>0<=10){de(a,b);a=we(a,d,b);t[c+15|0]=0;je(a+b|0,c+15|0);break a}f=a;a=w[a+11|0];ip(f,10,b-10|0,a,0,a,b,d)}kb=c+16|0;return}d=Mc(b);b=Hb(b);c=kb-16|0;kb=c;e=Ll(a);b:{if(e>>>0>b>>>0){e=v[a>>2];Gd(a,b);a=we(e,d,b);t[c+15|0]=0;je(a+b|0,c+15|0);break b}f=a;a=v[a+4>>2];ip(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}kb=c+16|0}}function bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-32|0;kb=c;nd(b,0);_h(c,1,a);d=c+16|0;Fc(d,c);Ce(b+43|0,d);zb(d);v[b+24>>2]=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);u[b+34>>1]=x[b+34>>1]&65533|(w[a+13|0]|w[a+14|0]<<8)<<1&2;v[b>>2]=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b+4>>2]=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);v[b+8>>2]=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);t[c+16|0]=w[a+15|0];t[c|0]=64;e=b,f=w[Xb(d,c)|0]<<2,u[e+30>>1]=f;kb=c+32|0}function JE(a,b,c,d){var e=0,f=0,g=0;e=kb-80|0;kb=e;f=Af(e+48|0);v[23588]=0;d=Q(d|0,b|0,f|0)|0;g=v[23588];v[23588]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23588]=0;S(c|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}break c}c=v[f+4>>2];v[23588]=0;U(190,e|0,b|0,cc(c)|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Ad(f);T(a|0);L()}b=kc(e+24|0,e);hd(f+8|0,b);Bb(b);Bb(e);xk(a,f)}Ad(f);kb=e+80|0}function Fm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){if(th(715827882)>>>0<b>>>0){cd();L()}d=B(b,6);c=tc(d);v[a>>2]=c;v[a+4>>2]=c;f=Gb(a),g=c+d|0,v[f>>2]=g;d=kb-16|0;kb=d;c=Gq(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){lc(c);kb=d+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4;b=b+6|0;v[c+4>>2]=b;continue}break}}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function Gl(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(w[a+35|0]&2)){break a}Lo(a)}d=x[a+34>>1]&-513|d;u[a+34>>1]=d;if(b){v[a>>2]=4;u[a+34>>1]=d&65470;Og(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}}function B5(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0);v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){a=v[v[a+24>>2]+24>>2];if(!((b|0)<0|x[a+480188>>1]<=b>>>0)){a=a+B(b,872)|0;c=C(C(w[a+1075834|0])*C(.0078125));e=C(c*c);c=C(C(w[a+1075835|0])*C(.0078125));c=C(K(C(e+C(c*c))))}return C(c)}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9337,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function QO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=wt(b);v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);mz(a,2048);g=kb-16|0;kb=g;f=lr(g,a,2048);d=v[f+4>>2];i=v[f+8>>2];while(1){if((d|0)==(i|0)){lc(f);kb=g+16|0}else{v[d>>2]=0;v[d+4>>2]=0;d=d+8|0;v[f+4>>2]=d;continue}break}while(1){a:{c=1;if((e|0)!=1024){if((e|0)==2048){break a}c=+(e-1024|0);j=wt(K(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=j*Di(c)/(h*c)}k=bf(v[a>>2],e),l=c*.011841342921061943,A[k>>3]=l;e=e+1|0;continue}break}}function j_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=vc(d,v[a+4>>2]);if(c>>>0<b>>>0){f=kb-32|0;kb=f;d=b-c|0;c=v[Gb(a)>>2];b=v[a+4>>2];a:{if(d>>>0<=c-b>>2>>>0){Ct(a,d);break a}c=sw(a);g=qg(a,vc(v[a>>2],b)+d|0);e=vc(v[a>>2],v[a+4>>2]);b=f+8|0;pg(b+12|0,c);if(g){c=RF(v[b+16>>2],g)}else{c=0}v[b>>2]=c;e=c+(e<<2)|0;v[b+8>>2]=e;v[b+4>>2]=e;h=Cc(b),i=c+(g<<2)|0,v[h>>2]=i;NL(b,d);Ed(a,b);fQ(b);a=v[b>>2];if(a){TF(v[b+16>>2],a,Kz(b))}}kb=f+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<2)|0)}}function L8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;t[d+15|0]=b;b=w[a+11|0];a:{b:{c:{if(!gf(b)){c=10;b=zf(b);if((b|0)==10){break c}de(a,b+1|0);c=a;break a}b=v[a+4>>2];c=vu(v[a+8>>2])-1|0;if((b|0)!=(c|0)){break b}}e=kb-16|0;kb=e;g=pd(a);f=-17;b=c;if(b>>>0<=2147483622){v[e+8>>2]=b<<1;v[e+12>>2]=b+1;f=Ng(v[Zc(e+12|0,e+8|0)>>2])+1|0}c=tc(f);if(b){we(c,g,b)}if((b|0)!=10){Nb(g)}vd(a,c);cf(a,f);kb=e+16|0}c=v[a>>2];Gd(a,b+1|0)}a=b+c|0;je(a,d+15|0);t[d+14|0]=0;je(a+1|0,d+14|0);kb=d+16|0}function pR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;ok(a+8|0,0);e=v[b+4>>2];if(e){_q(a,e);vl(c+8|0,v[b>>2]);Dm(c,v[b>>2],v[b+4>>2]);d=kb-16|0;kb=d;f=v[a+4>>2];b=v[c+8>>2];j=v[c+12>>2];e=v[c>>2];k=v[c+4>>2];g=f+nR(b,j,e,k)|0;v[a+4>>2]=g;a:{b:{if(!f){h=g-1|0;break b}h=g-1|0;if((h^f-1)>>>0>31){break b}i=v[a>>2];break a}i=v[a>>2];v[i+((g>>>0<33?0:h>>>5|0)<<2)>>2]=0}Mo(d+8|0,i,f);oR(d,b,j,e,k,v[d+8>>2],v[d+12>>2]);kb=d+16|0}kb=c+16|0;return a|0}function Hea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=kb-48|0;kb=f;Jq(f+8|0,c);v[23588]=0;c=f+20|0;R(575,c|0,d|0);d=v[23588];v[23588]=0;b:{c:{d:{if((d|0)==1){break d}v[23588]=0;c=f+32|0;R(575,c|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}Ov(f,f+8|0);v[23588]=0;X(296,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}mQ(f+8|0);kb=f+48|0;break a}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;mQ(f+8|0)}T(a|0);L()}}function IX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=kb-48|0;kb=f;_o(f+8|0,c);v[23588]=0;c=f+20|0;R(139,c|0,d|0);d=v[23588];v[23588]=0;b:{c:{d:{if((d|0)==1){break d}v[23588]=0;c=f+32|0;R(139,c|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}Ov(f,f+8|0);v[23588]=0;X(114,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}wr(f+8|0);kb=f+48|0;break a}a=P()|0;O()|0;while(1){c=Ab(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;wr(f+8|0)}T(a|0);L()}}function lia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;e=c+8|0;f=Tb(e+8|0);v[23588]=0;d=S(202,b|0)|0;g=v[23588];v[23588]=0;a:{b:{if((g|0)==1){break b}v[23588]=0;U(244,e|0,b|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break b}d=v[e>>2];v[23588]=0;Q(188,b|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ic(f);T(a|0);L()}Uu(c,e);v[23588]=0;U(463,a|0,v[c>>2],v[c+4>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){Uc(c+8|0);kb=c+32|0;return}a=P()|0;O()|0;Uc(c+8|0);T(a|0);L()}function Kfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-32|0;kb=d;nd(b,0);iB(d,a+1|0);c=d+16|0;Fc(c,d);Ce(b+43|0,c);zb(c);v[b+24>>2]=w[a+73|0]|w[a+74|0]<<8|(w[a+75|0]<<16|w[a+76|0]<<24);c=w[a+54|0]|w[a+55|0]<<8|(w[a+56|0]<<16|w[a+57|0]<<24);v[b>>2]=c;v[b+4>>2]=w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24);e=w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24);if(e){v[b+8>>2]=e+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;xc(b+8|0,c);xc(b+4|0,v[b+8>>2]);kb=d+32|0}function zM(a,b){var c=0,d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;a:{f=b-4e3&65535;if(f>>>0<61537){break a}c=B(b,104)+a|0;e=c+484380|0;if(!_d(v[e>>2],v[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){Em(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[d+24>>2]=0;v[d+8>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Gl(e,0,d);break a}if(v[c+104>>2]==(e|0)){v[c+76>>2]=0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0}c=c+872|0;continue}}kb=d+32|0;return f>>>0>61536}function rP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=v[a+8>>2]-1|0;e=v[a+12>>2];f=v[a>>2]+B(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=B(e,g);i=v[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!w[a+16|0]){d=1;c=0;break c}d=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=w[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{t[b+f|0]=w[v[a+4>>2]+(B(c,e)+b|0)|0];b=b+1|0;e=v[a+12>>2];continue}}break}}function ky(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{if((c|0)<2){break a}k=c-2>>>1|0;f=d-a|0;if((k|0)<f>>1){break a}h=f+1|0;e=(h<<1)+a|0;g=x[e>>1];i=f+2|0;if((i|0)<(c|0)){j=x[e+2>>1];f=Kp(b,g&65535,j);e=f?e+2|0:e;h=f?i:h;g=f?j:g}i=x[d>>1];if(Kp(b,g&65535,i)){break a}while(1){b:{f=e;u[d>>1]=g;if((h|0)>(k|0)){break b}d=h<<1;h=d|1;e=(h<<1)+a|0;g=x[e>>1];j=d+2|0;if((j|0)<(c|0)){l=x[e+2>>1];d=Kp(b,g&65535,l);e=d?e+2|0:e;h=d?j:h;g=d?l:g}d=f;if(!Kp(b,g&65535,i)){continue}}break}u[f>>1]=i}}function Pr(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=kb-16|0;kb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((Qm(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=oG(i,b,f);h=Ac(f);v[23588]=0;h=W(1155,a|0,h|0,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}Gc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((Qm(a,c,b)|0)!=(b|0)){break b}}Do(e);j=a}kb=i+16|0;return j|0}a=P()|0;O()|0;Gc(f);T(a|0);L()}function _4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;if((c|0)!=1){a=v[a+24>>2];c=-1;a:{if((b|0)<0){break a}d=v[a+24>>2];if(tj(Wb(v[d+484360>>2],w[d+484376|0]))>>>0<=b>>>0){break a}a=v[a+24>>2];c=x[dc(v[Wb(v[a+484360>>2],w[a+484376|0])>>2],b)>>1]}return c|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9751,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function rH(a){var b=0,c=0;a:{b=v[a+4>>2];b=v[v[b>>2]-12>>2]+b|0;b:{if(!v[b+24>>2]){break b}if(!Zg(b)|!(v[b+4>>2]&8192)){break b}if(JH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23588]=0;b=S(1105,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[23588]=0;Y(1106,a+b|0);a=v[23588];v[23588]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Vb();L()}function Fz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;f=a+14|0;c=v[a>>2];e=v[a+4>>2];if(pc(c,e)){b=c}else{u[c>>1]=0;wf(c+2|0,b);g=d,h=zm(Fb(v[a>>2]),1),v[g+8>>2]=h;while(1){e=Fb(v[a+4>>2]);c=v[d+8>>2];if(Pb(c,e)){g=c,h=x[le(c,zm(c,-1))>>1],u[g>>1]=h;wf(c+2|0,b);yQ(d+8|0);continue}else{e=v[a+4>>2];b=v[a>>2]}break}}wf(f,$d(b,e)-1&255);wf(a+13|0,w[a+14|0]);wf(a+16|0,$d(v[a>>2],v[a+4>>2])-1&255);wf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){wf(a+17|0,$d(v[a>>2],v[a+4>>2])-1&255)}kb=d+16|0}function Mv(a){var b=0,c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){b=kb-16|0;kb=b;a=zD(b,a);c=v[a+4>>2];v[23588]=0;Y(170,c|0);c=v[23588];v[23588]=0;a:{if((c|0)!=1){v[a+4>>2]=v[a+4>>2]+36;lc(a);kb=b+16|0;break a}b=P()|0;O()|0;lc(a);T(b|0);L()}return}c=kb-32|0;kb=c;b=Gb(a);b=xD(c+8|0,yD(a,kr(v[a>>2],v[a+4>>2])+1|0),kr(v[a>>2],v[a+4>>2]),b);d=v[b+8>>2];v[23588]=0;Y(170,d|0);d=v[23588];v[23588]=0;b:{if((d|0)!=1){v[b+8>>2]=v[b+8>>2]+36;wD(a,b);Cv(b);kb=c+32|0;break b}a=P()|0;O()|0;Cv(b);T(a|0);L()}}function zk(a){var b=0,c=0;a:{b=v[a+4>>2];b=v[v[b>>2]-12>>2]+b|0;b:{if(!v[b+24>>2]){break b}if(!Zg(b)|!(v[b+4>>2]&8192)){break b}if(JH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23588]=0;b=S(22,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[23588]=0;R(16,a+b|0,1);a=v[23588];v[23588]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Vb();L()}function AJ(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=v[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(y[a+12>>2]<=d>>>0)){while(1){e=xy(v[a>>2]);c=nb;f=v[a+36>>2];if((c|0)==(f|0)&y[a+32>>2]<=e>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(e&v[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){d=xy(v[a>>2]);c=nb;f=v[a+28>>2];if((c|0)==(f|0)&y[a+24>>2]<=d>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(d&v[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=oV(c,a);BA(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;lc(a);kb=c+16|0;return}e=kb-32|0;kb=e;c=Gb(a);c=mV(e+8|0,nV(a,Kq(v[a>>2],v[a+4>>2])+1|0),Kq(v[a>>2],v[a+4>>2]),c);BA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;BA(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}qc(a,b);qc(a+4|0,c+8|0);qc(Gb(a),Cc(c));v[c>>2]=v[c+4>>2];lV(c);kb=e+32|0}function Ej(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=oV(c,a);GB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;lc(a);kb=c+16|0;return}e=kb-32|0;kb=e;c=Gb(a);c=mV(e+8|0,nV(a,Kq(v[a>>2],v[a+4>>2])+1|0),Kq(v[a>>2],v[a+4>>2]),c);GB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;GB(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}qc(a,b);qc(a+4|0,c+8|0);qc(Gb(a),Cc(c));v[c>>2]=v[c+4>>2];lV(c);kb=e+32|0}function gJ(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==10){Gx(a,b,c,d);return}g=d;i=B(e,e);k=B(i,e);j=B(i,i);a:{while(1){h=f|1;if(e>>>0>g>>>0){break a}h=f|2;if(g>>>0<i>>>0){break a}h=f|3;if(g>>>0<k>>>0){break a}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;return}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;t[c|0]=w[(d-B(b,e)|0)+4898|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}v[a+4>>2]=0;v[a>>2]=f}function hF(a,b,c,d,e,f,g,h){var i=0,j=0;i=kb-16|0;kb=i;v[23588]=0;Y(952,a|0);j=v[23588];v[23588]=0;a:{b:{if((j|0)!=1){c:{j=v[a+24>>2];v[23588]=0;ia(h|0,i|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}b=gg(Mc(i));zb(i);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23588]=0;X(939,g|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}kb=i+16|0;return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function WL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=kb-16|0;kb=c;d=v[b>>2];f=v[b+4>>2];e=qk(d,f);a:{if(e>>>0<=Du(a)>>>0){g=f;h=v[a>>2];i=qk(h,v[a+4>>2]);j=i>>>0>=e>>>0;if(!j){v[c+12>>2]=d;v[c+12>>2]=v[c+12>>2]+B(i,6);g=v[c+12>>2]}d=YL(d,g,h);if(!j){$x(a,g,f,e-qk(v[a>>2],v[a+4>>2])|0);break a}Od(a,d);break a}XL(a);mu(a,IA(a,e));$x(a,d,f,e)}kb=c+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];VL(a+24|0,b+24|0);Nq(a+36|0,b+36|0);return a}function PQ(a){var b=0,c=0;a:{if(Sb(a+60|0,13774,4)){break a}b=w[a+28|0]|w[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=w[a+42|0];if(b>>>0>64&(b|0)!=88|(w[a+48|0]|w[a+49|0]<<8)>>>0>64|(w[a+50|0]|w[a+51|0]<<8)>>>0>96){break a}b=w[a+52|0]|w[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(w[a+30|0]|w[a+31|0]<<8)|(w[a+38|0]|w[a+39|0]<<8|(w[a+40|0]<<16|w[a+41|0]<<24)|(w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1)){break a}c=SQ(a+20|0)}return c}function Lf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function yu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=kb-16|0;kb=g;h=Lb(b,0);f=(w[h|0]&15)<<8|w[Lb(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{d=x[(e<<1)+32672>>1];if(d>>>0<=f>>>0){if(!e|(f|0)==(d|0)|(x[(e<<1)+32670>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}t[c|0]=d;e=Lb(b,2);d=w[e|0];f=w[h|0];t[c+3|0]=0;t[c+1|0]=f&16|d>>>4;c=w[e|0];i=g,j=w[Lb(b,3)|0],t[i+15|0]=j;ee(a,c&15,g+15|0);kb=g+16|0}function O3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-32|0;kb=e;d=pf(e+16|0,1,0);a:{b:{while(1){f=Ac(d);BJ(e+8|0,f,Hb(d)+f|0,w[b|0],c);if(!v[e+12>>2]){break b}f=dh(Hb(d));v[23588]=0;R(59,d|0,f|0);f=v[23588];v[23588]=0;if((f|0)!=1){continue}break}break a}b=v[e+8>>2];c=Ac(d);v[23588]=0;R(60,d|0,b-c|0);b=v[23588];v[23588]=0;c:{if((b|0)!=1){v[23588]=0;R(61,a|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break a}break a}zb(d);kb=e+32|0;return}a=P()|0;O()|0;zb(d);T(a|0);L()}function hD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;g=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=g;a:{if(!g){break a}e=b+80|0;c=v[b+84>>2];if(c>>>0<=15){d=v[e>>2]}else{v[f+12>>2]=c-16;d=v[Zc(e,f+12|0)>>2]}v[a+8>>2]=d;c=v[b+88>>2];if(!(c&2)){break a}d=c;c=v[b+104>>2];b:{if(!(!gD(d,c)|v[e>>2]!=v[c+12>>2])){e=1;d=v[b+84>>2];if((d|0)==v[c+16>>2]){break b}}e=0;d=v[b+84>>2];if((d|0)!=v[c+8>>2]){break a}}h=a,i=B((v[c>>2]-d|0)+(e?112:48)|0,Fk(x[c+34>>1]))+g|0,v[h+4>>2]=i}kb=f+16|0}function gF(a,b,c,d,e,f,g){var h=0,i=0;h=kb-16|0;kb=h;v[23588]=0;Y(952,a|0);i=v[23588];v[23588]=0;a:{b:{if((i|0)!=1){c:{i=v[v[a+24>>2]+24>>2];v[23588]=0;ma(g|0,h|0,i|0,b|0,c|0,d|0,e|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}b=gg(Mc(h));zb(h);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23588]=0;X(939,f|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}kb=h+16|0;return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function P2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=Uo(a);v[e>>2]=61212;c=Cc(e);a=kb-16|0;kb=a;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=kb-16|0;kb=d;b=v[a+12>>2];v[d+8>>2]=v[a+8>>2];v[d+12>>2]=b;b=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=b;b=aJ(d);c=en(c);t[c+8|0]=0;v[c+4>>2]=b;v[c>>2]=61612;Tb(c+12|0);v[c>>2]=61376;b=v[a+4>>2];v[c+24>>2]=v[a>>2];v[c+28>>2]=b;b=v[a+12>>2];v[c+32>>2]=v[a+8>>2];v[c+36>>2]=b;kb=d+16|0;kb=a+16|0;return e|0}function OM(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;nb=v[e+4>>2];return v[e>>2]}function KJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;v[d+12>>2]=c;a:{if(!b){a=a+120|0;Hn(a);g=GJ(a,v[d+12>>2]),h=0,t[g+20|0]=h;break a}e=kb-16|0;kb=e;v[e+12>>2]=c;b:{if((b|0)==1){b=a+120|0;Hn(b);g=wx(b,a,v[e+12>>2]),h=1,t[g+20|0]=h;break b}f=kb-16|0;kb=f;v[f+12>>2]=c;c:{if((b|0)==2){a=a+120|0;Hn(a);a=GJ(a,v[f+12>>2]);fe(a+12|0);t[a+20|0]=2;break c}b=kb-16|0;kb=b;v[b+12>>2]=c;c=a+120|0;Hn(c);g=wx(c,a,v[b+12>>2]),h=3,t[g+20|0]=h;kb=b+16|0}kb=f+16|0}kb=e+16|0}kb=d+16|0}function w3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=kb-16|0;kb=c;a:{d=Th(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}j=d>>31;k=v[b>>2];g=v[b+4>>2];l=v[b+8>>2];b:while(1){if((f|0)==(l|0)){break a}m=B(f,g);e=0;while(1)if((e|0)==(g|0)){f=f+1|0;continue b}else{h=(e+m<<2)+k|0;i=v[h>>2];n=h,o=Ic(Pka(Oka(i,i>>31,d,j),nb,65536,0),nb),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;vJ(a,c);kb=c+16|0}function pS(a,b,c,d){var e=0,f=0,g=0;f=kb-16|0;kb=f;while(1){a:{e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!of(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){e=of(a,f+14|0);if(e){g=w[f+14|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!e){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}kb=f+16|0}function n3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=kb-16|0;kb=c;a:{d=Th(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}j=d>>31;k=v[b>>2];g=v[b+4>>2];l=v[b+8>>2];b:while(1){if((f|0)==(l|0)){break a}m=B(f,g);e=0;while(1)if((e|0)==(g|0)){f=f+1|0;continue b}else{h=(e+m<<2)+k|0;i=v[h>>2];n=h,o=Ic(Pka(Oka(i,i>>31,d,j),nb,65536,0),nb),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;nJ(a,c);kb=c+16|0}function K9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=kb-48|0;kb=f;d=v[a+36>>2];Tl(v[v[d>>2]-12>>2]+d|0,0);e=v[b>>2];d=v[e+12>>2];g=v[e+8>>2];if(d|g){h=v[a+36>>2];d=v[a+20>>2]+d|0;e=v[a+16>>2];g=g+e|0;e=Yg(f+32|0,g,e>>>0>g>>>0?d+1|0:d);d=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=d;d=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=d;Yj(h,f)}d=f+16|0;ne(d,v[a+36>>2]);vz(v[a+36>>2],c,v[v[b>>2]+16>>2]);c=v[b>>2];b=Mk(d,Lb(v[a+40>>2],v[c>>2]),x[c+20>>1]);Ye(a,c);$b(b);kb=f+48|0}function Z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;v[d+4>>2]=1;g=d,h=tc(56),v[g+8>>2]=h;c=Uo(v[d+8>>2]);v[c>>2]=61712;e=Cc(c);c=kb-16|0;kb=c;f=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=f;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;b=en(e);v[b>>2]=62076;Tb(b+4|0);t[b+20|0]=0;v[b+16>>2]=0;v[b>>2]=61876;e=v[c+4>>2];v[b+24>>2]=v[c>>2];v[b+28>>2]=e;e=v[c+12>>2];v[b+32>>2]=v[c+8>>2];v[b+36>>2]=e;t[b+40|0]=0;kb=c+16|0;b=a;a=Wo(d);Vo(b,Cc(a),a);fn(d);kb=d+16|0}function Tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;i=e,j=Aj(b),v[i>>2]=j;g=x[b>>1];c=kb-16|0;kb=c;f=a;d=Td(a);a:{if(d){b=jc(f);while(1){a=d;d=x[a+16>>1];if(no(g,d)){b=a;d=v[a>>2];if(d){continue}break a}if(!no(d,g)){break a}b=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=jc(f);b=a}v[c+12>>2]=a;a=v[b>>2];if(!a){oT(c,f,e);Kg(f,v[c+12>>2],b,v[c>>2]);a=ce(c);nT(c);h=1}Jg(e+8|0,v[fc(c,a)>>2],h);kb=c+16|0;a=wd(v[e+8>>2]);kb=e+16|0;return a+4|0}function waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-32|0;kb=d;Ii(d,2,a+2|0);e=d+16|0;Fc(e,d);Dc(b+492|0,e);f=b+236|0;g=c+1|0;zb(e);c=0;while(1){if((c|0)==120){v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;aM(w[a|0]&15,w[a+1|0]&15,w[a+2|0]&15,w[a+3|0]&15,w[a+4|0]&15,a+5|0,b+48|0);aM(w[a|0]>>>4|0,w[a+1|0]>>>4|0,w[a+2|0]>>>4|0,w[a+3|0]>>>4|0,w[a+4|0]>>>4|0,a+35|0,b+68|0);kb=d+32|0}else{h=dc(f,c),i=w[(a+c|0)+31|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function LL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;i=e,j=Aj(b),v[i>>2]=j;g=x[b>>1];c=kb-16|0;kb=c;f=a;d=Td(a);a:{if(d){b=jc(f);while(1){a=d;d=x[a+16>>1];if(Ys(g,d)){b=a;d=v[a>>2];if(d){continue}break a}if(!Ys(d,g)){break a}b=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=jc(f);b=a}v[c+12>>2]=a;a=v[b>>2];if(!a){oT(c,f,e);Kg(f,v[c+12>>2],b,v[c>>2]);a=ce(c);nT(c);h=1}Jg(e+8|0,v[fc(c,a)>>2],h);kb=c+16|0;a=wd(v[e+8>>2]);kb=e+16|0;return a+4|0}function oW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=kb-32|0;kb=d;nd(b,0);_h(d,1,a+33|0);c=d+16|0;Fc(c,d);Ce(b+43|0,c);zb(c);e=w[a+50|0]|w[a+51|0]<<8;v[b>>2]=e;v[b+24>>2]=w[a+52|0]|w[a+53|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;g=b,h=w[Xb(c,d)|0]<<2,u[g+30>>1]=h;f=w[a+55|0]|w[a+56|0]<<8;v[b+4>>2]=f;c=w[a+57|0]|w[a+58|0]<<8;v[b+8>>2]=c;a:{if((c|0)==65535){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(!w[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}u[b+34>>1]=x[b+34>>1]|2}kb=d+32|0}function vf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=Oka(b,c,h,i);i=nb;j=h;h=Oka(d,e,f,g);e=j+h|0;d=nb+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=Oka(g,e,c,d);g=j+i|0;c=nb+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=Oka(h,0,i,0);b=nb;c=0;d=Oka(h,c,l,d);b=b+d|0;c=nb+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=Oka(i,m,k,e)+b|0;e=nb;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;v[g+8>>2]=h;v[g+12>>2]=h>>>0<i>>>0?c+1|0:c;v[g>>2]=f;v[g+4>>2]=d}function p9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ti(a,b,c,d);v[a>>2]=44076;b=Tb(a+4208|0);v[a+4236>>2]=-1;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Ub(a+4248|0,0,48);v[23588]=0;Z(810);c=v[23588];v[23588]=0;a:{if((c|0)==1){break a}e=a,f=VM(),v[e+4296>>2]=f;Ts(a);Ss(a);v[23588]=0;R(897,a+44|0,2);c=v[23588];v[23588]=0;if((c|0)==1){break a}return a|0}c=P()|0;O()|0;ic(b);Jf(a);T(c|0);L()}function Zo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!gf(w[a+11|0])){c=w[b+11|0];if(!gf(c)){d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];return}d=pd(b);b=zd(v[b+4>>2],c);a:{if(b>>>0<=10){de(a,b);xd(we(a,d,b)+b|0,0);break a}e=a;a=zf(w[a+11|0]);pq(e,10,b-10|0,a,0,a,b,d)}return}d=pd(b);b=zd(v[b+4>>2],w[b+11|0]);c=vu(v[a+8>>2]);b:{if(b>>>0<c>>>0){c=v[a>>2];Gd(a,b);xd(we(c,d,b)+b|0,0);break b}e=a;a=v[a+4>>2];pq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function Uq(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=kb-16|0;kb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>0){if((Qm(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=pf(i,b,f);g=Ac(f);v[23588]=0;g=W(23,a|0,g|0,b|0)|0;h=v[23588];v[23588]=0;if((h|0)==1){break a}zb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((Qm(a,c,b)|0)!=(b|0)){break b}}Do(e);j=a}kb=i+16|0;return j|0}a=P()|0;O()|0;zb(f);T(a|0);L()}function Qy(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}gk(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}Db(d+8|0,a+1074312|0,7);if(Cb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}kb=d+16|0}function AG(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[116064];v[116064]=0;Hd();a=Aw(a,e+12|0,d);d=nb;g=v[116064];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}v[116064]=h;if((b|0)!=v[e+12>>2]){break c}if(!d&a>>>0<65536){break b}}v[c>>2]=4;a=65535;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}kb=e+16|0;return a&65535}function DE(a,b,c,d,e,f){var g=0;a:{g=kb-48|0;kb=g;mn(g+8|0,c);v[23588]=0;c=g+20|0;R(f|0,c|0,d|0);d=v[23588];v[23588]=0;b:{c:{d:{if((d|0)==1){break d}v[23588]=0;c=g+32|0;R(113,c|0,e|0);d=v[23588];v[23588]=0;if((d|0)==1){break d}Ov(g,g+8|0);v[23588]=0;X(114,a|0,b|0,v[g>>2],v[g+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}wr(g+8|0);kb=g+48|0;break a}a=P()|0;O()|0;while(1){c=Ab(c-12|0);if((c|0)!=(g+8|0)){continue}break}break b}a=P()|0;O()|0;wr(g+8|0)}T(a|0);L()}}function L9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=kb-48|0;kb=g;e=v[a+36>>2];Tl(v[v[e>>2]-12>>2]+e|0,0);f=v[b>>2];e=v[f+12>>2];h=v[f+8>>2];if(e|h){i=v[a+36>>2];e=v[a+20>>2]+e|0;f=v[a+16>>2];h=h+f|0;f=Yg(g+32|0,h,f>>>0>h>>>0?e+1|0:e);e=v[f+12>>2];v[g+8>>2]=v[f+8>>2];v[g+12>>2]=e;e=v[f+4>>2];v[g>>2]=v[f>>2];v[g+4>>2]=e;Yj(i,g)}e=g+16|0;ne(e,v[a+36>>2]);GL(d,v[a+36>>2],c);c=v[b>>2];b=Mk(e,Lb(v[a+40>>2],v[c>>2]),x[c+20>>1]);Ye(a,c);$b(b);kb=g+48|0}function J9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=kb-48|0;kb=g;e=v[a+36>>2];Tl(v[v[e>>2]-12>>2]+e|0,0);f=v[b>>2];e=v[f+12>>2];h=v[f+8>>2];if(e|h){i=v[a+36>>2];e=v[a+20>>2]+e|0;f=v[a+16>>2];h=h+f|0;f=Yg(g+32|0,h,f>>>0>h>>>0?e+1|0:e);e=v[f+12>>2];v[g+8>>2]=v[f+8>>2];v[g+12>>2]=e;e=v[f+4>>2];v[g>>2]=v[f>>2];v[g+4>>2]=e;Yj(i,g)}e=g+16|0;ne(e,v[a+36>>2]);CL(c,v[a+36>>2],d);c=v[b>>2];b=Mk(e,Lb(v[a+40>>2],v[c>>2]),x[c+20>>1]);Ye(a,c);$b(b);kb=g+48|0}function yE(a,b,c,d){var e=0,f=0,g=0;f=kb-32|0;kb=f;e=pf(f+16|0,1,0);a:{b:{while(1){g=Ac(e);BJ(f+8|0,g,Hb(e)+g|0,v[b>>2],c);if(!v[f+12>>2]){break b}g=dh(Hb(e));v[23588]=0;R(59,e|0,g|0);g=v[23588];v[23588]=0;if((g|0)!=1){continue}break}break a}b=v[f+8>>2];c=Ac(e);v[23588]=0;R(60,e|0,b-c|0);b=v[23588];v[23588]=0;c:{if((b|0)!=1){v[23588]=0;R(d|0,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break a}break a}zb(e);kb=f+32|0;return}a=P()|0;O()|0;zb(e);T(a|0);L()}function xE(a,b,c,d){var e=0,f=0,g=0;f=kb-32|0;kb=f;e=pf(f+16|0,1,0);a:{b:{while(1){g=Ac(e);gJ(f+8|0,g,Hb(e)+g|0,v[b>>2],c);if(!v[f+12>>2]){break b}g=dh(Hb(e));v[23588]=0;R(59,e|0,g|0);g=v[23588];v[23588]=0;if((g|0)!=1){continue}break}break a}b=v[f+8>>2];c=Ac(e);v[23588]=0;R(60,e|0,b-c|0);b=v[23588];v[23588]=0;c:{if((b|0)!=1){v[23588]=0;R(d|0,a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){break c}break a}break a}zb(e);kb=f+32|0;return}a=P()|0;O()|0;zb(e);T(a|0);L()}function Ws(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{d:{if(!(a&3)|!c){break d}e=b&255;while(1){if((e|0)==w[a|0]){break c}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break d}if(c){continue}break}}if(!d){break a}if(w[a|0]==(b&255)|c>>>0<4){break c}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){if(w[a|0]==(b&255)){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function C1(){var a=0,b=0,c=0,d=0,e=0,f=0;c=kb-48|0;kb=c;if($H(0,c+32|0)){js(v[116064],12594);L()}a=is(c+16|0,v[c+32>>2]);f=is(c+8|0,v[c+36>>2]/1e3|0);b=kb-32|0;kb=b;a=$G(b+8|0,a);e=v[a>>2];d=v[a+4>>2];a=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=a;d=v[b+4>>2]+d|0;a=v[b>>2];e=e+a|0;v[b+16>>2]=e;v[b+20>>2]=a>>>0>e>>>0?d+1|0:d;a=sl(b+24|0,b+16|0);d=v[a+4>>2];a=v[a>>2];kb=b+32|0;v[c+24>>2]=a;v[c+28>>2]=d;b=sl(c+40|0,c+24|0);a=v[b+4>>2];b=v[b>>2];kb=c+48|0;nb=a;return b|0}function Py(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}gk(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}Db(d+8|0,a+1074312|0,7);if(Cb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}kb=d+16|0}function wY(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[23588]=0;m=a;a=b;b=0;a=Na(1048,m|b,a|0,c|0,d|0,b|e,f|0)|0;b=v[23588];v[23588]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;ia(935,8803,g|0,h|0,i|0,j|0,k|0,l|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}return a|0}function $1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-16|0;kb=d;a:{g=v[c+12>>2];if(!g){break a}e=Jk(d,c+16|0);f=Gk(v[b+4>>2],w[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){Ab(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(w[pd(b)|0]==43){break c}if(w[pd(b)|0]==45){break c}}v[23588]=0;W(84,b|0,f-c|0,e|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=P()|0;O()|0;Ab(e);T(a|0);L()}ad(a,b);kb=d+16|0}function f6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[23588]=0;Y(977,a|0);f=v[23588];v[23588]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[23588]=0;b=Wa(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11218,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function QL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=v[a>>2];c=vc(d,v[a+4>>2]);if(c>>>0<=127){f=kb-32|0;kb=f;c=128-c|0;e=v[Gb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){Yx(a,c,b);break a}e=Gb(a);d=Vf(f+8|0,qg(a,vc(v[a>>2],d)+c|0),vc(v[a>>2],v[a+4>>2]),e);g=kb-16|0;kb=g;c=Wm(g,d+8|0,c);e=v[c>>2];while(1){if(v[c+4>>2]!=(e|0)){ek(e,z[b>>2]);e=v[c>>2]+4|0;v[c>>2]=e;continue}break}Ud(c);kb=g+16|0;Ed(a,d);Uf(d)}kb=f+32|0;return}if((c|0)!=128){Od(a,d+512|0)}}function wG(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{if((a|0)!=(b|0)){b:{c:{f=w[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=v[116064];v[116064]=0;Hd();a=Aw(a,e+12|0,d);d=nb;d:{g=v[116064];if(g){if(v[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}v[c>>2]=4;b=-1;a=-1;break a}v[116064]=h;if(v[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}v[c>>2]=4;b=0;a=0}kb=e+16|0;nb=a;return b}function g$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;d=Hb(a);e=bd(a);g=Sh(b,c);a:{if(!g){break a}b:{if(!_s(a,b)){if(e-d>>>0<g>>>0){sm(a,e,(d+g|0)-e|0,d,d,0,0)}e=Ac(a)+d|0;while(1){if((b|0)==(c|0)){break b}je(e,b);b=b+1|0;e=e+1|0;continue}}b=Uh(f,b,c);c=Mc(b);d=Hb(b);v[23588]=0;W(1065,a|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){zb(b);break a}a=P()|0;O()|0;zb(b);T(a|0);L()}t[f+15|0]=0;je(e,f+15|0);Rh(a,d+g|0)}kb=f+16|0;return a|0}function daa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);c=qk(v[b>>2],v[b+4>>2]);if(c){mu(a,c);$x(a,v[b>>2],v[b+4>>2],c)}v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[23588]=0;c=Q(878,a+24|0,b+24|0)|0;d=v[23588];v[23588]=0;b:{c:{if((d|0)!=1){v[23588]=0;Q(54,a+36|0,b+36|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}v[a+48>>2]=v[b+48>>2];break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;wc(c)}vk(a);T(b|0);L()}}function aO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=kb-16|0;kb=d;j=d,k=Aj(b),v[j>>2]=k;c=kb-16|0;kb=c;g=Iy(a,c+12|0,w[b|0],v[b+4>>2]);b=v[g>>2];if(!b){e=kb-16|0;kb=e;b=jc(a);h=mh(c,tc(28),nh(e+8|0,b));b=v[h>>2];f=v[d>>2];i=v[f+4>>2];f=v[f>>2];v[b+24>>2]=0;v[b+16>>2]=f;v[b+20>>2]=i;j=jc(h),k=1,t[j+4|0]=k;kb=e+16|0;Kg(a,v[c+12>>2],g,v[c>>2]);b=ce(c);rk(c);e=1}Jg(d+8|0,v[fc(c,b)>>2],e);kb=c+16|0;a=wd(v[d+8>>2]);kb=d+16|0;return a+8|0}function Jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Fb(v[b>>2]);h=Fb(v[b+4>>2]);g=kb-16|0;kb=g;v[g+8>>2]=d;while(1){a:{if(!Pb(d,h)){break a}e=kb-16|0;kb=e;f=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[e+8|0]=f;t[e+9|0]=f>>>8;t[e+10|0]=f>>>16;t[e+11|0]=f>>>24;f=w[d+4|0]|w[d+5|0]<<8;t[e+12|0]=f;t[e+13|0]=f>>>8;kb=e+16|0;if(x[e+8>>1]==(c|0)){break a}d=v[Nm(g+8|0)>>2];continue}break}kb=g+16|0;if(pc(d,Fb(v[b+4>>2]))){Jh(a);return}Ao(a,d)}function wE(a,b,c,d,e){var f=0,g=0,h=0;a:{f=kb-32|0;kb=f;h=Tb(a);b:{c:{d:{e:{while(1){a=v[b+8>>2];g=v[b>>2];v[23588]=0;a=W(156,g|0,a|0,8)|0;g=v[23588];v[23588]=0;if((g|0)==1){break c}if(!a){break d}v[23588]=0;U(e|0,f|0,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;R(d|0,h|0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}Ad(f);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ad(f);break b}kb=f+32|0;break a}a=P()|0;O()|0}Zd(h);T(a|0);L()}}function i6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23588]=0;Y(977,a|0);e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[23588]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11363,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+12>>2]+i|0;e=t[f|0];e=((B(t[f+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;kb=b+16|0}function uca(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:ih(a,0,c);return;case 1:ih(a,1,c);return;case 2:ih(a,2,c);return;case 3:ih(a,3,c);return;case 4:ih(a,4,c);return;case 5:ih(a,5,c);return;case 6:eP(a,23696,c);return;case 7:eP(a,24720,c);return;case 8:ih(a,6,c);return;case 9:ih(a,7,c);return;case 10:ih(a,8,c);return;case 11:ih(a,9,c);return;case 12:ih(a,10,c);return;case 13:ih(a,11,c);return;case 14:ih(a,12,c);return;default:break a}}Mb(a)}function h6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23588]=0;Y(977,a|0);e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[23588]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11399,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function XV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;a:{b:{if(!fg(a,7)){break b}c=0;if(!nC(a,17792)){break a}if(!fg(a,1)){break b}c=-1;if(!id(a,Oq(a))){break a}c=kb-16|0;kb=c;f=d+8|0;Fo(c+8|0,f);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(g|0);if(!e){Su(f)}c=-1;if(!e){break a}c=0;if(!aC(w[d+8|0],w[d+9|0])){break a}c=Be(a,b,$B(d+8|0),nb);break a}c=-1}kb=d+16|0;return c|0}function fp(a,b,c,d,e){var f=0,g=0,h=0;a:{f=kb-32|0;kb=f;h=Tb(a);b:{c:{d:{e:{while(1){a=v[b+8>>2];g=v[b>>2];v[23588]=0;a=W(156,g|0,a|0,e|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break c}if(!a){break d}v[23588]=0;R(d|0,f|0,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){v[23588]=0;R(c|0,h|0,f|0);a=v[23588];v[23588]=0;if((a|0)==1){break e}Ad(f);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ad(f);break b}kb=f+32|0;break a}a=P()|0;O()|0}Zd(h);T(a|0);L()}}function NX(a,b){a=a|0;b=b|0;var c=0;a=Mb(a);a:{if(w[b+16|0]){v[23588]=0;Q(133,a|0,4948)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[23588]=0;Q(133,a|0,12460)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}}if(sh(v[a+4>>2],w[a+11|0])){v[23588]=0;Q(133,a|0,10017)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[23588]=0;Q(133,a|0,11053)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;Ab(a);T(b|0);L()}function Xaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;d=x[a+30>>1];if(d){b=Pn(b<<16>>16,d<<16>>16)}u[e+14>>1]=b;a=a+52|0;a:{if(!sh(v[c+4>>2],w[c+11|0])){Zo(LL(a,e+14|0),c);break a}b=Xx(a,e+14|0);if(!Ig(b,xf(a))){break a}c=kb-16|0;kb=c;b=v[fc(c,b)>>2];d=kb-16|0;kb=d;f=Lg(fc(d+8|0,b));if((b|0)==v[a>>2]){v[a>>2]=v[f>>2]}g=Gb(a);v[g>>2]=v[g>>2]-1;KL(v[jc(a)>>2],b);a=v[f>>2];kb=d+16|0;KA(wd(b));Nb(b);fc(c+8|0,a);kb=c+16|0}kb=e+16|0}function A1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-32|0;kb=e;v[e+16>>2]=b;d=v[a+48>>2];v[e+20>>2]=c-((d|0)!=0);f=v[a+44>>2];v[e+28>>2]=d;v[e+24>>2]=f;a:{b:{if(bx(gb(v[a+60>>2],e+16|0,2,e+12|0)|0)){b=32}else{d=v[e+12>>2];if((d|0)>0){break b}b=d?32:16}v[a>>2]=b|v[a>>2];break a}g=d;f=v[e+20>>2];if(f>>>0>=d>>>0){break a}d=v[a+44>>2];v[a+4>>2]=d;v[a+8>>2]=d+(g-f|0);if(v[a+48>>2]){v[a+4>>2]=d+1;t[(b+c|0)-1|0]=w[d|0]}g=c}kb=e+32|0;return g|0}function iD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=kb-16|0;kb=d;b:{c:{if(!b){b=Mc(c);e=b;f=Hb(c)+b|0;c=Sh(b,f);if(c>>>0<4294967280){d:{if(Fl(c)){de(a,c);break d}g=Ng(c)+1|0;b=tc(g);vd(a,b);cf(a,g);Gd(a,c);a=b}while(1){if((e|0)!=(f|0)){xd(a,w[e|0]);a=a+1|0;e=e+1|0;continue}break}xd(a,0);break c}jf();L()}BP(d,b,c);v[23588]=0;R(50,a|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Gc(d)}kb=d+16|0;break a}a=P()|0;O()|0;Gc(d);T(a|0);L()}}function dfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb+-64|0;kb=c;Bm(c+48|0,b);se(c+16|0,v[c+48>>2],v[c+52>>2]);b=fe(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23588]=0;b=Fg(166,c+24|0,v[c+16>>2],v[c+20>>2],b,d);d=v[23588];v[23588]=0;a:{if((d|0)!=1){d=Tb(a);a=v[c+52>>2];e=v[c+48>>2];v[23588]=0;U(703,b|0,d|0,fd(e,a)>>>5|0);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;Ei(d);Bb(b);break a}Bb(b);ic(c+48|0);kb=c- -64|0;return}a=P()|0;O()|0}ic(c+48|0);T(a|0);L()}function dF(a,b,c,d){var e=0,f=C(0);v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;if((e|0)!=1){a=v[v[a+24>>2]+24>>2];a:{if((b|0)<0|x[a+480188>>1]<=b>>>0){break a}a=a+B(b,872)|0;if(!(t[a+1075081|0]&1)){break a}f=C(C(w[a+d|0])*C(.0078125))}return f}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,c|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return C(0)}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function d6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23588]=0;Y(977,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[23588]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6663,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function b6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23588]=0;Y(977,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[23588]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6717,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb+-64|0;kb=c;Bm(c+48|0,b);se(c+16|0,v[c+48>>2],v[c+52>>2]);b=fe(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23588]=0;b=Fg(166,c+24|0,v[c+16>>2],v[c+20>>2],b,d);d=v[23588];v[23588]=0;a:{if((d|0)!=1){d=Tb(a);a=v[c+52>>2];e=v[c+48>>2];v[23588]=0;U(704,b|0,d|0,fd(e,a)>>>2|0);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;wc(d);Bb(b);break a}Bb(b);ic(c+48|0);kb=c- -64|0;return}a=P()|0;O()|0}ic(c+48|0);T(a|0);L()}function _ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb+-64|0;kb=c;Bm(c+48|0,b);se(c+16|0,v[c+48>>2],v[c+52>>2]);b=fe(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23588]=0;b=Fg(166,c+24|0,v[c+16>>2],v[c+20>>2],b,d);d=v[23588];v[23588]=0;a:{if((d|0)!=1){d=Tb(a);a=v[c+52>>2];e=v[c+48>>2];v[23588]=0;U(706,b|0,d|0,fd(e,a)>>>4|0);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;Cm(d);Bb(b);break a}Bb(b);ic(c+48|0);kb=c- -64|0;return}a=P()|0;O()|0}ic(c+48|0);T(a|0);L()}function Qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=(v[b+12>>2]<<1)+i|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;kb=b+16|0}function Jfa(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-32|0;kb=d;nd(b,0);iB(d,a+1|0);c=d+16|0;Fc(c,d);Ce(b+43|0,c);zb(c);v[b+24>>2]=w[a+78|0]|w[a+79|0]<<8;c=w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24);v[b>>2]=c;v[b+4>>2]=w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24);v[b+8>>2]=w[a+66|0]|w[a+67|0]<<8|(w[a+68|0]<<16|w[a+69|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;xc(b+8|0,c);xc(b+4|0,v[b+8>>2]);kb=d+32|0}function $ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb+-64|0;kb=c;Bm(c+48|0,b);se(c+16|0,v[c+48>>2],v[c+52>>2]);b=fe(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23588]=0;b=Fg(166,c+24|0,v[c+16>>2],v[c+20>>2],b,d);d=v[23588];v[23588]=0;a:{if((d|0)!=1){d=Tb(a);a=v[c+52>>2];e=v[c+48>>2];v[23588]=0;U(705,b|0,d|0,fd(e,a)>>>8|0);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;Pt(d);Bb(b);break a}Bb(b);ic(c+48|0);kb=c- -64|0;return}a=P()|0;O()|0}ic(c+48|0);T(a|0);L()}function zC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=Rc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=kb-32|0;kb=e;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){sC(a,b);break a}c=Gb(a);c=Nj(e+8|0,Oj(a,Rc(v[a>>2],d)+b|0),Rc(v[a>>2],v[a+4>>2]),c);f=kb-16|0;kb=f;b=Oo(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){rC(d);d=v[b>>2]+2|0;v[b>>2]=d;continue}break}Ud(b);kb=f+16|0;Ed(a,c);Oi(c)}kb=e+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<1)|0)}}function E3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-16|0;kb=d;a:{g=v[c+12>>2];if(!g){break a}e=yh(d,c+16|0);f=Hb(b);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){zb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(w[Tc(b,0)|0]==43){break c}if(w[Tc(b,0)|0]==45){break c}}v[23588]=0;W(77,b|0,f-c|0,e|0)|0;i=v[23588];v[23588]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=P()|0;O()|0;zb(e);T(a|0);L()}ad(a,b);kb=d+16|0}function eF(a,b,c,d){var e=0,f=C(0);v[23588]=0;Y(952,a|0);e=v[23588];v[23588]=0;if((e|0)!=1){a=v[v[a+24>>2]+24>>2];a:{if((b|0)<0|x[a+480188>>1]<=b>>>0){break a}a=a+B(b,872)|0;if(t[a+1075081|0]&1){break a}f=C(C(w[a+d|0])*C(.0078125))}return f}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,c|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return C(0)}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function oc(a,b){var c=0,d=0,e=0;c=v[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return oc(a,24)+(oc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=qs(a);d=0;if((e|0)==-1){break a}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){aa(10027,13110,1632,6833);L()}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}function gg(a){var b=0,c=0,d=0;d=yp(yg(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=w[a|0];break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}t[c|0]=b;if(!(b&255)){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function Ms(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(v[23584]){b=Ms(v[23584])}if(!v[23508]){break a}c=b|c;a=v[23508];continue}break}d=v[a+76>>2]>=0;b:{c:{if(v[a+20>>2]==v[a+28>>2]){break c}ob[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break c}b=-1;if(d){break b}break a}b=v[a+8>>2];e=v[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;ob[v[a+40>>2]](a,b,b>>31,1)|0}b=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;if(!d){break a}}}return b|c}function Kk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;v[b>>2]=0;v[b+4>>2]=0;t[e+15|0]=0;Nh(a,e+15|0);c=w[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){v[b>>2]=f;v[b+4>>2]=d;if(!g&(h|0)==(i|0)){kb=e+16|0}else{t[e+15|0]=0;Nh(a,e+15|0);c=v[b>>2];j=v[b+4>>2];f=w[e+15|0];d=g;g=h+1|0;d=g?d:d+1|0;h=g;g=d;k=c;d=(h<<3)-2|0;c=d&31;if((d&63)>>>0>=32){d=f<<c;c=0}else{d=(1<<c)-1&f>>>32-c;c=f<<c}f=k|c;d=d|j;continue}break}}function qM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;d=bd(a);a:{b:{c:{f=Sh(b,c);if(d>>>0<f>>>0){if(_s(a,b)){break c}g=d;h=f-d|0;d=Hb(a);sm(a,g,h,d,0,d,0)}d=Ac(a);while(1){if((b|0)==(c|0)){break b}je(d,b);b=b+1|0;d=d+1|0;continue}}b=Uh(e,b,c);c=Mc(b);d=Hb(b);v[23588]=0;U(57,a|0,c|0,d|0);c=v[23588];v[23588]=0;if((c|0)!=1){zb(b);break a}a=P()|0;O()|0;zb(b);T(a|0);L()}t[e+15|0]=0;je(d,e+15|0);Rh(a,f)}kb=e+16|0;return a|0}function fM(a,b,c,d,e,f,g,h){var i=0,j=0;i=kb-16|0;kb=i;v[i+12>>2]=d;a:{if(!(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24))){break a}v[i+8>>2]=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);j=b;b=v[Kb(i+8|0,i+12|0)>>2];v[j>>2]=b;b=Dd(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),b,d);v[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=x[e>>1]|f;u[e>>1]=b;if((w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=1){break a}u[e>>1]=b|g}kb=i+16|0}function $w(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[116090]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[116064]=25;a=-1}else{a=1}return a}t[a|0]=b;return 1}function n6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-32|0;kb=e;v[e+24>>2]=c;c=v[eg(e+16|0,e+24|0)>>2];v[23588]=0;f=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;fa(946,a+8|0,e|0,c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=XI(a);b=WI(a+88|0);c=VI(a+92|0);d=UI(a+96|0);v[a>>2]=62440;v[b>>2]=62556;v[c>>2]=62636;v[d>>2]=62676;Ee(e+24|0);kb=e+32|0;return a|0}a=P()|0;O()|0;Ee(e+24|0);T(a|0);L()}function bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=kb-4096|0;kb=c;Bm(a,b);a:while(1){if(fd(v[a>>2],v[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){g=f|2048;b=0;while(1){if((b|0)!=2048){h=Lb(v[a>>2],b+g|0);i=Lb(c,b<<1);d=w[h|0]+d|0;t[i|0]=d;b=b+1|0;continue}break}qh(c,wQ(c),Rf(Fb(v[a>>2]),f));e=e+1|0;continue a}else{g=Lb(v[a>>2],b+f|0);h=Lb(c,b<<1|1);d=w[g|0]+d|0;t[h|0]=d;b=b+1|0;continue}}break}kb=c+4096|0}function R5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23588]=0;Y(977,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+96>>2];v[23588]=0;ta(f|0,d|0,b|0,+c);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11536,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function P5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23588]=0;Y(977,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+88>>2];v[23588]=0;ta(f|0,d|0,b|0,+c);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10987,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function O8(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;c=kb-32|0;kb=c;pi(c,b);v[23588]=0;U(917,c+16|0,0,c|0);b=v[23588];v[23588]=0;a:{b:{c:{if((b|0)!=1){v[23588]=0;R(918,d|0,c+16|0);b=v[23588];v[23588]=0;if((b|0)==1){break c}Gc(c+16|0);zb(c);kb=c+32|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Gc(c+16|0)}zb(c);T(a|0);L()}v[23588]=0;Q(915,a|0,d|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){Ab(d);kb=d+16|0;return}a=P()|0;O()|0;Ab(d);T(a|0);L()}function $5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23588]=0;Y(977,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[23588]=0;ta(f|0,d|0,b|0,+c);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11598,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function eca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=rg(e,v[a+4>>2]);if(d>>>0<b>>>0){e=kb-32|0;kb=e;a:{b:{d=b-d|0;b=v[Gb(a)>>2];f=v[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){yz(a,d,c);break c}b=Gb(a);b=Et(e+8|0,dq(a,rg(v[a>>2],f)+d|0),rg(v[a>>2],v[a+4>>2]),b);v[23588]=0;U(757,b|0,d|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}dP(a,b);wz(b)}kb=e+32|0;break a}a=P()|0;O()|0;wz(b);T(a|0);L()}return}if(b>>>0<d>>>0){gP(a,e+(b<<5)|0)}}function Si(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=fd(d,v[a+4>>2]);if(c>>>0<b>>>0){e=kb-32|0;kb=e;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>>0){sE(a,b);break a}c=Gb(a);c=Zl(e+8|0,Xl(a,fd(v[a>>2],d)+b|0),fd(v[a>>2],v[a+4>>2]),c);f=kb-16|0;kb=f;b=Xv(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){rE(d);d=v[b>>2]+1|0;v[b>>2]=d;continue}break}Ud(b);kb=f+16|0;Ed(a,c);Yl(c)}kb=e+32|0;return}if(b>>>0<c>>>0){Od(a,b+d|0)}}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){if(th(178956970)>>>0<b>>>0){cd();L()}d=B(b,24);c=tc(d);v[a>>2]=c;v[a+4>>2]=c;g=Gb(a),h=c+d|0,v[g>>2]=h;d=kb-16|0;kb=d;b=lE(d,a,b);c=v[b+4>>2];e=v[b+8>>2];a:{while(1){if((c|0)==(e|0)){break a}v[23588]=0;Y(576,c|0);f=v[23588];v[23588]=0;if((f|0)!=1){c=c+24|0;v[b+4>>2]=c;continue}break}a=P()|0;O()|0;lc(b);T(a|0);L()}lc(b);kb=d+16|0}return a|0}function Zia(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=kb-32|0;kb=g;a:{if(x[a+480192>>1]<b>>>0){break a}b=v[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+16|0;VT(h,b);i=g,j=Fb(v[g+16>>2]),v[i+8>>2]=j;h=Zf(h);while(1){b=v[g+8>>2];if(Pb(b,h)){b=x[ro(b)>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Lg(g+8|0);continue}else{ru(g+16|0)}break}}kb=g+32|0}function sO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;j=e,k=Aj(b),v[j>>2]=k;c=kb-16|0;kb=c;f=iz(a,c+12|0,x[b>>1],v[b+4>>2]);b=v[f>>2];if(!b){b=kb-16|0;kb=b;d=jc(a);g=mh(c,tc(36),nh(b+8|0,d));d=v[g>>2]+16|0;h=v[e>>2];i=v[h+4>>2];v[d>>2]=v[h>>2];v[d+4>>2]=i;Tb(d+8|0);j=jc(g),k=1,t[j+4|0]=k;kb=b+16|0;Kg(a,v[c+12>>2],f,v[c>>2]);b=ce(c);xO(c);d=1}Jg(e+8|0,v[fc(c,b)>>2],d);kb=c+16|0;a=wd(v[e+8>>2]);kb=e+16|0;return a+8|0}function q4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=kb-16|0;kb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[23588]=0;b=Q(55,h|0,8160)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}d=P()|0;O()|0;zb(b);break b}el(a,b,4);c=ux(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);kb=h+16|0;return c|0}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}function X4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;if((c|0)!=1){a=v[v[a+24>>2]+24>>2];c=0;a:{if(!ts(b)){break a}d=v[a+484344>>2];if(!ye(d,v[a+484348>>2],b&65535)){break a}c=v[Zb(d,b)+12>>2]}return c|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6627,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function E4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=kb-16|0;kb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[23588]=0;b=Q(55,h|0,8160)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}d=P()|0;O()|0;zb(b);break b}el(a,b,4);c=tx(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);kb=h+16|0;return c|0}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}function yV(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];if(b){iL(v[b+12>>2],b);b=v[a>>2];ob[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Lc(a);b=kb-32|0;kb=b;a:{b:{d=kp(a);c=fd(v[a>>2],v[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}v[23588]=0;c=fa(906,b+8|0,c|0,c|0,Gb(a)|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){Ed(a,c);Yl(c);break c}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break b}}kb=b+32|0;break a}V(0)|0;O()|0;Vb();L()}}function ZS(a,b){var c=0,d=0,e=0,f=0;d=v[a>>2];c=vc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=kb-32|0;kb=e;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){DA(a,b);break a}c=Gb(a);c=Vf(e+8|0,qg(a,vc(v[a>>2],d)+b|0),vc(v[a>>2],v[a+4>>2]),c);f=kb-16|0;kb=f;b=Wm(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){Om(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Ud(b);kb=f+16|0;Ed(a,c);Uf(c)}kb=e+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<2)|0)}}function xG(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[116064];v[116064]=0;Hd();a=Aw(a,e+12|0,d);d=nb;g=v[116064];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}v[116064]=h;if((b|0)!=v[e+12>>2]){break c}if(!d){break b}}v[c>>2]=4;a=-1;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}kb=e+16|0;return a}function Oea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-16|0;kb=c;d=_c(c+8|0,16,1,1,0);v[c+4>>2]=0;nd(a,0);zc(b);a:{b:{if(Tq(b,13711)){dd(b,12);if(!Co(b)){Ko(d,2)}dd(b,24);break b}if(Gh(b,13583)){zc(b);v[c+4>>2]=4;e=1;break a}xd(d,8)}e=0}f=a,g=(df(b)>>>0)/(B(w[d|0],oq(w[d+1|0]))>>>3>>>0)|0,v[f>>2]=g;b=wg(d,a,b);if(!(!b|!e)){d=v[a+20>>2];f=c,g=Ij(v[a>>2],x[a+34>>1]),v[f>>2]=g;Ub(d,0,v[Kb(c+4|0,c)>>2])}kb=c+16|0;return(b|0)!=0|0}function BP(a,b,c){a:{switch(b|0){case 0:jh(a,0,c);return;case 1:jh(a,1,c);return;case 2:jh(a,2,c);return;case 3:jh(a,3,c);return;case 4:jh(a,4,c);return;case 5:jh(a,5,c);return;case 6:qP(a,23696,c);return;case 7:qP(a,24720,c);return;case 8:jh(a,6,c);return;case 9:jh(a,7,c);return;case 10:jh(a,8,c);return;case 11:jh(a,9,c);return;case 12:jh(a,10,c);return;case 13:jh(a,11,c);return;case 14:jh(a,12,c);return;default:break a}}Mb(a)}function hX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-16|0;kb=e;v[e+4>>2]=1;k=e,l=tc(32),v[k+8>>2]=l;f=Uo(v[e+8>>2]);v[f>>2]=42968;i=Cc(f);f=kb-16|0;kb=f;g=Ql(f+8|0,v[b>>2],v[b+4>>2]);h=v[g>>2];j=v[c>>2];d=v[d>>2];b=kb-16|0;kb=b;g=v[g+4>>2];v[b+12>>2]=g;v[b+8>>2]=h;c=en(i);v[c>>2]=43104;Ql(c+4|0,h,g);v[c+16>>2]=d;v[c+12>>2]=j;me(b+8|0);kb=b+16|0;kb=f+16|0;b=a;a=Wo(e);Vo(b,Cc(a),a);fn(e);kb=e+16|0}function NU(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(B(b,6)+a|0)+1072|0,g=Hk(a,7),t[f|0]=g;d=Hk(a,1);e=Hk(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;NU(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;continue}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=v[a>>2];c=Cf(d,v[a+4>>2]);if(c>>>0<b>>>0){d=kb-32|0;kb=d;a:{b:{c=b-c|0;b=v[Gb(a)>>2];e=v[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){wC(a,c);break c}b=Gb(a);b=lB(d+8|0,mB(a,Cf(v[a>>2],e)+c|0),Cf(v[a>>2],v[a+4>>2]),b);v[23588]=0;R(506,b|0,c|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}kB(a,b);wu(b)}kb=d+32|0;break a}a=P()|0;O()|0;wu(b);T(a|0);L()}return}if(b>>>0<c>>>0){uC(a,d+B(b,20)|0)}}function g6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[23588]=0;R(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11228,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function T5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[23588]=0;R(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12699,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function O5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+84>>2];v[23588]=0;R(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12182,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function N5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+80>>2];v[23588]=0;R(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11077,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function M5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+104>>2];v[23588]=0;oa(e|0,c|0,+b);c=v[23588];v[23588]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23588]=0;X(939,15104,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);d=v[23588];v[23588]=0;if((d|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function y1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+16>>2];d=v[a+12>>2];b:{if(g>>>0>d>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=g-d;v[e+4>>2]=c-f;g=d;d=v[td(e+12|0,td(e+8|0,e+4|0))>>2];b=we(b,g,d);v[a+12>>2]=v[a+12>>2]+d;b=b+d|0;break b}d=ob[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=qp(d),t[h|0]=i;d=1;b=b+1|0}f=d+f|0;continue}break}kb=e+16|0;return f|0}function xF(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=kb-16|0;kb=i;if(1073741806-b>>>0>=c>>>0){j=Ac(a);k=1073741807;if(b>>>0<=536870886){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=cm(v[Zc(i+12|0,i+8|0)>>2])+1|0}c=Ci(k);if(e){mi(c,j,e)}if(g){mi(c+(e<<2)|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){d=e<<2;mi((d+c|0)+(g<<2)|0,(d+j|0)+(f<<2)|0,h)}if((b|0)!=1){Nb(j)}vd(a,c);cf(a,k);b=a;a=h+(e+g|0)|0;Gd(b,a);vd(c+(a<<2)|0,0);kb=i+16|0;return}jf();L()}function Z5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[23588]=0;oa(e|0,c|0,+b);c=v[23588];v[23588]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23588]=0;X(939,11636,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);d=v[23588];v[23588]=0;if((d|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function U5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[23588]=0;R(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9272,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function S5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+100>>2];v[23588]=0;d=+sa(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11554,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function a6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[23588]=0;d=+sa(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11617,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function YX(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb-32|0;kb=c;b=yc(c,16736);v[23588]=0;U(120,c+16|0,a|0,b|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){Ab(b);a=0;b=0;while(1){d=v[c+16>>2];if(!(b>>>0<=3&yd(d,v[c+20>>2])>>>0>b>>>0)){Sl(c+16|0);kb=c+32|0;return a|0}v[23588]=0;d=S(121,Nd(d,b)|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=P()|0;O()|0;Sl(c+16|0);break a}a=P()|0;O()|0;Ab(b)}T(a|0);L()}function X5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[23588]=0;oa(e|0,c|0,+b);c=v[23588];v[23588]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23588]=0;X(939,7737,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);d=v[23588];v[23588]=0;if((d|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function V5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[23588]=0;oa(e|0,c|0,+b);c=v[23588];v[23588]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23588]=0;X(939,7685,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);d=v[23588];v[23588]=0;if((d|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Tq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=hc(c+8|0,c+24|0,7);nc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Sb(c+24|0,b,7)){break b}_b(a,7);d=1}kb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d|0}function Q5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+92>>2];v[23588]=0;d=+sa(e|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11007,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function OL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-32|0;kb=d;v[d+16>>2]=c;v[d+24>>2]=b;i=d,j=ie(a),v[i+8>>2]=j;c=d+24|0;b=On(c,d+8|0);c=On(d+16|0,c);a:{if(Hb(a)>>>0>=b>>>0){if((c|0)==-1){FL(a,b);break a}f=a;e=kb-16|0;kb=e;v[e+12>>2]=c;if(c){g=Hb(f);h=Ac(f);c=g-b|0;v[e+8>>2]=c;a=v[Kb(e+12|0,e+8|0)>>2];v[e+12>>2]=a;b:{if((a|0)==(c|0)){a=c;break b}b=b+h|0;Xh(b,a+b|0,c-a|0)}Vx(f,h,g-a|0)}kb=e+16|0;break a}sk();L()}kb=d+32|0}function eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=kb-16|0;kb=b;i=v[a+16>>2];f=Tf(1,2);g=nb;Rb(a,f,g);j=v[a+24>>2];k=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=u[(v[b+12>>2]<<1)+i>>1];v[c>>2]=v[c>>2]+B(h,k);v[c+4>>2]=v[c+4>>2]+B(j,h);Rb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;mg(a,f,g);kb=b+16|0}function OQ(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;v[b+4>>2]=((w[a+48|0]|w[a+49|0]<<8)<<1)+((w[a+32|0]|w[a+33|0]<<8)<<4);v[b+8>>2]=((w[a+50|0]|w[a+51|0]<<8)<<1)+((w[a+34|0]|w[a+35|0]<<8)<<4);v[b+12>>2]=(B(w[a+52|0]|w[a+53|0]<<8,5)+((w[a+36|0]|w[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=Eb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=lp(v[a>>2],v[c>>2])?c:a;continue}}kb=b+16|0;a=v[a>>2];nb=a>>31;return a}function Ls(a,b){var c=0,d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;c=Td(a);d=jc(a);f=kb-16|0;kb=f;while(1){if(c){g=pt(c+16|0,b);d=g?d:c;c=v[(g?c+4|0:c)>>2];continue}break}c=v[fc(f+8|0,d)>>2];kb=f+16|0;a:{if(Pb(c,Zf(a))){if(!pt(b,wd(c))){break a}}c=Zf(a)}if(!pc(c,Zf(a))){b=v[fc(e+8|0,c)>>2];c=kb-16|0;kb=c;d=Lg(fc(c+8|0,b));if((b|0)==v[a>>2]){v[a>>2]=v[d>>2]}d=Gb(a);v[d>>2]=v[d>>2]-1;KL(v[jc(a)>>2],b);kb=c+16|0;xm(wd(b));Nb(b)}kb=e+16|0}function e6(a,b){a=a|0;b=b|0;var c=0,d=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[23588]=0;b=Q(d|0,c|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6690,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function c6(a,b){a=a|0;b=b|0;var c=0,d=0;v[23588]=0;Y(977,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[23588]=0;b=Q(d|0,c|0,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6741,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function sJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=kb-16|0;kb=g;v[g+8>>2]=b;j=g,k=ie(a),v[j>>2]=k;b=On(g+8|0,g);h=kb-16|0;kb=h;a:{f=Hb(a);if(b>>>0<=f>>>0){if(c){e=bd(a);b:{if(e-f>>>0>=c>>>0){e=Ac(a);if((b|0)==(f|0)){break b}i=b+e|0;Xh(i+c|0,i,f-b|0);break b}sm(a,e,(c+f|0)-e|0,f,b,0,c);e=v[a>>2]}zB(b+e|0,c,d);b=c+f|0;Rh(a,b);t[h+15|0]=0;je(b+e|0,h+15|0)}kb=h+16|0;break a}sk();L()}ie(a);kb=g+16|0}function hH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-48|0;kb=e;v[e+44>>2]=c;v[e+40>>2]=b;b=Nc(e+8|0,d);v[23588]=0;U(1108,e+24|0,e+40|0,b|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){v[23588]=0;a=Q(1109,a|0,e+24|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}zb(e+24|0);zb(b);v[a>>2]=92220;b=v[e+44>>2];v[a+8>>2]=v[e+40>>2];v[a+12>>2]=b;kb=e+48|0;return a|0}c=P()|0;O()|0;break a}c=P()|0;O()|0;zb(e+24|0)}zb(b);T(c|0);L()}function vg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Wc(42956,d+14|0)>>1];e=v[a>>2];c=Rc(e,v[a+4>>2]);a:{if(b>>>0>c>>>0){e=kb-32|0;kb=e;b=b-c|0;c=v[Gb(a)>>2];g=v[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){Ho(a,b,f);break b}c=Gb(a);c=Nj(e+8|0,Oj(a,Rc(v[a>>2],g)+b|0),Rc(v[a>>2],v[a+4>>2]),c);KC(c,b,f);Ed(a,c);Oi(c)}kb=e+32|0;break a}if(b>>>0<c>>>0){Od(a,e+(b<<1)|0)}}kb=d+16|0}function fea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=kb-16|0;kb=b;i=v[a+16>>2];f=Tf(1,2);g=nb;Rb(a,f,g);j=v[a+24>>2];k=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=t[v[b+12>>2]+i|0]<<8;v[c>>2]=v[c>>2]+B(h,k);v[c+4>>2]=v[c+4>>2]+B(j,h);Rb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;mg(a,f,g);kb=b+16|0}function VS(a,b,c,d,e){var f=0,g=0,h=0,i=0;h=-1;f=d&2147483647;i=f;g=(f|0)==2147418112;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=(f|0)==2147418112;if(g?0:g&0|f>>>0>2147418112){break a}if(!(a|c|(f|i|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function O6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;if(a){a=rc(d+8|0,a);e=v[a+4>>2];f=v[a>>2];b=kb-16|0;kb=b;a=0;a:{if(!e){break a}a=32224;while(1){if((a|0)==32624){c=32624;while(1){a=c;if((a|0)!=32672){c=a+12|0;if(!mM(f,e,v[rc(b,v[a+8>>2])>>2],v[b+4>>2])){continue}}break}a=(a|0)!=32672;break a}c=v[a+4>>2];a=a+8|0;if(!mM(f,e,v[rc(b+8|0,c)>>2],v[b+12>>2])){continue}break}a=1}kb=b+16|0}else{a=0}kb=d+16|0;return a|0}function i_(a){a=a|0;if(w[468416]){return v[117103]}if(!w[468936]){a=468768;while(1){a=Mb(a)+12|0;if((a|0)!=468936){continue}break}t[468936]=1}rd(468768,88900);rd(468780,88928);rd(468792,88956);rd(468804,88988);rd(468816,89028);rd(468828,89064);rd(468840,89092);rd(468852,89128);rd(468864,89144);rd(468876,89160);rd(468888,89176);rd(468900,89192);rd(468912,89208);rd(468924,89224);t[468416]=1;v[117103]=468768;return 468768}function Us(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16);b=a;c=v[a+4232>>2];a=w[a+4264|0];v[b+4228>>2]=(B(c,(a?a:-89)&255)+250>>>0)/500}function e4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=kb-32|0;kb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{e=a;a=hc(b+16|0,c,d);a=bt(e,v[a>>2],v[a+4>>2],b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[23588]=0;b=Q(55,b|0,8017)|0;c=v[23588];v[23588]=0;b:{if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break b}c=P()|0;O()|0;ca(a|0)}T(c|0);L()}kb=b+32|0;return a|0}L()}function bF(a,b,c,d,e,f,g,h,i){var j=0;v[23588]=0;Y(952,a|0);j=v[23588];v[23588]=0;a:{b:{if((j|0)!=1){j=v[a+24>>2];v[23588]=0;b=ua(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,h|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Ofa(a){a=a|0;var b=0,c=0,d=0;b=kb-16|0;kb=b;t[b+15|0]=128;a=Pm(a,127,b+15|0);v[23588]=0;t[b+14|0]=64;d=W(577,a+12|0,127,b+14|0)|0;c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){v[23588]=0;t[b+13|0]=0;Q(652,a+24|0,b+13|0)|0;c=v[23588];v[23588]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;kb=b+16|0;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;ic(d)}ic(a);T(b|0);L()}function hI(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;c=z[a>>2];i=a-16|0;d=z[i>>2];e=C(c+d);b=a-8|0;f=z[b>>2];j=a-24|0;g=z[j>>2];h=C(f+g);z[a>>2]=e+h;z[b>>2]=e-h;b=a-12|0;h=z[b>>2];k=a-28|0;l=z[k>>2];e=C(h+l);p=b;b=a-4|0;m=z[b>>2];a=a-20|0;n=z[a>>2];o=C(m+n);z[p>>2]=o-e;f=C(f-g);g=C(m-n);z[k>>2]=f+g;c=C(c-d);d=C(h-l);z[i>>2]=c+d;z[j>>2]=c-d;z[b>>2]=e+o;z[a>>2]=g-f}function g4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23588]=0;U(1047,d|0,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10271,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Cx(a,b,c,d,e){var f=0,g=0;a:{if(!ts(b)){break a}f=v[a+484344>>2];if(!ye(f,v[a+484348>>2],b&65535)){break a}b=Zb(f,b);if(v[b+12>>2]<=(c|0)|e>>>0>5|x[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=jd(v[b>>2],v[v[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=w[b|0]}return g}function Be(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;g=Wg(a);a:{b:{if(!b){i=e,j=Wg(a),v[i+8>>2]=j;v[e+12>>2]=0;break b}f=v[b+4>>2];h=v[b>>2];v[e+8>>2]=h;v[e+12>>2]=f;a=v[a+12>>2];v[e>>2]=2048;v[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Zq(e+8|0,e);c=v[a>>2];a=v[a+4>>2];if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break b}break a}a=0;if((d|0)==(f|0)&b>>>0>h>>>0|d>>>0>f>>>0){break a}}a=1}kb=e+16|0;return a}function vY(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[23588]=0;a=La(1050,a|0,b|0,c|0,d|0)|0;b=v[23588];v[23588]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;ia(935,11100,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}return a|0}function p8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ti(a,b,c,d);v[a>>2]=45156;c=Tb(a+4256|0);b=a+4208|0;e=Eb(b,0),f=1056964608,v[e>>2]=f;e=Eb(b,1),f=1017370378,v[e>>2]=f;e=Eb(b,2),f=1028670828,v[e>>2]=f;e=Eb(b,3),f=1059760811,v[e>>2]=f;e=Eb(b,4),f=1017370378,v[e>>2]=f;e=Eb(b,5),f=1065353216,v[e>>2]=f;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;wc(c);Jf(a);T(b|0);L()}function k1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;f=d;d=v[td(e+12|0,td(e+8|0,e+4|0))>>2];mi(b,f,d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=ob[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}kb=e+16|0;return g|0}function tia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=qk(e,v[a+4>>2]);if(d>>>0<b>>>0){e=kb-32|0;kb=e;d=b-d|0;b=v[Gb(a)>>2];f=v[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){NA(a,d,c);break a}b=Gb(a);b=jT(e+8|0,IA(a,qk(v[a>>2],f)+d|0),qk(v[a>>2],v[a+4>>2]),b);iT(b,d,c);c=b+4|0;gT(v[a>>2],v[a+4>>2],c);qc(a,c);qc(a+4|0,b+8|0);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2];hT(b)}kb=e+32|0;return}if(b>>>0<d>>>0){Od(a,e+B(b,6)|0)}}function k4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23588]=0;e=+ya(1043,d|0,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5353,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function eW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=-1;if(Ag(a,d+8|0)){v[d+4>>2]=w[d+8|0];f=v[Kb(d+4|0,d+12|0)>>2];c=kb+-64|0;kb=c;e=c+40|0;Of(e,a,f);g=v[c+40>>2];a=c+8|0;cg(a,3,Je(e),g);v[23588]=0;R(222,c+24|0,a|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){hc(c,b,11);a=c+24|0;Nl(c,a);zb(a);Uc(c+40|0);kb=c- -64|0;e=!f|(g|0)!=0;break a}a=P()|0;O()|0;Uc(c+40|0);T(a|0);L()}}kb=d+16|0;return e|0}function RE(a,b,c,d,e,f){var g=0,h=0;g=kb-256|0;kb=g;v[g+248>>2]=37;v[g+252>>2]=0;h=g+248|0;Rr(h|1,10537,f,v[b+4>>2]);f=Hd();v[g>>2]=d;v[g+4>>2]=e;d=g+224|0;e=ah(d,24,f,h,g)+d|0;f=$i(d,e,b);h=g+16|0;gd(h,b);v[23588]=0;ia(1153,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=v[23588];v[23588]=0;a:{if((d|0)!=1){ac(g+16|0);a=Pr(a,g+32|0,v[g+28>>2],v[g+24>>2],b,c);kb=g+256|0;break a}a=P()|0;O()|0;ac(g+16|0);T(a|0);L()}return a}function DO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;v[a+4>>2]=0;a:{if(b){b:{if(Dt(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}e=ho(d+16|0);v[23588]=0;f=Q(728,a|0,b|0)|0;g=v[23588];v[23588]=0;if((g|0)==1){break a}v[23588]=0;R(729,e|0,f|0);f=v[23588];v[23588]=0;if((f|0)==1){break a}v[e+4>>2]=b;Mt(a,e);We(e)}vl(d+8|0,v[a>>2]);qv(v[d+8>>2],v[d+12>>2],b,w[c|0])}kb=d+32|0;return}a=P()|0;O()|0;We(e);T(a|0);L()}function _5(a){a=a|0;var b=0,c=0,d=0;v[23588]=0;Y(977,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[23588]=0;c=+la(d|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11654,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function TE(a,b,c,d,e,f){var g=0,h=0;g=kb-112|0;kb=g;v[g+104>>2]=37;v[g+108>>2]=0;h=g+104|0;Rr(h|1,10537,f,v[b+4>>2]);f=Hd();v[g>>2]=d;v[g+4>>2]=e;d=g+80|0;e=ah(d,24,f,h,g)+d|0;f=$i(d,e,b);h=g+16|0;gd(h,b);v[23588]=0;ia(1150,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=v[23588];v[23588]=0;a:{if((d|0)!=1){ac(g+16|0);a=Uq(a,g+32|0,v[g+28>>2],v[g+24>>2],b,c);kb=g+112|0;break a}a=P()|0;O()|0;ac(g+16|0);T(a|0);L()}return a}function gI(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){ec(a,21);return-1}if(v[a+1396>>2]<=9){al(a)}d=v[a+1392>>2];c=u[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=w[d+v[b+8>>2]|0];v[a+1392>>2]=e>>>c;c=v[a+1396>>2]-c|0;v[a+1396>>2]=(c|0)>0?c:0;c=(c|0)>=0?d:-1;break a}c=im(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>=0)){ec(a,21)}return c}aa(7526,13110,1793,5753);L()}function Y5(a){a=a|0;var b=0,c=0,d=0;v[23588]=0;Y(977,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[23588]=0;c=+la(d|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7754,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function W5(a){a=a|0;var b=0,c=0,d=0;v[23588]=0;Y(977,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[23588]=0;c=+la(d|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7702,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function o4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[23588]=0;b=Q(55,f|0,8160)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}e=P()|0;O()|0;zb(b);break b}el(a,b,2);c=ux(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);kb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}T(e|0)}L()}function C4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[23588]=0;b=Q(55,f|0,8160)|0;c=v[23588];v[23588]=0;if((c|0)==1){break c}a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}e=P()|0;O()|0;zb(b);break b}el(a,b,2);c=tx(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);kb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}T(e|0)}L()}function ix(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!ps(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}ec(a,32);return 0}aa(15721,13110,1564,6039);L()}function WZ(a){a=a|0;if(w[468408]){return v[117101]}if(!w[468760]){a=468592;while(1){a=Mb(a)+12|0;if((a|0)!=468760){continue}break}t[468760]=1}qd(468592,5243);qd(468604,5250);qd(468616,5216);qd(468628,5224);qd(468640,5207);qd(468652,5257);qd(468664,5234);qd(468676,9708);qd(468688,9914);qd(468700,11214);qd(468712,12782);qd(468724,5506);qd(468736,10718);qd(468748,6590);t[468408]=1;v[117101]=468592;return 468592}function Uv(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=pd(a);a=zd(v[a+4>>2],w[a+11|0]);d=pd(b);b=zd(v[b+4>>2],w[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}c=c+e|0;a=a+e|0;b=b+d|0;b:{if((b|0)==(d|0)){break b}c:{b=b-d|0;if((b|0)>(a-c|0)){break c}g=1-b|0;h=w[d|0];while(1){f=a-c|0;if((f|0)<(b|0)){break c}c=ou(c,g+f|0,h);if(!c){break c}if(!Rv(c,d,b)){break b}c=c+1|0;continue}}c=a}c=(a|0)==(c|0)?-1:c-e|0}else{c=-1}}return c}function h3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-16|0;kb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;iJ(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=B(v[a+16>>2],e+g|0);j=v[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=(b+i<<2)+j|0;z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}kb=c+16|0}function b3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-32|0;kb=e;v[e+24>>2]=c;v[e+28>>2]=d;a:{a=hc(e+16|0,a,b);a=bt(3,v[a>>2],v[a+4>>2],e+24|0);if(a+1>>>0>=3){b=ba(8)|0;v[23588]=0;c=Q(55,e|0,8017)|0;a=v[23588];v[23588]=0;b:{if((a|0)!=1){a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}a=P()|0;O()|0;ca(b|0)}T(a|0);L()}kb=e+32|0;return a|0}L()}function aF(a,b,c,d,e,f,g){var h=0;v[23588]=0;Y(952,a|0);h=v[23588];v[23588]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[23588]=0;b=ja(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,f|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function II(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Qg(a)|0)>(b|0)){break d}}b=ba(8)|0;v[23588]=0;c=Q(55,c|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}kb=c+16|0;return(v[(a+B(b,872)|0)+1075080>>2]&134218752)!=0|0}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function Aba(a){a=a|0;var b=0;a=Mb(a);v[23588]=0;R(46,a|0,4);b=v[23588];v[23588]=0;a:{b:{if((b|0)==1){break b}v[23588]=0;R(47,a|0,32);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(47,a|0,10);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(47,a|0,13);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(47,a|0,9);b=v[23588];v[23588]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;zb(a);T(b|0);L()}}
function n4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23588]=0;R(1042,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10821,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function DX(a){a=a|0;var b=0;a=Mb(a);v[23588]=0;R(73,a|0,4);b=v[23588];v[23588]=0;a:{b:{if((b|0)==1){break b}v[23588]=0;R(51,a|0,32);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(51,a|0,10);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(51,a|0,13);b=v[23588];v[23588]=0;if((b|0)==1){break b}v[23588]=0;R(51,a|0,9);b=v[23588];v[23588]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;Ab(a);T(b|0);L()}}function q3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-16|0;kb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;qJ(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=v[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=v[(b<<2)+j>>2]+(i<<2)|0;z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}kb=c+16|0}function SE(a,b,c,d,e){var f=0,g=0,h=0;f=kb-160|0;kb=f;v[f+152>>2]=37;v[f+156>>2]=0;g=f+152|0;Rr(g|1,10704,e,v[b+4>>2]);e=Hd();v[f>>2]=d;d=f+139|0;e=ah(d,13,e,g,f)+d|0;g=$i(d,e,b);h=f+16|0;gd(h,b);v[23588]=0;ia(1153,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=v[23588];v[23588]=0;a:{if((d|0)!=1){ac(f+16|0);a=Pr(a,f+32|0,v[f+28>>2],v[f+24>>2],b,c);kb=f+160|0;break a}a=P()|0;O()|0;ac(f+16|0);T(a|0);L()}return a}function qu(a,b){var c=0;c=kb-16|0;kb=c;v[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b;b=a>>31<<6|a>>>26;a=a<<6;a=Ic(Pka(a- -8192|0,b-((a>>>0<4294959104)-1|0)|0,16384,0),nb);break a;case 1:a=b>>31;a=a<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=Ic(Pka(b,a,4096,0),nb);break a;default:break b}}v[c+8>>2]=1;a=zl(mK(8192/+v[Pe(c+12|0,c+8|0)>>2])*24+8)}v[c+12>>2]=a;kb=c+16|0;a=(a|0)<64?a:64;return(a|0)>0?a:0}function ip(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=kb-16|0;kb=i;if(-18-b>>>0>=c>>>0){j=Ac(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=Ng(v[Zc(i+12|0,i+8|0)>>2])+1|0}c=tc(k);if(e){we(c,j,e)}if(g){we(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){we((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Nb(j)}vd(a,c);cf(a,k);b=a;a=h+(e+g|0)|0;Gd(b,a);t[i+7|0]=0;je(a+c|0,i+7|0);kb=i+16|0;return}jf();L()}function PA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Qb(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=3){c=kb-16|0;kb=c;if(Qb(v[a>>2],v[a+8>>2],b)){while(1){if((d|0)==4){$l(c,v[c+12>>2]);d=v[c>>2]}else{t[c+11|0]=0;b:{if(b>>>0>d>>>0){Ag(a,c+11|0);e=t[c+11|0];g=e>>>31|0;break b}e=0-g|0}t[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}kb=c+16|0;c=d;break a}c=Cg(a);_b(a,b-4|0)}t[f|0]=c}function KI(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Qg(a)|0)>(b|0)){break d}}b=ba(8)|0;v[23588]=0;c=Q(55,c|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}kb=c+16|0;return+(+v[(a+B(b,872)|0)+1075740>>2]*.015625)}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function nn(a,b,c,d,e,f){var g=0;v[23588]=0;Y(952,a|0);g=v[23588];v[23588]=0;a:{b:{if((g|0)!=1){g=v[a+24>>2];v[23588]=0;b=fa(f|0,g|0,b|0,c|0,d|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,e|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function k6(a){a=a|0;var b=0;v[23588]=0;Y(977,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){ob[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Nb(b);v[a+20>>2]=0}Nb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5054,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function w1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+28>>2];d=v[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=zf(t[b|0]),h=v[v[a>>2]+52>>2],ob[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=g-d;v[e+8>>2]=c-f;g=d;d=v[td(e+12|0,e+8|0)>>2];we(g,b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}kb=e+16|0;return f|0}function taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-32|0;kb=d;Ne(d,2,a+6|0);e=d+16|0;Fc(e,d);Dc(b+492|0,e);f=b+236|0;g=c+1|0;zb(e);c=0;while(1){if((c|0)==128){v[b>>2]=(w[a+226|0]|w[a+227|0]<<8)<<5;ay(a+180|0,b+48|0,0);ay(a+228|0,b+88|0,2);ay(a+276|0,b+68|0,1);if(!(w[a+324|0]|w[a+325|0]<<8)){Ub(f,0,256)}kb=d+32|0}else{h=dc(f,c),i=w[(a+c|0)+38|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function iea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=v[b+4>>2];if(!c){break a}f=a+480190|0;u[d>>1]=x[f>>1];u[d+14>>1]=c-1;c=x[Wc(d,d+14|0)>>1];while(1){if(!c){break a}Db(d,v[b>>2],c);b:{if(Cb(v[v[d>>2]>>2],v[d+4>>2])){break b}if(zM(a,c&65535)){e=Nc(d,21619);Dc(((c<<5)+a|0)+946304|0,e);zb(e)}if(c>>>0<2){break b}e=x[f>>1];if((e|0)!=(c|0)){break b}u[f>>1]=e-1}c=c-1|0;continue}}kb=d+16|0}function TM(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];v[a>>2]=b;if(c){b=kb-16|0;kb=b;d=Fb(v[c>>2]);v[b+8>>2]=d;f=Fb(v[c+4>>2]);while(1){a:{b:{if(Pb(d,f)){while(1){a=v[d>>2];e=v[a>>2];if(!e){break b}iL(a,e);a=v[v[e>>2]+8>>2];v[23588]=0;Y(a|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){continue}break}V(0)|0;O()|0;Vb();L()}a=wc(c);kb=b+16|0;break a}bc(a+20|0);bc(a+8|0);Nb(a);d=v[Le(b+8|0)>>2];continue}break}Nb(a)}}function K2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=kb-32|0;kb=e;a:{if(w[b+8|0]){f=v[b+12>>2];h=e,i=fd(f,v[b+16>>2])-c|0,v[h+28>>2]=i;v[e+24>>2]=v[d+4>>2];g=v[Kb(e+28|0,e+24|0)>>2];f=Rf(Fb(f),c);c=Rf(Rf(Fb(v[b+12>>2]),c),g);b=v[d>>2];qh(f,c,b);gc(a,b,g);break a}g=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=g;f=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=g;ob[f|0](a,b,c,e+8|0)}kb=e+32|0}function af(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=gp(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(sF(a,b)&3){case 0:c=gp(A[b>>3],A[b+8>>3]);break a;case 1:c=-hp(A[b>>3],A[b+8>>3],1);break a;case 2:c=-gp(A[b>>3],A[b+8>>3]);break a;default:break b}}c=hp(A[b>>3],A[b+8>>3],1)}a=c;kb=b+16|0;return a}function UE(a,b,c,d,e){var f=0,g=0,h=0;f=kb-80|0;kb=f;v[f+72>>2]=37;v[f+76>>2]=0;g=f+72|0;Rr(g|1,10704,e,v[b+4>>2]);e=Hd();v[f>>2]=d;d=f+59|0;e=ah(d,13,e,g,f)+d|0;g=$i(d,e,b);h=f+16|0;gd(h,b);v[23588]=0;ia(1150,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=v[23588];v[23588]=0;a:{if((d|0)!=1){ac(f+16|0);a=Uq(a,f+32|0,v[f+28>>2],v[f+24>>2],b,c);kb=f+80|0;break a}a=P()|0;O()|0;ac(f+16|0);T(a|0);L()}return a}function s4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[23588]=0;c=Q(55,e|0,8160)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}a=sc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break b}el(a,b,1);c=ux(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);kb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function G4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[23588]=0;c=Q(55,e|0,8160)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}a=sc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break b}el(a,b,1);c=tx(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);kb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function B$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=kb-208|0;kb=a;f=Hd();v[a>>2]=e;g=a+176|0;i=ah(g,20,f,9222,a);e=i+g|0;g=$i(g,e,c);f=a+8|0;gd(f,c);v[23588]=0;f=S(1136,f|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){ac(a+8|0);h=f;f=a+16|0;qG(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Pr(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);kb=a+208|0;return b|0}b=P()|0;O()|0;ac(a+8|0);T(b|0);L()}function wy(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;LM(a+1074332|0,b);a=a+906300|0;f=fk(a);while(1){if((a|0)!=(f|0)){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;if(ob[v[v[b>>2]+140>>2]](b)|0){d=v[b+16>>2];e=d+1074332|0;c=C(C(c/z[e+8>>2])*C(C(y[d+480232>>2])/z[e+20>>2]))}z[b+4196>>2]=c}a=a+160|0;continue}break}}function i4(a,b){a=a|0;b=+b;var c=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23588]=0;b=+Za(1044,c|0,+b);c=v[23588];v[23588]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[23588]=0;X(939,7566,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;if((c|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;c=rf(a,c);ne(e,v[a+36>>2]);a:{b:{if(!c){Sc(e,a+32|0,5);d=-1;if(!Cb(v[v[e>>2]>>2],v[e+4>>2])){break b}break a}d=v[c+16>>2]}f=v[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=kb-32|0;kb=d;t[d+24|0]=0;Zi(d+8|0,d+24|0);wn(d+16|0,f,v[d+8>>2],v[d+12>>2]);t[b|0]=w[d+24|0];kb=d+32|0;break c;default:break d}}mT(f,b,d)}f=c}Ye(a,f);kb=e+16|0}function xt(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[b+40>>2]=0;v[b+44>>2]=0;f=b- -64|0;v[f>>2]=0;v[f+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=Fb(v[c>>2]);v[e+8>>2]=d;f=Fb(v[c+4>>2]);while(1){if(!Pb(d,f)){break a}g=d,h=HO(b,A[d>>3]),A[g>>3]=h;d=v[vt(e+8|0)>>2];continue}}}else{HO(b,A[bf(v[c>>2],0)>>3]);d=d+1|0;continue}break}wl(a,c);kb=e+16|0}function nC(a,b){var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=hc(c+8|0,c+24|0,7);md(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Sb(c+24|0,b,7)){break b}id(a,7);d=1}kb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d}function zI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=kb-16|0;kb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;d=Q(55,d|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(d);break b}e=(v[a+32>>2]+B(b,872)|0)+1075766|0,f=Qz(c*32768),u[e>>1]=f;kb=d+16|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function bga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;b=-1;a:{if(!fg(a,8)){break a}b=kb-32|0;kb=b;v[b+24>>2]=0;v[b+28>>2]=0;d=hc(b+8|0,b+24|0,8);md(b+16|0,a,v[d>>2],v[d+4>>2]);b:{if(v[b+20>>2]!=8){break b}if(Sb(b+24|0,14090,8)){break b}id(a,8);e=1}kb=b+32|0;b=0;if(!e){break a}b=-1;if(!Rj(a,c+8|0)){break a}b=0;if(!cc(v[c+12>>2])){break a}b=!(cc(v[c+8>>2])&-2139062144)}kb=c+16|0;return b|0}function yr(a){var b=0,c=0;jn(a,1,13515);v[23588]=0;b=ga(126)|0;c=v[23588];v[23588]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[23588]=0;b=ga(127)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}t[a+16|0]=b;v[23588]=0;b=ga(128)|0;c=v[23588];v[23588]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[23588]=0;Y(129,a+20|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;Ab(a);T(b|0);L()}function to(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=kb-16|0;kb=f;v[f+12>>2]=c;a:{if(!Qb(v[b>>2],v[b+8>>2],c)){break a}xc(f+12|0,65535);vg(a,x[f+12>>1]);c=Fb(v[a>>2]);v[f>>2]=c;h=Fb(v[a+4>>2]);while(1){if(!Pb(c,h)){break a}a=f+11|0;if(!Ag(b,a)){Dh(a)}a=w[f+11|0];u[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}u[c>>1]=g}c=v[Se(f)>>2];continue}}kb=f+16|0}function nea(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=Iz(c,a);$l(v[a+4>>2],w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));v[a+4>>2]=v[a+4>>2]+4;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=Vf(d+8|0,qg(a,vc(v[a>>2],v[a+4>>2])+1|0),vc(v[a>>2],v[a+4>>2]),c);$l(v[c+8>>2],w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));v[c+8>>2]=v[c+8>>2]+4;Ed(a,c);Uf(c);kb=d+32|0}function c5(a){a=a|0;var b=0,c=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23588]=0;b=S(1020,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7238,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function CE(a,b,c,d,e){var f=0,g=0;a:{f=kb-80|0;kb=f;nA(b);g=f+56|0;Of(g,a,c);a=v[f+56>>2];c=f+8|0;cg(c,e,Je(g),a);v[23588]=0;R(222,f+24|0,c|0);a=v[23588];v[23588]=0;b:{c:{if((a|0)!=1){v[23588]=0;U(11,f+40|0,d|0,f+24|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}a=f+40|0;Jb(b,a);Ab(a);zb(f+24|0);Uc(f+56|0);kb=f+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(f+24|0)}Uc(f+56|0);T(a|0);L()}}function Ifa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Wz(a,b);v[23588]=0;c=Q(657,a+12|0,b+12|0)|0;d=v[23588];v[23588]=0;b:{c:{if((d|0)!=1){v[23588]=0;Q(658,a+24|0,b+24|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;ic(c)}ic(a);T(b|0);L()}}function wea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=kb-16|0;kb=b;u[b+12>>1]=0;u[b+14>>1]=1;Ff(b+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=kb-16|0;kb=d;c=x[b+14>>1];v[d+12>>2]=c;a:{if(Ym(a)>>>0>=c>>>0){g=v[a>>2];f=Rc(g,v[a+4>>2]);v[d+8>>2]=f;au(g,v[Kb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){Ho(a,c-f|0,e);break a}Od(a,v[a>>2]+(c<<1)|0);break a}nP(a);iq(a,Oj(a,c));Ho(a,c,e)}kb=d+16|0;kb=b+16|0}function v3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=kb-16|0;kb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;uJ(a,c);kb=c+16|0}function rd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{e=LG(b);c=un(a);if(e>>>0<=c>>>0){f=Ac(a);d=f;c=e;if(c){b:{if((b|0)==(d|0)){break b}if(d-b>>>0>=c<<2>>>0){if(!c){break b}while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break b}if(!c){break b}while(1){c=c-1|0;g=c<<2;v[g+d>>2]=v[b+g>>2];if(c){continue}break}}}Rh(a,e);vd((e<<2)+f|0,0);break a}d=a;a=Hb(a);xF(d,c,e-c|0,a,0,a,e,b)}}function p5(a){a=a|0;var b=0,c=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23588]=0;c=+la(1011,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7638,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function p3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=kb-16|0;kb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;oJ(a,c);kb=c+16|0}function m3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=kb-16|0;kb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;mJ(a,c);kb=c+16|0}function g3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=kb-16|0;kb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;hJ(a,c);kb=c+16|0}function LS(a){var b=0;a:{if(Sb(a,14231,3)|(w[a+3|0]-52&255)>>>0<252){break a}if(cc(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788>>>0<840){break a}if(cc(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))>>>0<52){break a}if(cc(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))-1>>>0<51){break a}b=cc(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))>>>0<4294967216}return b}function CR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(!w[b+8|0]){while(1){if((d|0)==8){v[c+24>>2]=0;v[c+28>>2]=0;d=hc(c+8|0,c+24|0,8);nc(c+16|0,v[a>>2],v[a+8>>2],v[d>>2],v[d+4>>2]);d=0;b:{if(v[c+20>>2]!=8){break b}if(Sb(c+24|0,b,8)){break b}_b(a,8);d=1}kb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d|0}function Di(a){var b=0,c=0;b=kb-16|0;kb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=hp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(sF(a,b)&3){case 0:a=hp(A[b>>3],A[b+8>>3],1);break a;case 1:a=gp(A[b>>3],A[b+8>>3]);break a;case 2:a=-hp(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-gp(A[b>>3],A[b+8>>3])}kb=b+16|0;return a}function YV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;v[a>>2]=0;v[a+4>>2]=0;if(!Qb(v[b>>2],v[b+8>>2],c)){c=df(b)}v[a>>2]=c;c=v[b>>2];a:{if(ob[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];e=c,f=(ob[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;break a}Si(a+8|0,v[a>>2]);c=v[a+8>>2];a=v[a+12>>2];if(pc(c,a)){break a}se(d+8|0,c,a);nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2])}kb=d+16|0}function L$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=kb-96|0;kb=a;f=Hd();v[a>>2]=e;g=a- -64|0;i=ah(g,20,f,9222,a);e=i+g|0;g=$i(g,e,c);f=a+8|0;gd(f,c);v[23588]=0;f=S(19,f|0)|0;h=v[23588];v[23588]=0;if((h|0)!=1){ac(a+8|0);h=f;f=a+16|0;uG(h,a- -64|0,e,f);h=b;b=f+i|0;b=Uq(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);kb=a+96|0;return b|0}b=P()|0;O()|0;ac(a+8|0);T(b|0);L()}function vG(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0);e=kb-16|0;kb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[116064];v[116064]=0;Hd();d=kb-16|0;kb=d;Ew(d,a,e+12|0,0);f=pF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);kb=d+16|0;a=v[116064];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[116064]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}kb=e+16|0;return f}function qx(a,b,c){var d=0,e=0;d=kb-32|0;kb=d;a:{if(w[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=cJ(b,4096);bJ(a,b-c|0);c=v[a+16>>2];b=hc(d+16|0,Lb(v[a+4>>2],c),b-c|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;ob[c|0](d+24|0,a,d+8|0);v[a+16>>2]=v[a+16>>2]+v[d+28>>2];if(!(ob[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}kb=d+32|0}function pq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=kb-16|0;kb=i;if(-18-b>>>0>=c>>>0){j=pd(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=Ng(v[Zc(i+12|0,i+8|0)>>2])+1|0}c=tc(k);if(e){we(c,j,e)}if(g){we(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){we((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Nb(j)}vd(a,c);cf(a,k);b=a;a=h+(e+g|0)|0;Gd(b,a);xd(a+c|0,0);kb=i+16|0;return}jf();L()}function NB(a,b,c){var d=0,e=0,f=0;d=v[c+16>>2];a:{if(!d){if(oC(c)){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<b>>>0){return ob[v[c+36>>2]](c,a,b)|0}b:{if(v[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(w[e+a|0]!=10){continue}break}e=ob[v[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=v[c+20>>2]}uc(f,a,b);v[c+20>>2]=v[c+20>>2]+b;e=b+d|0}return e}function hS(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function bQ(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function P1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=pd(c);c=zd(v[c+4>>2],w[c+11|0]);a:{d=zd(v[a+4>>2],w[a+11|0]);if(d>>>0>=b>>>0){e=yl(a);if(c>>>0<=e-d>>>0){if(!c){break a}e=pd(a);h=e+b|0;if((b|0)!=(d|0)){g=b+e|0;Xh(c+g|0,g,d-b|0);f=(f>>>0>=g>>>0?d+e>>>0>f>>>0?c:0:0)+f|0}Xh(h,f,c);b=c+d|0;tq(a,b);xd(b+e|0,0);break a}pq(a,e,(c+d|0)-e|0,d,b,0,c,f);break a}sk();L()}return a|0}function Mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;gc(c+8|0,b,15);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function b4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=kb-32|0;kb=b;a:{e=a;a=hc(b+24|0,c,d);a=bt(e,v[a>>2],v[a+4>>2],0);if(a+1>>>0>=3){a=ba(8)|0;v[23588]=0;b=Q(55,b+8|0,8017)|0;c=v[23588];v[23588]=0;b:{if((c|0)!=1){a=sc(a,b);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break b}c=P()|0;O()|0;ca(a|0)}T(c|0);L()}kb=b+32|0;return a|0}L()}function Tja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(th(1073741823)>>>0<=8191){cd();L()}b=tc(32768);v[a>>2]=b;v[a+4>>2]=b;e=Gb(a),f=b+32768|0,v[e>>2]=f;b=kb-16|0;kb=b;v[b>>2]=a;c=v[a+4>>2];v[b+4>>2]=c;v[b+8>>2]=c+32768;c=v[b+4>>2];d=v[b+8>>2];while(1){if((c|0)==(d|0)){lc(b);kb=b+16|0}else{u[c>>1]=0;u[c+2>>1]=0;c=c+4|0;v[b+4>>2]=c;continue}break}return a|0}function Gha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;gc(c+8|0,b,14);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function $7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ti(a,b,c,d);v[a>>2]=45776;b=Tb(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=v[c+24620>>2];v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[23588]=0;R(897,a+44|0,2);c=v[23588];v[23588]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;wc(b);Jf(a);T(c|0);L()}function tG(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[116064];v[116064]=0;Hd();d=kb-16|0;kb=d;Ew(d,a,e+12|0,1);f=Hw(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);kb=d+16|0;a=v[116064];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[116064]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}kb=e+16|0;return f}function _E(a,b,c,d,e){var f=0;f=kb-16|0;kb=f;a:{b:{c:{if(!d){a=ba(8)|0;v[23588]=0;c=Q(55,f|0,8160)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}a=sc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break b}el(a,b,e);c=XE(a,c,e,d,59556,60328);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);kb=f+16|0;return c}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function RI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[23588]=0;c=Q(55,c|0,7814)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}a=sc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}d=P()|0;O()|0;zb(c);break b}a=v[a+32>>2];e=a,f=Qe(65536/b),v[e+480244>>2]=f;Np(a);kb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}function PI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[23588]=0;c=Q(55,c|0,7835)|0;d=v[23588];v[23588]=0;if((d|0)==1){break c}a=sc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}d=P()|0;O()|0;zb(c);break b}a=v[a+32>>2];e=a,f=Qe(b*65536),v[e+480240>>2]=f;Np(a);kb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}T(d|0)}L()}function $E(a,b,c,d,e){var f=0;f=kb-16|0;kb=f;a:{b:{c:{if(!d){a=ba(8)|0;v[23588]=0;c=Q(55,f|0,8160)|0;b=v[23588];v[23588]=0;if((b|0)==1){break c}a=sc(a,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break b}el(a,b,e);c=XE(a,c,e,d,60384,61156);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);kb=f+16|0;return c}b=P()|0;O()|0;ca(a|0)}T(b|0)}L()}function A9(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[23588]=0;R(285,b+4|0,8);b=v[23588];v[23588]=0;if((b|0)!=1){b=v[a+4264>>2];c=v[v[a+20>>2]+4>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(92948)|0;if((O()|0)==(ea(92948)|0)){_(b|0)|0;Lc(v[a+20>>2]+4|0);$();return}T(b|0);L()}function EI(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;c=Q(55,c|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;kb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function _ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;a:{e=Me(a);b:{if(e>>>0>1){break b}c:{if(e){v[23588]=0;U(329,d|0,a|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){Lm(b,d);ic(d);break c}a=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break a}_(a|0)|0;$();break b}if(!Qb(v[a>>2],v[a+8>>2],c)){break b}Zu(a,b,c)}f=fd(v[b>>2],v[b+4>>2])>>>0>=c>>>0}kb=d+16|0;return f|0}T(a|0);L()}function Yi(a,b,c,d,e){var f=0,g=0,h=0;f=kb-16|0;kb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(dj(a,f+8|0)){break b}h=Zk(v[a>>2]);g=4;if(!vh(v[d+8>>2],64,h)){break b}b=xn(d,h);while(1){c:{b=b-48|0;h=fm(a);if(!pp(h,f+8|0)|(e|0)<2){break c}g=Zk(v[h>>2]);if(!vh(v[d+8>>2],64,g)){break a}e=e-1|0;b=xn(d,g)+B(b,10)|0;continue}break}g=2;if(!dj(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}kb=f+16|0;return b}function v1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;Nq(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){b=Ac(c)+Hb(c)|0;v[a+44>>2]=b;d=Ac(c);Bn(a,d,d,b);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Hb(c);e=a,f=b+Ac(c)|0,v[e+44>>2]=f;Ix(c,bd(c));d=Ac(c);Pw(a,d,Hb(c)+d|0);if(!(w[a+48|0]&3)){break a}while(1){if((b|0)<0){cs(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}cs(a,b)}}function b5(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb-32|0;kb=c;a:{e=a+36|0;b=v[e>>2];d=v[a+40>>2];b:{if(Pb(b,d)){Hc(c+24|0);break b}b=c+8|0;Jn(b,a);v[23588]=0;b=S(1012,b|0)|0;d=v[23588];v[23588]=0;if((d|0)==1){break a}v[c+24>>2]=b;Xf(c+8|0);d=v[a+40>>2];b=v[a+36>>2]}if(!Pb(b,d)){e=v[c+24>>2];b=v[e>>2]}a=Ri(b,v[e+4>>2]);bl(c+24|0);kb=c+32|0;return a|0}a=P()|0;O()|0;Xf(c+8|0);T(a|0);L()}function Gh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=hc(c+8|0,c+28|0,4);nc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Sb(c+28|0,b,4)){break b}_b(a,4);d=1}kb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d|0}function AI(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;c=Q(55,c|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}kb=c+16|0;return+(+(v[(v[a+32>>2]+B(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function yI(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;c=Q(55,c|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}kb=c+16|0;return+(+u[(v[a+32>>2]+B(b,872)|0)+1075766>>1]*30517578125e-15)}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function t6(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Nb(Ks(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Nb(b);v[a+20>>2]=0}Nb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5081,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function jha(a){a=a|0;var b=0,c=0,d=0,e=0;e=kb-16|0;kb=e;b=tc(2500);c=kb-2496|0;kb=c;DR(a,c,c+2496|0);a=0;while(1){if((a|0)==624){v[b+2496>>2]=0;a:{if(v[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!v[b+d>>2]){continue}break a}break}v[b>>2]=-2147483648}kb=c+2496|0}else{d=a<<2;v[d+b>>2]=v[c+d>>2];a=a+1|0;continue}break}a=v[Mf(e+8|0,b)>>2];kb=e+16|0;return a|0}function i1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+24>>2];e=v[a+28>>2];if(d>>>0>=e>>>0){if((ob[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{v[f+12>>2]=e-d>>2;v[f+8>>2]=c-g;e=d;d=v[td(f+12|0,f+8|0)>>2];mi(e,b,d);e=d<<2;v[a+24>>2]=e+v[a+24>>2];g=g+d|0;b=b+e|0}continue}break}kb=f+16|0;return g|0}function dS(a,b){var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(!w[b+5|0]){while(1){if((d|0)==5){d=0;t[c+28|0]=0;v[c+24>>2]=0;e=hc(c+8|0,c+24|0,5);nc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=5){break b}if(Sb(c+24|0,b,5)){break b}_b(a,5);d=1}kb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d}function p6(a,b){a=a|0;b=b|0;var c=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Nb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5663,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function I9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;c=tc(64);v[23588]=0;e=S(835,c|0)|0;f=v[23588];v[23588]=0;a:{if((f|0)!=1){c=Mf(d,e);e=v[c>>2];v[23588]=0;a=W(895,e|0,a|0,b|0)|0;b=v[23588];v[23588]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}Hc(d+8|0);break b}a=P()|0;O()|0;sg(c);break a}eg(d+8|0,c)}sg(c);kb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Nb(c)}T(a|0);L()}function k9(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function JP(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a=Mb(a);d=Hb(b);v[23588]=0;R(46,a|0,d|0);d=v[23588];v[23588]=0;a:{if((d|0)!=1){e=c,f=rt(b),v[e+8>>2]=f;e=c,f=qt(b),v[e>>2]=f;while(1){if(!zi(c+8|0,c)){break a}b=w[v[c+8>>2]];v[23588]=0;R(47,a|0,((b|0)==13?10:b)<<24>>24);b=v[23588];v[23588]=0;if((b|0)!=1){He(c+8|0);continue}break}}b=P()|0;O()|0;zb(a);T(b|0);L()}kb=c+16|0}function aU(a){var b=0,c=0;a:{if(Sb(a,15193,3)){break a}c=w[a+3|0];if(c>>>0>9){break a}if((Ib(w[a+202|0]|w[a+203|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}if(!Ib(w[a+228|0]|w[a+229|0]<<8)){break a}if(!Ib(w[a+230|0]|w[a+231|0]<<8)){break a}b=0;if(Ib(w[a+232|0]|w[a+233|0]<<8)>>>0>4095){break b}b=Ib(w[a+234|0]|w[a+235|0]<<8)>>>0<100}return b}return 0}function OK(a){var b=C(0),c=0,d=C(0);b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);d=C(y[a+4256>>2]);b=C(C(C(C(z[a+4228>>2]*C(1999))+C(1))/C(1e3))*d);a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}v[a+4248>>2]=c;c=a+4252|0;b=C(C(C(C(z[a+4232>>2]*C(1999))+C(1))/C(1e3))*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function tja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){if(th(2147483647)>>>0<b>>>0){cd();L()}e=b<<1;d=tc(e);v[a>>2]=d;v[a+4>>2]=d;g=Gb(a),h=d+e|0,v[g>>2]=h;e=kb-16|0;kb=e;d=$h(e,a,b);b=v[d+4>>2];f=v[d+8>>2];while(1){if((b|0)==(f|0)){lc(d);kb=e+16|0}else{Kj(b,w[c|0]|w[c+1|0]<<8);b=b+2|0;v[d+4>>2]=b;continue}break}}return a|0}function oD(a,b,c){var d=0,e=0,f=0,g=0;a:{d=so(b,Pi(a));c=so(c,b);if(zd(v[a+4>>2],w[a+11|0])>>>0>=d>>>0){if((c|0)==-1){bB(a,pd(a),d);break a}b=a;e=kb-16|0;kb=e;v[e+12>>2]=c;if(c){f=zd(v[b+4>>2],w[b+11|0]);g=pd(b);c=f-d|0;v[e+8>>2]=c;a=v[Kb(e+12|0,e+8|0)>>2];v[e+12>>2]=a;b:{if((a|0)==(c|0)){a=c;break b}d=d+g|0;Xh(d,a+d|0,c-a|0)}bB(b,g,f-a|0)}kb=e+16|0;break a}sk();L()}}function wx(a,b,c){var d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(c){Bk(a,c);d=kb-16|0;kb=d;e=Bh(d,a,c);c=v[e+4>>2];f=v[e+8>>2];while(1){if((c|0)==(f|0)){lc(e);kb=d+16|0}else{v[c>>2]=0;Hc(c);c=c+4|0;v[e+4>>2]=c;continue}break}}c=0;e=0;d=kb-16|0;kb=d;f=d+8|0;while(1){if(c>>>0<32){c=c+48|0;e=PM(b);continue}break}v[f>>2]=e;Tn(f);kb=d+16|0;v[a+12>>2]=v[f>>2];return a}function Hx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(y[v[a+16>>2]+24620>>2]);c=C(C(C(ob[v[v[a>>2]+208>>2]](a))*b)/C(1e3));d=a,e=C(C(c*C(ob[v[v[a>>2]+200>>2]](a)))*C(2048)),z[d+4248>>2]=e;d=a,f=Th(C(C(c+C(2))*C(4096))),v[d+4256>>2]=f;c=C(ob[v[v[a>>2]+212>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(ob[v[v[a>>2]+196>>2]](a)|0)){b=WK(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function Gy(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;tm(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=v[a+1298300>>2];if(!Fd(a)){break a}rj(a,b,0)}}function G2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(c){if(th(357913941)>>>0<c>>>0){cd();L()}d=dE(c);v[a>>2]=d;v[a+4>>2]=d;f=Gb(a),g=d+B(c,12)|0,v[f>>2]=g;e=Nd(b,c);d=kb-16|0;kb=d;c=Qt(d,a,c);v[23588]=0;U(1083,b|0,e|0,c+4|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){lc(c);kb=d+16|0;break a}a=P()|0;O()|0;lc(c);T(a|0);L()}}return a|0}function jm(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return t[a+72688|0]}if(a>>>0<=511){return t[(a>>>5|0)+72688|0]+5|0}return t[(a>>>10|0)+72688|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return t[(a>>>15|0)+72688|0]+15|0}return t[(a>>>20|0)+72688|0]+20|0}if(a>>>0<=536870911){return t[(a>>>25|0)+72688|0]+25|0}a=t[(a>>>30|0)+72688|0]+30|0}else{a=0}return a}function s6(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Nb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,8876,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function VE(a,b,c){var d=0;d=kb-16|0;kb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23588]=0;c=Q(55,d|0,10656)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}a=(v[a+32>>2]+B(b,872)|0)+1075080|0;v[a>>2]=v[a>>2]|c;kb=d+16|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function SI(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ba(8)|0;v[23588]=0;c=Q(55,c|0,9323)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);kb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function EV(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){a=kb-16|0;kb=a;c=ba(16)|0;b=kb-16|0;kb=b;if(!w[464880]){t[464880]=1}hc(b+8|0,1,94040);d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;kb=b+16|0;b=v[a+12>>2];a=v[a+8>>2];v[23588]=0;a=lF(1110,c,8903,a,b);b=v[23588];v[23588]=0;if((b|0)!=1){ha(a|0,78372,1111);L()}a=P()|0;O()|0;ca(c|0);T(a|0);L()}}function B3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;a:{b:{if((ck(w[a+140|0])|0)!=1){break b}if((LJ(a)|0)!=(b|0)){break b}d=a+120|0;As(w[d+20|0]);b=kb-16|0;kb=b;v[b+8>>2]=c+8;a=kb-16|0;kb=a;e=v[14443];v[a+8>>2]=v[14442];v[a+12>>2]=e;e=v[14441];v[a>>2]=v[14440];v[a+4>>2]=e;ob[v[wp(a,ck(w[d+20|0]))>>2]](b+8|0,d);kb=a+16|0;kb=b+16|0;break a}KJ(a,1,b)}kb=c+16|0}function gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=kb-16|0;kb=f;c=rf(a,c);ne(f,v[a+36>>2]);a:{if(!c){Sc(f,a+32|0,5);e=0;if(Cb(v[v[f>>2]>>2],v[f+4>>2])){break a}}h=v[a+36>>2];g=kb-16|0;kb=g;e=Mb(g);v[23588]=0;fa(457,b|0,h|0,e|0,d|0)|0;b=v[23588];v[23588]=0;b:{if((b|0)!=1){Ab(e);kb=g+16|0;break b}a=P()|0;O()|0;Ab(e);T(a|0);L()}e=c}Ye(a,e);kb=f+16|0}function Xi(a,b,c,d,e){var f=0,g=0,h=0;f=kb-16|0;kb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if($j(a,f+8|0)){break b}g=4;h=Yk(v[a>>2]);if(!Xk(d,64,h)){break b}b=vn(d,h);while(1){c:{b=b-48|0;h=Cn(a);if(!ds(h,f+8|0)|(e|0)<2){break c}g=Yk(v[h>>2]);if(!Xk(d,64,g)){break a}e=e-1|0;b=vn(d,g)+B(b,10)|0;continue}break}g=2;if(!$j(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}kb=f+16|0;return b}function Qr(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function QC(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if(Sb(a,11074,2)){if(Sb(a,13728,2)){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){d=(b|0)==128;if(d){break a}c=a+b|0;e=t[c+113|0];if((e|0)<-2){break a}f=w[c+241|0];if(!f&(e|0)>=0|f>>>0>15){break a}b=b+1|0;if(w[c+369|0]<64){continue}break}}return d}function q6(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return gg(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12095,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();return 0}return gg(21619)|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function oka(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;c=d+8|0;Iu(c,a,b);Pf(b,w[d+8|0],w[Oc(c)|0]);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}t[b+3|0]=45;t[b+5|0]=a&15;break a}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;break a}t[b+3|0]=20;t[b+5|0]=a&15|160;break a}t[b+3|0]=0}kb=d+16|0}function iW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;c=-1;a:{if(!fg(a,7)){break a}c=0;if(!nC(a,11694)){break a}c=kb-16|0;kb=c;kC(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(f|0);if(!e){jC(d)}c=-1;if(!e){break a}c=0;if(!mC(w[d+1|0])){break a}c=Be(a,b,lC(d),nb)}kb=d+16|0;return c|0}function g8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ti(a,b,c,d);v[a>>2]=45396;b=a+4208|0;e=Eb(b,0),f=1060320051,v[e>>2]=f;e=Eb(b,1),f=1041865114,v[e>>2]=f;e=Eb(b,2),f=1065353216,v[e>>2]=f;e=Eb(b,3),f=1049951732,v[e>>2]=f;e=Eb(b,4),f=1049951732,v[e>>2]=f;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;Jf(a);T(b|0);L()}function uN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=(B(b,872)+a|0)+1429|0;e=v[a+16>>2];if(e){d=w[d|0]}else{t[d|0]=0;d=0}f=v[a+40>>2];b=B(b,872)+a|0;a=b+1467|0;t[a|0]=w[a|0]|64;a=b+1468|0;h=a;i=v[a>>2];g=(+(e>>>0)+1)*+(c|0)/+(f>>>0);a:{if(D(g)<2147483648){a=~~g;break a}a=-2147483648}v[h>>2]=i+(a+((c|0)<0?d:0-d|0)|0);c=(f|0)==(e+1|0)?c:a;a=c>>31;t[b+1429|0]=(a^c)-a}function tM(a,b){var c=0,d=0,e=0,f=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=t[c+1075785|0];d:{if((c|0)>=0){d=ze(a+901692|0,w[(B(b,872)+a|0)+1075836|0]);break d}d=ze(a+902204|0,c&127)}MN(a,e,b,f,d,c&255)}}function wba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=b;c=kb-16|0;kb=c;d=tc(223888);v[23588]=0;b=Q(802,d|0,b+1074376|0)|0;e=v[23588];v[23588]=0;a:{if((e|0)!=1){b=v[Mf(c+8|0,b)>>2];kb=c+16|0;break a}a=P()|0;O()|0;Nb(d);T(a|0);L()}v[a+4>>2]=b;b=Tb(a+8|0);v[23588]=0;Y(585,a|0);c=v[23588];v[23588]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;re(b);AN(a+4|0);T(c|0);L()}function W4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[23588]=0;Y(952,a|0);f=v[23588];v[23588]=0;if((f|0)!=1){return Cx(v[v[a+24>>2]+24>>2],b,c,d,e)|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12338,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function TI(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ba(8)|0;v[23588]=0;c=Q(55,c|0,5851)|0;a=v[23588];v[23588]=0;if((a|0)==1){break c}a=sc(b,c);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}v[v[a+32>>2]+1074416>>2]=b;kb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}T(a|0)}L()}function yU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=Tb(a);a=Fb(v[b>>2]);v[d+24>>2]=a;b=Fb(v[b+4>>2]);a:{while(1){if(Pb(a,b)){Zh(d,v[a>>2],v[a+4>>2]);if((cc(v[d>>2])|0)==(c|0)){Ao(d,a);v[23588]=0;R(352,e|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}Bb(d)}a=v[Nm(d+24|0)>>2];continue}break}kb=d+32|0;return}a=P()|0;O()|0;Bb(d);Vc(e);T(a|0);L()}function Yn(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function WE(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=kb-16|0;kb=h;a:{b:{c:{if(b<g|b>f){a=ba(8)|0;v[23588]=0;d=Q(55,h|0,e|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}a=sc(a,d);v[23588]=0;U(119,a|0,62688,956);a=v[23588];v[23588]=0;if((a|0)!=1){break a}e=P()|0;O()|0;zb(d);break b}i=v[a+32>>2]+d|0,j=Qe(b*c),v[i>>2]=j;kb=h+16|0;return}e=P()|0;O()|0;ca(a|0)}T(e|0)}L()}function BG(a,b,c,d){var e=0,f=0,g=0;e=kb-16|0;kb=e;a:{if((a|0)!=(b|0)){g=v[116064];v[116064]=0;Hd();d=CG(a,e+12|0,d);a=nb;f=v[116064];b:{if(f){if(v[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}v[c>>2]=4;a=!!d&(a|0)>=0|(a|0)>0;d=a?-1:0;a=a?2147483647:-2147483648;break a}v[116064]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0}kb=e+16|0;nb=a;return d}function Jt(a,b){var c=0,d=0;c=kb-32|0;kb=c;d=c+16|0;lQ(d,a,a+1|0,a+2|0,a+3|0);lQ(c,b,b+1|0,b+2|0,b+3|0);b=It(w[v[d>>2]],w[v[c>>2]]);a:{if(!xj(b)){break a}b=w[v[d+4>>2]];a=w[v[c+4>>2]];b=(a|0)==(b|0)?0:b<<24>>24<a<<24>>24?-1:1;if(!xj(b)){break a}b=It(w[v[d+8>>2]],w[v[c+8>>2]]);if(!xj(b)){break a}b=It(w[v[d+12>>2]],w[v[c+12>>2]])}a=gf(b);kb=c+32|0;return a}function gW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=kb-32|0;kb=e;av(e+8|0,c);c=w[d|0];v[23588]=0;R(243,e+20|0,c|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Xj(e,e+8|0);v[23588]=0;X(114,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Xg(e+8|0);kb=e+32|0;break a}a=P()|0;O()|0;Ab(e+8|0);break b}a=P()|0;O()|0;Xg(e+8|0)}T(a|0);L()}}function f5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){a=v[v[a+24>>2]+24>>2];return tj(Wb(v[a+484360>>2],w[a+484376|0]))|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6888,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function l6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;v[f+8>>2]=d;d=v[eg(f,f+8|0)>>2];v[23588]=0;ja(950,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){a=XI(a);b=WI(a+88|0);c=VI(a+92|0);d=UI(a+96|0);v[a>>2]=62440;v[b>>2]=62556;v[c>>2]=62636;v[d>>2]=62676;Ee(f+8|0);kb=f+16|0;return a|0}a=P()|0;O()|0;Ee(f+8|0);T(a|0);L()}function Kt(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;Oka(b,0,a,0);a=nb?0:B(a,b)}else{a=0}a:{if(!a){break a}v[23588]=0;b=S(751,a|0)|0;c=v[23588];v[23588]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;Z(18);c=v[23588];v[23588]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Vb();L()}if(!b){break a}d=Ub(b,0,a)- -64|0}return d}function e5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){a=v[v[a+24>>2]+24>>2];return ut(v[a+484344>>2],v[a+484348>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6956,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function _z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=Tb(a);a=Fb(v[b>>2]);v[d+24>>2]=a;b=Fb(v[b+4>>2]);a:{while(1){if(Pb(a,b)){Zh(d,v[a>>2],v[a+4>>2]);if(v[d>>2]==(c|0)){Ao(d,a);v[23588]=0;R(352,e|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}Bb(d)}a=v[Nm(d+24|0)>>2];continue}break}kb=d+32|0;return}a=P()|0;O()|0;Bb(d);Vc(e);T(a|0);L()}function x0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=v[a+84>>2];f=v[e>>2];d=v[e+4>>2];h=v[a+28>>2];g=v[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){uc(f,h,g);f=g+v[e>>2]|0;v[e>>2]=f;d=v[e+4>>2]-g|0;v[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){uc(f,b,d);f=d+v[e>>2]|0;v[e>>2]=f;v[e+4>>2]=v[e+4>>2]-d}t[f|0]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;return c|0}function mp(a,b,c){var d=0,e=0,f=0;e=kb-16|0;kb=e;d=e+8|0;gd(d,b);v[23588]=0;b=S(1137,d|0)|0;d=v[23588];v[23588]=0;a:{if((d|0)==1){break a}v[23588]=0;d=S(1146,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break a}v[c>>2]=d;v[23588]=0;R(1147,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}ac(e+8|0);kb=e+16|0;return}a=P()|0;O()|0;ac(e+8|0);T(a|0);L()}function lJ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;e=Hb(a);if(e>>>0>=b>>>0){f=bd(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=Ac(a);i=f+b|0;if((b|0)!=(e|0)){h=b+f|0;Xh(h+d|0,h,e-b|0);c=(c>>>0>=h>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}Xh(i,c,d);b=d+e|0;Rh(a,b);t[g+15|0]=0;je(b+f|0,g+15|0);break a}ip(a,f,(d+e|0)-f|0,e,b,0,d,c)}kb=g+16|0;return a}sk();L()}function $Q(a,b){var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=hc(c+8|0,c+28|0,4);md(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Sb(c+28|0,b,4)){break b}id(a,4);d=1}kb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17430,9039,413,13074);L()}aa(17409,9039,411,13074);L()}return d}function op(a,b,c){var d=0,e=0,f=0;e=kb-16|0;kb=e;d=e+8|0;gd(d,b);v[23588]=0;b=S(1119,d|0)|0;d=v[23588];v[23588]=0;a:{if((d|0)==1){break a}v[23588]=0;d=S(1132,b|0)|0;f=v[23588];v[23588]=0;if((f|0)==1){break a}t[c|0]=d;v[23588]=0;R(1133,a|0,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}ac(e+8|0);kb=e+16|0;return}a=P()|0;O()|0;ac(e+8|0);T(a|0);L()}function Waa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=kb-16|0;kb=b;u[a>>1]=0;c=Tb(a+4|0);d=Tb(a+16|0);v[a+36>>2]=0;e=Mb(a+40|0);f=Yf(a+52|0);Lc(c);u[a+28>>1]=65472;v[23588]=0;v[b+12>>2]=1065353216;R(839,c|0,b+12|0);g=v[23588];v[23588]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Lc(d);kb=b+16|0;return a|0}a=P()|0;O()|0;pT(f);Ab(e);wc(d);wc(c);T(a|0);L()}function U7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=eL(a,b,c,d,e^1);v[b>>2]=46008;a=b+4208|0;f=Eb(a,0),g=1056964608,v[f>>2]=g;f=Eb(a,1),g=1065353216,v[f>>2]=g;f=Eb(a,2),g=1020054733,v[f>>2]=g;f=Eb(a,3),g=1065353216,v[f>>2]=g;f=Eb(a,4),g=1056964608,v[f>>2]=g;f=Eb(a,5),g=1048406533,v[f>>2]=g;f=Eb(a,6),g=1056964608,v[f>>2]=g;return b|0}function EL(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0);c=kb-16|0;kb=c;d=0;a:{if(!Zg(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;pk(a,c+12|0);e=v[c+12>>2];d=0;if(e>>>0>65535){break a}dk(b,e);while(1){if((f|0)==(e|0)){d=Zg(v[v[a>>2]-12>>2]+a|0)}else{v[c+8>>2]=0;Ep(a,c+8|0);g=Eb(v[b>>2],f),h=z[c+8>>2],z[g>>2]=h;f=f+1|0;continue}break}}a=d;kb=c+16|0;return a}function vba(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=kb-16|0;kb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+32;lN(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;lc(c);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=Et(d+8|0,dq(a,rg(v[a>>2],v[a+4>>2])+1|0),rg(v[a>>2],v[a+4>>2]),c);lN(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;Ed(a,c);dQ(c);kb=d+32|0}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=kb-32|0;kb=e;JT(e+8|0,c);v[23588]=0;R(113,e+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Xj(e,e+8|0);v[23588]=0;X(114,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Xg(e+8|0);kb=e+32|0;break a}a=P()|0;O()|0;Ab(e+8|0);break b}a=P()|0;O()|0;Xg(e+8|0)}T(a|0);L()}}function dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=kb-32|0;kb=e;Jq(e+8|0,c);v[23588]=0;R(575,e+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Xj(e,e+8|0);v[23588]=0;X(296,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}nS(e+8|0);kb=e+32|0;break a}a=P()|0;O()|0;zb(e+8|0);break b}a=P()|0;O()|0;nS(e+8|0)}T(a|0);L()}}function Q6(a){a=a|0;var b=0,c=0,d=0,e=0;b=kb-32|0;kb=b;a=Tb(a);v[23588]=0;Y(942,b+16|0);c=v[23588];v[23588]=0;a:{b:{if((c|0)!=1){c=Fb(v[b+16>>2]);d=Fb(v[b+20>>2]);e=v[fc(b+8|0,a)>>2];v[23588]=0;U(943,c|0,d|0,e|0);c=v[23588];v[23588]=0;if((c|0)==1){break b}wc(b+16|0);kb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;wc(b+16|0)}Xe(a);T(c|0);L()}function HT(a){var b=0,c=0,d=0;a:{if(Sb(a+60|0,15507,4)|(w[a+32|0]|w[a+33|0]<<8)>>>0>256|(w[a+49|0]<32|(w[a+36|0]|w[a+37|0]<<8)>>>0>255)){break a}if(t[a+51|0]<4|w[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(w[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function m4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12959,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function gU(a){var b=0,c=0;a:{if(Sb(a,13832,3)|(w[a+3|0]-1&255)>>>0>3){break a}if(Ib(w[a+196|0]|w[a+197|0]<<8)>>>0>255){break a}if((Ib(w[a+198|0]|w[a+199|0]<<8)-1&65535)>>>0>255){break a}if((Ib(w[a+200|0]|w[a+201|0]<<8)-1&65535)>>>0>31){break a}b=Ib(w[a+202|0]|w[a+203|0]<<8);if(b>>>0>256){break a}c=Ib(w[a+204|0]|w[a+205|0]<<8)>>>0<b>>>0}return c}function cY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=kb-32|0;kb=e;mn(e+8|0,c);v[23588]=0;R(113,e+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Xj(e,e+8|0);v[23588]=0;X(114,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Xg(e+8|0);kb=e+32|0;break a}a=P()|0;O()|0;Ab(e+8|0);break b}a=P()|0;O()|0;Xg(e+8|0)}T(a|0);L()}}function Ru(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=kb-32|0;kb=e;UB(e+8|0,c);v[23588]=0;R(113,e+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Xj(e,e+8|0);v[23588]=0;X(114,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Xg(e+8|0);kb=e+32|0;break a}a=P()|0;O()|0;Ab(e+8|0);break b}a=P()|0;O()|0;Xg(e+8|0)}T(a|0);L()}}function ht(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-16|0;kb=e;a:{if(!b){break a}Db(e+8|0,a+1074312|0,73);j=Cb(v[v[e+8>>2]>>2],v[e+12>>2])?c- -64|0:c;c=120;h=oj(a);k=h^-1;f=1;while(1){if(!c){break a}l=c;c=c>>>1|0;i=f+c|0;g=fh(a,i,j,d);if(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0)){continue}f=i+1|0;c=(c^-1)+l|0;continue}}kb=e+16|0;return f}function Xn(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function M3(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;WJ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;lc(c);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=oE(d+8|0,qE(a,Ri(v[a>>2],v[a+4>>2])+1|0),Ri(v[a>>2],v[a+4>>2]),c);WJ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;nE(a,c);mE(c);kb=d+32|0}function ow(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if((d|0)!=1){break a}if(v[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Vu(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if(!(w[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function aJ(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=ob[a|0](b)|0;d=nb;if((d|0)<0){break b}if((ob[c|0](b,0,0,0)|0)<0){break a}if((ob[c|0](b,0,0,2)|0)<0){break a}f=ob[a|0](b)|0;a=nb;ob[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=bz(f,a)}return g}ob[c|0](b,e,d,0)|0;return 0}function RC(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a:{if(b>>>0<3){if(!b){break a}if(!Qb(v[a>>2],v[a+8>>2],b)){break a}while(1)if((d|0)==2){Kj(c+8|0,x[c+14>>1]);d=x[c+8>>1];break a}else{t[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){Ag(a,c+13|0);e=w[c+13|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}aa(11143,9039,136,14156);L()}kb=c+16|0;return d&65535}function Lfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+11|0;sR(a,c);if(Sb(c,13490,4)){a=1}else{sR(a,d+11|0);t[b|0]=1;a=0}c=kb-16|0;kb=c;a:{b:{a=(d+11|0)+a|0;c:{if(!a){a=0;break c}b=Nc(c,a);v[23588]=0;a=S(655,b|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break b}zb(b)}kb=c+16|0;break a}a=P()|0;O()|0;zb(b);T(a|0);L()}kb=d+16|0;return a|0}function jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=kb-32|0;kb=d;GA(d+8|0,c);v[23588]=0;R(462,d+20|0,43212);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Xj(d,d+8|0);v[23588]=0;X(114,a|0,b|0,v[d>>2],v[d+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Xg(d+8|0);kb=d+32|0;break a}a=P()|0;O()|0;Ab(d+8|0);break b}a=P()|0;O()|0;Xg(d+8|0)}T(a|0);L()}}function Xia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(y[a+4>>2]<y[Gb(a)>>2]){d=kb-16|0;kb=d;a=Bh(d,a,1);NT(v[a+4>>2],x[b>>1],w[c|0]);v[a+4>>2]=v[a+4>>2]+4;lc(a);kb=d+16|0;return}e=kb-32|0;kb=e;d=Gb(a);d=Vf(e+8|0,qg(a,vc(v[a>>2],v[a+4>>2])+1|0),vc(v[a>>2],v[a+4>>2]),d);NT(v[d+8>>2],x[b>>1],w[c|0]);v[d+8>>2]=v[d+8>>2]+4;Ed(a,d);Uf(d);kb=e+32|0}function Nk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;v[f+8>>2]=a;v[f+12>>2]=b;h=v[a+8>>2]+120|0;As(w[h+20|0]);g=kb-16|0;kb=g;v[g+8>>2]=f+8;e=kb-16|0;kb=e;i=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=i;d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;ob[v[wp(e,ck(w[h+20|0]))>>2]](g+8|0,h);kb=e+16|0;kb=g+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];kb=f+16|0}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-112|0;kb=d;c=kb-16|0;kb=c;f=d+8|0;uU(c+8|0,f);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(g|0);if(!e){tU(f)}c=-1;a:{if(!e){break a}c=0;if(!wU(d+8|0)){break a}c=Be(a,b,vU(w[d+55|0]|w[d+56|0]<<8),nb)}kb=d+112|0;return c|0}function Eg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=Mc(a);d=Hb(a);c=yg(b);a=0;a:{if(!c){break a}a=e;d=d+a|0;c=b+c|0;b:{if((c|0)==(b|0)){break b}c:{c=c-b|0;if((c|0)>(d-a|0)){break c}g=1-c|0;h=w[b|0];while(1){f=d-a|0;if((c|0)>(f|0)){break c}a=Dp(a,g+f|0,h);if(!a){break c}if(!Mp(a,b,c)){break b}a=a+1|0;continue}}a=d}a=(a|0)==(d|0)?-1:a-e|0}return a}function O0(a){a=a|0;a:{v[23588]=0;S(1113,467144)|0;a=v[23588];v[23588]=0;b:{if((a|0)==1){break b}v[23588]=0;S(1113,467480)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}v[23588]=0;S(1114,467228)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}v[23588]=0;S(1114,467564)|0;a=v[23588];v[23588]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Vb();L()}}function zW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-512|0;kb=d;c=kb-16|0;kb=c;f=d+8|0;OC(c+8|0,f);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(g|0);if(!e){NC(f)}c=-1;a:{if(!e){break a}c=0;if(!QC(d+8|0)){break a}c=Be(a,b,PC(w[d+118|0],w[d+119|0]),nb)}kb=d+512|0;return c|0}function f4(a,b){a=a|0;b=b|0;var c=0;v[23588]=0;Y(952,a|0);c=v[23588];v[23588]=0;if((c|0)!=1){v[v[v[a+24>>2]+24>>2]+480272>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5787,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function cO(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;i=v[d+20>>2];h=v[d+52>>2];g=!h|e;t[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}v[(B(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}v[d+24>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+48>>2]=h;u[d+72>>1]=x[d+74>>1];ee(a,i>>>0>1&e&(b|0)==1,f+15|0);kb=f+16|0}function MY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=kb+-64|0;kb=e;d=1;a:{if(_g(a,b,0)){break a}d=0;if(!b){break a}b=Ky(b,92556,92604);d=0;if(!b){break a}d=e+8|0;Ub(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;ob[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}kb=e- -64|0;return d|0}function ty(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-16|0;kb=d;e=Sh(b,c);a:{if(e>>>0<=kp(a)>>>0){f=c;g=v[a>>2];h=fd(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+h;f=v[d+12>>2]}b=Qi(b,f,g);if(!i){ku(a,f,c,e-fd(v[a>>2],v[a+4>>2])|0);break a}Od(a,b);break a}rB(a);Ol(a,Xl(a,e));ku(a,b,c,e)}kb=d+16|0}function oz(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function tZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=kb-16|0;kb=g;k=ki(g+8|0,v[a+8>>2]);i=Xr(0,c,d-c|0,b?b:468124);ji(k);kb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function l4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:933;return}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,12989,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function aX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-32|0;kb=e;f=v[b+16>>2];a:{if(f>>>0<=c>>>0){gc(a,v[d>>2],0);break a}g=v[b+12>>2];b=v[b+4>>2];v[e+20>>2]=v[d+4>>2];v[e+16>>2]=f-c;gc(e+24|0,v[d>>2],v[Kb(e+20|0,e+16|0)>>2]);d=v[v[b>>2]+28>>2];f=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=f;ob[d|0](a,b,c+g|0,e+8|0)}kb=e+32|0}function aH(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=kb-16|0;kb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=ob[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((wk(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=Ms(v[a+32>>2])?-1:0}kb=b+16|0;return d|0}function Vj(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)>-2960?b:-2960)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function q5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return+(+y[v[v[a+24>>2]+24>>2]+1074420>>2]/1e4)}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,15123,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function be(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;cn(b);f=Mf(e+8|0,b);a:{d=a+8|0;b=v[d>>2];if(vc(b,v[a+12>>2])>>>0<=c>>>0){v[23588]=0;R(1210,d|0,c+1|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}b=v[d>>2]}a=Eb(b,c);b=v[a>>2];if(b){gn(b);a=Eb(v[d>>2],c)}g=a,h=ce(f),v[g>>2]=h;SF(f);kb=e+16|0;return}a=P()|0;O()|0;SF(f);T(a|0);L()}function V2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;g=v[d+4>>2];qx(b,c,g);f=v[b+16>>2];a:{if(f>>>0<=c>>>0){gc(a,v[d>>2],0);break a}v[e+12>>2]=f-c;v[e+8>>2]=g;d=v[d>>2];f=v[Kb(e+12|0,e+8|0)>>2];Cq(e,d,g,0,f);h=v[e>>2];i=v[e+4>>2];qh(Rf(Fb(v[b+4>>2]),c),Rf(Rf(Fb(v[b+4>>2]),c),i),h);Cq(a,d,g,0,f)}kb=e+16|0}function r5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return y[v[v[a+24>>2]+24>>2]+1074420>>2]/1e4|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,9290,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function lC(a){var b=0,c=0,d=0,e=0,f=0;d=w[a+9|0]|w[a+10|0]<<8;c=Oka(w[a+3|0],0,18,0);d=d+c|0;b=nb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;c=w[a+6|0]|w[a+7|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=w[a+4|0]|w[a+5|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;nb=a;return b}function J8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ti(a,b,c,d);v[a>>2]=44896;c=Tb(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){Qs(a);return a|0}b=P()|0;O()|0;wc(c);Jf(a);T(b|0);L()}function Iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb+-64|0;kb=c;b=-1;a:{if(!(ob[v[v[a>>2]+32>>2]](a,0,1084)|0)){break a}xl(a,1080);d=c+60|0;mS(a,d);e=d;d=lS(c+40|0);b=0;if(!kS(e,d)){break a}xl(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=y[d+4>>2]>=f>>>0}else{e=c+8|0;jS(a,e);b=b+1|0;f=mA(e)+f|0;continue}break}}kb=c- -64|0;return b|0}function BL(a){var b=0,c=0,d=0;c=kb-32|0;kb=c;a:{d=Sx(a);b=Qj(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[23588]=0;b=fa(901,c+8|0,b|0,b|0,Gb(a)|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){Ed(a,b);yL(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break a}}kb=c+32|0;return}V(0)|0;O()|0;Vb();L()}function AL(a){var b=0,c=0,d=0;c=kb-32|0;kb=c;a:{d=Vh(a);b=vc(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[23588]=0;b=fa(902,c+8|0,b|0,b|0,Gb(a)|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){Ed(a,b);Uf(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);a=v[23588];v[23588]=0;if((a|0)==1){break a}}kb=c+32|0;return}V(0)|0;O()|0;Vb();L()}function kz(a,b,c){var d=0,e=0,f=0;d=Mb(a);a=Hb(b);v[23588]=0;R(48,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){a:{while(1){if(Hb(b)>>>0>e>>>0){a=65533;f=t[hg(b,e)|0];if((f|0)>=-96){a=v[((f&255)<<2)+c>>2]}v[23588]=0;R(49,d|0,a|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;Gc(d);T(a|0);L()}function Gaa(a){a=a|0;var b=0,c=0;b=kb-32|0;kb=b;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;v[b+16>>2]=0;v[b+20>>2]=0;c=hc(b,b+16|0,15);nc(b+8|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);c=0;a:{if(v[b+12>>2]!=15){break a}if(Sb(b+16|0,8485,15)){break a}_b(a,15);c=1}kb=b+32|0;return c|0}function Lq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Fb(v[b>>2]);g=Fb(v[b+4>>2]);e=kb-16|0;kb=e;v[e+8>>2]=d;while(1){a:{if(!Pb(d,g)){break a}f=kb-16|0;kb=f;Zh(f+8|0,v[d>>2],v[d+4>>2]);h=cc(v[f+8>>2]);kb=f+16|0;if((c|0)==(h|0)){break a}d=v[Nm(e+8|0)>>2];continue}break}kb=e+16|0;if(pc(d,Fb(v[b+4>>2]))){Jh(a);return}Ao(a,d)}function SC(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a:{if(b>>>0<5){if(!b){break a}if(!Qb(v[a>>2],v[a+8>>2],b)){break a}while(1)if((d|0)==4){$l(c,v[c+12>>2]);d=v[c>>2];break a}else{t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Ag(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}aa(11143,9039,136,14156);L()}kb=c+16|0;return d}function JR(a){var b=0,c=0,d=0,e=0,f=0;e=w[a+28|0]|w[a+29|0]<<8;b=Oka(w[a+30|0],0,37,0);c=nb;d=b;b=Oka(w[a+24|0]|w[a+25|0]<<8,0,192,0);d=d+b|0;c=nb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=w[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;nb=a;return b}function Yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;v[c+12>>2]=1;a:{if(Vh(a)){d=v[a>>2];e=vc(d,v[a+4>>2]);v[c+8>>2]=e;f=v[Kb(c+12|0,c+8|0)>>2];while(1){if(f){u[d>>1]=x[b>>1];t[d+2|0]=w[b+2|0];f=f-1|0;d=d+4|0;continue}break}if(!e){RT(a,1-e|0,b);break a}Od(a,v[a>>2]+4|0);break a}pu(a);Bk(a,qg(a,1));RT(a,1,b)}kb=c+16|0}function Lka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;gc(c+8|0,b,10);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function J2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=0;a:{if(!v[b+28>>2]){break a}e=0;if((ob[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}f=v[d+4>>2];c=v[d>>2];while(1){b:{if(!f){break b}e=ob[v[b+28>>2]](v[b+24>>2],c,f)|0;if(!e){break b}f=f-e|0;c=c+e|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}break}e=g}gc(a,v[d>>2],e)}function _p(a){var b=0,c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;d=Fb(v[a>>2]);e=a;f=Fb(v[a+4>>2]);a=kb-16|0;kb=a;v[a+8>>2]=d;while(1){if(Pb(d,f)){b=b+A[d>>3];d=v[vt(a+8|0)>>2];continue}break}kb=a+16|0;a=Fb(v[e>>2]);v[c+8>>2]=a;b=-b;e=Fb(v[e+4>>2]);while(1){if(Pb(a,e)){b=b+A[a>>3];A[a>>3]=b;a=v[vt(c+8|0)>>2];continue}else{kb=c+16|0}break}}function SK(a){a=a|0;var b=0,c=0;c=kb-16|0;kb=c;b=v[v[a+16>>2]+24620>>2]/5|0;b=Ic(b,b>>31);v[a+4272>>2]=b;v[23588]=0;v[c+12>>2]=0;U(903,a+4256|0,b<<1,c+12|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(92948)|0;if((O()|0)!=(ea(92948)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;kb=c+16|0;return}T(b|0);L()}function nd(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;Em(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;d=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?d|32:d;b=Nc(c,21619);Ce(a+43|0,b);zb(b);pQ(a);kb=c+16|0}function fJ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a>>2];a:{if(!b){break a}c=v[a+8>>2];if(!c){break a}d=v[a+12>>2];if(!d){break a}e=ob[d|0](b)|0;a=nb;f=a;if((a|0)<0){break a}a=0;b:{if((ob[c|0](b,0,0,0)|0)<0){break b}a=0;if((ob[c|0](b,0,0,2)|0)<0){break b}ob[d|0](b)|0;a=nb;a=(a|0)>0|(a|0)>=0}g=a;ob[c|0](b,e,f,0)|0}return g|0}function bN(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{b:{while(1){v[e+12>>2]=b;v[e+8>>2]=d;if(y[Kb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=Qp(t[Lb(a,f)|0]);h=Qp(t[Lb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}kb=e+16|0;return a}function xW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-48|0;kb=d;c=kb-16|0;kb=c;f=d+8|0;HC(c+8|0,f);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(g|0);if(!e){GC(f)}c=-1;a:{if(!e){break a}c=0;if(!JC(d+8|0)){break a}c=Be(a,b,IC(w[d+43|0]),nb)}kb=d+48|0;return c|0}function wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb+-64|0;kb=d;c=kb-16|0;kb=c;f=d+8|0;JS(c+8|0,f);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(g|0);if(!e){IS(f)}c=-1;a:{if(!e){break a}c=0;if(!LS(d+8|0)){break a}c=Be(a,b,KS(d+8|0),nb)}kb=d- -64|0;return c|0}function sm(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=kb-16|0;kb=h;i=-17;if(-17-b>>>0>=c>>>0){j=Ac(a);if(b>>>0<=2147483622){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;i=Ng(v[Zc(h+12|0,h+8|0)>>2])+1|0}c=tc(i);if(e){we(c,j,e)}k=e+f|0;if((k|0)!=(d|0)){we((c+e|0)+g|0,(e+j|0)+f|0,d-k|0)}if((b|0)!=10){Nb(j)}vd(a,c);cf(a,i);kb=h+16|0;return}jf();L()}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-32|0;kb=e;v[e+24>>2]=d;c=rf(a,c);ne(e+8|0,v[a+36>>2]);f=a;a:{if(!c){Sc(e+8|0,a+32|0,5);d=0;if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}d=v[a+36>>2];a=0;zC(b,v[e+24>>2]);while(1){if(y[e+24>>2]>a>>>0){cP(d,dc(v[b>>2],a));a=a+1|0;continue}break}d=c}Ye(f,d);kb=e+32|0}function dx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=kb-240|0;kb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((ob[b|0](a,f)|0)>=0){if((ob[b|0](a,e)|0)>=0){break a}}j=f;f=(ob[b|0](f,e)|0)>=0;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}XH(g,h);kb=g+240|0}function $9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+e;b=v[d>>2];a:{while(1){if(v[d+4>>2]==(b|0)){break a}v[23588]=0;R(877,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){b=v[d>>2]+52|0;v[d>>2]=b;continue}break}a=P()|0;O()|0;Ud(d);T(a|0);L()}Ud(d);kb=d+16|0}function cG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-16|0;kb=d;i=v[b>>2];h=v[a>>2];e=v[jc(a)>>2]==1158;f=v[c>>2]-h|0;g=f<<1;f=f>>>0<2147483647?g?g:4:-1;g=ls(e?0:h,f);if(g){if(!e){ce(a)}v[d+4>>2]=1123;e=te(d+8|0,g,d+4|0);a=$F(a,e);Xc(e);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=v[a>>2]+(f&-4);kb=d+16|0;return}Cw();L()}function Yaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;if(!Fd(v[a+1298300>>2])){d=v[a+24620>>2];e=kb-16|0;kb=e;b=tc(536);v[23588]=0;d=Q(834,b|0,d|0)|0;f=v[23588];v[23588]=0;a:{if((f|0)!=1){b=v[Mf(e+8|0,d)>>2];kb=e+16|0;break a}a=P()|0;O()|0;Nb(b);T(a|0);L()}v[c+8>>2]=b;b=a+1298300|0;a=c+8|0;SM(b,ce(a));Ay(a)}kb=c+16|0}function Via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-576|0;kb=d;c=kb-16|0;kb=c;FT(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(f|0);if(!e){ET(d)}c=-1;a:{if(!e){break a}c=0;if(!HT(d)){break a}c=Be(a,b,GT(x[d+34>>1],x[d+36>>1]),nb)}kb=d+576|0;return c|0}function IE(a,b,c,d,e){var f=0;a:{f=kb-32|0;kb=f;_o(f+8|0,c);v[23588]=0;R(e|0,f+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Xj(f,f+8|0);v[23588]=0;X(114,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Xg(f+8|0);kb=f+32|0;break a}a=P()|0;O()|0;Ab(f+8|0);break b}a=P()|0;O()|0;Xg(f+8|0)}T(a|0);L()}}function FE(a,b,c,d,e){var f=0;a:{f=kb-32|0;kb=f;xU(f+8|0,c);v[23588]=0;R(e|0,f+20|0,d|0);c=v[23588];v[23588]=0;b:{c:{if((c|0)!=1){Xj(f,f+8|0);v[23588]=0;X(114,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23588];v[23588]=0;if((a|0)==1){break c}Xg(f+8|0);kb=f+32|0;break a}a=P()|0;O()|0;Ab(f+8|0);break b}a=P()|0;O()|0;Xg(f+8|0)}T(a|0);L()}}function AS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-16|0;kb=d;e=$d(b,c);a:{if(e>>>0<=Vh(a)>>>0){f=c;g=v[a>>2];h=vc(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+(h<<2);f=v[d+12>>2]}b=Qi(b,f,g);if(!i){tA(a,f,c,e-vc(v[a>>2],v[a+4>>2])|0);break a}Od(a,b);break a}pu(a);Bk(a,qg(a,e));tA(a,b,c,e)}kb=d+16|0}function uia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=fd(e,v[a+4>>2]);if(d>>>0<b>>>0){e=kb-32|0;kb=e;b=b-d|0;d=v[Gb(a)>>2];f=v[a+4>>2];a:{if(b>>>0<=d-f>>>0){No(a,b,c);break a}d=Gb(a);d=Zl(e+8|0,Xl(a,fd(v[a>>2],f)+b|0),fd(v[a>>2],v[a+4>>2]),d);eT(d,b,c);Ed(a,d);Yl(d)}kb=e+32|0;return}if(b>>>0<d>>>0){Od(a,b+e|0)}}function kM(a,b){var c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;hc(d+8|0,pd(b),zd(v[b+4>>2],w[b+11|0]));b=v[d+8>>2];e=v[d+12>>2];c=kb-16|0;kb=c;f=zd(v[a+4>>2],w[a+11|0]);v[c+12>>2]=f;v[c+8>>2]=e;g=Kb(c+12|0,c+8|0);a=Rv(pd(a),b,v[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}kb=c+16|0;kb=d+16|0;return a>>>31|0}function a1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=v[a+44>>2];c=v[a+24>>2];if(e>>>0<c>>>0){v[a+44>>2]=c;e=c}f=v[a+8>>2];c=v[a+12>>2];d=-1;a:{if(f>>>0>=c>>>0){break a}if(pc(b,-1)){Bn(a,f,c-1|0,e);return Ow(b)|0}g=qp(b);if(!(v[a+48>>2]&16)){d=-1;if(!pc(g,t[c-1|0])){break a}}Bn(a,f,c-1|0,e);t[v[a+12>>2]]=g;d=b}return d|0}function q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ti(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=47040;b=a+4208|0;e=Eb(b,0),f=1056880300,v[e>>2]=f;e=Eb(b,1),f=1050733080,v[e>>2]=f;e=Eb(b,2),f=1056964608,v[e>>2]=f;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;Jf(a);T(b|0);L()}function i7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ti(a,b,c,d);v[a>>2]=47276;b=a+4208|0;e=Eb(b,0),f=1065353216,v[e>>2]=f;e=Eb(b,1),f=1065353216,v[e>>2]=f;e=Eb(b,2),f=1051372203,v[e>>2]=f;e=Eb(b,3),f=0,v[e>>2]=f;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;Jf(a);T(b|0);L()}function Jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=c;a:{e=Qb(v[b>>2],v[b+8>>2],c<<2);if(!e){break a}xc(d+12|0,65535);vg(a,x[d+12>>1]);c=Fb(v[a>>2]);v[d>>2]=c;a=Fb(v[a+4>>2]);while(1){if(!Pb(c,a)){break a}f=d+8|0;if(!So(b,f)){Om(f)}u[c>>1]=v[d+8>>2];c=v[Se(d)>>2];continue}}kb=d+16|0;return e|0}function iX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-32|0;kb=f;v[f+28>>2]=c;v[f+24>>2]=b;v[f+20>>2]=d;v[f+16>>2]=e;v[23588]=0;X(173,f|0,f+24|0,f+20|0,f+16|0);b=v[23588];v[23588]=0;if((b|0)!=1){b=f+8|0;Dv(b,v[f>>2],v[f+4>>2]);Dg(a,b);me(b);me(f);me(f+24|0);kb=f+32|0;return}a=P()|0;O()|0;me(f+24|0);T(a|0);L()}function YF(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;g=1073741807;if(1073741807-b>>>0>=c>>>0){h=Ac(a);if(b>>>0<=536870886){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;g=cm(v[Zc(f+12|0,f+8|0)>>2])+1|0}c=Ci(g);if(e){mi(c,h,e)}if((d|0)!=(e|0)){i=e<<2;mi(c+i|0,h+i|0,d-e|0)}if((b|0)!=1){Nb(h)}vd(a,c);cf(a,g);kb=f+16|0;return}jf();L()}function Cba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;b=yh(d,b);v[23588]=0;U(799,d+16|0,b|0,c|0);e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){v[23588]=0;U(56,a|0,d+16|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}zb(d+16|0);zb(b);kb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;zb(d+16|0)}zb(b);T(c|0);L()}function i$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-16|0;kb=d;i=v[b>>2];h=v[a>>2];e=v[jc(a)>>2]==1158;f=v[c>>2]-h|0;g=f<<1;f=f>>>0<2147483647?g?g:1:-1;g=ls(e?0:h,f);if(g){if(!e){ce(a)}v[d+4>>2]=1123;e=te(d+8|0,g,d+4|0);a=$F(a,e);Xc(e);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=f+v[a>>2];kb=d+16|0;return}Cw();L()}function h5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return Qg(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7081,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function g5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return Hs(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,6790,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function d5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return Gs(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7440,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function YB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=kb-16|0;kb=c;a=$h(c,a,1);Ni(v[a+4>>2],x[b>>1]);v[a+4>>2]=v[a+4>>2]+2;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=Nj(d+8|0,Oj(a,Rc(v[a>>2],v[a+4>>2])+1|0),Rc(v[a>>2],v[a+4>>2]),c);Ni(v[c+8>>2],x[b>>1]);v[c+8>>2]=v[c+8>>2]+2;Ed(a,c);Oi(c);kb=d+32|0}function P9(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=kb-16|0;kb=c;a=Bh(c,a,1);ek(v[a+4>>2],z[b>>2]);v[a+4>>2]=v[a+4>>2]+4;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=Vf(d+8|0,qg(a,vc(v[a>>2],v[a+4>>2])+1|0),vc(v[a>>2],v[a+4>>2]),c);ek(v[c+8>>2],z[b>>2]);v[c+8>>2]=v[c+8>>2]+4;Ed(a,c);Uf(c);kb=d+32|0}function MV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb-1968|0;kb=e;c=kb-16|0;kb=c;f=e+8|0;SB(c+8|0,f);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;d=(d|0)==(g|0);if(!d){RB(f)}c=-1;a:{if(!d){break a}c=0;if(!TB(e+8|0)){break a}c=Be(a,b,1024,0)}kb=e+1968|0;return c|0}function G8(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb-16|0;kb=c;v[v[a+20>>2]+148>>2]=-1;Fo(c+8|0,a+4228|0);d=v[a+20>>2];e=v[c+12>>2];b=v[c+8>>2];v[23588]=0;U(921,d+4|0,b|0,Lb(b,e)|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(92948)|0;if((O()|0)!=(ea(92948)|0)){break a}_(b|0)|0;Lc(v[a+20>>2]+4|0);$()}kb=c+16|0;return}T(b|0);L()}function x5(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return+FM(v[v[a+24>>2]+24>>2])}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10099,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function tj(a){var b=0,c=0,d=0,e=0,f=0;b=v[a+4>>2];if(pc(v[a>>2],b)){a=0}else{b=Gi(b);e=Gi(v[a>>2]);c=kb-16|0;kb=c;v[c+8>>2]=b;while(1){a:{if(!Ig(b,e)){break a}d=kb-16|0;kb=d;v[d+8>>2]=b;f=lP(d+8|0);kb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}b=v[lP(c+8|0)>>2];continue}break}kb=c+16|0;a=HB(Fb(v[a>>2]),b)}return a&65535}function iw(a,b,c){var d=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){return v[v[v[a+24>>2]+24>>2]+c>>2]}c=V(0)|0;O()|0;_(c|0)|0;v[23588]=0;X(939,b|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function dk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=v[a>>2];c=vc(d,v[a+4>>2]);if(c>>>0<b>>>0){d=kb-32|0;kb=d;b=b-c|0;c=v[Gb(a)>>2];e=v[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Ct(a,b);break a}c=Gb(a);c=Vf(d+8|0,qg(a,vc(v[a>>2],e)+b|0),vc(v[a>>2],v[a+4>>2]),c);NL(c,b);Ed(a,c);Uf(c)}kb=d+32|0;return}if(b>>>0<c>>>0){Od(a,d+(b<<2)|0)}}function cF(a,b,c){var d=0;v[23588]=0;Y(952,a|0);d=v[23588];v[23588]=0;if((d|0)!=1){return x[v[v[a+24>>2]+24>>2]+c>>1]}c=V(0)|0;O()|0;_(c|0)|0;v[23588]=0;X(939,b|0,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Y8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+28>>2]=c;v[d+8>>2]=33;e=v[a>>2];f=v[a+8>>2];c=v[Kb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=df(a)}e=d+8|0;CA(e,b);f=hc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);CA(e,b);Ub(v[d+8>>2]+c|0,0,33-c|0);_b(a,v[d+28>>2]);kb=d+32|0;return c|0}function CX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;b=Jk(d,b);v[23588]=0;U(154,d+16|0,b|0,c|0);e=v[23588];v[23588]=0;a:{b:{if((e|0)!=1){v[23588]=0;U(4,a|0,d+16|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Ab(d+16|0);Ab(b);kb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;Ab(d+16|0)}Ab(b);T(c|0);L()}function dJ(a){var b=0,c=0,d=0,e=0;b=kb-32|0;kb=b;if(!w[a+20|0]){while(1){if(!(ob[v[v[a>>2]+40>>2]](a)|0)){bJ(a,65536);c=hc(b+16|0,Lb(v[a+4>>2],v[a+16>>2]),65536);d=v[v[a>>2]+44>>2];e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;ob[d|0](b+24|0,a,b+8|0);v[a+16>>2]=v[a+16>>2]+v[b+28>>2];continue}break}t[a+20|0]=1}kb=b+32|0}function XO(a){a=a|0;var b=0,c=0,d=0;b=kb-16|0;kb=b;if(w[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){t[a+534|0]=0}else{rj(a,d,1);c=c+1|0;continue}break}}t[b+15|0]=0;ci(a+8|0,18,b+15|0);au(a+26|0,18,29194);t[b+14|0]=255;ci(a+62|0,256,b+14|0);hh(v[a>>2],v[a+4>>2],65535,261,1);hh(v[a>>2],v[a+4>>2],65535,260,0);kb=b+16|0}function Uh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=a;f=kb-16|0;kb=f;a:{e=Sh(b,c);if(e>>>0<4294967280){b:{if(Fl(e)){de(d,e);break b}g=Ng(e)+1|0;h=tc(g);vd(d,h);cf(d,g);Gd(d,e);d=h}while(1){if((b|0)!=(c|0)){je(d,b);d=d+1|0;b=b+1|0;continue}break}t[f+15|0]=0;je(d,f+15|0);kb=f+16|0;break a}jf();L()}return a|0}function FY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(_g(a,v[b+8>>2],e)){nw(b,c,d);return}a:{if(!_g(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function zha(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,20)+d;b=v[c>>2];a:{while(1){if(v[c+4>>2]==(b|0)){break a}v[23588]=0;Y(228,b|0);a=v[23588];v[23588]=0;if((a|0)!=1){b=v[c>>2]+20|0;v[c>>2]=b;continue}break}a=P()|0;O()|0;Ud(c);T(a|0);L()}Ud(c);kb=c+16|0}function aka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb-32|0;kb=e;c=kb-16|0;kb=c;f=e+8|0;cC(c+8|0,f);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;d=(d|0)==(g|0);if(!d){Tu(f)}c=-1;a:{if(!d){break a}c=0;if(!HU(e+8|0)){break a}c=Be(a,b,72,0)}kb=e+32|0;return c|0}function HN(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;f=-2147483648;f=!c|!(t[c+15|0]&1)?f:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){f=x[d+28>>1];break b}if((f|0)==-2147483648){break a}}bq(b,f,a);Db(e+8|0,a+1074312|0,10);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}kb=e+16|0}function mR(a){var b=0,c=0;a:{if(Sb(a,3868,4)|w[a+63|0]!=26){break a}b=w[a+65|0];if(w[a+66|0]|(b|0)!=16&(b|0)!=1|(w[a+64|0]&3|(w[a+78|0]|w[a+79|0]<<8)>>>0>127)){break a}if((w[a+80|0]|w[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=Ek(w[a|0]|w[a+1|0]<<8,w[b|0]|w[b+1|0]<<8)?b:a;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function ey(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=F(c,.999);h=c*3.141592653589793;i=wt(b);while(1){if((e|0)!=32768){f=((e<<12^-1)&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Di(g)*wt(K(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=Qz(c*d*32768),u[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function V4(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return+A[v[a+24>>2]+16>>3]}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,7602,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function P4(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return v[v[a+24>>2]+8>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,10851,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-608|0;kb=d;c=kb-16|0;kb=c;hR(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(f|0);if(!e){gR(d)}c=-1;a:{if(!e){break a}c=0;if(!jR(d)){break a}c=Be(a,b,iR(x[d+34>>1]),nb)}kb=d+608|0;return c|0}function qja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-240|0;kb=d;c=kb-16|0;kb=c;_T(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(f|0);if(!e){ZT(d)}c=-1;a:{if(!e){break a}c=0;if(!aU(d)){break a}c=Be(a,b,$T(v[d+4>>2]),nb)}kb=d+240|0;return c|0}function lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+28>>2]=c;v[d+8>>2]=4896;e=v[a>>2];f=v[a+8>>2];c=v[Kb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=df(a)}e=d+8|0;EA(e,b);f=hc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);EA(e,b);Ub(v[d+8>>2]+c|0,0,4896-c|0);_b(a,v[d+28>>2]);kb=d+32|0}function jR(a){var b=0;a:{if(Sb(a+44|0,14113,4)|w[a+28|0]!=26|(w[a+40|0]|w[a+41|0]<<8|w[a+30|0]>2)){break a}if(((w[a+38|0]|w[a+39|0]<<8)-33&65535)>>>0<65504|((w[a+32|0]|w[a+33|0]<<8)-257&65535)>>>0<65280|((w[a+34|0]|w[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((w[a+36|0]|w[a+37|0]<<8)-1&65535)>>>0<128}return b}function I4(a,b){a=a|0;b=b|0;var c=0,d=0;a=Mb(a);c=Hb(b);v[23588]=0;R(73,a|0,c|0);c=v[23588];v[23588]=0;if((c|0)!=1){a:{b:{while(1){if(Hb(b)>>>0<=d>>>0){break b}c=t[hg(b,d)|0];v[23588]=0;R(51,a|0,zf(zf(c))|0);c=v[23588];v[23588]=0;if((c|0)!=1){d=d+1|0;continue}break}break a}return}}b=P()|0;O()|0;Ab(a);T(b|0);L()}function uea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+28>>2]=c;v[d+8>>2]=263;e=v[a>>2];f=v[a+8>>2];c=v[Kb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=df(a)}e=d+8|0;NP(e,b);f=hc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);NP(e,b);Ub(v[d+8>>2]+c|0,0,263-c|0);_b(a,v[d+28>>2]);kb=d+32|0}function dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+28>>2]=c;v[d+8>>2]=102;e=v[a>>2];f=v[a+8>>2];c=v[Kb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=df(a)}e=d+8|0;ST(e,b);f=hc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);ST(e,b);Ub(v[d+8>>2]+c|0,0,102-c|0);_b(a,v[d+28>>2]);kb=d+32|0}function Zfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=kb-16|0;kb=c;a=dv(c,a,1);BR(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=lB(d+8|0,mB(a,Cf(v[a>>2],v[a+4>>2])+1|0),Cf(v[a>>2],v[a+4>>2]),c);BR(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;kB(a,c);wu(c);kb=d+32|0}function Xx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;h=x[b>>1];c=Td(a);e=jc(a);f=kb-16|0;kb=f;while(1){if(c){g=Ys(x[c+16>>1],h);e=g?e:c;c=v[(g?c+4|0:c)>>2];continue}break}c=v[fc(f+8|0,e)>>2];kb=f+16|0;a:{if(Pb(c,Zf(a))){if(!Ys(x[b>>1],x[wd(c)>>1])){break a}}c=Zf(a)}a=v[fc(d+8|0,c)>>2];kb=d+16|0;return a}function my(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;f=v[b+656>>2];e=0;a:{if(!f){break a}f=jv(f,c);e=a+1074312|0;Db(d+8|0,e,31);a=0;if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){Db(d,e,93);a=Cb(v[v[d>>2]>>2],v[d+4>>2])^1}if(!(t[oM(b,c)+6|0]&1)){e=0;if(!(t[f+12|0]&1)|a){break a}}e=pc(v[f>>2],v[f+4>>2])^1}kb=d+16|0;return e}function kca(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=Lz(c,a,1);xz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+32;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=Et(d+8|0,dq(a,rg(v[a>>2],v[a+4>>2])+1|0),rg(v[a>>2],v[a+4>>2]),c);xz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;dP(a,c);wz(c);kb=d+32|0}function R_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!ff(f)){b=v[f+4>>2];v[a>>2]=v[f>>2];v[a+4>>2]=b;v[a+8>>2]=v[f+8>>2];break a}d=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(Vr(c)){de(a,c);break d}if(c>>>0>=1073741808){break c}e=cm(c)+1|0;b=Ci(e);vd(a,b);cf(a,e);Gd(a,c);a=b}mi(a,d,c+1|0);break b}jf();L()}}}function Hja(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=dv(c,a,1);nB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=lB(d+8|0,mB(a,Cf(v[a>>2],v[a+4>>2])+1|0),Cf(v[a>>2],v[a+4>>2]),c);nB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;kB(a,c);wu(c);kb=d+32|0}function DB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=kb-16|0;kb=c;a=VU(c,a,1);UU(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+40;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=SU(d+8|0,TU(a,Fq(v[a>>2],v[a+4>>2])+1|0),Fq(v[a>>2],v[a+4>>2]),c);UU(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+40;RU(a,c);QU(c);kb=d+32|0}function u$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-32|0;kb=g;h=v[20803];v[g+24>>2]=v[20802];v[g+28>>2]=h;h=v[20801];v[g+16>>2]=v[20800];v[g+20>>2]=h;h=v[20799];v[g+8>>2]=v[20798];v[g+12>>2]=h;h=v[20797];v[g>>2]=v[20796];v[g+4>>2]=h;h=a;a=g+32|0;b=Zj(h,b,c,d,e,f,g,a);kb=a;return b|0}function sha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+28>>2]=c;v[d+8>>2]=22;e=v[a>>2];f=v[a+8>>2];c=v[Kb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=df(a)}e=d+8|0;Au(e,b);f=hc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Au(e,b);Ub(v[d+8>>2]+c|0,0,22-c|0);_b(a,v[d+28>>2]);kb=d+32|0}function qha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+28>>2]=c;v[d+8>>2]=40;e=v[a>>2];f=v[a+8>>2];c=v[Kb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=df(a)}e=d+8|0;uA(e,b);f=hc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);uA(e,b);Ub(v[d+8>>2]+c|0,0,40-c|0);_b(a,v[d+28>>2]);kb=d+32|0}function hfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=kb-16|0;kb=c;a=Tv(c,a);Tz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=Ik(d+8|0,kn(a,yd(v[a>>2],v[a+4>>2])+1|0),yd(v[a>>2],v[a+4>>2]),c);Tz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;IQ(a,c);HQ(c);kb=d+32|0}function hO(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=Qt(c,a,1);ap(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=Ik(d+8|0,kn(a,yd(v[a>>2],v[a+4>>2])+1|0),yd(v[a>>2],v[a+4>>2]),c);ap(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;zr(a,c);gO(c);kb=d+32|0}function nW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+28>>2]=c;v[d+8>>2]=65;e=v[a>>2];f=v[a+8>>2];c=v[Kb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=df(a)}e=d+8|0;cv(e,b);f=hc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);cv(e,b);Ub(v[d+8>>2]+c|0,0,65-c|0);_b(a,v[d+28>>2]);kb=d+32|0}function hga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-1120|0;kb=d;c=kb-16|0;kb=c;GR(c+8|0,d+8|0);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!IR(d+8|0)){break a}c=Be(a,b,HR(v[d+1112>>2]),nb)}kb=d+1120|0;return c|0}function Yp(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;t[d+15|0]=b;a:{b:{c:{if(!ff(a)){c=10;b=w[a+11|0];if((b|0)==10){break c}de(a,b+1|0);c=a;break a}c=Ll(a);b=v[a+4>>2];c=c-1|0;if((b|0)!=(c|0)){break b}}sm(a,c,1,c,c,0,0);b=c}c=v[a>>2];Gd(a,b+1|0)}a=b+c|0;je(a,d+15|0);t[d+14|0]=0;je(a+1|0,d+14|0);kb=d+16|0}function Gf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Hb(a)|(c-b|0)<5){break a}Tr(b,c);e=c-4|0;c=Mc(a);g=c+Hb(a)|0;b:{while(1){c:{a=t[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=v[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>v[e>>2]-1>>>0){break a}}v[d>>2]=4}}function sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+28>>2]=c;v[d+8>>2]=5;e=v[a>>2];f=v[a+8>>2];c=v[Kb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=df(a)}e=d+8|0;Eo(e,b);f=hc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Eo(e,b);Ub(v[d+8>>2]+c|0,0,5-c|0);_b(a,v[d+28>>2]);kb=d+32|0}function UX(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=Tv(c,a);ap(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=Ik(d+8|0,kn(a,yd(v[a>>2],v[a+4>>2])+1|0),yd(v[a>>2],v[a+4>>2]),c);ap(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;zr(a,c);Sv(c);kb=d+32|0}function OW(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=zD(c,a);Av(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+36;lc(a);kb=c+16|0;return}d=kb-32|0;kb=d;c=Gb(a);c=xD(d+8|0,yD(a,kr(v[a>>2],v[a+4>>2])+1|0),kr(v[a>>2],v[a+4>>2]),c);Av(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+36;wD(a,c);Cv(c);kb=d+32|0}function MK(a){var b=0,c=C(0),d=0,e=0;e=v[v[a+16>>2]+24620>>2];b=kb-16|0;kb=b;v[b+12>>2]=0;v[b+8>>2]=1065353216;c=Wh(C(z[lq(a+4208|0,b+12|0,b+8|0)>>2]*C(999)));a:{if(c<C(4294967296)&c>=C(0)){d=~~c>>>0;break a}d=0}kb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;xc(a+4224|0,b)}function Cja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-224|0;kb=d;c=kb-16|0;kb=c;mU(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!oU(d)){break a}c=Be(a,b,nU(w[d+216|0],w[d+217|0]),nb)}kb=d+224|0;return c|0}function sL(a){a=a|0;var b=0,c=0;c=kb-16|0;kb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[23588]=0;v[c+12>>2]=0;U(903,a+4208|0,b<<1,c+12|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(92948)|0;if((O()|0)!=(ea(92948)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;kb=c+16|0;return}T(b|0);L()}function pfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb+-64|0;kb=d;c=kb-16|0;kb=c;Hu(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(f|0);if(!e){Cu(d)}c=-1;a:{if(!e){break a}c=0;if(!PQ(d)){break a}c=Be(a,b,OQ(d),nb)}kb=d- -64|0;return c|0}function o0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Mb(a);d=zd(v[b+4>>2],w[b+11|0]);e=zd(v[c+4>>2],w[c+11|0]);b=pd(b);v[23588]=0;X(102,a|0,b|0,d|0,d+e|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){b=pd(c);v[23588]=0;W(103,a|0,b|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;Ab(a);T(b|0);L()}}function R8(a,b){a=a|0;b=b|0;var c=0;a:{c=kb-32|0;kb=c;Es(c,b);v[23588]=0;R(913,c+16|0,c|0);b=v[23588];v[23588]=0;b:{c:{if((b|0)!=1){v[23588]=0;U(914,a|0,0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break c}Gc(c+16|0);Ab(c);kb=c+32|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Gc(c+16|0)}Ab(c);T(a|0);L()}}function R2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}d=v[c+4>>2];f=v[c>>2];while(1){b:{if(d){e=ob[v[b+28>>2]](v[b+24>>2],f,d)|0;if(e){break b}t[b+40|0]=1}d=g;break a}d=d-e|0;f=e+f|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}}gc(a,v[c>>2],d)}function Oy(a,b,c,d,e,f){var g=0,h=0,i=0;g=kb-16|0;kb=g;h=-17;if(-17-b>>>0>=c>>>0){i=pd(a);if(b>>>0<=2147483622){v[g+8>>2]=b<<1;v[g+12>>2]=b+c;h=Ng(v[Zc(g+12|0,g+8|0)>>2])+1|0}c=tc(h);if(e){we(c,i,e)}if((d|0)!=(e|0)){we((c+e|0)+f|0,e+i|0,d-e|0)}if((b|0)!=10){Nb(i)}vd(a,c);cf(a,h);kb=g+16|0;return}jf();L()}function wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-208|0;kb=d;c=kb-16|0;kb=c;eU(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(f|0);if(!e){dU(d)}c=-1;a:{if(!e){break a}c=0;if(!gU(d)){break a}c=Be(a,b,fU(d),nb)}kb=d+208|0;return c|0}function r6(a){a=a|0;var b=0;v[23588]=0;Y(952,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,5693,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Ts(a){var b=0,c=0,d=0;b=ni(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){if(b>45e-5){c=Ap(b)/.6931471805599453;b=c-H(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=ni(d+c)*.5}else{b=0}A[a+4248>>3]=b}Ss(a)}function Pl(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=B(c,872)+b|0;f=pN(v[d+720>>2],v[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return oN(a,b,c,e);case 1:break b;default:break a}}f=oN(a,b,c,e);if((f+5&255)>>>0>5){break a}a=B(c,872)+b|0;f=pN(v[a+720>>2],v[a+1272>>2],e)}return f}function Nia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-192|0;kb=d;c=kb-16|0;kb=c;Mq(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(f|0);if(!e){zT(d)}c=-1;a:{if(!e){break a}c=0;if(!BT(d)){break a}c=Be(a,b,AT(d),nb)}kb=d+192|0;return c|0}function L5(a){a=a|0;var b=0;v[23588]=0;Y(977,a|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[23588]=0;X(939,11894,a|0,0,0);a=v[23588];v[23588]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;if((b|0)!=1){T(a|0);L()}V(0)|0;O()|0;Vb();L()}function Ika(a){a=a|0;var b=0,c=0,d=0;c=kb-32|0;kb=c;b=255;a:{if(sj(v[a>>2],v[a+4>>2])>>>0<=49){b=Bz(c,v[a+12>>2]);v[23588]=0;R(289,a|0,b|0);d=v[23588];v[23588]=0;if((d|0)==1){break a}rl(b);Gj(a,sj(v[a>>2],v[a+4>>2])-1&255);b=sj(v[a>>2],v[a+4>>2])-1|0}kb=c+32|0;return b&255}a=P()|0;O()|0;rl(b);T(a|0);L()}function BB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=kb-32|0;kb=f;v[f+8>>2]=c;g=f,h=df(b),v[g+28>>2]=h;c=f+8|0;Of(c,b,v[Kb(c,f+28|0)>>2]);b=Je(c);v[23588]=0;da(236,a|0,b|0,v[f+8>>2],d|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){Uc(f+8|0);kb=f+32|0;return}a=P()|0;O()|0;Uc(f+8|0);T(a|0);L()}function Zx(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;v[d>>2]=a;a=v[a+4>>2];v[d+4>>2]=a;v[d+8>>2]=a+B(b,52);b=v[d+4>>2];a=v[d+8>>2];a:{while(1){if((a|0)==(b|0)){break a}v[23588]=0;R(877,b|0,c|0);e=v[23588];v[23588]=0;if((e|0)!=1){b=b+52|0;v[d+4>>2]=b;continue}break}a=P()|0;O()|0;lc(d);T(a|0);L()}lc(d);kb=d+16|0}function Gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=c;a:{if(!Qb(v[b>>2],v[b+8>>2],c<<1)){break a}xc(d+12|0,65535);vg(a,x[d+12>>1]);c=Fb(v[a>>2]);v[d>>2]=c;a=Fb(v[a+4>>2]);while(1){if(!Pb(c,a)){break a}Xu(b,d+8|0);e=c,f=Ib(x[d+8>>1]),u[e>>1]=f;c=v[Se(d)>>2];continue}}kb=d+16|0}function $m(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(v[c>>2]|v[d>>2]){while(1){if((b|0)==(f|0)){break a}e=v[d>>2];g=v[c>>2];h=c,i=g-ld((ld(0-g|0,31)&255)+g|0,8)|0,v[h>>2]=i;h=d,i=v[d>>2]-ld(e+(ld(0-e|0,31)&255)|0,8)|0,v[h>>2]=i;e=(f<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];f=f+1|0;continue}}Ub(a,0,b<<3)}}function yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-80|0;kb=d;c=kb-16|0;kb=c;bT(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(f|0);if(!e){FA(d)}c=-1;a:{if(!e){break a}c=0;if(!TP(d)){break a}c=Be(a,b,SP(d),nb)}kb=d+80|0;return c|0}function vZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;v[e>>2]=c;a=qw(f+12|0,0,v[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-v[e>>2]>>>0){break a}b=f+12|0;while(1){if(c){a=w[b|0];d=v[e>>2];v[e>>2]=d+1;t[d|0]=a;c=c-1|0;b=b+1|0;continue}break}b=0}kb=f+16|0;return b|0}function su(a){var b=0,c=0;b=v[a+76>>2];if(!((b|0)>=0&(!b|v[116072]!=(b&-1073741825)))){b=v[a+4>>2];if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return Lw(a)}b=v[a+76>>2];v[a+76>>2]=b?b:1073741823;c=a+76|0;b=v[a+4>>2];a:{if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=Lw(a)}v[c>>2]=0;return a}function s7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;gd(a,b);v[23588]=0;U(66,d+8|0,b|0,c|0);e=v[23588];v[23588]=0;a:{if((e|0)==1){break a}ac(d+8|0);b=v[b+24>>2];if(b){v[23588]=0;U(67,d|0,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)==1){break a}ac(d)}kb=d+16|0;return}b=P()|0;O()|0;ac(a);T(b|0);L()}function Rr(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}t[a|0]=b}function H2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-32|0;kb=f;v[f+28>>2]=e;v[f+24>>2]=d;$g(f+16|0,b,c);b=Dg(f+8|0,f+24|0);c=v[b+4>>2];b=v[b>>2];v[23588]=0;Fg(169,a,v[f+16>>2],v[f+20>>2],b,c);a=v[23588];v[23588]=0;if((a|0)!=1){me(f+24|0);kb=f+32|0;return}a=P()|0;O()|0;me(f+24|0);T(a|0);L()}function xga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-128|0;kb=d;c=kb-16|0;kb=c;SR(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;e=(e|0)==(f|0);if(!e){RR(d)}c=-1;a:{if(!e){break a}c=0;if(!TR(d)){break a}c=Be(a,b,256,0)}kb=d+128|0;return c|0}function nba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=uc(a,b,614);e=c+616|0;a=0;while(1){d=B(a,872);Sp(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=Wz(c+223848|0,b+223848|0);v[23588]=0;Q(803,c+223860|0,b+223860|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){return c|0}b=P()|0;O()|0;ic(a);T(b|0);L()}function fl(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;Es(c,b);v[23588]=0;R(1057,c+16|0,c|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){v[23588]=0;U(914,a|0,0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Gc(c+16|0);Ab(c);kb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Gc(c+16|0)}Ab(c);T(b|0);L()}function fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;c=rf(a,c);ne(d,v[a+36>>2]);a:{b:{if(!c){Sc(d,a+32|0,5);e=-1;if(!Cb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}e=v[c+16>>2]}f=v[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:ii(f,b);break c;default:break d}}mT(f,b,e)}f=c}Ye(a,f);kb=d+16|0}function $L(a){var b=0,c=0;a:{if(Sb(a,14147,4)){break a}b=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))}return c}function qq(a){var b=0,c=0;b=kb-32|0;kb=b;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;c=a+288|0;Gz(c,c+512|0,b);v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;a=a+800|0;Gz(a,wQ(a),b);kb=b+32|0}function bw(a,b,c,d,e){var f=0,g=0;g=c-b|0;a:{if((e|0)>=(g|0)){e=B(32-E(d|1)|0,1233)>>12;f=61;if((g|0)<(e+(y[(e<<2)+25744>>2]<=d>>>0)|0)){break a}}b:{if(d>>>0<=99999999){c=Zw(b,d);break b}c=d;d=(d>>>0)/1e8|0;e=c+B(d,-1e8)|0;c=(e>>>0)/1e4|0;c=ej(ej(LH(b,d),c),e+B(c,-1e4)|0)}f=0}v[a+4>>2]=f;v[a>>2]=c}function I3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;a:{if(!(c&1024)){break a}f=e,g=ie(b),v[f+8>>2]=g;b:{if(!Hb(b)){break b}if(w[Tc(b,0)|0]!=43){if(w[Tc(b,0)|0]!=45){break b}}d=d+1|0;xJ(e+8|0)}c=Hb(b);if(c>>>0>=d>>>0){break a}sJ(b,v[mj(e,e+8|0)>>2],d-c|0,48)}ad(a,b);kb=e+16|0}function y8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=6){c=Yd(c,C(0));a:{b:{switch(b-3|0){case 0:c=Wh(c);if(c==z[Eb(a+4208|0,3)>>2]){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b;default:break a}}c=C(Wh(C(c*C(4)))*C(.25))}d=Eb(a+4208|0,b),e=c,z[d>>2]=e;Hx(a)}}function R7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=6){c=Yd(c,C(0));a:{b:{switch(b-1|0){case 0:c=Wh(c);if(c==z[Eb(a+4208|0,1)>>2]){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b;default:break a}}c=C(Wh(C(c*C(4)))*C(.25))}d=Eb(a+4208|0,b),e=c,z[d>>2]=e;Hx(a)}}function bO(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[Zb(v[a+484344>>2],x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;Db(d+8|0,a+1074312|0,63);if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}kb=d+16|0}function nl(a,b,c){var d=0,e=0;a=Mb(a);d=Hb(b);v[23588]=0;R(48,a|0,d|0);d=v[23588];v[23588]=0;if((d|0)!=1){a:{while(1){if(Hb(b)>>>0>e>>>0){d=v[(w[hg(b,e)|0]<<2)+c>>2];v[23588]=0;R(49,a|0,d|0);d=v[23588];v[23588]=0;if((d|0)==1){break a}e=e+1|0;continue}break}return}}b=P()|0;O()|0;Gc(a);T(b|0);L()}function mL(a){a=a|0;var b=0,c=0,d=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];a:{if(D(b)<0x8000000000000000){d=~~b>>>0;c=D(b)>=1?~~(b>0?F(H(b*2.3283064365386963e-10),4294967295):I((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}A[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function HY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(_g(a,v[b+8>>2],0)){mw(b,c,d);return}e=v[a+12>>2];f=a+16|0;uF(v[f>>2],v[a+20>>2],b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){uF(v[a>>2],v[a+4>>2],b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function F9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ti(a,b,c,d);v[a>>2]=43836;b=Tb(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;v[a+4232>>2]=v[c+24620>>2];wV(a+4260|0,80,150,80,255);v[23588]=0;R(897,a+44|0,2);c=v[23588];v[23588]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;wc(b);Jf(a);T(c|0);L()}function U3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);c=mk(v[b+4>>2],v[b+8>>2]);if(c){GO(a,c);d=v[b+4>>2];e=v[b+8>>2];b=kb-16|0;kb=b;a=Ft(b,a,c);v[23588]=0;U(1058,d|0,e|0,a+4|0);c=v[23588];v[23588]=0;a:{if((c|0)!=1){lc(a);kb=b+16|0;break a}b=P()|0;O()|0;lc(a);T(b|0);L()}}}function xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+8>>2]=c;v[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Hb(a),v[f>>2]=g;e=v[Kb(d+12|0,d)>>2];v[d+4>>2]=e;a=Mp(Mc(a),b,v[Kb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}kb=d+16|0;return a|0}sk();L()}function bh(a,b){var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=E(e);Lf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;kb=d+16|0}function JO(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=Fs(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);ol(e,b,+n());return}a:{if(!nf(b)){break a}d=D(c)<N;if(b<0){c=d?c:1;break a}if(d){break a}ol(a,b,nf(c)?M:c);return}b=Fs(b);g=Di(c);ol(a,b*af(c),g*b)}function uB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-32|0;kb=e;v[e+8>>2]=c;f=e,g=df(b),v[f+28>>2]=g;c=e+8|0;Of(c,b,v[Kb(c,e+28|0)>>2]);b=Je(c);v[23588]=0;X(337,a|0,b|0,v[e+8>>2],d|0);a=v[23588];v[23588]=0;if((a|0)!=1){Uc(e+8|0);kb=e+32|0;return}a=P()|0;O()|0;Uc(e+8|0);T(a|0);L()}function lba(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Qd(w[b+24|0])){a=Yf(a);c=Gi(v[b>>2]);d=xf(b);v[23588]=0;U(806,a|0,c|0,d|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}v[23588]=0;Q(805,a+12|0,b+12|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}t[a+24|0]=1}return}b=P()|0;O()|0;yN(a);T(b|0);L()}function WB(a,b,c){var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+28>>2]=c;v[d+8>>2]=192;e=v[a>>2];f=v[a+8>>2];c=v[Kb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=df(a)}e=d+8|0;Mq(e,b);f=hc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Mq(e,b);Ub(v[d+8>>2]+c|0,0,192-c|0);_b(a,v[d+28>>2]);kb=d+32|0}function PY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;a:{e=v[b>>2];if(Fd(e)){if(!Re(c)){rK(c,17734);e=v[b>>2]}b=v[b+4>>2];ob[v[v[b>>2]+24>>2]](d,b,e);v[23588]=0;Q(800,c|0,d|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}zb(d)}ad(a,c);kb=d+16|0;return}a=P()|0;O()|0;zb(d);T(a|0);L()}function rQ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;v[e+12>>2]=6553600;i=e,j=cc(b),v[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=Aq(f*+y[Kb(g,b)>>2]);v[e+8>>2]=6553600;i=e,j=cc(c),v[i+4>>2]=j;i=e,j=Aq(f*+y[Kb(b,e+4|0)>>2]),v[i+12>>2]=j;v[e+8>>2]=d-h;io(a,h,Kb(b,g));kb=e+16|0}function VT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;a=Yf(a);b=b+236|0;e=zq(b);a:{while(1){if((b|0)!=(e|0)){d=x[b>>1];u[c+14>>1]=d;if(d){v[23588]=0;U(392,c|0,a|0,c+14|0);d=v[23588];v[23588]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}kb=c+16|0;return}b=P()|0;O()|0;ru(a);T(b|0);L()}function DL(a,b){var c=0,d=0,e=0,f=0,g=C(0);c=kb-16|0;kb=c;if(Zg(v[v[a>>2]-12>>2]+a|0)){u[c+14>>1]=0;Wf(a,c+14|0);e=x[c+14>>1];dk(b,e);while(1){if((d|0)!=(e|0)){v[c+8>>2]=0;Ep(a,c+8|0);f=Eb(v[b>>2],d),g=z[c+8>>2],z[f>>2]=g;d=d+1|0;continue}break}d=Zg(v[v[a>>2]-12>>2]+a|0)}kb=c+16|0;return d}function XJ(a,b){var c=0;c=kb-32|0;kb=c;pi(c,b);v[23588]=0;U(917,c+16|0,0,c|0);b=v[23588];v[23588]=0;a:{b:{if((b|0)!=1){v[23588]=0;R(1060,a|0,c+16|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Gc(c+16|0);zb(c);kb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Gc(c+16|0)}zb(c);T(b|0);L()}function Nv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Ew(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-160|0;kb=e;v[e+60>>2]=b;v[e+20>>2]=b;v[e+24>>2]=-1;f=e+16|0;li(f,0,0);UG(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+60>>2]|0)+b}v[a+8>>2]=d;v[a+12>>2]=f;v[a>>2]=g;v[a+4>>2]=h;kb=e+160|0}function AU(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function np(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;gd(d,a);v[23588]=0;a=S(1136,d|0)|0;d=v[23588];v[23588]=0;a:{b:{if((d|0)==1){break b}v[23588]=0;X(1148,a|0,82976,83002,b|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}ac(c+8|0);kb=c+16|0;break a}a=P()|0;O()|0;ac(c+8|0);T(a|0);L()}return b}function jD(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){v[a+96>>2]=e;v[a+92>>2]=d}else{f=(g<<3)+b|0;h=v[f>>2];d=d-ld((ld(0-d|0,31)&255)+d|0,8)|0;v[f>>2]=h+d;h=v[f+4>>2];e=e-ld((ld(0-e|0,31)&255)+e|0,8)|0;v[f+4>>2]=h+e;g=g+1|0;continue}break}}}function Ry(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}gk(a,b,b+700|0,c<<2,0)}}function NK(a){a=a|0;var b=0,c=0;c=kb-16|0;kb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[23588]=0;v[c+12>>2]=0;U(903,a+4208|0,b<<2,c+12|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(92948)|0;if((O()|0)!=(ea(92948)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;kb=c+16|0;return}T(b|0);L()}function Uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;$f(b);v[d+12>>2]=0;a:{if(!pk(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}t[d+11|0]=0;if(Nh(a,d+11|0)){Yp(b,t[d+11|0]);e=e+1|0;continue}break}e=0}kb=d+16|0;return e|0}function o$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=kb-128|0;kb=c;v[c+12>>2]=c+116;d=v[a+8>>2];a=c+16|0;gG(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=kb-16|0;kb=d;v[d+8>>2]=b;while(1){if((a|0)!=(e|0)){uH(d+8|0,t[a|0]);a=a+1|0;continue}break}kb=d+16|0;kb=c+128|0;return v[d+8>>2]}function lca(a,b){a=a|0;b=b|0;var c=0;a:{v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);c=Rc(v[b>>2],v[b+4>>2]);if(c){iq(a,c);fP(a,v[b>>2],v[b+4>>2],c)}v[23588]=0;Q(3,a+12|0,b+12|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}b=P()|0;O()|0;od(a);T(b|0);L()}}function Zy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=kb-16|0;kb=f;g=v[b+480180>>2];a:{if(g&64671904){b=w[(d&15)+43744|0];t[a+2|0]=0;u[a>>1]=b;break a}Db(f+8|0,b+1074312|0,66);h=a;a=(c&255)==4&(g|0)==4;b=(d&255)<<a<<4;Al(h,(i=Cb(v[v[f+8>>2]>>2],v[f+12>>2])?0:b,j=b,k=e,k?i:j),a)}kb=f+16|0}function Sy(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}gk(a,b,b+700|0,c,0)}}function Uz(a,b,c,d,e){var f=0;a:{f=v[a>>2];if(!_d(f,v[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}Em(b);b=ko(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Og(b)){break a}if(v[a>>2]!=(d|0)){gr(b+68|0)}uc(v[b+20>>2],v[a+20>>2]+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function Haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb+-64|0;kb=d;$f(b);e=d+40|0;Of(e,a,c);a=v[d+40>>2];c=d+8|0;cg(c,1,Je(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Bc(b,a);zb(a);Uc(d+40|0);kb=d- -64|0;break a}a=P()|0;O()|0;Uc(d+40|0);T(a|0);L()}}function fH(a,b,c){var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;a=Is(a);v[a+32>>2]=b;v[a>>2]=78660;b=d+8|0;bs(b,a);v[23588]=0;b=S(1115,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){ac(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;f=a,g=An(b),t[f+44|0]=g;kb=d+16|0;return}b=P()|0;O()|0;ac(d+8|0);Ln(a);T(b|0);L()}function dH(a,b,c){var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;a=tH(a);v[a+32>>2]=b;v[a>>2]=79028;b=d+8|0;bs(b,a);v[23588]=0;b=S(1116,b|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){ac(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;f=a,g=An(b),t[f+44|0]=g;kb=d+16|0;return}b=P()|0;O()|0;ac(d+8|0);es(a);T(b|0);L()}function cD(a,b,c,d){var e=0,f=0,g=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;e=d;d=v[a+1068>>2];u[e+(d<<1)>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;f=a,g=Ld(x[v[a+1060>>2]+34>>1])+d|0,v[f+1068>>2]=g;v[a+1072>>2]=v[a+1072>>2]-1}function JL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=b;a:{if(Vh(a)>>>0>=b>>>0){f=v[a>>2];e=vc(f,v[a+4>>2]);v[d+8>>2]=e;IL(f,v[Kb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Yx(a,b-e|0,c);break a}Od(a,v[a>>2]+(b<<2)|0);break a}pu(a);Bk(a,qg(a,b));Yx(a,b,c)}kb=d+16|0}function J1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=Ns(c);v[a>>2]=78120;v[d>>2]=78140;v[a+60>>2]=78180;v[a>>2]=78160;v[a+4>>2]=0;e=c;c=a+8|0;Kn(e,c);v[a>>2]=78120;v[d>>2]=78140;v[23588]=0;Q(91,c|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;$k(d);T(a|0);L()}function vT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=kb+-64|0;kb=c;d=c+40|0;Of(d,a,32);a=v[c+40>>2];e=c+8|0;cg(e,2,Je(d),a);v[23588]=0;R(222,c+24|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){Vm(c,b);a=c+24|0;Nl(c,a);zb(a);Uc(c+40|0);kb=c- -64|0;break a}a=P()|0;O()|0;Uc(c+40|0);T(a|0);L()}}function cW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;a:{if(!Qb(v[b>>2],v[b+8>>2],c<<1)){break a}xc(d+12|0,65535);vg(a,x[d+12>>1]);c=Fb(v[a>>2]);v[d>>2]=c;a=Fb(v[a+4>>2]);while(1){if(!Pb(c,a)){break a}Xu(b,d+8|0);u[c>>1]=x[d+8>>1];c=v[Se(d)>>2];continue}}kb=d+16|0}function $p(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{e=pl(a,b);if((e|0)==255){break a}g=v[a>>2];if(jk(g)){break a}f=Nd(a+318|0,e);e=VO(e);if(h=1,i=t[Lb(f,10)|0]&1,j=d,j?h:i){hh(g,v[a+4>>2],b,e- -64|0,UO(c,w[Lb(f,2)|0]))}if(d){break a}hh(v[a>>2],v[a+4>>2],b,e+67|0,UO(c,w[Lb(f,3)|0]))}}function tm(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!vj(w[f+31|0])){break a}e=w[f+34|0]-1|0;if((e&255)>>>0>249){break a}e=v[Md(a+906300|0,e)>>2];if(!e){break a}ob[v[v[e>>2]+96>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function Wr(a,b,c,d){var e=0,f=0;e=kb-160|0;kb=e;f=-1;v[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;v[e+144>>2]=a;e=Ub(e,0,144);v[e+76>>2]=-1;v[e+36>>2]=1118;v[e+80>>2]=-1;v[e+44>>2]=e+159;v[e+84>>2]=e+144;a:{if((b|0)<0){v[116064]=61;break a}t[a|0]=0;f=RH(e,c,d,1092,1093)}kb=e+160|0;return f}function LJ(a){var b=0,c=0,d=0,e=0;d=kb-16|0;kb=d;b=a+120|0;As(w[b+20|0]);c=kb-16|0;kb=c;v[c+8>>2]=d+8;a=kb-16|0;kb=a;e=v[14439];v[a+8>>2]=v[14438];v[a+12>>2]=e;e=v[14437];v[a>>2]=v[14436];v[a+4>>2]=e;b=ob[v[wp(a,ck(w[b+20|0]))>>2]](c+8|0,b)|0;kb=a+16|0;kb=c+16|0;kb=d+16|0;return b}function Gv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;v[f+12>>2]=e;v[f+8>>2]=d;$g(f,b,c);v[23588]=0;Ra(171,a|0,v[f>>2],v[f+4>>2]);b=v[23588];v[23588]=0;if((b|0)!=1){v[a+8>>2]=0;b=f+8|0;Dg(a+12|0,b);me(b);kb=f+16|0;return a|0}a=P()|0;O()|0;me(f+8|0);T(a|0);L()}function AK(a,b,c){t[a+12|0]=0;v[c>>2]=0;v[b>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;u[a+24>>1]=0;v[a+36>>2]=0;v[a+40>>2]=0;v[a+44>>2]=0;v[a+48>>2]=0;zK(a+60|0);zK(a+52|0);Op(a+49956|0);Op(a+58148|0);Op(a+66340|0);Op(a+74532|0);Ub(a+228|0,0,32768);Ub(a+32996|0,0,512);Ub(a+33508|0,0,16384)}function haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;c=rf(a,c);ne(d,v[a+36>>2]);a:{b:{if(!c){Sc(d,a+32|0,5);e=-1;if(!Cb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}e=v[c+16>>2]}f=v[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){pk(f,b);break c}zG(f,b,e)}f=c}Ye(a,f);kb=d+16|0}function bC(a,b,c){var d=0,e=0,f=0;d=kb+-64|0;kb=d;$f(b);e=d+40|0;Of(e,a,c);a=v[d+40>>2];f=d+8|0;cg(f,3,Je(e),a);v[23588]=0;R(222,d+24|0,f|0);e=v[23588];v[23588]=0;if((e|0)!=1){e=b;b=d+24|0;Bc(e,b);zb(b);Uc(d+40|0);kb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Uc(d+40|0);T(a|0);L()}function _i(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=d;g=ki(e+8|0,b);b=kb-16|0;kb=b;d=v[e+12>>2];v[b+12>>2]=d;v[b+8>>2]=d;f=-1;d=Wr(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Pd(d);v[h>>2]=a;if(!a){break a}f=Wr(a,d,c,v[b+12>>2])}kb=b+16|0;ji(g);kb=e+16|0;return f}function Sba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=b;a:{if(kp(a)>>>0>=b>>>0){f=v[a>>2];e=fd(f,v[a+4>>2]);v[d+8>>2]=e;ci(f,v[Kb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){No(a,b-e|0,c);break a}Od(a,v[a>>2]+b|0);break a}rB(a);Ol(a,Xl(a,b));No(a,b,c)}kb=d+16|0}function Wh(a){var b=C(0),c=0,d=0;c=(p(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return C(a*C(0))}a=(c|0)>=0?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){a=C(C(a+b)+C(-1));break a}a=C(a+b);if(!(b<=C(-.5))){break a}a=C(a+C(1))}a=(c|0)>=0?a:C(-a)}return a}function Fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb+-64|0;kb=d;e=d+40|0;Of(e,a,c);a=v[d+40>>2];c=d+8|0;cg(c,2,Je(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Hl(b,a);zb(a);Uc(d+40|0);kb=d- -64|0;break a}a=P()|0;O()|0;Uc(d+40|0);T(a|0);L()}}function Eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb+-64|0;kb=d;e=d+40|0;Of(e,a,c);a=v[d+40>>2];c=d+8|0;cg(c,1,Je(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Ce(b,a);zb(a);Uc(d+40|0);kb=d- -64|0;break a}a=P()|0;O()|0;Uc(d+40|0);T(a|0);L()}}function hV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb+-64|0;kb=d;e=d+40|0;Of(e,a,c);a=v[d+40>>2];c=d+8|0;cg(c,2,Je(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Dc(b,a);zb(a);Uc(d+40|0);kb=d- -64|0;break a}a=P()|0;O()|0;Uc(d+40|0);T(a|0);L()}}function Wq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;v[f+12>>2]=c;c=f+12|0;xc(c,256);xc(c,65535);h=x[f+12>>1];vg(a,h);c=0;while(1){if((c|0)==(h|0)){kb=f+16|0}else{g=w[b+c|0];i=Jl(v[a>>2],v[a+4>>2],c),j=(d|0)==(g|0)?-1:(e|0)==(g|0)?-2:g,u[i>>1]=j;c=c+1|0;continue}break}}function GP(a,b){var c=0,d=0,e=0,f=0;c=kb-96|0;kb=c;DR(b,c,c+96|0);b=0;while(1){if((b|0)==12){v[a+104>>2]=0;v[a+96>>2]=!(v[a+88>>2]|v[a+92>>2]);v[a+100>>2]=0;kb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d&65535;b=b+1|0;continue}break}v[a+112>>2]=0}function pt(a,b){var c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;Ge(d+8|0,b);b=v[d+8>>2];e=v[d+12>>2];c=kb-16|0;kb=c;f=Hb(a);v[c+12>>2]=f;v[c+8>>2]=e;g=Kb(c+12|0,c+8|0);a=Mp(Mc(a),b,v[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}kb=c+16|0;kb=d+16|0;return a>>>31|0}function bD(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=v[a+1068>>2]+Ld(x[v[a+1060>>2]+34>>1])|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function PJ(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=v[a>>2];d=yg(e);b:{c:{if((Hb(c)|0)==(d|0)){v[23588]=0;d=W(361,c|0,e|0,d|0)|0;e=v[23588];v[23588]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}V(0)|0;O()|0;Vb();L()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function CS(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;v[e+12>>2]=a;a:{if(!(!c|b)){a=Qe(+(B(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){xc(e+12|0,10);a=B(w[v[e+12>>2]+26800|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Qe(733.8401379310345/f*1e4);break a}a=Qe(f/.264*1e4)}kb=e+16|0;return a}function ef(a){var b=0,c=0;b=kb-32|0;kb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;LC(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];kb=b+32|0}function Dba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=kb+-64|0;kb=c;d=c+40|0;Of(d,a,32);a=v[c+40>>2];e=c+8|0;cg(e,1,Je(d),a);v[23588]=0;R(222,c+24|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=c+24|0;Dc(b,a);zb(a);Uc(c+40|0);kb=c- -64|0;break a}a=P()|0;O()|0;Uc(c+40|0);T(a|0);L()}}function z9(a,b){a=a|0;b=b|0;var c=0;a:{b:{c=v[a+20>>2];b=v[c+4>>2];if((fd(b,v[c+8>>2])|0)!=8){break b}if(Sb(b,9516,4)){break b}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4264>>2]=c;break a}Qx(a,a)}Us(a)}function ska(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=kb-624|0;kb=b;d=-1;c=kb-16|0;kb=c;e=b+8|0;jV(c+8|0,e);f=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(f|0)==(g|0);if(!a){iV(e)}if(a){d=kV(b+8|0)}kb=b+624|0;return d|0}function bca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;a=cQ(d,a+8|0,b);b=v[a>>2];a:{while(1){if(v[a+4>>2]==(b|0)){break a}v[23588]=0;R(754,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){b=v[a>>2]+32|0;v[a>>2]=b;continue}break}b=P()|0;O()|0;Ud(a);T(b|0);L()}Ud(a);kb=d+16|0}function Ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=kb-160|0;kb=b;d=-1;c=kb-16|0;kb=c;e=b+8|0;lR(c+8|0,e);f=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(f|0)==(g|0);if(!a){kR(e)}if(a){d=mR(b+8|0)}kb=b+160|0;return d|0}function fL(a){a=a|0;var b=0,c=0;c=kb-16|0;kb=c;b=v[v[a+16>>2]+1074404>>2];v[23588]=0;v[c+12>>2]=0;U(903,a+4208|0,B(b,254)|0,c+12|0);b=v[23588];v[23588]=0;a:{if((b|0)==1){b=V(92948)|0;if((O()|0)!=(ea(92948)|0)){break a}_(b|0)|0;$()}v[a+4220>>2]=0;kb=c+16|0;return}T(b|0);L()}function eC(a,b,c){var d=0,e=0,f=0;d=kb+-64|0;kb=d;e=d+40|0;Of(e,a,c);a=v[d+40>>2];f=d+8|0;cg(f,3,Je(e),a);v[23588]=0;R(222,d+24|0,f|0);e=v[23588];v[23588]=0;if((e|0)!=1){e=b;b=d+24|0;Dc(e,b);zb(b);Uc(d+40|0);kb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Uc(d+40|0);T(a|0);L()}function dw(a,b,c,d,e){var f=0,g=0;a:{f=kb+-64|0;kb=f;g=f+40|0;Of(g,a,e);a=v[f+40>>2];e=f+8|0;cg(e,d,Je(g),a);v[23588]=0;R(222,f+24|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){hc(f,b,c);a=f+24|0;Nl(f,a);zb(a);Uc(f+40|0);kb=f- -64|0;break a}a=P()|0;O()|0;Uc(f+40|0);T(a|0);L()}}function TR(a){var b=0;a:{if(Sb(a,15477,4)|((w[a+8|0]|w[a+9|0]<<8)-768&65535)>>>0<65280|(((w[a+112|0]|w[a+113|0]<<8)-65&65535)>>>0<65472|(w[a+106|0]|w[a+107|0]<<8)>>>0>256)){break a}if((w[a+122|0]|w[a+123|0]<<8)>>>0>255){break a}b=(w[a+124|0]|w[a+125|0]<<8)>>>0<4e3}return b}function nV(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;v[d+12>>2]=b;c=kb-16|0;kb=c;v[c+12>>2]=153391689;v[c+8>>2]=2147483647;e=Kb(c+12|0,c+8|0);kb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=IB(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Zc(d+8|0,d+12|0)>>2]}kb=d+16|0;return b}cd();L()}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[c+8>>2]=b;a:{if(vc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!Fd(b)){break a}v[23588]=0;R(487,a|0,c+8|0);a=v[23588];v[23588]=0;d=b;if((a|0)!=1){break a}a=P()|0;O()|0;sg(c+8|0);T(a|0);L()}sg(c+8|0);kb=c+16|0;return d|0}function TU(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;v[d+12>>2]=b;c=kb-16|0;kb=c;v[c+12>>2]=107374182;v[c+8>>2]=2147483647;e=Kb(c+12|0,c+8|0);kb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=PU(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Zc(d+8|0,d+12|0)>>2]}kb=d+16|0;return b}cd();L()}function Sja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=kb-32|0;kb=b;d=-1;c=kb-16|0;kb=c;e=b+8|0;Au(c+8|0,e);f=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(f|0)==(g|0);if(!a){AU(e)}if(a){d=BU(b+8|0)}kb=b+32|0;return d|0}function Mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=kb-16|0;kb=b;d=-1;c=kb-16|0;kb=c;e=b+8|0;Eo(c+8|0,e);f=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(f|0)==(g|0);if(!a){WS(e)}if(a){d=XS(b+8|0)}kb=b+16|0;return d|0}function yS(a,b){var c=0,d=0;a:{c=v[b>>2];d=v[b+20>>2];if(!_d(c,d)){break a}if(v[a+20>>2]==(d|0)){v[a+20>>2]=0;c=v[b>>2]}xc(a,c);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!Og(a)){break a}uc(v[a+20>>2],v[b+20>>2],Ij(v[a>>2],x[a+34>>1]))}}function VD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-32|0;kb=e;g=v[b+8>>2];f=v[b>>2];$g(e+16|0,c,d);c=v[v[f>>2]+28>>2];d=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=d;ob[c|0](e+24|0,f,g,e+8|0);$g(a,v[e+24>>2],v[e+28>>2]);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];kb=e+32|0}function AV(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function v0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function L3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;Jn(c,a);if(v[b>>2]){Lc(b);a=v[b>>2];Br(b);Nb(a);d=Gb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=Gb(c);d=Gb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Xf(c);kb=c+16|0}function Jh(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;b=kb-16|0;kb=b;v[b+4>>2]=1;f=b,g=tc(16),v[f+8>>2]=g;c=Uo(v[b+8>>2]);v[c>>2]=42728;f=en(Cc(c)),g=42860,v[f>>2]=g;c=d+8|0;e=Wo(b);Vo(c,Cc(e),e);fn(b);kb=b+16|0;Dg(a,c);me(c);kb=d+16|0;v[a+8>>2]=0;fe(a+12|0);return a}function En(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Rka(a,b,10,0);f=nb;e=Oka(d,f,246,0)+a|0;c=c-1|0;t[c|0]=e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=B(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function xe(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function e3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;v[d+24>>2]=c;a:{while(1){if((a|0)==(b|0)){break a}c=Nc(d+8|0,v[a>>2]);v[23588]=0;Q(1075,d+24|0,c|0)|0;e=v[23588];v[23588]=0;if((e|0)!=1){zb(c);a=a+4|0;continue}break}a=P()|0;O()|0;zb(c);T(a|0);L()}kb=d+32|0}function pn(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a:{if(!b){b=0;break a}d=b;b=E(b);Lf(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+v[c+8>>2]|0;e=e+(v[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=v[c>>2];b=v[c+4>>2]}v[a>>2]=d;v[a+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=e;kb=c+16|0}function X8(a){a=a|0;var b=0,c=0,d=0,e=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=4104;a=0;d=v[b+8>>2];a:{if(d>>>0<4096){break a}c=v[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}v[b+12>>2]=e;v[b+8>>2]=d-c;a=e}if(!a){aa(6056,8974,88,7360);L()}kb=b+16|0;return a|0}function CP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=kb-16|0;kb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Mc(d);Uh(b,a,Hb(d)+a|0);break c}BP(e,c,d);v[23588]=0;U(44,a|0,b|0,e|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Gc(e)}kb=e+16|0;break a}a=P()|0;O()|0;Gc(e);T(a|0);L()}}function tV(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=kb-16|0;kb=b;f=Lb(a,31),g=0,t[f|0]=g;t[b+15|0]=0;c=xi(a,go(a),b+15|0);t[b+14|0]=0;c=Sh(a,c);pm(c+a|0,go(a),b+14|0);while(1){if((c|0)!=(d|0)){e=Lb(a,d);if((w[e|0]-127&255)>>>0<=160){t[e|0]=32}d=d+1|0;continue}break}kb=b+16|0}function Qs(a){var b=0,c=0,d=C(0);b=a+4232|0;c=w[b|0];if(c>>>0>=5){t[b|0]=0;c=0}if(t[a+4233|0]<0){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<0){t[a+4234|0]=127;b=127}a:{if((c|0)==3){d=C(C(1)-ue(C(2),C(-C((b&255)+1|0))));break a}d=ue(C(2),C(-C((b&255)>>>0)))}z[a+4224>>2]=d}function qX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d+8>>2]=b;c=kb-16|0;kb=c;v[c+4>>2]=1;e=c,f=tc(24),v[e+8>>2]=f;b=Uo(v[c+8>>2]);v[b>>2]=62132;QD(Cc(b),v[d+8>>2],v[d+12>>2]);b=Wo(c);Vo(d,Cc(b),b);fn(c);kb=c+16|0;Dg(a,d);me(d);kb=d+16|0}function WD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=kb-16|0;kb=d;b:{c:{if(!b){b=a;a=pd(c);Uh(b,a,zd(v[c+4>>2],w[c+11|0])+a|0);break c}xN(d,c);v[23588]=0;U(44,a|0,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}Gc(d)}kb=d+16|0;break a}a=P()|0;O()|0;Gc(d);T(a|0);L()}}function RQ(a){var b=0,c=0,d=0,e=0;c=kb-16|0;kb=c;b=Fb(v[a>>2]);v[c+8>>2]=b;e=Fb(v[a+4>>2]);while(1){a:{d=Pb(b,e);if(!d){break a}a=x[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){u[b>>1]=65535;break b}if(a>>>0>63){break a}}b=v[Se(c+8|0)>>2];continue}break}kb=c+16|0;return d^1}function yz(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;a=Lz(d,a,b);b=v[a+4>>2];e=v[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}v[23588]=0;R(754,b|0,c|0);f=v[23588];v[23588]=0;if((f|0)!=1){b=b+32|0;v[a+4>>2]=b;continue}break}b=P()|0;O()|0;lc(a);T(b|0);L()}lc(a);kb=d+16|0}function oh(a,b){var c=0,d=0,e=0;a:{if(!(b?1:t[a+480180|0]&1)){break a}e=v[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function js(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=ba(16)|0;if(!w[470113]){t[470113]=1}a=hc(c+8|0,a,94344);c=v[a+4>>2];a=v[a>>2];v[23588]=0;a=fa(1094,d|0,a|0,c|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){ha(a|0,92256,1095);L()}a=P()|0;O()|0;ca(d|0);T(a|0);L()}function hp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function _U(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[kf(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[kf(d+13|0,d+12|0)|0]}kb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function _C(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;gd(d,a);v[23588]=0;a=S(19,d|0)|0;d=v[23588];v[23588]=0;a:{if((d|0)==1){break a}v[23588]=0;a=Q(20,a|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}ac(c+8|0);kb=c+16|0;return a}a=P()|0;O()|0;ac(c+8|0);T(a|0);L()}function YC(a,b,c){var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=v[a>>2];break a}a=v[a>>2];v[a+((f>>>0<33?0:g>>>5|0)<<2)>>2]=0}Mo(d+8|0,a,e);qv(v[d+8>>2],v[d+12>>2],b,c);kb=d+16|0}function ME(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=c;c=e+12|0;xc(c,d);xc(c,65535);f=x[e+12>>1];vg(a,f);c=0;while(1){if((c|0)==(f|0)){kb=e+16|0}else{d=w[b+c|0];g=Jl(v[a>>2],v[a+4>>2],c),h=(d|0)==255?-1:(d|0)==254?-2:d,u[g>>1]=h;c=c+1|0;continue}break}}function F0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=zf(t[b|0]),e=v[v[a>>2]+52>>2],ob[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=wk(b,1,c,v[a+32>>2])}return c|0}function Cj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Fb(v[b>>2]);f=Fb(v[b+4>>2]);e=kb-16|0;kb=e;v[e+8>>2]=d;while(1){a:{if(!Pb(d,f)){break a}if(WU(c,v[d>>2],v[d+4>>2])){break a}d=v[Nm(e+8|0)>>2];continue}break}kb=e+16|0;if(pc(d,Fb(v[b+4>>2]))){Jh(a);return}Ao(a,d)}function N8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=lu(a+8|0,d);v[23588]=0;Q(916,a+20|0,c|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;bc(b);T(a|0);L()}function OJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Mb(a);d=yg(b);e=Hb(c);v[23588]=0;X(1064,a|0,b|0,d|0,d+e|0);b=v[23588];v[23588]=0;a:{if((b|0)!=1){b=Mc(c);v[23588]=0;W(1065,a|0,b|0,e|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;zb(a);T(b|0);L()}}function c1(a){a=a|0;var b=0,c=0,d=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}d=-1;a:{if(!(w[a+48|0]&8)){break a}b=v[a+16>>2];if(b>>>0<c>>>0){Bn(a,v[a+8>>2],v[a+12>>2],c);b=v[a+16>>2]}a=v[a+12>>2];if(a>>>0>=b>>>0){break a}d=zf(t[a|0])}return d|0}function _r(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{c=v[b+4>>2];c:{if(!c){Xw(b);c=v[b+4>>2];if(!c){break c}}if(v[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;d=a&255}return d}function GE(a,b,c,d){var e=0,f=0;a:{e=kb+-64|0;kb=e;f=e+40|0;Of(f,a,d);a=v[e+40>>2];d=e+8|0;cg(d,c,Je(f),a);v[23588]=0;R(222,e+24|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=e+24|0;Ce(b,a);zb(a);Uc(e+40|0);kb=e- -64|0;break a}a=P()|0;O()|0;Uc(e+40|0);T(a|0);L()}}function uV(a,b,c){var d=0,e=0;d=kb+-64|0;kb=d;$f(b);e=d+40|0;Of(e,a,c);a=v[d+40>>2];c=d+8|0;cg(c,2,Je(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Bc(b,a);zb(a);Uc(d+40|0);kb=d- -64|0;return}a=P()|0;O()|0;Uc(d+40|0);T(a|0);L()}function Nl(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;d=Mc(b);e=c,f=Hb(b),v[e+12>>2]=f;v[c+8>>2]=v[a+4>>2]-1;qh(d,d+v[Kb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];e=c,f=Hb(b),v[e+12>>2]=f;a=v[a+4>>2];v[c+8>>2]=a-1;pm(d+v[Kb(c+12|0,c+8|0)>>2]|0,a+d|0,62364);kb=c+16|0}function AT(a){var b=0,c=0,d=0,e=0;d=w[a+32|0]|w[a+33|0]<<8;e=w[a+38|0]|w[a+39|0]<<8;c=w[a+34|0]|w[a+35|0]<<8;b=c+(w[a+36|0]|w[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;nb=a;return b}function $G(a,b){var c=0,d=0,e=0,f=0,g=0;c=kb-16|0;kb=c;d=kb-16|0;kb=d;f=d,g=Oka(v[b>>2],v[b+4>>2],1e6,0),v[f>>2]=g;v[d+4>>2]=nb;b=sl(d+8|0,d);e=v[b+4>>2];b=v[b>>2];kb=d+16|0;v[c+8>>2]=b;v[c+12>>2]=e;b=v[c+12>>2];v[a>>2]=v[c+8>>2];v[a+4>>2]=b;kb=c+16|0;return a}function $2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=kb-16|0;kb=c;v[c+4>>2]=1;e=c,f=tc(52),v[e+8>>2]=f;d=v[c+8>>2];v[23588]=0;Q(1082,d|0,b|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){b=a;a=Wo(c);Vo(b,Cc(a),a);fn(c);kb=c+16|0;break a}a=P()|0;O()|0;fn(c);T(a|0);L()}}function wC(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;a=dv(c,a,b);b=v[a+4>>2];d=v[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}v[23588]=0;Y(228,b|0);e=v[23588];v[23588]=0;if((e|0)!=1){b=b+20|0;v[a+4>>2]=b;continue}break}b=P()|0;O()|0;lc(a);T(b|0);L()}lc(a);kb=c+16|0}function pba(a,b){a=a|0;b=b|0;var c=0,d=0;c=w[a+11|0];a:{b:{c:{if(!gf(c)){d=10;c=zf(c);if((c|0)==10){break c}de(a,c+1|0);d=a;break a}c=v[a+4>>2];d=vu(v[a+8>>2])-1|0;if((c|0)!=(d|0)){break b}}Oy(a,d,1,d,d,0);c=d}d=v[a>>2];Gd(a,c+1|0)}a=c+d|0;xd(a,b);xd(a+1|0,0)}function al(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=qs(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Sj(a,b){var c=0,d=0,e=0,f=0,g=0;g=v[a+8>>2];while(1){if((b|0)!=(e|0)){d=v[a>>2];if(d){c=v[a+4>>2]}else{v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=8;c=w[c|0]}v[a>>2]=d-1;v[a+4>>2]=c>>>1;f=c&1|f<<1;e=e+1|0;continue}break}return f}function zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=kb-160|0;kb=b;d=-1;c=kb-16|0;kb=c;jU(c+8|0,b);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(e|0)==(f|0);if(!a){iU(b)}if(a){d=kU(b)}kb=b+160|0;return d|0}function nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=kb-208|0;kb=b;d=-1;c=kb-16|0;kb=c;MQ(c+8|0,b);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(e|0)==(f|0);if(!a){LQ(b)}if(a){d=NQ(b)}kb=b+208|0;return d|0}function iA(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=kb-1024|0;kb=e;d=kb-16|0;kb=d;fA(d+8|0,e);f=v[d+12>>2];nc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){_b(a,v[d+12>>2])}kb=d+16|0;if((f|0)==(g|0)){h=gA(e,c)>>>0<=b>>>0}kb=e+1024|0;return h}function Vb(){var a=0;a=v[23587];v[23588]=0;Z(a|0);a=v[23588];v[23588]=0;a:{if((a|0)!=1){v[23588]=0;Z(1227);a=v[23588];v[23588]=0;if((a|0)!=1){break a}}a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(1227);a=v[23588];v[23588]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Vb()}L()}function x9(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0),f=0,g=C(0);d=kb-16|0;kb=d;f=d,g=C(C(ob[v[v[a>>2]+48>>2]](a,b))+c),z[f+12>>2]=g;c=C(0);e=z[d+12>>2];a:{if(!(e<C(0))){c=C(1);if(!(e>C(1))){break a}}z[d+12>>2]=c}ob[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);kb=d+16|0}function iz(a,b,c,d){var e=0,f=0,g=0;e=Td(a);a:{if(e){f=jc(a);while(1){a=e;e=x[a+16>>1];g=v[a+20>>2];if(ml(c,d,e,g)){f=a;e=v[a>>2];if(e){continue}break a}if(!ml(e,g,c,d)){break a}f=a+4|0;e=v[a+4>>2];if(e){continue}break}break a}a=jc(a);f=a}v[b>>2]=a;return f}function HG(a,b,c){var d=0,e=0,f=0,g=0;d=a;a:{e=$d(b,c);if(e>>>0<1073741808){b:{if(Vr(e)){de(d,e);break b}f=cm(e)+1|0;g=Ci(f);vd(d,g);cf(d,f);Gd(d,e);d=g}while(1){if((b|0)!=(c|0)){vd(d,v[b>>2]);d=d+4|0;b=b+4|0;continue}break}vd(d,0);break a}jf();L()}return a}function EP(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=94360;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function oX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;f=v[b+8>>2];a:{if(f>>>0<=c>>>0){c=v[d>>2];b=0;break a}v[e+12>>2]=f-c;v[e+8>>2]=v[d+4>>2];c=v[b+4>>2]+c|0;f=c;b=v[Kb(e+12|0,e+8|0)>>2];g=c+b|0;c=v[d>>2];Qi(f,g,c)}gc(a,c,b);kb=e+16|0}function cl(a,b,c){var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+8>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=kb-16|0;kb=c;d=rc(c+8|0,v[a>>2]);f=v[d>>2];g=v[d+4>>2];d=v[e+8>>2];d=Qc(f,g,v[d>>2],v[d+4>>2]);kb=c+16|0;if(!d){break a}b=a}kb=e+16|0;return b}a=a+8|0;continue}}function Iy(a,b,c,d){var e=0,f=0,g=0;e=Td(a);a:{if(e){f=jc(a);while(1){a=e;e=w[a+16|0];g=v[a+20>>2];if(Rn(c,d,e,g)){f=a;e=v[a>>2];if(e){continue}break a}if(!Rn(e,g,c,d)){break a}f=a+4|0;e=v[a+4>>2];if(e){continue}break}break a}a=jc(a);f=a}v[b>>2]=a;return f}function vW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=kb-48|0;kb=b;d=-1;c=kb-16|0;kb=c;DC(c+8|0,b);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(e|0)==(f|0);if(!a){CC(b)}if(a){d=EC(b)}kb=b+48|0;return d|0}function X9(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Mb(c+16|0);v[23588]=0;v[c>>2]=v[c>>2]&-1332|1058;v[c+4>>2]=1;U(101,a|0,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){Pj(c);kb=c+32|0;return}a=P()|0;O()|0;Pj(c);T(a|0);L()}function Sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;$f(b);t[c+15|0]=0;a:{if(!Nh(a,c+15|0)){break a}f=w[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}t[c+14|0]=0;if(Nh(a,c+14|0)){Yp(b,t[c+14|0]);e=e+1|0;continue}break}d=0}kb=c+16|0;return d|0}function L7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ti(a,b,c,d);v[a>>2]=46512;b=a+4208|0;e=Eb(b,0),f=1017370378,v[e>>2]=f;e=Eb(b,1),f=0,v[e>>2]=f;v[23588]=0;R(897,a+44|0,2);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;Jf(a);T(b|0);L()}function s0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function pf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=kb-16|0;kb=e;a:{if(b>>>0<4294967280){b:{if(Fl(b)){de(d,b);break b}f=Ng(b)+1|0;g=tc(f);vd(d,g);cf(d,f);Gd(d,b);d=g}c=zB(d,b,c);t[e+15|0]=0;je(b+c|0,e+15|0);kb=e+16|0;break a}jf();L()}return a|0}function gC(a,b,c){var d=0,e=0;d=kb+-64|0;kb=d;e=d+40|0;Of(e,a,c);a=v[d+40>>2];c=d+8|0;cg(c,3,Je(e),a);v[23588]=0;R(222,d+24|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){a=d+24|0;Hl(b,a);zb(a);Uc(d+40|0);kb=d- -64|0;return}a=P()|0;O()|0;Uc(d+40|0);T(a|0);L()}function s$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-16|0;kb=g;v[g+8>>2]=b;gd(g,d);v[23588]=0;b=S(1136,g|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){ac(g);kG(a,f+24|0,g+8|0,c,e,b);kb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;ac(g);T(a|0);L()}function r$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-16|0;kb=g;v[g+8>>2]=b;gd(g,d);v[23588]=0;b=S(1136,g|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){ac(g);jG(a,f+16|0,g+8|0,c,e,b);kb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;ac(g);T(a|0);L()}function hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=kb-16|0;kb=d;b=rf(a,c);ne(d,v[a+36>>2]);a:{b:{if(!b){Sc(d,a+32|0,5);c=-1;if(!Cb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}c=v[b+16>>2]}vz(v[a+36>>2],e,c);f=1;g=b}Ye(a,g);kb=d+16|0;return f|0}function Xw(a){var b=0,c=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;if(v[a+20>>2]!=v[a+28>>2]){ob[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function y$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-16|0;kb=g;v[g+8>>2]=b;gd(g,d);v[23588]=0;b=S(19,g|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){ac(g);nG(a,f+24|0,g+8|0,c,e,b);kb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;ac(g);T(a|0);L()}function x$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-16|0;kb=g;v[g+8>>2]=b;gd(g,d);v[23588]=0;b=S(19,g|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){ac(g);mG(a,f+16|0,g+8|0,c,e,b);kb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;ac(g);T(a|0);L()}function aV(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[kf(d+15|0,d+14|0)|0]}a=e;kb=d+16|0;return a&255}function xA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;HS(a,b);dd(a,cc(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))+504|0);GS(a,d);a:{b=cc(w[b+32|0]|w[b+33|0]<<8|(w[b+34|0]<<16|w[b+35|0]<<24));if(!b){break a}if(!dd(a,b)){break a}AA(a,c);return}Ub(c,0,80)}function oba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{if((b|0)!=437){if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}c:{if((b|0)!=28591){if((b|0)==28605){break c}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=5;break a}d=8}iD(a,d,c)}function yg(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(w[b|0]){continue}break}}return b-a|0}function x3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=v[b>>2];e=v[b+8>>2];f=v[b+4>>2];a=0;a:while(1){if((a|0)!=(f|0)){g=(a<<2)+d|0;b=0;while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=v[g>>2]+(b<<3)|0;v[c>>2]=0;v[c+4>>2]=0;b=b+1|0;continue}}break}}function L2(a){a=a|0;var b=0,c=0,d=0;b=kb-32|0;kb=b;if(!w[a+8|0]){Si(a+12|0,v[a+4>>2]);se(b+24|0,v[a+12>>2],v[a+16>>2]);c=v[v[a>>2]+40>>2];d=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=d;ob[c|0](b+16|0,a,0,b+8|0);t[a+8|0]=1}kb=b+32|0;return v[a+12>>2]}function vE(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;v[b>>2]=0;t[c+15|0]=0;Nh(a,c+15|0);d=w[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){v[b>>2]=e;if((d|0)==(f|0)){kb=c+16|0}else{t[c+15|0]=0;Nh(a,c+15|0);d=d+1|0;e=v[b>>2]|w[c+15|0]<<(d<<3)-2;continue}break}}function Gr(a,b,c,d){var e=0;e=kb-32|0;kb=e;v[e+8>>2]=-1;v[e+12>>2]=0;v[e>>2]=0;Mb(e+16|0);v[e+4>>2]=d;v[23588]=0;v[e>>2]=v[e>>2]&-1332|1058;U(c|0,a|0,b|0,e|0);a=v[23588];v[23588]=0;if((a|0)!=1){km(e);kb=e+32|0;return}a=P()|0;O()|0;km(e);T(a|0);L()}function F8(a,b){a=a|0;b=b|0;var c=0,d=0;b=kb-16|0;kb=b;a:{b:{d=v[a+20>>2];c=v[d+4>>2];if((fd(c,v[d+8>>2])|0)!=7){break b}if(Sb(c,9516,4)){break b}c=Fb(c);d=Fb(v[v[a+20>>2]+8>>2]);Fo(b+8|0,a+4228|0);qh(c,d,v[b+8>>2]);break a}Qx(a,a)}Qs(a);kb=b+16|0}function NQ(a){var b=0;a:{if(Sb(a,14971,4)){break a}if(Ib(w[a+4|0]|w[a+5|0]<<8)>>>0>2|w[a+6|0]>128){break a}if(Ib(w[a+200|0]|w[a+201|0]<<8)>>>0>3999){break a}if(!Ib(w[a+140|0]|w[a+141|0]<<8)){break a}b=(Ib(w[a+148|0]|w[a+149|0]<<8)|0)==50}return b}function oG(a,b,c){var d=0,e=0,f=0;d=a;a:{if(b>>>0<1073741808){b:{if(Vr(b)){de(d,b);break b}e=cm(b)+1|0;f=Ci(e);vd(d,f);cf(d,e);Gd(d,b);d=f}e=b;f=d;while(1){v[f>>2]=c;f=f+4|0;e=e-1|0;if(e){continue}break}vd((b<<2)+d|0,0);break a}jf();L()}return a}function SH(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=SH(a*0x10000000000000000,b);c=v[b>>2]+-64|0}v[b>>2]=c;return a}v[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function Ir(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=kb-16|0;kb=f;d=bd(a);e=Hb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Ac(a);we(d+e|0,b,c);b=c+e|0;Rh(a,b);t[f+15|0]=0;je(b+d|0,f+15|0);break a}ip(a,d,(c+e|0)-d|0,e,e,0,c,b)}kb=f+16|0;return a|0}function Vl(a,b,c,d,e,f){var g=0;g=kb-32|0;kb=g;v[g+8>>2]=-1;v[g+12>>2]=0;v[g>>2]=0;Mb(g+16|0);v[g+4>>2]=f;v[23588]=0;v[g>>2]=v[g>>2]&e|d;U(c|0,a|0,b|0,g|0);a=v[23588];v[23588]=0;if((a|0)!=1){Pj(g);kb=g+32|0;return}a=P()|0;O()|0;Pj(g);T(a|0);L()}function Oba(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{if(!ff(a)){c=1;d=w[a+11|0];if((d|0)==1){break c}de(a,d+1|0);c=a;break a}c=Ll(a)-1|0;d=v[a+4>>2];if((c|0)!=(d|0)){break b}}YF(a,c,1,c,c);d=c}c=v[a>>2];Gd(a,d+1|0)}a=(d<<2)+c|0;vd(a,b);vd(a+4|0,0)}function wia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb-32|0;kb=d;e=d+16|0;GA(e,c);Zi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){bc(d+16|0);kb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);T(a|0);L()}}function sia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb-32|0;kb=d;e=d+16|0;_o(e,c);Zi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){bc(d+16|0);kb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);T(a|0);L()}}function sga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb-32|0;kb=d;e=d+16|0;Bp(e,c);Zi(d+8|0,e);v[23588]=0;X(296,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){$b(d+16|0);kb=d+32|0;break a}a=P()|0;O()|0;$b(d+16|0);T(a|0);L()}}function q$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=kb-16|0;kb=a;v[a+8>>2]=b;gd(a,d);v[23588]=0;b=S(1136,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){ac(a);iG(f+20|0,a+8|0,c,e,b);kb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;ac(a);T(b|0);L()}function lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb-32|0;kb=d;e=d+16|0;JT(e,c);Zi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){bc(d+16|0);kb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);T(a|0);L()}}function kP(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;eq(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Ni(v[d>>2],x[c>>1]);v[d>>2]=v[d>>2]+2;c=c+2|0;continue}break}qc(a,e);qc(a+4|0,d);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2];return f}function jaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;c=rf(a,c);ne(e,v[a+36>>2]);a:{b:{if(!c){Sc(e,a+32|0,5);f=-1;if(!Cb(v[v[e>>2]>>2],v[e+4>>2])){break b}break a}f=v[c+16>>2]}ob[d|0](v[a+36>>2],b,f);g=c}Ye(a,g);kb=e+16|0}function MA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Tb(a+8|0);v[23588]=0;d=S(202,b|0)|0;e=v[23588];v[23588]=0;b:{if((e|0)==1){break b}v[23588]=0;U(244,a|0,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;ic(c);T(a|0);L()}}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb-32|0;kb=d;e=d+16|0;Jq(e,c);Zi(d+8|0,e);v[23588]=0;X(296,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){$b(d+16|0);kb=d+32|0;break a}a=P()|0;O()|0;$b(d+16|0);T(a|0);L()}}function dV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb-32|0;kb=d;e=d+16|0;UB(e,c);Zi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){bc(d+16|0);kb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);T(a|0);L()}}function aw(a,b,c,d,e){var f=0;f=kb-32|0;kb=f;v[f+8>>2]=-1;v[f+12>>2]=0;v[f>>2]=0;v[f+4>>2]=0;Mb(f+16|0);v[23588]=0;v[f>>2]=v[f>>2]&e|d;U(c|0,a|0,b|0,f|0);a=v[23588];v[23588]=0;if((a|0)!=1){Pj(f);kb=f+32|0;return}a=P()|0;O()|0;Pj(f);T(a|0);L()}function _D(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb-32|0;kb=d;e=d+16|0;mn(e,c);Zi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){bc(d+16|0);kb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);T(a|0);L()}}function DU(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;eq(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){xd(v[d>>2],w[c|0]);v[d>>2]=v[d>>2]+1;c=c+1|0;continue}break}qc(a,e);qc(a+4|0,d);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2];return f}function AC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=kb-32|0;kb=d;e=d+16|0;av(e,c);Zi(d+8|0,e);v[23588]=0;X(114,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23588];v[23588]=0;if((a|0)!=1){bc(d+16|0);kb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);T(a|0);L()}}function w$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=kb-16|0;kb=a;v[a+8>>2]=b;gd(a,d);v[23588]=0;b=S(19,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){ac(a);lG(f+20|0,a+8|0,c,e,b);kb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;ac(a);T(b|0);L()}function KO(a){var b=0,c=0,d=0,e=0,f=0;b=kb-16|0;kb=b;c=a;d=v[a>>2];f=mk(d,v[a+4>>2]);a=Fb(d);v[b+8>>2]=a;e=+(f>>>0);c=Fb(v[c+4>>2]);while(1){if(Pb(a,c)){A[a>>3]=A[a>>3]/e;A[a+8>>3]=A[a+8>>3]/e;a=v[fq(b+8|0)>>2];continue}else{kb=b+16|0}break}}function AD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function $B(a){var b=0,c=0,d=0,e=0;b=w[a+2|0];c=b+(w[a+5|0]|w[a+6|0]<<8)|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=w[a+3|0]|w[a+4|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;nb=a;return b}function hA(a,b,c){var d=0;d=kb-16|0;kb=d;u[d+12>>1]=c;u[d+14>>1]=b;b=Fb(v[a>>2]);c=Fb(v[a+4>>2]);a=kb-16|0;kb=a;v[a+8>>2]=b;while(1){if(Pb(b,c)){if(x[b>>1]==x[d+14>>1]){u[b>>1]=x[d+12>>1]}b=v[Se(a+8|0)>>2];continue}break}kb=a+16|0;kb=d+16|0}function gp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function WN(a,b){var c=0,d=0;d=kb-16|0;kb=d;c=v[a+104>>2];a:{if(!c){break a}c=v[c>>2];if(!c){break a}v[a+76>>2]=c;v[a+88>>2]=v[a+88>>2]&-131|128;v[d+12>>2]=b<<8;v[d+8>>2]=c-1;b=c+(v[Kb(d+12|0,d+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}kb=d+16|0}function kD(a){var b=0,c=0;a:{if(Sb(a,14132,4)){break a}if(Sb(a+8|0,14053,4)){break a}b=cc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24));if(!b){break a}c=(cc(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function TK(a,b,c){var d=0,e=0;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return C((e?b^-1|e:b)|0)}function jO(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function he(a,b){var c=0,d=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if(v[a+8>>2]>=(d|0)){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=w[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function aN(a,b){a=YM(a);YM(a+368680|0);if(b){XM(a,1);return}if(!w[463224]){aN(94520,1);t[463224]=1}$n(225632,291168,a+131112|0);$n(291168,356704,a+196648|0);$n(356704,422240,a+262184|0);$n(94544,225632,a+24|0);uc(a+327720|0,422240,40960)}function UQ(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=SQ(a+20|0)}return c}function S3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-32|0;kb=d;fl(d,c);c=d+16|0;v[c>>2]=b;ad(c+4|0,d);v[23588]=0;R(1059,a+4|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ds(d+16|0);zb(d);kb=d+32|0;return}a=P()|0;O()|0;Ds(d+16|0);zb(d);T(a|0);L()}function Of(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Tb(a+8|0);v[23588]=0;U(244,a|0,b|0,c|0);c=v[23588];v[23588]=0;a:{if((c|0)!=1){a=v[a>>2];v[23588]=0;Q(188,b|0,a|0)|0;a=v[23588];v[23588]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;ic(d);T(a|0);L()}}function Kia(a){a=a|0;var b=0,c=0,d=0;b=kb-32|0;kb=b;t[b+30|0]=0;u[b+28>>1]=0;c=hc(b+8|0,b+28|0,3);nc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=3){break a}if(Sb(b+28|0,14711,3)){break a}_b(a,3);d=1}kb=b+32|0;return d|0}function Jea(a){a=a|0;var b=0,c=0,d=0;b=kb-32|0;kb=b;u[b+28>>1]=0;v[b+24>>2]=0;c=hc(b+8|0,b+24|0,6);nc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=6){break a}if(Sb(b+24|0,3856,6)){break a}_b(a,6);d=1}kb=b+32|0;return d|0}function HE(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=c;c=e+12|0;xc(c,d);xc(c,65535);d=x[e+12>>1];vg(a,d);c=0;while(1){if((c|0)==(d|0)){kb=e+16|0}else{f=w[b+c|0];g=Jl(v[a>>2],v[a+4>>2],c),h=f,u[g>>1]=h;c=c+1|0;continue}break}}function dka(a,b){a=a|0;b=b|0;var c=0;b=kb-32|0;kb=b;c=-1;a:{if(!vB(a,b+16|0)){break a}c=0;if(!MU(b+16|0)){break a}if(!Sb(b+16|0,14118,4)){c=-1;if(!id(a,4)){break a}}c=-1;if(!Rj(a,b+8|0)){break a}c=!Sb(b+8|0,14094,4)}kb=b+32|0;return c|0}function _v(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;u[b>>1]=0;t[c+15|0]=0;Nh(a,c+15|0);d=w[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){u[b>>1]=e;if(d>>>0>=f>>>0){kb=c+16|0}else{t[c+15|0]=0;Nh(a,c+15|0);e=x[b>>1]|w[c+15|0]<<7;d=1;continue}break}}function If(a,b,c){var d=0;a:{if(y[b+8>>2]<c>>>0){v[23588]=0;X(1074,17347,9070,435,6384);a=v[23588];v[23588]=0;if((a|0)==1){break a}L()}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return}V(0)|0;O()|0;Vb();L()}function hw(a,b,c,d,e,f){var g=0;g=kb-16|0;kb=g;v[g+12>>2]=e;v[g+8>>2]=d;d=Dg(g,g+8|0);e=v[d+4>>2];d=v[d>>2];v[23588]=0;a=Fg(f,a,b,c,d,e);b=v[23588];v[23588]=0;if((b|0)!=1){me(g+8|0);kb=g+16|0;return a}a=P()|0;O()|0;me(g+8|0);T(a|0);L()}function WY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-16|0;kb=e;if(d>>>0<4294967280){a:{if(Fl(d)){de(a,c);break a}f=Ng(d)+1|0;d=tc(f);vd(a,d);cf(a,f);Gd(a,c);a=d}a=we(a,b,c);t[e+15|0]=0;je(a+c|0,e+15|0);kb=e+16|0;return}jf();L()}function CN(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];b:{if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[b>>2]=a}}function li(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;e=v[a+4>>2];d=v[a+44>>2]-e|0;v[a+120>>2]=d;v[a+124>>2]=d>>31;d=a;a=v[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}v[d+104>>2]=a}function kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;yv(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function fU(a){var b=0,c=0,d=0,e=0;b=w[a+3|0];c=Oka(b>>>0<3?48:64,0,Ib(w[a+196|0]|w[a+197|0]<<8),0);d=nb;e=c;c=Oka(Oka(Ib(w[a+198|0]|w[a+199|0]<<8),0,b>>>0<4?4:5,0),nb,Ib(w[a+200|0]|w[a+201|0]<<8),0);b=e+c|0;b=b+512|0;a=b;nb=0;return a}function VN(a,b){var c=0,d=0;a:{if(!(t[a+851|0]&1)){break a}c=v[a+104>>2];if(!c){break a}d=v[c>>2];if(!d){break a}v[a+76>>2]=d;v[a>>2]=0;v[a+4>>2]=d-1;c=v[a+88>>2];v[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}v[a+84>>2]=d;v[a+80>>2]=0}}function S9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=kb-16|0;kb=d;b=rf(a,c);ne(d,v[a+36>>2]);a:{b:{if(!b){Sc(d,a+32|0,5);c=-1;if(!Cb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}c=v[b+16>>2]}vz(v[a+36>>2],e,c);f=b}Ye(a,f);kb=d+16|0}function Yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;while(1){a:{d=v[a>>2];if(vc(d,v[a+4>>2])>>>0>e>>>0){Jk(c,v[Eb(d,e)>>2]+40|0);d=nq(c,b);Ab(c);if(!d){break a}f=v[Eb(v[a>>2],e)>>2]}kb=c+16|0;return f|0}e=e+1|0;continue}}function QN(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;Db(d+8|0,a+1074312|0,80);if(!(!e|!Cb(v[v[d+8>>2]>>2],v[d+12>>2]))){t[b+824|0]=w[b+824|0]<<2}kb=d+16|0}function r9(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Sb(b,9516,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4264>>2]=c;Us(a)}}function OO(a,b){var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){GO(a,b);d=kb-16|0;kb=d;c=Ft(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){lc(c);kb=d+16|0}else{ol(b,0,0);b=b+16|0;v[c+4>>2]=b;continue}break}}return a}function Gia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;EA(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){Ub(b,0,4896)}return a|0}function B8(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Sb(b,9516,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4228>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4232>>2]=c;Qs(a)}}function $i(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function M0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((ob[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=wk(b,4,c,v[a+32>>2])}return c|0}function Dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=Bf(v[b>>2],v[b+4>>2]);c=ZP(d+8|0,c);v[23588]=0;X(727,a|0,b|0,e-1&65535,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){We(c);kb=d+32|0;return}a=P()|0;O()|0;We(c);T(a|0);L()}function Nz(a,b){var c=0,d=0,e=0,f=0;u[a+24>>1]=0;v[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[a+16>>2]=b;v[a>>2]=0;v[a+4>>2]=0;e=a,f=tQ(c-+(b<<2)),v[e+8>>2]=f;v[a+12>>2]=nb;return a}function Jy(a,b,c){var d=0,e=0;d=Td(a);a:{if(d){e=jc(a);while(1){a=d;d=w[a+16|0];if(Sn(c,d)){e=a;d=v[a>>2];if(d){continue}break a}if(!Sn(d,c)){break a}e=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=jc(a);e=a}v[b>>2]=a;return e}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;CA(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){Ub(b,0,33)}return a|0}function AM(a){var b=0,c=0,d=0;c=kb-544|0;kb=c;a:{if(!(w[a+480210|0]&128)|!v[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=Nz(c,v[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}uc(b+112|0,a,538);b=b+872|0;continue}}kb=c+544|0}function sW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;cv(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){Ub(b,0,65)}return a|0}function aE(){var a=0,b=0,c=0;b=kb-16|0;kb=b;a=Nc(b,14930);a:{if(!Hb(a)){break a}c=1;if((Eg(a,14600)|0)!=-1){break a}if((Eg(a,16764)|0)!=-1){break a}if((Eg(a,13662)|0)!=-1){break a}c=(Eg(a,13705)|0)!=-1}zb(a);kb=b+16|0;return c|0}function YD(a){var b=0;if(!(Sb(a,13261,8)|(w[a+8|0]|w[a+9|0]<<8)!=14|(!(w[a+12|0]|w[a+13|0]<<8)|(w[a+14|0]|w[a+15|0]<<8|(w[a+16|0]<<16|w[a+17|0]<<24))<=0))){b=(w[a+18|0]|w[a+19|0]<<8|(w[a+20|0]<<16|w[a+21|0]<<24))>>>0>23}return b}function Sfa(a,b){a=a|0;b=b|0;var c=0;b=kb-32|0;kb=b;c=-1;a:{if(!vB(a,b+16|0)){break a}c=0;if(!vR(b+16|0)){break a}c=-1;if(!Rj(a,b+8|0)){break a}c=0;if(!v[b+12>>2]){break a}a=v[b+8>>2];c=(a&2139062143)==(a|0)}kb=b+32|0;return c|0}function y3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=v[b>>2];d=v[b+8>>2];e=v[b+4>>2];a=0;a:while(1){if((a|0)!=(e|0)){f=(a<<2)+c|0;b=0;while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{v[v[f>>2]+(b<<2)>>2]=0;b=b+1|0;continue}}break}}function jg(a,b){var c=0,d=0,e=0,f=0;d=x[a+22>>1];e=d+x[a+20>>1]|0;c=x[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-B(v[Eb(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;continue}break}return a}function iS(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){e=v[a+4>>2];f=e>>>8|0;d=v[a>>2];e=(e&255)<<24|d>>>8;d=(((d^w[b|0])&255)<<3)+21640|0;g=v[d>>2];d=v[d+4>>2]^f;v[a>>2]=e^g;v[a+4>>2]=d;b=b+1|0;continue}break}return a}function SV(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Qb(v[a>>2],v[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){Dh(a+b|0);a=a+1|0;continue}break}break a}gc(c+8|0,b,120);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0;return d|0}function Pja(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Qb(v[a>>2],v[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){Go((a<<1)+b|0);a=a+1|0;continue}break}break a}Hu(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0;return d|0}function zga(a){a=a|0;var b=0,c=0,d=0;b=kb-32|0;kb=b;u[b+30>>1]=0;c=hc(b+8|0,b+30|0,2);nc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=2){break a}if(Sb(b+30|0,13570,2)){break a}_b(a,2);d=1}kb=b+32|0;return d|0}function ui(a){var b=0,c=0,d=0,e=0;e=Me(a);c=e&63;a:{if(!(e&64)){break a}b=6;while(1){d=Me(a);c=(d&127)<<b|c;if(!(d&128)){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}a=e>>>7|0;b=a?-2147483648:c;return a?(c|0)>=0?0-c|0:b:b}function nM(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Ic(Pka(Oka(d,d>>31,g,h),nb,256,0),nb);v[a+4>>2]=f-d;v[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function Oq(a){var b=0,c=0,d=0,e=0;c=kb-16|0;kb=c;b=kb-16|0;kb=b;Yq(b+8|0,c+15|0);d=v[b+12>>2];md(b,a,v[b+8>>2],v[b+12>>2]);e=v[b+4>>2];if((e|0)==(d|0)){id(a,v[b+12>>2])}kb=b+16|0;kb=c+16|0;return((d|0)==(e|0)?w[c+15|0]:0)&255}function AB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=v[a>>2];f=yk(e,v[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=bg(e,c);if(!Pb(v[c>>2],v[c+4>>2])){break a}d=d+1|0;continue}break}return(ph(a,d&65535,b)?d:-1)&65535}function Pka(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Rka(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;nb=(g^nb)-((a>>>0<f>>>0)+g|0)|0;return b}function Ju(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;if(b){e=bd(a);d=Hb(a);g=d+b|0;if(e-d>>>0<b>>>0){sm(a,e,g-e|0,d,d,0,0)}e=d;d=Ac(a);zB(e+d|0,b,c);Rh(a,g);t[f+15|0]=0;je(d+g|0,f+15|0)}kb=f+16|0;return a|0}function $ba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;RO(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){oz(b)}return a|0}function $N(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;a:{if(!c){break a}v[b+40>>2]=c;if(!c|v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Zc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=Vz(c&255),v[e+44>>2]=f}kb=d+16|0}function ud(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;g=v[b+8>>2];f=v[b>>2];v[e+8>>2]=c;v[e+12>>2]=d;h=v[v[f>>2]+28>>2];v[e>>2]=c;v[e+4>>2]=d;ob[h|0](a,f,g,e);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];kb=e+16|0}function pA(a,b){var c=0,d=0,e=0,f=0;c=a<<8;d=c&16711680;c=e;e=a<<24|d;f=c;d=b<<24|a>>>8;c=b<<8|a>>>24;a=f|(((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24));nb=e|(d&65280|c&255);return a}
function _u(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;kC(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){jC(b)}return a|0}function Wt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;wR(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){xR(b)}return a|0}function BC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;DC(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){CC(b)}return a|0}function ct(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=43820;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=43672;break a;case 2:c=43668;break a;case 1:break b;case 0:break c}}c=43664;break a}c=43660}v[a>>2]=v[c>>2]}function Rd(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+22>>1];g=d+x[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0<2048){break a}u[a+20>>1]=c-d}return}c=c+1|0;continue}}function Zp(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(A[b-8>>3]-A[a>>3]);b=0;while(1){if((b|0)!=2048){d=-xe(f*A[bf(a,b)>>3]);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Eb(c,b),h=e,v[g>>2]=h;b=b+1|0;continue}break}}function ZG(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c>>2]=a;v[c+4>>2]=b;d=kb-16|0;kb=d;a=Zr(d+8|0,Pka(v[c>>2],v[c+4>>2],1e6,0),nb);b=v[a+4>>2];a=v[a>>2];kb=d+16|0;v[c+8>>2]=a;v[c+12>>2]=b;kb=c+16|0;nb=v[c+12>>2];return v[c+8>>2]}function Lia(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[a+480180>>2]=b;wq(c,xq(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;ct(a+8|0,xq(a));kb=c+16|0}function kga(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Qb(v[a>>2],v[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){Dh(a+b|0);a=a+1|0;continue}break}break a}oB(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0;return d|0}function UN(a,b,c,d){var e=0;a=ed(Wn(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=jl(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=ed(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function TA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=yl(a);e=zd(v[a+4>>2],w[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=pd(a);we(d+e|0,b,c);b=c+e|0;tq(a,b);xd(b+d|0,0);return a|0}pq(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function LE(a,b,c,d,e){var f=0;f=kb-32|0;kb=f;v[f+24>>2]=a;v[f+28>>2]=b;v[f+16>>2]=d;v[f+20>>2]=e;v[f+8>>2]=c;v[f+12>>2]=0;a=VB(f+24|0,f+8|0);b=f+16|0;a=Ar(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?a:b;kb=f+32|0;return v[a>>2]}function GJ(a,b){var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){Ol(a,b);d=kb-16|0;kb=d;b=Pk(d,a,b);c=v[b+4>>2];e=v[b+8>>2];while(1){if((c|0)==(e|0)){lc(b);kb=d+16|0}else{c=c+1|0;v[b+4>>2]=c;continue}break}}return a}function Ut(a,b){var c=0,d=0,e=0;if(v[a>>2]){sV(a);c=v[a>>2];IB(a);Nb(c);d=Gb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Gb(b);d=Gb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function vN(a,b){var c=0,d=0,e=0,f=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];d=Gb(a);c=jc(a);a:{if(!v[d>>2]){v[a>>2]=c;break a}v[v[c>>2]+8>>2]=c;c=jc(b);v[b>>2]=c;v[c>>2]=0;e=Gb(b),f=0,v[e>>2]=f}return a}function qs(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!ix(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=$e(a)}return b}aa(15678,13110,1578,5432);L()}function g_(a){a=a|0;if(w[468448]){return v[117111]}if(!w[469608]){a=469584;while(1){a=Mb(a)+12|0;if((a|0)!=469608){continue}break}t[469608]=1}rd(469584,89760);rd(469596,89772);t[468448]=1;v[117111]=469584;return 469584}function WQ(a,b,c){var d=0;d=kb-16|0;kb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){t[d+14|0]=(x[(b<<1)+32622>>1]-x[(c<<1)+32622>>1]|0)/5;a=w[Xb(d+15|0,d+14|0)|0]}kb=d+16|0;return a&255}function UZ(a){a=a|0;if(w[468440]){return v[117109]}if(!w[469576]){a=469552;while(1){a=Mb(a)+12|0;if((a|0)!=469576){continue}break}t[469576]=1}qd(469552,13812);qd(469564,13791);t[468440]=1;v[117109]=469552;return 469552}function zs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-16|0;kb=c;d=v[b>>2];b=vc(d,v[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){kb=c+16|0}else{v[c+8>>2]=0;e=Hc(c+8|0);f=Eb(d,a),g=v[e>>2],v[f>>2]=g;a=a+1|0;continue}break}}function v8(a){a=a|0;var b=0;ob[v[v[a>>2]+132>>2]](a);Hx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=ob[v[v[a>>2]+196>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function oN(a,b,c,d){var e=0,f=0;e=v[(B(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=x[(B(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=w[((b<<5)+a|0)+480288|0]}return f}function ei(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;gc(d+8|0,b,c);e=v[d+12>>2];nc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);f=v[d+4>>2];if((f|0)==(e|0)){_b(a,v[d+12>>2])}kb=d+16|0;a=(e|0)==(f|0);if(!a){Ub(b,0,c)}return a}function QS(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Nha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=-1;a:{if(!Rj(a,d+8|0)){break a}e=v[d+12>>2];c=0;if(!(v[d+8>>2]==(Um(8938)|0)&e>>>0>255&e>>>0<260)){break a}c=Be(a,b,e>>>0<259?80:76,0)}kb=d+16|0;return c|0}function dy(a,b,c,d,e){var f=0,g=0,h=0;f=kb-16|0;kb=f;a:{if(!c){a=Kd(v[a>>2],b);A[a+8>>3]=e;A[a>>3]=d;break a}g=c>>>1|0;dy(a,b,g,d,e);h=Kd(v[a>>2],c);vi(f,d,e,A[h>>3],A[h+8>>3]);dy(a,b|c,g,A[f>>3],A[f+8>>3])}kb=f+16|0}function bq(a,b,c){var d=0;d=kb-16|0;kb=d;Db(d+8|0,c+1074312|0,102);a:{if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;kb=d+16|0}function ZO(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function Oka(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;nb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function BT(a){var b=0;a:{b:{if(Sb(a,13789,4)){if(Sb(a,16245,4)){break a}if((w[a+34|0]|w[a+35|0]<<8)>>>0<=255){break b}break a}if((w[a+34|0]|w[a+35|0]<<8)>>>0>255){break a}}b=(w[a+36|0]|w[a+37|0]<<8)>>>0<4e3}return b}function zL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;pg(a+12|0,d);if(b){if(b>>>0>=2097152){Mg();L()}d=tc(b<<11)}else{d=0}v[a>>2]=d;c=d+(c<<11)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Cc(a),f=d+(b<<11)|0,v[e>>2]=f;return a|0}function vq(a,b,c){var d=0,e=0;e=x[a+480192>>1];a:{if(e){if(!$c(b)|c>>>0>e>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[dc(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function gx(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!ps(a)){break a}if(!(t[a+1375|0]&1)){continue}break}ec(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function XH(a,b){var c=0,d=0,e=0;c=kb-256|0;kb=c;if((b|0)>=2){v[(b<<2)+a>>2]=c;uc(c,v[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;uc(v[e>>2],v[(d<<2)+a>>2],4);v[e>>2]=v[e>>2]+4;if((b|0)!=(d|0)){continue}break}}kb=c+256|0}function xu(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;if(c>>>0<4294967280){a:{if(Fl(c)){de(a,c);break a}e=Ng(c)+1|0;f=tc(e);vd(a,f);cf(a,e);Gd(a,c);a=f}a=we(a,b,c);t[d+15|0]=0;je(a+c|0,d+15|0);kb=d+16|0;return}jf();L()}function vz(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:cP(a,b);return;default:break a}}d=kb-32|0;kb=d;v[d+28>>2]=c;u[d+24>>1]=0;v[d+12>>2]=2;tw(d+16|0,a,d+24|0,v[Kb(d+28|0,d+12|0)>>2]);Kj(b,x[d+24>>1]);kb=d+32|0}function HO(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=e*A[a+16>>3]+(A[a>>3]*b+c*A[a+8>>3])-d*A[a+24>>3]-f*A[a+32>>3];A[a+56>>3]=b;return b}function zP(a){var b=0;b=u[a+784>>1];if(b){v[a+692>>2]=(b&32767)-1;if((b|0)<0){v[a+88>>2]=v[a+88>>2]|256}u[a+784>>1]=0}b=w[a+795|0];if(b){t[a+795|0]=0;t[a+838|0]=b-1}b=w[a+796|0];if(b){t[a+796|0]=0;t[a+837|0]=b-1}}function Sp(a,b){a=uc(a,b,88);v[a+88>>2]=v[b+88>>2];uc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];uc(a+672|0,b+672|0,52);My(a+724|0,b+724|0);My(a+732|0,b+732|0);My(a+740|0,b+740|0);uc(a+748|0,b+748|0,123);return a}function Fn(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return C(b?-1/a:a)}function $_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=un(a);e=Hb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Ac(a);mi(d+(e<<2)|0,b,c);b=c+e|0;Rh(a,b);vd(d+(b<<2)|0,0);return a|0}xF(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function rm(a,b){var c=C(0),d=0,e=0;c=C(1);d=u[a+28>>1];a:{if((d|0)>(b|0)){break a}e=v[a+4>>2];if((vc(e,v[a+8>>2])+d<<16)-65536>>16<(b|0)){break a}c=z[Eb(e,b-d|0)>>2];c=c<=C(10000000036274937e-31)?C(1):c}return c}function fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-16|0;kb=e;c=rf(a,c);ne(e,v[a+36>>2]);a:{if(!c){Sc(e,a+32|0,5);f=0;if(Cb(v[v[e>>2]>>2],v[e+4>>2])){break a}}tT(v[a+36>>2],b,d,0);f=c}Ye(a,f);kb=e+16|0}function iT(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,6)+e;b=v[d>>2];while(1){if(v[d+4>>2]!=(b|0)){iu(b,c);b=v[d>>2]+6|0;v[d>>2]=b;continue}break}Ud(d);kb=d+16|0}function Vba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Tb(a);d=Yf(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[23588]=0;R(765,a|0,1);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;BO(d);FO(a);T(b|0);L()}function oP(a,b,c,d){var e=0;e=kb-16|0;kb=e;a=$h(e,a,d);d=kb-16|0;kb=d;v[d+8>>2]=b;while(1){if(Pb(b,c)){Ni(v[a+4>>2],x[b>>1]);b=Se(d+8|0);v[a+4>>2]=v[a+4>>2]+2;b=v[b>>2];continue}break}kb=d+16|0;lc(a);kb=e+16|0}function jB(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;pU(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){qU(b)}return a}function cN(a,b){v[a+24>>2]=0;v[a+28>>2]=0;v[a+40>>2]=0;v[a+32>>2]=0;v[a+36>>2]=0;v[a+20>>2]=v[b>>2]-1900;v[a+16>>2]=v[b+4>>2]-1;v[a+12>>2]=v[b+8>>2];v[a+8>>2]=v[b+12>>2];v[a+4>>2]=v[b+16>>2];v[a>>2]=v[b+24>>2]}function TC(a,b){var c=0,d=0;c=kb-16|0;kb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Qb(v[a>>2],v[a+8>>2],1)){break b}t[c+15|0]=0;Ag(a,c+15|0);d=t[c+15|0]}kb=c+16|0;a=d;break a}aa(11143,9039,136,14156);L()}return a}function Kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(Vh(a)>>>0<b>>>0){if(th(1073741823)>>>0<b>>>0){break a}d=Gb(a);e=a;a=Vf(c+8|0,b,vc(v[a>>2],v[a+4>>2]),d);Ed(e,a);Uf(a)}kb=c+32|0;return}cd();L()}function HS(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;JS(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){IS(b)}return a}function Dk(a){xc(a+16|0,v[a>>2]);xc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function py(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;uM(a+24648|0);AM(a)}function nH(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=ob[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!Dn(b)){break a}v[a>>2]=0}return a|0}function ifa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(Wj(a)>>>0<b>>>0){if(th(357913941)>>>0<b>>>0){break a}d=Gb(a);e=a;a=Ik(c+8|0,b,yd(v[a>>2],v[a+4>>2]),d);IQ(e,a);HQ(a)}kb=c+32|0;return}cd();L()}function Xba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);c=Vg(v[b>>2],v[b+4>>2]);if(c){mz(a,c);d=kb-16|0;kb=d;e=v[b>>2];f=v[b+4>>2];b=lr(d,a,c);ju(e,f,b+4|0);lc(b);kb=d+16|0}return a|0}function V9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-16|0;kb=e;c=rf(a,c);ne(e,v[a+36>>2]);a:{if(!c){Sc(e,a+32|0,5);f=0;if(Cb(v[v[e>>2]>>2],v[e+4>>2])){break a}}GL(d,v[a+36>>2],b);f=c}Ye(a,f);kb=e+16|0}function Uba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(hn(a)>>>0<b>>>0){if(th(536870911)>>>0<b>>>0){break a}d=Gb(a);e=a;a=nr(c+8|0,b,Vg(v[a>>2],v[a+4>>2]),d);Ed(e,a);mr(a)}kb=c+32|0;return}cd();L()}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(Wj(a)>>>0<b>>>0){if(th(357913941)>>>0<b>>>0){break a}d=Gb(a);e=a;a=Ik(c+8|0,b,yd(v[a>>2],v[a+4>>2]),d);zr(e,a);gO(a)}kb=c+32|0;return}cd();L()}function Lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(ez(a)>>>0<b>>>0){if(th(613566756)>>>0<b>>>0){break a}d=Gb(a);e=a;a=mO(c+8|0,b,dz(v[a>>2],v[a+4>>2]),d);lO(e,a);kO(a)}kb=c+32|0;return}cd();L()}function Daa(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=-1;a:{if(!Rj(a,b+8|0)){break a}c=0;if(!dM(v[b+8>>2],v[b+12>>2])){break a}a=YQ(a,b);if(!a){Om(b)}c=-1;if(!a){break a}c=cM(v[b>>2])}a=c;kb=b+16|0;return a|0}function DS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(Ym(a)>>>0<b>>>0){if(th(2147483647)>>>0<b>>>0){break a}d=Gb(a);e=a;a=Nj(c+8|0,b,Rc(v[a>>2],v[a+4>>2]),d);Ed(e,a);Oi(a)}kb=c+32|0;return}cd();L()}function zr(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;ap(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}qc(a,d);qc(a+4|0,b+8|0);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2]}function wD(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-36|0;Av(v[d>>2]-36|0,c);v[d>>2]=v[d>>2]-36;continue}break}qc(a,d);qc(a+4|0,b+8|0);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2]}function mw(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function kB(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-20|0;nB(v[d>>2]-20|0,c);v[d>>2]=v[d>>2]-20;continue}break}qc(a,d);qc(a+4|0,b+8|0);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2]}function jn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;a:{if(c){Nc(d,c);break a}Mb(d)}v[23588]=0;U(11,a|0,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(d);kb=d+16|0;return}a=P()|0;O()|0;zb(d);T(a|0);L()}function f9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;a=lj(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=ob[e|0](a,c)|0}else{a=1}kb=c+16|0;return a|0}function dP(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-32|0;xz(v[d>>2]-32|0,c);v[d>>2]=v[d>>2]-32;continue}break}qc(a,d);qc(a+4|0,b+8|0);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2]}function tQ(a){a=a*4294967296;if(D(a)<0x8000000000000000){nb=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}nb=-2147483648;return 0}function ry(a,b){var c=0;c=v[b+24>>2];v[a+24628>>2]=c?c>>>0<512?c:512:1;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}uc(a+24604|0,b,40);vM(a,c)}function gA(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=MD(a);a:while(1){if((a|0)!=(e|0)){f=wd(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((w[Lb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function cba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;v[a>>2]=v[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){ty(d,v[c+4>>2],v[c+8>>2])}uc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function NW(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-48|0;kb=c;d=-1;a:{if(!lD(a,c+8|0)){break a}d=0;if(!kD(c+8|0)){break a}if(b){a=v[b>>2];if(!v[b+4>>2]&a>>>0<cc(v[c+12>>2])-8>>>0){break a}}d=1}kb=c+48|0;return d|0}function lN(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function at(a){var b=0;v[23588]=0;a=S(812,a|0)|0;b=v[23588];v[23588]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23588]=0;Z(18);b=v[23588];v[23588]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Vb();L()}function Tu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Cd(a,b){var c=0,d=0;c=kb-16|0;kb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Qb(v[a>>2],v[a+8>>2],1)){break b}t[c+15|0]=0;Ag(a,c+15|0);d=w[c+15|0]}kb=c+16|0;break a}aa(11143,9039,136,14156);L()}return d}function z1(a,b){a=a|0;b=b|0;var c=0;a=Is(a);v[a>>2]=77440;c=Mb(a+32|0);v[a+44>>2]=0;v[a+48>>2]=8;v[23588]=0;R(92,a|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;zb(c);Ln(a);T(b|0);L()}function fi(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;gc(d+8|0,b,c);e=v[d+12>>2];nc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);f=v[d+4>>2];if((f|0)==(e|0)){_b(a,v[d+12>>2])}kb=d+16|0;if((e|0)!=(f|0)){Ub(b,0,c)}}function pka(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[a>>2],v[a+8>>2],64)){a=0;while(1){if((a|0)!=64){Dh(a+b|0);a=a+1|0;continue}break}break a}Hu(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function pea(a){a=a|0;var b=0;b=kb-16|0;kb=b;a:{if(yq(a,10215)){OJ(b,17538,a);a=Mc(b);v[23588]=0;R(41,44,a|0);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(b);T(a|0);L()}kb=b+16|0;return}L()}function cfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;Bm(a,b);b=Fb(v[a>>2]);v[c+8>>2]=b;a=Fb(v[a+4>>2]);while(1){if(Pb(b,a)){d=w[b|0]+(d&255)|0;t[b|0]=d;b=v[He(c+8|0)>>2];continue}else{kb=c+16|0}break}}function _ba(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[a>>2],v[a+8>>2],27)){a=0;while(1){if((a|0)!=27){Dh(a+b|0);a=a+1|0;continue}break}break a}RO(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function Q3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;XJ(d,c);a=v[a+1298464>>2];v[23588]=0;U(376,a|0,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(d);kb=d+16|0;return}a=P()|0;O()|0;Ab(d);T(a|0);L()}function $k(a){a=a|0;var b=0;v[a>>2]=78636;v[23588]=0;R(70,a|0,0);b=v[23588];v[23588]=0;if((b|0)!=1){ac(a+28|0);Nb(v[a+32>>2]);Nb(v[a+36>>2]);Nb(v[a+48>>2]);Nb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Vb();L()}function $O(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=v[c>>2];if(d){eo(d);_O(v[c>>2])}b=b+1|0;continue}break}}function OR(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[a>>2],v[a+8>>2],32)){a=0;while(1){if((a|0)!=32){Dh(a+b|0);a=a+1|0;continue}break}break a}LR(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function Hf(a,b,c,d,e){var f=0;f=kb-256|0;kb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Ub(f,b&255,c?d:256);if(!c){while(1){tf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}tf(a,f,d)}kb=f+256|0}function kU(a){var b=0;a:{if(Sb(a,3873,4)|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(Sb(a+71|0,13650,4)|w[a+75|0]!=1|w[a+76|0]){break a}b=((w[a+116|0]|w[a+117|0]<<8)-1&65535)>>>0<9}return b}function ge(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Pd(b)}return c}function gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;c=rf(a,c);ne(d,v[a+36>>2]);a:{if(!c){Sc(d,a+32|0,5);e=0;if(Cb(v[v[d>>2]>>2],v[d+4>>2])){break a}}wT(v[a+36>>2],b,a);e=c}Ye(a,e);kb=d+16|0}function c7(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=v[b+52>>2];if(c&16){d=v[b+48>>2];c=v[b+28>>2];if(d>>>0<c>>>0){v[b+48>>2]=c;d=c}Uh(a,v[b+24>>2],d);break a}if(c&8){Uh(a,v[b+12>>2],v[b+20>>2]);break a}Mb(a)}}function NS(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;oB(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)|0}function Ih(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;bn(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)|0}function D7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;b=Ic(Pka(Oka(d,d>>31,b,0),nb,1e3,0),nb);v[a+16>>2]=0;v[a+12>>2]=b+c;LK(a,e);b=v[a+12>>2];v[f+12>>2]=0;JL(a,b,f+12|0);kb=f+16|0}function Aea(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;if((b|0)>=0){d=2147483647;a=Dt(a);if(a>>>0<=1073741822){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Zc(c+12|0,c+8|0)>>2]}kb=c+16|0;return d|0}cd();L()}function zV(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[a>>2],v[a+8>>2],8)){a=0;while(1){if((a|0)!=8){Dh(a+b|0);a=a+1|0;continue}break}break a}bn(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function rn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(kp(a)>>>0<b>>>0){if(th(-1)>>>0<b>>>0){break a}d=Gb(a);e=a;a=Zl(c+8|0,b,fd(v[a>>2],v[a+4>>2]),d);Ed(e,a);Yl(a)}kb=c+32|0;return}cd();L()}function gG(a,b,c,d,e,f){var g=0,h=0,i=0;g=kb-16|0;kb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){Ji(g+13|0,g+14|0)}h=c,i=(db(b|0,fd(b,v[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,v[h>>2]=i;kb=g+16|0}function dh(a){var b=0,c=0,d=0,e=0;b=kb-16|0;kb=b;c=2;if(a>>>0>=2){v[b+12>>2]=a>>>1;v[b+8>>2]=a^-1;d=b,e=v[Kb(b+12|0,b+8|0)>>2]+a|0,v[d+12>>2]=e;v[b+8>>2]=-1;c=v[Kb(b+12|0,b+8|0)>>2]}kb=b+16|0;return c}function bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){if(th(1073741823)>>>0<b>>>0){cd();L()}c=XC(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=(b<<2)+c|0,v[d>>2]=e;DA(a,b)}return a|0}function qW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){if(th(214748364)>>>0<b>>>0){cd();L()}c=tC(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=B(b,20)+c|0,v[d>>2]=e;wC(a,b)}return a|0}function fY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;f=v[v[b>>2]+20>>2];e=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=e;e=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=e;ob[f|0](a,b,d,8);kb=d+16|0}function eh(a,b){var c=0,d=0,e=0;c=Hb(a);a:{if((c|0)!=(Hb(b)|0)){break a}d=Mc(a);b=Mc(b);if(!ff(a)){while(1){e=!c;if(!c|w[d|0]!=w[b|0]){break a}b=b+1|0;d=d+1|0;c=c-1|0;continue}}e=!Mp(d,b,c)}return e}function PR(a,b){a=a|0;b=b|0;var c=0,d=0;d=v[a>>2];c=65535;a:{if(!ye(d,v[a+4>>2],b)){break a}d=AB(a,v[bg(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=v[a>>2];a=bg(c,b);WL(bg(c,d),a);c=d}return c|0}function yK(a){var b=0,c=0,d=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(D(c)<2147483648){a=~~c;break a}a=-2147483648}d=C(ni(b-+(a|0)))}else{d=C(0)}return d}function eR(a){var b=0,c=0,d=0;d=w[a+32|0]|w[a+33|0]<<8;b=w[a+34|0]|w[a+35|0]<<8;a=b+(w[a+36|0]|w[a+37|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<1|a>>>31;b=b<<1;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;nb=a;return c}function VX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;v[e+12>>2]=d;d=zd(v[b+4>>2],w[b+11|0]);if(d>>>0<c>>>0){sk();L()}b=pd(b);v[e+8>>2]=d-c;PD(a,b+c|0,v[Kb(e+12|0,e+8|0)>>2]);kb=e+16|0}function SP(a){var b=0,c=0,d=0;d=w[a+64|0]|w[a+65|0]<<8;b=w[a+70|0]|w[a+71|0]<<8;a=b+(w[a+72|0]|w[a+73|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<2|a>>>30;b=b<<2;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;nb=a;return c}function QB(a,b){var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[a>>2],v[a+8>>2],512)){a=0;while(1){if((a|0)!=128){Om((a<<2)+b|0);a=a+1|0;continue}break}break a}Mu(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function P8(a){a=a|0;var b=0,c=0,d=0;b=kb-32|0;kb=b;a:{if(Vh(a)>>>0<=12){if(th(1073741823)>>>0<=12){break a}c=Gb(a);d=a;a=Vf(b+8|0,13,vc(v[a>>2],v[a+4>>2]),c);Ed(d,a);Uf(a)}kb=b+32|0;return}cd();L()}function fv(a,b){var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[a>>2],v[a+8>>2],256)){a=0;while(1){if((a|0)!=256){Dh(a+b|0);a=a+1|0;continue}break}break a}gc(c+8|0,b,256);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function aS(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;gS(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;if((d|0)!=(e|0)){hS(b)}}function oU(a){var b=0,c=0,d=0;a:{if(Sb(a,21608,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|w[a+16|0]>3|w[a+17|0]>3){break a}d=a;a=a+19|0;if(w[d+18|0]<16){continue}break}}return b}function VJ(){var a=0,b=0,c=0,d=0;a=kb-16|0;kb=a;b=tc(1298472);v[23588]=0;c=S(1062,b|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){b=v[Mf(a+8|0,c)>>2];kb=a+16|0;return b|0}a=P()|0;O()|0;Nb(b);T(a|0);L()}function Sd(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function IO(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function ij(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Er(a,b,c,d){var e=0,f=0,g=0;e=b+4|0;g=c;f=v[a>>2];c=v[a+4>>2]-f|0;d=v[e>>2]+B(g,(c|0)/(d|0)|0)|0;v[e>>2]=d;if((c|0)>0){uc(d,f,c)}qc(a,e);qc(a+4|0,b+8|0);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2]}function vB(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;Dq(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){LU(b)}return a}function lD(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;fr(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){gr(b)}return a}function jS(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;gS(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){hS(b)}return a}function hG(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;dG(e+8|0,b);f=c;Vk(v[e+12>>2],c,d);b=kb-16|0;kb=b;v[b+12>>2]=v[v[e+12>>2]+4>>2];v[b+8>>2]=0;c=v[Pe(b+8|0,b+12|0)>>2];kb=b+16|0;gc(a,f,c);kb=e+16|0}function gV(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;Gu(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){EB(b)}return a}function ZD(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;XD(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){Nv(b)}return a}function VQ(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;pU(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){qU(b)}return a}function Rj(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;bn(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){Tj(b)}return a}function PH(a){var b=0,c=0,d=0;d=v[a>>2];while(1){c=t[d|0];if(ak(c)){d=d+1|0;v[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=B(b,10);b=(c|0)>(2147483647-b|0)?-1:c+b|0}else{b=-1}continue}break}return b}function Eu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function DM(a){var b=0,c=0;a=a+906300|0;c=fk(a);while(1){if((a|0)!=(c|0)){b=v[a>>2];a:{if(!b){break a}if(!(ob[v[v[b>>2]+120>>2]](b)|0)){break a}ob[v[v[b>>2]+100>>2]](b)}a=a+160|0;continue}break}}function AR(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;wR(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;a=(d|0)==(e|0);if(!a){xR(b)}return a}function $3(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;XJ(c,b);a=v[a+1298464>>2];v[23588]=0;U(376,a|0,1,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){Ab(c);kb=c+16|0;return}a=P()|0;O()|0;Ab(c);T(a|0);L()}function xB(a,b){var c=0;c=kb-16|0;kb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Yb(128/(B(v[Pe(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[kf(c+7|0,c+6|0)|0];kb=c+16|0;return a|b<<4&240}function jP(a){a=a|0;var b=0,c=0;b=kb-32|0;kb=b;t[a+16|0]=0;c=Bz(b,v[a+12>>2]);v[23588]=0;R(753,a|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){rl(c);kb=b+32|0;return}a=P()|0;O()|0;rl(c);T(a|0);L()}function Pu(a,b,c){var d=0;a=(a&65535)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function yR(a){var b=0,c=0,d=0,e=0;nb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+94|0]|w[a+95|0]<<8;b=c+w[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function xK(a,b){var c=0,d=0,e=0,f=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);c=+a;e=32768/(1-c);f=c;c=af(31415.926535897932/+b);d=zl(e*(1-(f*c+K(+C(a+a)*(1-c)-+C(a*a)*(1-c*c)))))}return d}function wT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;Wf(a,d+14|0);e=x[d+14>>1];JM(b,e);c=0;while(1){if((c|0)==(e|0)){uy(b);kb=d+16|0}else{pk(a,Eb(v[b>>2],c));c=c+1|0;continue}break}}function sI(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=z[e>>2];c=c+h|0;g=z[c>>2];z[e>>2]=f+g;z[c>>2]=f-g;d=d+1|0;continue}break}}function RT(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;a=Bh(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);kb=d+16|0}else{Im(b,x[c>>1]|x[c+2>>1]<<16);b=b+4|0;v[a+4>>2]=b;continue}break}}function Eh(a,b){var c=0;c=v[a>>2];a=Wd(b);b=v[c+8>>2];if(vc(b,v[c+12>>2])>>>0>a>>>0){c=v[Eb(b,a)>>2]!=0}else{c=0}if(!c){a=lm(ba(4)|0);v[a>>2]=93404;ha(a|0,93540,1107);L()}return v[Eb(b,a)>>2]}function xg(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb+-64|0;kb=c;d=_x(c+8|0,a);v[23588]=0;U(201,a|0,b|0,d|0);a=v[23588];v[23588]=0;if((a|0)!=1){hl(d);kb=c- -64|0;return}a=P()|0;O()|0;hl(d);T(a|0);L()}function sy(a,b){var c=0;a=AQ(a,b);t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function cp(a,b,c,d,e,f){var g=0,h=0;pg(a+12|0,d);if(b){if(b>>>0>=f>>>0){Mg();L()}d=tc(B(b,e))}else{d=0}v[a>>2]=d;c=d+B(c,e)|0;v[a+8>>2]=c;v[a+4>>2]=c;g=Cc(a),h=d+B(b,e)|0,v[g>>2]=h;return a}
function zF(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83224;d=a+8|0;while(1){b=v[a+8>>2];if(vc(b,v[a+12>>2])>>>0>c>>>0){b=v[Eb(b,c)>>2];if(b){gn(b)}c=c+1|0;continue}break}zb(a+152|0);UF(d);return a|0}function rj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=pl(a,b);if((d|0)==255){break a}ik(a,b);$p(a,b,0,0);if(!c){break a}e=dc(a+26|0,d),f=65535,u[e>>1]=f;a=Lb(a+62|0,b);t[a|0]=w[a|0]|128}}function qg(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(1073741823);if(d>>>0<=b>>>0){a=Vh(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function Oj(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(2147483647);if(d>>>0<=b>>>0){a=Ym(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function yD(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(119304647);if(d>>>0<=b>>>0){a=Bv(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function qE(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(178956970);if(d>>>0<=b>>>0){a=Br(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function or(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(536870911);if(d>>>0<=b>>>0){a=hn(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function mB(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(214748364);if(d>>>0<=b>>>0){a=vC(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function lA(a,b,c,d){var e=0,f=0,g=0;e=kb-16|0;kb=e;f=v[b+12>>2];v[e+8>>2]=c;v[e+12>>2]=d;g=v[v[b>>2]+28>>2];v[e>>2]=c;v[e+4>>2]=d;ob[g|0](a,b,f,e);v[b+12>>2]=v[b+12>>2]+v[a+4>>2];kb=e+16|0}function kn(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(357913941);if(d>>>0<=b>>>0){a=Wj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function hQ(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(268435455);if(d>>>0<=b>>>0){a=Nt(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function dq(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(134217727);if(d>>>0<=b>>>0){a=lo(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function aB(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c,e=(Ap(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),A[d+8>>3]=e;fO(c+8|0,127);a=tk(A[c+8>>3]);kb=c+16|0;return a}function Uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(vc(v[a+4>>2],v[a+8>>2])+e|0)-1|0,u[f+10>>1]=g;a=ML(a,b,c,d+8|0);kb=d+16|0;return a|0}function IA(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(715827882);if(d>>>0<=b>>>0){a=Du(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function Hn(a){var b=0,c=0;b=kb-16|0;kb=b;a:{if(!JJ(w[a+20|0])){v[23588]=0;R(1067,b+8|0,a|0);c=v[23588];v[23588]=0;if((c|0)==1){break a}}t[a+20|0]=255;kb=b+16|0;return}V(0)|0;O()|0;Vb();L()}function uD(a,b){var c=0,d=0;c=kb-16|0;kb=c;XD(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function rh(a,b,c){a:{if(b>>>0<=c>>>0){a=ba(8)|0;v[23588]=0;b=S(193,a|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){break a}b=P()|0;O()|0;ca(a|0);T(b|0);L()}return w[a+c|0]}ha(b|0,26056,168);L()}function oC(a){var b=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;b=v[a>>2];if(b&8){v[a>>2]=b|32;return-1}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];return 0}function nN(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;a=lr(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);kb=d+16|0}else{mN(b,v[c>>2],v[c+4>>2]);b=b+8|0;v[a+4>>2]=b;continue}break}}function mD(a,b){var c=0,d=0;c=kb-16|0;kb=c;fr(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function dC(a,b){var c=0,d=0;c=kb-16|0;kb=c;cC(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function cT(a,b){var c=0,d=0;c=kb-16|0;kb=c;bT(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function YU(a,b){var c=0,d=0;c=kb-16|0;kb=c;bv(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function TL(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(82595524);if(d>>>0<=b>>>0){a=dt(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function So(a,b){var c=0,d=0;c=kb-16|0;kb=c;Kh(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function SG(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function Po(a,b){var c=0,d=0;c=kb-16|0;kb=c;Xm(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function Ou(a,b){var c=0,d=0;c=kb-16|0;kb=c;Eo(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function OU(a,b){var c=0,d=0;c=kb-16|0;kb=c;Gu(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function Nu(a,b){var c=0,d=0;c=kb-16|0;kb=c;Fo(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function Lt(a){var b=0;a:{if(Sb(a,13505,4)|w[a+4|0]){break a}if(Ib(w[a+6|0]|w[a+7|0]<<8)>>>0>1){break a}if(Ib(w[a+12|0]|w[a+13|0]<<8)){break a}b=(Ib(w[a+16|0]|w[a+17|0]<<8)|0)==20}return b}function JU(a,b){var c=0,d=0;c=kb-16|0;kb=c;Hu(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function IU(a,b){var c=0,d=0;c=kb-16|0;kb=c;Dq(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function Hr(a,b,c){var d=0;d=kb-16|0;kb=d;gc(d+8|0,b,c);b=v[d+12>>2];nc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);c=v[d+4>>2];if((b|0)==(c|0)){_b(a,v[d+12>>2])}kb=d+16|0;return(b|0)==(c|0)}function FR(a,b){var c=0,d=0;c=kb-16|0;kb=c;uA(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function Ag(a,b){var c=0,d=0;c=kb-16|0;kb=c;Yq(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function $R(a,b){var c=0,d=0;c=kb-16|0;kb=c;_R(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){_b(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function kA(a,b){var c=0,d=0;d=kb-32|0;kb=d;c=Gb(a);c=Vf(d+8|0,qg(a,vc(v[a>>2],v[a+4>>2])+1|0),vc(v[a>>2],v[a+4>>2]),c);gq(v[c+8>>2],v[b>>2]);v[c+8>>2]=v[c+8>>2]+4;Ed(a,c);Uf(c);kb=d+32|0}function Mw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Lx(a,b,c,d,e,f,g,h,i){var j=0;j=kb-16|0;kb=j;Gg(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;kb=j+16|0}function yF(a,b){var c=0,d=0;d=kb-32|0;kb=d;c=Gb(a);c=Zl(d+8|0,Xl(a,fd(v[a>>2],v[a+4>>2])+1|0),fd(v[a>>2],v[a+4>>2]),c);xd(v[c+8>>2],w[b|0]);v[c+8>>2]=v[c+8>>2]+1;Ed(a,c);Yl(c);kb=d+32|0}function sn(a,b){var c=0,d=0,e=0;a:{c=LG(b);if(c>>>0<1073741808){b:{if(Vr(c)){de(a,c);break b}d=cm(c)+1|0;e=Ci(d);vd(a,e);cf(a,d);Gd(a,c);a=e}mi(a,b,c);vd((c<<2)+a|0,0);break a}jf();L()}}function j0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(d>>>0<4294967280){a:{if(Fl(d)){de(a,c);break a}e=Ng(d)+1|0;d=tc(e);vd(a,d);cf(a,e);Gd(a,c);a=d}xd(we(a,b,c)+c|0,0);return}jf();L()}function MP(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=Ws(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;uc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function wi(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function kT(a,b,c,d){var e=0;e=kb-16|0;kb=e;v[e+12>>2]=b;v[e+8>>2]=d;c=Mp(a,c,v[Kb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}kb=e+16|0;return c}function N6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=kb-16|0;kb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=pK(f,b,c,d,0,0,0,0,e);kb=f+16|0;return a|0}function Mx(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Tn(d)|b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function A$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-16|0;kb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=_j(h,b,c,d,e,f,g+8|0,a);kb=a;return b|0}function ws(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=v[a+4>>2];d=((b<<2)+(ov(v[a>>2],1)^270549120)|0)+2019860093|0;v[a>>2]=d;b=b+B(ov(d,16),5)|0;v[a+4>>2]=b;continue}break}return b}function Dia(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Qb(v[a>>2],v[a+8>>2],12);a:{if(!d){t[c|0]=0;ci(b,12,c);break a}Dq(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0;return d|0}function D3(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=v[14447];v[c+8>>2]=v[14446];v[c+12>>2]=d;d=v[14445];v[c>>2]=v[14444];v[c+4>>2]=d;ob[v[wp(c,ck(w[b+20|0]))>>2]](a,b);kb=c+16|0}function Xl(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=th(-1);if(d>>>0<=b>>>0){a=kp(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Zc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}cd();L()}function Th(a){var b=0;a=Wh(a);b=2147483647;a:{if(a>=C(2147483648)){break a}b=-2147483648;if(a<=C(-2147483648)){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function vK(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=kb-16|0;kb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=uK(f,b,c,d,e,0,0,0,0);kb=f+16|0;return+c}function _l(a,b){v[a+28>>2]=0;u[a+24>>1]=65535;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;t[a|0]=0;v[a+32>>2]=11;v[a+36>>2]=b;Tb(a+40|0);Tb(a+52|0);Ub(a- -64|0,0,48);return a}function Vf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;pg(a+12|0,d);if(b){d=Ci(b)}else{d=0}v[a>>2]=d;c=d+(c<<2)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Cc(a),f=d+(b<<2)|0,v[e>>2]=f;return a|0}function Ks(a){var b=0;b=v[a+24>>2];v[23588]=0;Y(813,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){Xe(a+68|0);Xf(a+36|0);Bs(a+32|0);kj(a+24|0);jj(a+4|0);return Ee(a)}V(0)|0;O()|0;Vb();L()}function Iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;ZS(b,c);c=Qb(v[a>>2],v[a+8>>2],c<<2);if(c){YS(d+8|0,v[b>>2],v[b+4>>2]);ud(d,a,v[d+8>>2],v[d+12>>2])}kb=d+16|0;return c|0}function Iea(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Qb(v[a>>2],v[a+8>>2],4);a:{if(!d){t[c|0]=0;rD(b,4,c);break a}Kh(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0;return d|0}function xs(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;v[b+12>>2]=12;while(1){v[b+8>>2]=32;if(y[Kb(b+12|0,b+8|0)>>2]<=c>>>0){kb=b+16|0;a=d&4095}else{c=c+15|0;d=Tn(a);continue}break}return a}function vX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;FD(b,c);c=Qb(v[a>>2],v[a+8>>2],c<<3);if(c){ED(d+8|0,v[b>>2],v[b+4>>2]);ud(d,a,v[d+8>>2],v[d+12>>2])}kb=d+16|0;return c|0}function kX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=0;a=ob[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Kb(d+12|0,d+8|0)>>2]}kb=d+16|0;return c|0}function jz(a){var b=0,c=0;b=v[a>>2];c=v[b>>2];a:{if(!c){while(1){c=Ch(b);b=v[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=v[b+4>>2];if(c){continue}break}}v[a>>2]=b;return a}function Qv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;v[e+12>>2]=d;d=Hb(b);if(d>>>0<c>>>0){sk();L()}b=Mc(b);v[e+8>>2]=d-c;xu(a,b+c|0,v[Kb(e+12|0,e+8|0)>>2]);kb=e+16|0}function IM(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;GM(c,b+80|0);v[23588]=0;U(11,a|0,0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){zb(c);kb=c+16|0;return}a=P()|0;O()|0;zb(c);T(a|0);L()}function uX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(fd(v[c>>2],v[c+4>>2])>>>0>=a>>>0){break a}Si(c,a)}return!d|0}function YN(a,b,c,d){a:{if((a|0)!=67108864){break a}a=B(d,872)+c|0;v[a+704>>2]=v[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=B(a,872)+c|0;v[a+704>>2]=v[a+704>>2]&-129}}function Lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;zQ(b,c);if(Qb(v[a>>2],v[a+8>>2],c<<8)){c=v[b>>2];gc(d+8|0,c,Ah(c,v[b+4>>2])<<8);ud(d,a,v[d+8>>2],v[d+12>>2])}kb=d+16|0}function xC(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;a=Bh(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);kb=d+16|0}else{gq(b,v[c>>2]);b=b+4|0;v[a+4>>2]=b;continue}break}}function ve(a,b){var c=0;a:{c=yg(b);if((c|0)==(Hb(a)|0)){v[23588]=0;a=W(361,a|0,b|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Vb();L()}function pM(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;while(1){v[b+12>>2]=7;v[b+8>>2]=32;if(y[Kb(b+12|0,b+8|0)>>2]<=c>>>0){kb=b+16|0;a=d&127}else{c=c+15|0;d=Tn(a);continue}break}return a}function iu(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function Yx(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;a=Bh(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);kb=d+16|0}else{ek(b,z[c>>2]);b=b+4|0;v[a+4>>2]=b;continue}break}}function Ho(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;a=$h(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);kb=d+16|0}else{Ni(b,x[c>>1]);b=b+2|0;v[a+4>>2]=b;continue}break}}function wl(a,b){var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Gb(b);d=Gb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function via(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;vT(b,c);uT(a,c);kb=c+32|0}function paa(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-32|0;kb=d;c=-1;a:{if(!ZD(a,d+8|0)){break a}c=0;if(!$L(d+8|0)|(v[d+16>>2]!=v[b>>2]|v[b+4>>2]?b:0)){break a}c=1}kb=d+32|0;return c|0}function pZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[(a<<2)+83296>>2]}else{a=0}v[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function aia(){var a=0,b=0,c=0;a=kb-16|0;kb=a;b=tc(1);v[23588]=0;Z(32);c=v[23588];v[23588]=0;if((c|0)!=1){b=v[Mf(a+8|0,b)>>2];kb=a+16|0;return b|0}a=P()|0;O()|0;Nb(b);T(a|0);L()}function No(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;a=Pk(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);kb=d+16|0}else{xd(b,w[c|0]);b=b+1|0;v[a+4>>2]=b;continue}break}}function EC(a){var b=0,c=0;a:{if(Sb(a,14128,3)){break a}b=w[a+3|0];b:{if(b>>>0<=7){if((b|0)==1){break b}break a}if(b>>>0>14){break a}}c=(w[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function Bc(a,b){var c=0,d=0;c=kb-16|0;kb=c;if(ff(a)){Nb(v[a>>2])}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];de(b,0);t[c+15|0]=0;je(b,c+15|0);kb=c+16|0;return a}function w7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);if(b>>>0<=12){c=Yd(c,C(0));d=a+4208|0;if((b|0)==12){c=C(Wh(C(c*C(3)))/C(3));b=12}e=Eb(d,b),f=c,z[e>>2]=f;t[a+5046|0]=1}}function uO(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;while(1){if(c){f=ml(x[c+16>>1],v[c+20>>2],a,b);d=f?d:c;c=v[(f?c+4|0:c)>>2];continue}break}a=v[fc(e+8|0,d)>>2];kb=e+16|0;return a}function fE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=yl(a);d=zd(v[a+4>>2],w[a+11|0]);e=d+1|0;if((c|0)==(d|0)){Oy(a,c,e-c|0,c,c,0)}c=pd(a);nI(c+d|0,1,b);tq(a,e);xd(c+e|0,0);return a|0}function cE(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function WX(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;WD(b,0,a);v[23588]=0;a=S(125,b|0)|0;c=v[23588];v[23588]=0;if((c|0)!=1){zb(b);kb=b+16|0;return a|0}a=P()|0;O()|0;zb(b);T(a|0);L()}function jw(a,b,c,d,e){var f=0;a:{f=at(4332);if(f){v[23588]=0;ja(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break a}}return f}a=P()|0;O()|0;Nb(f);T(a|0);L()}function iF(a,b,c){var d=0;a:{if(!a){a=ba(8)|0;v[23588]=0;c=S(c|0,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){break a}b=P()|0;O()|0;ca(a|0);T(b|0);L()}return}ha(c|0,b|0,956);L()}function T2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;qx(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Kb(d+8|0,d+12|0)>>2]}kb=d+16|0;return c|0}function Oja(a,b){a=a|0;b=b|0;if(!IU(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function kba(a,b){a=a|0;b=b|0;var c=0;a=Yf(a);c=Gi(v[b>>2]);b=xf(b);v[23588]=0;U(807,a|0,c|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;zN(a);T(b|0);L()}function ffa(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;b=-1;a:{if(!Rj(a,c+8|0)){break a}b=0;if(!BQ(c+8|0)){break a}b=-1;if(!fg(a,4)){break a}b=ZQ(a)>>>31|0}kb=c+16|0;return b|0}function UY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;ob[v[v[a>>2]+12>>2]](d+8|0,a,b);a=v[d+8>>2];b=v[c>>2];a=pc(v[d+12>>2],v[c+4>>2])&(a|0)==(b|0);kb=d+16|0;return a|0}function rp(a){var b=0,c=0;b=v[23509];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(_w()>>>0<a>>>0){if(!(xa(a|0)|0)){break a}}v[23509]=a;return b}v[116064]=48;return-1}function Hq(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];d=v[a+4>>2];if(Rc(c,d)>>>0>b>>>0){a=v[a+24>>2];b=Jl(c,d,b);a=ye(v[a+484344>>2],v[a+484348>>2],x[b>>1])}else{a=0}return a|0}function Zu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;Si(b,c);if(Qb(v[a>>2],v[a+8>>2],c)){c=v[b>>2];gc(d+8|0,c,fd(c,v[b+4>>2]));ud(d,a,v[d+8>>2],v[d+12>>2])}kb=d+16|0}function YQ(a,b){var c=0,d=0;c=kb-16|0;kb=c;Kh(c+8|0,b);b=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){id(a,v[c+12>>2])}kb=c+16|0;return(b|0)==(d|0)}function NA(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;a=Gq(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);kb=d+16|0}else{iu(b,c);b=b+6|0;v[a+4>>2]=b;continue}break}}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+8>>2]=b;while(1){if(Pb(b,c)){v[d+4>>2]=v[b>>2];zA(a,d+4|0);b=v[Le(d+8|0)>>2];continue}else{kb=d+16|0}break}}function Bg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=rh(v[d>>2],v[d+4>>2],a);return((rh(v[d>>2],v[d+4>>2],a+1|0)<<8|e<<16|rh(v[d>>2],v[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function BU(a){var b=0;a:{if(Sb(a,16682,4)){break a}if(cc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Ib(w[a+8|0]|w[a+9|0]<<8)}return b}function Zl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;pg(a+12|0,d);if(b){d=tc(b)}else{d=0}v[a>>2]=d;c=c+d|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Cc(a),f=b+d|0,v[e>>2]=f;return a|0}function Nh(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+24|0]=0;Zi(c+8|0,c+24|0);wn(c+16|0,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];t[b|0]=w[c+24|0];kb=c+32|0;return(a|0)==1|0}function M9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;f=v[c>>2];if(f>>>0<fd(a,b)>>>0){a=Mk(e,Lb(a,f),x[c+20>>1]);g=cw(d,a);$b(a)}kb=e+16|0;return g|0}function nZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=v[c>>2];if(!(a>>>0>127|!(v[(a<<2)+83296>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function lka(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;bn(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);if((b|0)==v[c+4>>2]){_b(a,v[c+12>>2])}kb=c+16|0}function hf(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+8>>2]=c;v[d+4>>2]=31;e=d,f=rV(b,c),v[e+12>>2]=f;c=b;b=JB(d+4|0);qh(c,c+b|0,a);e=Lb(a,b),f=0,t[e|0]=f;tV(a);kb=d+16|0}function DD(a,b,c){var d=0,e=0;a:{b:{if(Fl(c)){de(a,c);break b}if(c>>>0>=4294967280){break a}d=Ng(c)+1|0;e=tc(d);vd(a,e);cf(a,d);Gd(a,c);a=e}we(a,b,c+1|0);return}jf();L()}function yba(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Qb(v[a>>2],v[a+8>>2],16);a:{if(!d){pC(b);break a}bv(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0;return d|0}function lX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ob[v[v[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;a:{if(a){ob[v[v[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}NM(d,9113,10812,140,42);pE(d,b,c)}kb=d+16|0}function hm(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function Oha(){var a=0,b=0,c=0;a=kb-16|0;kb=a;b=Nc(a,10215);v[23588]=0;Y(36,b|0);c=v[23588];v[23588]=0;if((c|0)!=1){zb(b);kb=a+16|0;return}a=P()|0;O()|0;zb(b);T(a|0);L()}function sE(a,b){var c=0,d=0;c=kb-16|0;kb=c;a=Pk(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){lc(a);kb=c+16|0}else{rE(b);b=b+1|0;v[a+4>>2]=b;continue}break}}function sC(a,b){var c=0,d=0;c=kb-16|0;kb=c;a=$h(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){lc(a);kb=c+16|0}else{rC(b);b=b+2|0;v[a+4>>2]=b;continue}break}}function oZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=v[c>>2];if(a>>>0>127|!(v[(a<<2)+83296>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function DA(a,b){var c=0,d=0;c=kb-16|0;kb=c;a=Bh(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){lc(a);kb=c+16|0}else{Om(b);b=b+4|0;v[a+4>>2]=b;continue}break}}function Ct(a,b){var c=0,d=0;c=kb-16|0;kb=c;a=Bh(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){lc(a);kb=c+16|0}else{PP(b);b=b+4|0;v[a+4>>2]=b;continue}break}}function tI(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function oo(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Qb(v[a>>2],v[a+8>>2],4);a:{if(!d){$S(b);break a}Kh(c+8|0,b);ud(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0;return d|0}function Xt(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=w[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function rfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-48|0;kb=c;d=-1;a:{if(!VQ(a,c)){break a}d=0;if(!UQ(c)){break a}d=Be(a,b,TQ(w[c+31|0],w[c+33|0]),nb)}kb=c+48|0;return d|0}function oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;FD(b,c);if(Qb(v[a>>2],v[a+8>>2],c<<3)){ED(d+8|0,v[b>>2],v[b+4>>2]);ud(d,a,v[d+8>>2],v[d+12>>2])}kb=d+16|0}function Sb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function KC(a,b,c){var d=0;d=kb-16|0;kb=d;a=Oo(d,a+8|0,b);b=v[a>>2];while(1){if((b|0)!=v[a+4>>2]){Ni(b,x[c>>1]);b=v[a>>2]+2|0;v[a>>2]=b;continue}break}Ud(a);kb=d+16|0}function yA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;ZS(b,c);if(Qb(v[a>>2],v[a+8>>2],c<<2)){YS(d+8|0,v[b>>2],v[b+4>>2]);ud(d,a,v[d+8>>2],v[d+12>>2])}kb=d+16|0}function ik(a,b){var c=0,d=0,e=0;a:{c=pl(a,b);if((c|0)==255){break a}if(jk(v[a>>2])){break a}d=Lb(a+8|0,c);e=w[d|0]&223;t[d|0]=e;hh(v[a>>2],v[a+4>>2],b,zt(c)|176,e)}}function eT(a,b,c){var d=0;d=kb-16|0;kb=d;a=Xv(d,a+8|0,b);b=v[a>>2];while(1){if((b|0)!=v[a+4>>2]){xd(b,w[c|0]);b=v[a>>2]+1|0;v[a>>2]=b;continue}break}Ud(a);kb=d+16|0}function aca(a,b){a=a|0;b=b|0;a=Hc(a);t[a+534|0]=0;v[a+4>>2]=0;v[23588]=0;R(758,a|0,b|0);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;zj(a);T(b|0);L()}function _W(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Kb(d+12|0,d+8|0)>>2]}kb=d+16|0;return c|0}function Rl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=pr(b);d=yl(a);if(c>>>0<=d>>>0){bB(a,Xh(pd(a),b,c),c);break a}e=a;a=zd(v[a+4>>2],w[a+11|0]);pq(e,d,c-d|0,a,0,a,c,b)}}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Tb(a+8|0);v[23588]=0;U(244,a|0,b|0,c|0);a=v[23588];v[23588]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ic(d);T(a|0);L()}}function P6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=xp(d,a);gK(a,c);v[23588]=0;R(70,b|0,1);a=v[23588];v[23588]=0;if((a|0)==1){a=P()|0;O()|0;ac(d);T(a|0);L()}}function zA(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=kb-16|0;kb=c;a=Bh(c,a,1);gq(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;lc(a);kb=c+16|0;return}kA(a,b)}function t$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ob[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=Ac(a);return Zj(g,h,c,d,e,f,b,b+(Hb(a)<<2)|0)|0}function oT(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;b=jc(b);a=mh(a,tc(32),nh(d+8|0,b));b=v[a>>2]+16|0;u[b>>1]=x[v[c>>2]>>1];Mb(b+4|0);e=jc(a),f=1,t[e+4|0]=f;kb=d+16|0}function nja(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[b>>2],v[b+8>>2],12)){u[c>>1]=0;IT(a,6,c);break a}Dq(c+8|0,a);ud(c,b,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function mX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Kb(d+12|0,d+8|0)>>2]}kb=d+16|0;return c|0}function U2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;qx(a,b,c);a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function PD(a,b,c){var d=0,e=0;if(c>>>0<4294967280){a:{if(Fl(c)){de(a,c);break a}d=Ng(c)+1|0;e=tc(d);vd(a,e);cf(a,d);Gd(a,c);a=e}xd(we(a,b,c)+c|0,0);return}jf();L()}function LP(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function G1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;a=bx(Ua(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);kb=e+16|0;nb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function yH(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=zf(b),d=v[v[a>>2]+52>>2],ob[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return zf(b)}function $fa(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[b>>2],v[b+8>>2],8)){u[c>>1]=0;IT(a,4,c);break a}bn(c+8|0,a);ud(c,b,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function jQ(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;Nz(a+112|0,48e3);v[a+668>>2]=0;Mz(a+724|0);Mz(a+732|0);Mz(a+740|0);ug(a+788|0);return a}function _e(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(c){a=v[jc(a)>>2];v[23588]=0;Y(a|0,c|0);a=v[23588];v[23588]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Vb();L()}function Tfa(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[b>>2],v[b+8>>2],5)){t[c|0]=0;ci(a,5,c);break a}Eo(c+8|0,a);ud(c,b,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function Kja(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[b>>2],v[b+8>>2],6)){t[c|0]=0;ci(a,6,c);break a}oB(c+8|0,a);ud(c,b,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function nca(a,b){a=a|0;b=b|0;a=Tb(a);t[a+16|0]=0;v[a+12>>2]=b;v[23588]=0;Y(752,a|0);b=v[23588];v[23588]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;zz(a);T(b|0);L()}function cq(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function Tm(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[b>>2],v[b+8>>2],4)){t[c|0]=0;ci(a,4,c);break a}Kh(c+8|0,a);ud(c,b,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function Taa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c,e=Fi(b),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Jj(c+12|0,c+8|0,43824)>>2],v[d+36>>2]=e;Fp(a);kb=c+16|0}function Jk(a,b){a=a|0;b=b|0;var c=0;if(!gf(w[b+11|0])){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return a|0}DD(a,v[b>>2],v[b+4>>2]);return a|0}function JB(a){var b=0,c=0;a:{c=Eb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=qo(v[b>>2],v[a>>2])?b:a;continue}}return v[a>>2]}function ID(a,b,c,d,e){var f=0;f=kb-16|0;kb=f;v[f+12>>2]=e;v[f+8>>2]=d;v[f+4>>2]=c;v[f>>2]=b;a=Dg(a,f);v[a+8>>2]=0;b=a+12|0;a=f+8|0;Dg(b,a);me(a);me(f);kb=f+16|0}function CY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=v[c>>2];a=ob[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}kb=d+16|0;return a|0}function sq(a){var b=0,c=0,d=0,e=0;b=v[a+4>>2];c=v[b>>2];v[a+4>>2]=c;if(c){mm(c,a)}v[b+8>>2]=v[a+8>>2];d=v[a+8>>2]+(Ch(a)?0:4)|0,e=b,v[d>>2]=e;v[b>>2]=a;mm(a,b)}function rq(a){var b=0,c=0,d=0,e=0;b=v[a>>2];c=v[b+4>>2];v[a>>2]=c;if(c){mm(c,a)}v[b+8>>2]=v[a+8>>2];d=v[a+8>>2]+(Ch(a)?0:4)|0,e=b,v[d>>2]=e;v[b+4>>2]=a;mm(a,b)}function jga(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-80|0;kb=d;c=-1;a:{if(!gV(a,d+8|0)){break a}c=0;if(!KR(d+8|0)){break a}c=Be(a,b,JR(d+8|0),nb)}kb=d+80|0;return c|0}function dB(a){var b=0,c=0;b=kb-16|0;kb=b;u[b+14>>1]=a;Ff(b+14|0,4095);a=x[b+14>>1];c=bU(ni(+((a&255)>>>0)*.00390625)*32768);kb=b+16|0;return c>>>15-(a>>>8|0)|0}function Ui(a,b,c,d,e){a:{e=at(e);if(e){v[23588]=0;fa(d|0,e|0,a|0,b|0,c|0)|0;a=v[23588];v[23588]=0;if((a|0)==1){break a}}return e}a=P()|0;O()|0;Nb(e);T(a|0);L()}function PM(a){var b=0,c=0,d=0;b=v[a+112>>2];if((b|0)>=11){c=378;while(1){if(c|d){OM(a);b=c;c=b-1|0;d=d-!b|0;continue}break}b=0}v[a+112>>2]=b+1;a=OM(a);return a}function OP(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;c=v[a>>2]+(b>>>3&536870908)|0;break a}b=b+c|0;c=v[a>>2]+((b-31|0)/32<<2)|0}v[a>>2]=c;v[a+4>>2]=b&31}function z$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ob[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=Mc(a);return _j(g,h,c,d,e,f,b,Hb(a)+b|0)|0}function ps(a){var b=0;a:{if(($e(a)|0)!=79){break a}if(($e(a)|0)!=103){break a}if(($e(a)|0)!=103){break a}b=($e(a)|0)==83}if(!b){ec(a,30);return 0}return lI(a)}function ev(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[b>>2],v[b+8>>2],2)){t[c|0]=0;qC(a,c);break a}Xm(c+8|0,a);ud(c,b,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function bJ(a,b){var c=0,d=0;d=a+4|0;c=fd(v[d>>2],v[a+8>>2]);a=v[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=dh(c);if(a>>>0<=b>>>0){break a}}b=cJ(a,65536)}Si(d,b)}}function pk(a,b){var c=0;c=kb-32|0;kb=c;v[c+24>>2]=0;Vv(c+8|0,c+24|0);wn(c+16|0,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];$l(b,v[c+24>>2]);kb=c+32|0;return(a|0)==4}function j9(a){a=a|0;var b=0,c=0,d=0;b=kb-16|0;kb=b;oL(b+8|0,a,0);c=v[b+12>>2];if(c){a=v[a+20>>2];v[a+148>>2]=-1;d=a+4|0;a=v[b+8>>2];ty(d,a,Lb(a,c))}kb=b+16|0}function iC(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=-1;if(Ag(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=bC(a,b,v[Kb(c+4|0,c+12|0)>>2])}kb=c+16|0;return d|0}function aW(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=-1;if(Ag(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=eC(a,b,v[Kb(c+4|0,c+12|0)>>2])}kb=c+16|0;return d|0}function Yd(a,b){var c=0,d=0,e=C(0);c=kb-16|0;kb=c;v[c+8>>2]=1065353216;z[c+12>>2]=b;d=c,e=Kf(a),z[d+4>>2]=e;a=z[lq(c+4|0,c+12|0,c+8|0)>>2];kb=c+16|0;return a}function WJ(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Jm(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(D(a)<2147483648){return~~a}b=-2147483648}return b}function HU(a){var b=0;if(!(Sb(a,17813,8)|w[a+8|0]>1|((w[a+9|0]-1&255)>>>0>7|(w[a+10|0]|w[a+11|0]<<8)>>>0>4096))){b=(w[a+12|0]|w[a+13|0]<<8)>>>0<4097}return b}function GT(a,b){var c=0;c=Oka(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+nb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;nb=a;return b}function tD(a){var b=0;if(!(Sb(a,15492,4)|(w[a+4|0]-16&255)>>>0<249|((w[a+5|0]-16&255)>>>0<249|(w[a+6|0]-16&255)>>>0<249))){b=(w[a+7|0]-9&255)>>>0<7}return b}function q0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function md(a,b,c,d){var e=0,f=0,g=0;e=kb-16|0;kb=e;f=v[b+12>>2];v[e+8>>2]=c;v[e+12>>2]=d;g=v[v[b>>2]+28>>2];v[e>>2]=c;v[e+4>>2]=d;ob[g|0](a,b,f,e);kb=e+16|0}function lB(a,b,c,d){var e=0,f=0;pg(a+12|0,d);if(b){d=tC(b)}else{d=0}v[a>>2]=d;c=d+B(c,20)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Cc(a),f=d+B(b,20)|0,v[e>>2]=f;return a}function Qz(a){var b=0;a=xe(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function Ik(a,b,c,d){var e=0,f=0;pg(a+12|0,d);if(b){d=dE(b)}else{d=0}v[a>>2]=d;c=d+B(c,12)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Cc(a),f=d+B(b,12)|0,v[e>>2]=f;return a}function EK(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function t0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function gw(a,b,c,d){var e=0;e=ba(8)|0;v[23588]=0;a=Q(d|0,e|0,a|0)|0;d=v[23588];v[23588]=0;if((d|0)!=1){ha(a|0,c|0,b|0);L()}a=P()|0;O()|0;ca(e|0);T(a|0);L()}function _b(a,b){a=a|0;b=b|0;var c=0;c=Qb(v[a>>2],v[a+8>>2],b);a:{if(c){b=v[a+8>>2]+b|0;break a}b=v[a>>2];b=ob[v[v[b>>2]+24>>2]](b)|0}v[a+8>>2]=b;return c|0}function T3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((a|0)!=(b|0)){d=v[c>>2];v[d>>2]=v[a>>2];yh(d+4|0,a+4|0);v[c>>2]=v[c>>2]+16;a=a+16|0;continue}break}}function NR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;while(1){if((b|0)==(c|0)){kb=d+16|0}else{v[d+12>>2]=v[b>>2];zA(a,d+12|0);b=b+4|0;continue}break}}function NL(a,b){var c=0;c=kb-16|0;kb=c;a=Wm(c,a+8|0,b);b=v[a>>2];while(1){if((b|0)!=v[a+4>>2]){PP(b);b=v[a>>2]+4|0;v[a>>2]=b;continue}break}Ud(a);kb=c+16|0}function Gea(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-48|0;kb=d;c=-1;a:{if(!VQ(a,d)){break a}c=0;if(!$P(d)){break a}c=Be(a,b,_P(w[d+47|0]),nb)}kb=d+48|0;return c|0}function tc(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Pd(a);if(b){break a}b=v[117529];if(b){ob[b|0]();continue}break}ha(nm(ba(4)|0)|0,92948,26);L()}return b|0}function nr(a,b,c,d){var e=0,f=0;pg(a+12|0,d);if(b){d=CD(b)}else{d=0}v[a>>2]=d;c=d+(c<<3)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Cc(a),f=d+(b<<3)|0,v[e>>2]=f;return a}function jT(a,b,c,d){var e=0,f=0;pg(a+12|0,d);if(b){d=fT(b)}else{d=0}v[a>>2]=d;c=d+B(c,6)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Cc(a),f=d+B(b,6)|0,v[e>>2]=f;return a}function gQ(a,b,c,d){var e=0,f=0;pg(a+12|0,d);if(b){d=eQ(b)}else{d=0}v[a>>2]=d;c=d+(c<<4)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Cc(a),f=d+(b<<4)|0,v[e>>2]=f;return a}function ft(a,b){var c=0,d=0,e=C(0);c=kb-16|0;kb=c;z[c+12>>2]=b;v[c+8>>2]=0;v[c+4>>2]=1065353216;d=a,e=z[lq(c+12|0,c+8|0,c+4|0)>>2],z[d+144>>2]=e;kb=c+16|0}function cA(a,b,c){var d=0;d=kb-16|0;kb=d;v[d+8>>2]=a;c=c&65535;while(1){if(!(!Pb(a,b)|(c|0)==x[a>>1])){a=v[Se(d+8|0)>>2];continue}break}kb=d+16|0;return a}function VM(){var a=0,b=0,c=0,d=0;a=kb-16|0;kb=a;b=a+8|0;while(1){if(c>>>0<32){c=c+48|0;d=xy(94392);continue}break}v[b>>2]=d;Tn(b);kb=a+16|0;return v[b>>2]}function Nj(a,b,c,d){var e=0,f=0;pg(a+12|0,d);if(b){d=$C(b)}else{d=0}v[a>>2]=d;c=d+(c<<1)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Cc(a),f=d+(b<<1)|0,v[e>>2]=f;return a}function Et(a,b,c,d){var e=0,f=0;pg(a+12|0,d);if(b){d=aQ(b)}else{d=0}v[a>>2]=d;c=d+(c<<5)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=Cc(a),f=d+(b<<5)|0,v[e>>2]=f;return a}function yp(a,b){var c=0,d=0;a:{if(!a){break a}c=Oka(a,0,b,0);d=nb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Pd(c);if(!(!a|!(w[a-4|0]&3))){Ub(a,0,c)}return a}function y2(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=yh(a,b);v[23588]=0;Q(54,a+12|0,c|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){break a}b=P()|0;O()|0;zb(a);T(b|0);L()}}function xV(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function sD(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=(ob[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0;a=v[b>>2];hc(c,d,(ob[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function nj(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;A[a>>3]=A[a>>3]-c;A[a+8>>3]=A[a+8>>3]-d}function hi(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function $W(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function yh(a,b){a=a|0;b=b|0;var c=0;if(!ff(b)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return a|0}DD(a,v[b>>2],v[b+4>>2]);return a|0}function nX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function lx(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(a*C(z[((c&3)<<2)+65808>>2]*C(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function k7(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=az(C(C(C(C(y[v[a+16>>2]+24620>>2])/C(3))+C(-80))/C(15920)),C(0),C(1)),z[b+4272>>2]=c;FK(a);EK(a)}function Lg(a){var b=0,c=0;b=v[a>>2];c=v[b+4>>2];a:{if(!c){while(1){if(!Ch(b)){b=v[b+8>>2];continue}break}b=v[b+8>>2];break a}b=MT(c)}v[a>>2]=b;return a}function Gn(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Pd(b)}return c}function zG(a,b,c){var d=0;d=kb-32|0;kb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;tw(d+16|0,a,d+24|0,v[Kb(d+28|0,d+12|0)>>2]);$l(b,v[d+24>>2]);kb=d+32|0}function vx(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;Ds(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Nt(a);Nb(b)}}function vD(a){a=a|0;var b=0;a=Mb(a);v[23588]=0;S(174,a+12|0)|0;b=v[23588];v[23588]=0;if((b|0)!=1){Hc(a+32|0);return a|0}b=P()|0;O()|0;Ab(a);T(b|0);L()}function tS(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;Bb(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Br(a);Nb(b)}}function tR(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-56|0;Tt(b);continue}break}v[a+4>>2]=c;b=v[a>>2];rR(a);Nb(b)}}function gZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function dd(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(ob[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function Xe(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;$b(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Wj(a);Nb(b)}}function Sl(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;bc(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Wj(a);Nb(b)}}function O9(a){a=a|0;var b=0;b=kb-16|0;kb=b;Sc(b,a+32|0,4);if(!Cb(v[v[b>>2]>>2],v[b+4>>2])){Yv(a)}a=v[fc(b+8|0,Fb(v[a+52>>2]))>>2];kb=b+16|0;return a|0}function N9(a){a=a|0;var b=0;b=kb-16|0;kb=b;Sc(b,a+32|0,4);if(!Cb(v[v[b>>2]>>2],v[b+4>>2])){Yv(a)}a=v[fc(b+8|0,Fb(v[a+56>>2]))>>2];kb=b+16|0;return a|0}function Lm(a,b){var c=0,d=0,e=0;rB(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Gb(b);d=Gb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function K0(a,b){a=a|0;b=b|0;var c=0,d=0;b=Iw(b);v[a+36>>2]=b;c=a,d=Wg(b),v[c+44>>2]=d;c=a,d=An(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Yr(5566);L()}}function D0(a,b){a=a|0;b=b|0;var c=0,d=0;b=Nw(b);v[a+36>>2]=b;c=a,d=Wg(b),v[c+44>>2]=d;c=a,d=An(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Yr(5566);L()}}function AQ(a,b){var c=0,d=0,e=0;pu(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Gb(b);d=Gb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function nU(a,b){var c=0;c=Oka(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+nb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;a=b>>>0<11?a+1|0:a;nb=a;return b}function mT(a,b,c){var d=0;d=kb-32|0;kb=d;v[d+28>>2]=c;t[d+24|0]=0;v[d+12>>2]=1;tw(d+16|0,a,d+24|0,v[Kb(d+28|0,d+12|0)>>2]);t[b|0]=w[d+24|0];kb=d+32|0}function Pp(a,b,c){var d=0;a:{if(b&134218752){break a}if(!qj(c)){break a}b=w[c+34|0];if((b+5&255)>>>0<6){break a}d=v[Md(a+906300|0,b-1|0)>>2]}return d}function L4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=kb-32|0;kb=h;i=h+8|0;ZI(i,b,c,d,e,f,g);ad(a,h+20|0);xm(i);kb=h+32|0}function Kn(a,b){v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Ub(a+32|0,0,40);EH(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function zv(a,b){var c=0;c=kb-16|0;kb=c;a:{if(!Qb(v[b>>2],v[b+8>>2],3)){t[c|0]=0;ci(a,3,c);break a}yv(c+8|0,a);ud(c,b,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function kE(a){v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;u[a+20>>1]=0;v[a+16>>2]=-1;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0}function SN(a,b,c){var d=0,e=0;v[b+56>>2]=0;d=b,e=Wn(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(w[a+480180|0]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function yfa(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-96|0;kb=d;c=-1;a:{if(!AR(a,d)){break a}c=0;if(!fR(d)){break a}c=Be(a,b,eR(d),nb)}kb=d+96|0;return c|0}function uv(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function _Y(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function Xfa(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-96|0;kb=d;c=-1;a:{if(!AR(a,d)){break a}c=0;if(!zR(d)){break a}c=Be(a,b,yR(d),nb)}kb=d+96|0;return c|0}function $f(a){var b=0,c=0;b=kb-16|0;kb=b;a:{if(ff(a)){c=v[a>>2];t[b+15|0]=0;je(c,b+15|0);Gd(a,0);break a}t[b+14|0]=0;je(a,b+14|0);de(a,0)}kb=b+16|0}function wz(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;rl(b);continue}break}c=v[a>>2];if(c){$o(a);Nb(c)}}function wu(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;v[a+8>>2]=b;Bb(b);continue}break}c=v[a>>2];if(c){Cc(a);Nb(c)}}function tK(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;c=YJ(tc(12));v[c+8>>2]=b;v[c+4>>2]=a;v[c>>2]=49020;a=v[Mf(d+8|0,c)>>2];kb=d+16|0;return a|0}function qR(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;v[a+8>>2]=b;Tt(b);continue}break}c=v[a>>2];if(c){Cc(a);Nb(c)}}function lV(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;v[a+8>>2]=b;Ad(b);continue}break}c=v[a>>2];if(c){Cc(a);Nb(c)}}function gO(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;$b(b);continue}break}c=v[a>>2];if(c){$o(a);Nb(c)}}function Sv(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;bc(b);continue}break}c=v[a>>2];if(c){$o(a);Nb(c)}}function RL(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;v[a+8>>2]=b;hl(b);continue}break}c=v[a>>2];if(c){Cc(a);Nb(c)}}function LY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(_g(a,v[b+8>>2],f)){ow(b,c,d,e);return}a=v[a+8>>2];ob[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function FM(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]/1e4}return+y[a+24620>>2]/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))*60}function Cv(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;v[a+8>>2]=b;jr(b);continue}break}c=v[a>>2];if(c){Cc(a);Nb(c)}}function up(a,b){var c=0;a:{if(!tI(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=!(b&240)^(a&240)!=0}return c}function sz(a,b,c){var d=0,e=0,f=0;d=pl(a,b);if((d|0)!=255){e=dc(a+26|0,d),f=c,u[e>>1]=f;a=a+62|0;e=Lb(a,b),f=255,t[e|0]=f;e=Lb(a,c),f=d,t[e|0]=f}}function qF(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Ye(a,b){var c=0;c=kb-16|0;kb=c;a:{if(!b){Sc(c+8|0,a+32|0,5);if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}}v[a+28>>2]=v[a+28>>2]+1}kb=c+16|0}function TO(a){var b=0,c=0,d=0;d=w[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=w[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function Qka(a,b,c){var d=0;d=b>>31;a=a^d;Mka(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);nb=mb;a=d^lb;b=a-d|0;nb=(d^nb)-((a>>>0<d>>>0)+d|0)|0;return b}function Q0(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;ob[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function LU(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function $x(a,b,c,d){var e=0;e=kb-16|0;kb=e;a=Gq(e,a,d);c=c-b|0;if((c|0)>0){uc(v[a+4>>2],b,c);v[a+4>>2]=v[a+4>>2]+B((c>>>0)/6|0,6)}lc(a);kb=e+16|0}function jC(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function iL(a,b){var c=0;c=v[b+4>>2];if(v[a>>2]==(b|0)){v[a>>2]=c}if(c){v[c+8>>2]=v[b+8>>2]}a=v[b+8>>2];if(a){v[a+4>>2]=c}v[b+4>>2]=0;v[b+8>>2]=0}function J7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);if(b>>>0<=1){c=Yd(c,C(0));if((b|0)==1){d=1;c=Wh(c)}e=Eb(a+4208|0,d),f=c,z[e>>2]=f;MK(a)}}function J5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=kb-32|0;kb=h;i=h+8|0;ZI(i,b,c,d,e,f,g);ad(a,i);xm(i);kb=h+32|0}function dca(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-32|0;kb=c;t[c+24|0]=b;b=c+24|0;Yq(c+16|0,b);d=v[c+16>>2];Yq(c+8|0,b);Mk(a,d,v[c+12>>2]);kb=c+32|0}function caa(a,b){a=a|0;b=b|0;var c=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);c=vc(v[b>>2],v[b+4>>2]);if(c){Bk(a,c);tA(a,v[b>>2],v[b+4>>2],c)}return a|0}function Z9(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-32|0;kb=c;u[c+24>>1]=b;b=c+24|0;Xm(c+16|0,b);d=v[c+16>>2];Xm(c+8|0,b);Mk(a,d,v[c+12>>2]);kb=c+32|0}function Lw(a){var b=0,c=0;b=kb-16|0;kb=b;c=-1;a:{if(Xw(a)){break a}if((ob[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}kb=b+16|0;return c}function HL(a){var b=0;b=kb-16|0;kb=b;z[b+12>>2]=D(a);v[b+8>>2]=646978941;v[b+4>>2]=1259902592;a=z[lq(b+12|0,b+8|0,b+4|0)>>2];kb=b+16|0;return a}function EH(a){var b=0,c=0;v[23588]=0;c=ga(1096)|0;b=v[23588];v[23588]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;cn(a);return}V(0)|0;O()|0;Vb();L()}function wk(a,b,c,d){var e=0;e=B(b,c);a:{if(v[d+76>>2]<0){a=NB(a,e,d);break a}a=NB(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function hj(a,b,c){if(a>>>0<b>>>0){uc(a,b,c);return}if(c){a=a+c|0;b=b+c|0;while(1){a=a-1|0;b=b-1|0;t[a|0]=w[b|0];c=c-1|0;if(c){continue}break}}}function Wz(a,b){a=a|0;b=b|0;var c=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);c=fd(v[b>>2],v[b+4>>2]);if(c){Ol(a,c);ku(a,v[b>>2],v[b+4>>2],c)}return a|0}function S6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){Ax(a,0,0,0,0,0,0,c,d);return}Ax(a,v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2],v[b+24>>2],b,c,d)}
function KN(a,b){t[a+840|0]=b;t[a+812|0]=b;t[a+811|0]=b;t[a+809|0]=b;t[a+807|0]=b;t[a+806|0]=b;t[a+833|0]=b;t[a+826|0]=b>>>4;t[a+827|0]=b<<2&60}function zS(a){var b=0;if(!(Sb(a,14990,3)|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))-2147483647>>>0<2147484072)){b=w[a+3|0]<6}return b}function rga(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Cg(b);Cg(b);break a}a=Sg(b);Sg(b)}while(1){if(a){if(a&1){_b(b,260)}a=a>>>1|0;continue}break}}function oj(a){var b=0,c=0;b=kb-16|0;kb=b;Db(b+8|0,a+1074312|0,7);if(Cb(v[v[b+8>>2]>>2],v[b+12>>2])){c=Km(v[a+480180>>2])^1}kb=b+16|0;return c}function nc(a,b,c,d,e){var f=0,g=0;f=kb-16|0;kb=f;v[f+8>>2]=d;v[f+12>>2]=e;g=v[v[b>>2]+28>>2];v[f>>2]=d;v[f+4>>2]=e;ob[g|0](a,b,c,f);kb=f+16|0}function hz(a){var b=0,c=0;b=kb-16|0;kb=b;v[b+8>>2]=a;c=b+8|0;a=1;while(1){if((a|0)>0){Lg(c);a=a-1|0;continue}break}kb=b+16|0;return v[b+8>>2]}function bR(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}_c(a,8,1,0,10);return}b=16;if(e){break a}}b=8}_c(a,b,c&2|1,0,d^1)}function bI(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function Wf(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;u[c+24>>1]=0;Xj(c+8|0,c+24|0);wn(c+16|0,a,v[c+8>>2],v[c+12>>2]);Kj(b,x[c+24>>1]);kb=c+32|0}function Ul(a,b){var c=0,d=0;d=v[a+4>>2];c=v[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;v[a+8>>2]=c;continue}break}b=v[a>>2];if(b){Cc(a);Nb(b)}}function Eka(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;v[c+12>>2]=-1;if(Ag(a,c+8|0)){v[c+4>>2]=w[c+8|0];uV(a,b,v[Kb(c+4|0,c+12|0)>>2])}kb=c+16|0}function ut(a,b){var c=0,d=0;d=Bf(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!ye(a,b,d&65535)){continue}}break}return c&65535}function gi(a){var b=0;a=a*a;b=a*a;return C(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function fW(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;v[c+12>>2]=-1;if(Ag(a,c+8|0)){v[c+4>>2]=w[c+8|0];gC(a,b,v[Kb(c+4|0,c+12|0)>>2])}kb=c+16|0}function dQ(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){$o(a);Nb(b)}}function an(a,b){var c=0;a=en(a);v[a>>2]=62268;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function Jf(a){a=a|0;var b=0;v[a>>2]=44312;v[v[a+20>>2]>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;v[a+20>>2]=0;lL(a+44|0);return a|0}function HQ(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){$o(a);Nb(b)}}function pz(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];v[a>>2]=d<<8^v[((w[b|0]^d>>>24)<<2)+29196>>2];b=b+1|0;continue}break}return a}function mba(a,b){a=a|0;b=b|0;a=Ly(a);v[23588]=0;R(804,a|0,b|0);b=v[23588];v[23588]=0;if((b|0)==1){b=P()|0;O()|0;Tp(a);T(b|0);L()}return a|0}function J4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-32|0;kb=g;h=g+8|0;_I(h,b,c,d,e,f);ad(a,g+20|0);xm(h);kb=g+32|0}function CB(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;u[c+14>>1]=1;d=c,e=El(a,b),u[d+12>>1]=e;a=x[le(c+14|0,c+12|0)>>1];kb=c+16|0;return a-1&65535}function kv(a,b){var c=0;a:{if(!b){break a}if(!Qb(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=1){c=RC(a,1);break a}c=Sg(a);_b(a,b-2|0)}return c}function Oe(a,b,c){t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;if(b>>>0>=118){uq(12062);L()}e=d+8|0;Db(e,a,b);Ze(e,c);kb=d+16|0;return a|0}function Jo(a,b){var c=0;a:{if(!b){break a}if(!Qb(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=3){c=SC(a,b);break a}c=Cg(a);_b(a,b-4|0)}return c}function Jb(a,b){var c=0;if(gf(w[a+11|0])){Nb(v[a>>2])}c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];de(b,0);xd(b,0);return a}function $T(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;c=b,d=cc(a),v[c+12>>2]=d;v[b+8>>2]=236;a=v[Zc(b+12|0,b+8|0)>>2];kb=b+16|0;nb=0;return a-216|0}function uF(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=lw(v[d>>2],c)}ob[v[v[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function rZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb-16|0;kb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Kb(a+12|0,a+8|0);kb=a+16|0;return v[b>>2]}function jl(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;c=v[a+24>>2];d=v[a+40>>2];v[b+12>>2]=1;a=v[Zc(a+20|0,b+12|0)>>2];kb=b+16|0;return B(a,c+d|0)}function ed(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[Pe(b+8|0,td(b+12|0,b+4|0))>>1];kb=b+16|0;return a}function Xz(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=Gb(b),d=0,v[c>>2]=d;return a}function Vz(a){a=50-(B(w[(a>>>4|0)+31536|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Ic((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function Mj(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Xb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;kb=d+16|0}function Lj(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Xb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;kb=d+16|0}function Hba(a){a=a|0;var b=0;b=v[a>>2];if(ob[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=ob[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function i9(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=v[a+20>>2];se(b,v[c+4>>2],v[c+8>>2]);nL(a,hc(b+8|0,v[b>>2],v[b+4>>2]),0);kb=b+16|0}function Yw(a,b){var c=0;if(b>>>0<=99){return LH(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return ks(KH(c,a),B(a,-100)+b|0)}return ej(a,b)}function QE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a>>2];if(d>>>0<=127){d=v[(d<<2)+c>>2]}v[a>>2]=d;a=a+4|0;continue}break}return b}function FU(a){var b=0,c=0,d=0;c=kb-16|0;kb=c;b=c+8|0;zv(b,a);a=w[Lb(b,0)|0];d=w[Lb(b,1)|0];b=w[Lb(b,2)|0];kb=c+16|0;return a|d<<8|b<<16}function mA(a){var b=0;b=Ib(w[a+26|0]|w[a+27|0]<<8);return((w[a+24|0]>15)+(w[a+25|0]>64)|0)+(Ib(w[a+22|0]|w[a+23|0]<<8)<<1>>>0<b>>>0)|0}function id(a,b){var c=0,d=0,e=0;c=fg(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=ob[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function fN(a,b,c,d){var e=0;e=a+1074376|0;Ty(a,e,b,c,d);e=0-w[(B(b,872)+e|0)+1428|0]|0;if(d){c=0}else{c=gt(v[a+480180>>2])}Qn(a,b,e,c)}function _q(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)<0){cd();L()}b=(b-1>>>5|0)+1|0;c=XC(b);v[a+4>>2]=0;v[a>>2]=c;d=Gb(a),e=b,v[d>>2]=e}function H5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-32|0;kb=g;h=g+8|0;_I(h,b,c,d,e,f);ad(a,h);xm(h);kb=g+32|0}function D1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=Hw(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function os(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function Yl(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;v[a+8>>2]=b;continue}break}a=v[a>>2];if(a){Nb(a)}}function x2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Cx(v[a+32>>2],b,c,d,2);if(a>>>0<=15){a=w[a+43728|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function a9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!$c(c&255))){qL(a,8,C(0))}a=lj(a);if(a){ob[v[v[a>>2]+96>>2]](a,b,c,d,e)}}function KE(a,b,c,d){a=Tb(a);v[23588]=0;U(d|0,a|0,b|0,c|0);b=v[23588];v[23588]=0;if((b|0)!=1){return a}b=P()|0;O()|0;wc(a);T(b|0);L()}function oS(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[b+4>>2]=127;a=t[Pe(b+8|0,td(b+12|0,b+4|0))|0];kb=b+16|0;return a}function Zh(a,b,c){t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;t[a+4|0]=c;t[a+5|0]=c>>>8;t[a+6|0]=c>>>16;t[a+7|0]=c>>>24}function Wi(a,b){var c=0;if(ff(a)){c=v[a>>2];Ll(a);Nb(c)}c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];de(b,0);vd(b,0)}function PE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=t[a|0];if((d|0)>=0){d=v[(d<<2)+c>>2]}t[a|0]=d;a=a+1|0;continue}break}return b}function Kba(a,b){a=a|0;b=b|0;a=Nu(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function ms(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function lj(a){var b=0,c=0;b=Zm(v[v[a+20>>2]+28>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[Md(v[a+16>>2]+906300|0,b)>>2]}return c}function iq(a,b){var c=0,d=0,e=0;if(th(2147483647)>>>0<b>>>0){cd();L()}c=$C(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=(b<<1)+c|0,v[d>>2]=e}function gN(a,b,c,d){var e=0;e=a+1074376|0;Uy(a,e,b,c,d);e=w[(B(b,872)+e|0)+1427|0];if(d){c=0}else{c=gt(v[a+480180>>2])}Qn(a,b,e,c)}function _f(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;if(b>>>0>=118){uq(12027);L()}d=c+8|0;Db(d,a,b);Ze(d,0);kb=c+16|0;return a|0}function Z7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if(b>>>0<=4){c=Yd(c,C(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=Wh(c)}z[d>>2]=c;OK(a)}}function Tw(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return ob[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return zf(t[b|0])|0}function Qh(a,b){var c=0,d=0;c=v[a>>2];d=v[a+4>>2];b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Pc(c,d,(b>>31&a)+b|0)>>2]}function Bk(a,b){var c=0,d=0,e=0;if(th(1073741823)>>>0<b>>>0){cd();L()}c=Ci(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=(b<<2)+c|0,v[d>>2]=e}function $D(a){a=a|0;var b=0;a=Mb(a);v[23588]=0;R(136,a|0,13608);b=v[23588];v[23588]=0;if((b|0)==1){b=P()|0;O()|0;Ab(a);T(b|0);L()}}function x1(a){a=a|0;var b=0;if((ob[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+1;a=zf(t[a|0])}else{a=-1}return a|0}function qba(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;if(b>>>0>=250){uq(12062);L()}d=c+8|0;Db(d,a,b);po(d);kb=c+16|0;return a|0}function mz(a,b){var c=0,d=0,e=0;if(th(536870911)>>>0<b>>>0){cd();L()}c=CD(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=(b<<3)+c|0,v[d>>2]=e}function mu(a,b){var c=0,d=0,e=0;if(th(715827882)>>>0<b>>>0){cd();L()}c=fT(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=B(b,6)+c|0,v[d>>2]=e}function aI(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}aa(14180,13110,1180,5737);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function GO(a,b){var c=0,d=0,e=0;if(th(268435455)>>>0<b>>>0){cd();L()}c=eQ(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=(b<<4)+c|0,v[d>>2]=e}function tg(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[Pe(b+8|0,td(b+12|0,b+4|0))|0];kb=b+16|0;return a}function PC(a,b){var c=0;c=Oka(b&255,0,1536,0);b=nb;a=Oka(a&255,0,25,0);c=a+c|0;b=nb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;nb=b;return a}function uW(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;b=v[v[b>>2]-12>>2]+b|0;if(Zg(b)){b=v[b+72>>2];if(b){ar(b)}t[a|0]=1}return a|0}function nq(a,b){var c=0;c=zd(v[a+4>>2],w[a+11|0]);if((c|0)==(zd(v[b+4>>2],w[b+11|0])|0)){a=Rv(pd(a),pd(b),c)}else{a=1}return!a}function me(a){var b=0;a=v[a+4>>2];if(a){if(gn(a)){a:{b=a+8|0;if(v[b>>2]){if((Fv(b)|0)!=-1){break a}}ob[v[v[a>>2]+16>>2]](a)}}}}function mG(a,b,c,d,e,f){a=ob[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Ur(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function lz(a,b){var c=0;c=v[a+484360>>2];b=b&255;if(sj(c,v[a+484364>>2])>>>0<=b>>>0){return Wb(c,w[a+484376|0])}return yj(c,b)}function jG(a,b,c,d,e,f){a=ob[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Sr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function j1(a){a=a|0;var b=0;if((ob[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+4;a=v[a>>2]}else{a=-1}return a|0}function iZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function hx(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}uc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function g1(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;b=v[v[b>>2]-12>>2]+b|0;if(Zg(b)){b=v[b+72>>2];if(b){sH(b)}t[a|0]=1}return a|0}function RN(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(w[a+480180|0]&2){break a}}v[b+56>>2]=0;d=Wn(a,x[b+70>>1],v[b+48>>2],c,0)}return d}function NE(a,b,c){var d=0;d=kb-16|0;kb=d;v[d+8>>2]=a;v[d+12>>2]=b;v[d>>2]=c;v[d+4>>2]=0;a=Zq(d+8|0,d);kb=d+16|0;return v[a>>2]}function uZ(a){a=a|0;var b=0;b=kb-16|0;kb=b;ji(ki(b+8|0,v[a+8>>2]));kb=b+16|0;a=v[a+8>>2];if(!a){return 1}return(EF(a)|0)==1|0}function hC(a,b){var c=0;c=v[b+4>>2];if(c){gc(a,c,v[b>>2]);return}c=v[b+8>>2];b=v[b+12>>2];if(!pc(c,b)){se(a,c,b);return}fe(a)}function bP(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){Gd(b,a)}if(c){Gd(c,a)}if(d){Gd(d,a)}if(e){Gd(e,a)}}function bE(){var a=0,b=0,c=0;a=kb-16|0;kb=a;b=Nc(a,14930);if(Hb(b)){c=(Eg(b,13813)|0)!=-1}else{c=0}zb(b);kb=a+16|0;return c|0}function aZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function UJ(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;c=DJ(tc(8));v[c+4>>2]=a;v[c>>2]=57800;a=v[Mf(b+8|0,c)>>2];kb=b+16|0;return a|0}function Ss(a){var b=0;b=A[a+4248>>3]/+y[v[a+16>>2]+24620>>2];A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*(A[a+4288>>3]/60)}}function Aq(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function AE(a,b,c){a=Wh(a);a:{if(a>=b){break a}c=0;if(a<=C(0)){break a}if(a<C(4294967296)&a>=C(0)){c=~~a>>>0;break a}}return c}function xl(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(ob[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function pw(a,b){var c=0,d=0,e=0,f=0;c=yg(b);d=tc(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=uc(Cc(d),b,c+1|0),v[e>>2]=f}function Sq(a,b){return qo(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24),w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))?b:a}function PS(a,b){var c=0;c=kb-16|0;kb=c;a=Bh(c,a,1);Im(v[a+4>>2],x[b>>1]|x[b+2>>1]<<16);v[a+4>>2]=v[a+4>>2]+4;lc(a);kb=c+16|0}function JY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(_g(a,v[b+8>>2],0)){mw(b,c,d);return}a=v[a+8>>2];ob[v[v[a>>2]+28>>2]](a,b,c,d)}function wU(a){var b=0;a:{if(Sb(a,3863,4)){break a}if(Sb(a+44|0,17805,3)){break a}b=(w[a+47|0]|w[a+48|0]<<8)>>>0>97}return b}function nG(a,b,c,d,e,f){a=ob[v[v[a+8>>2]>>2]](a+8|0)|0;a=Ur(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function kg(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return bo(a,d)}function kG(a,b,c,d,e,f){a=ob[v[v[a+8>>2]>>2]](a+8|0)|0;a=Sr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function gl(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;cy(a,c,d)}function dO(a){Xy(a);v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;a=Yf(a);Yf(a+12|0);t[a+24|0]=1}function Yc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}nb=c;return a}function ES(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;u[c+14>>1]=b;if((El(v[a>>2],v[a+4>>2])|0)!=65535){YB(a,c+14|0)}kb=c+16|0}function sc(a,b){var c=0;a=lm(a);v[a+4>>2]=0;v[a>>2]=49120;c=Pd(Hb(b)+1|0);v[a+4>>2]=c;if(c){uc(c,Mc(b),Hb(b)+1|0)}return a}function iH(a,b){var c=0;c=kb-32|0;kb=c;a=sl(c+24|0,$G(c+16|0,Zr(c+8|0,a,b)));b=v[a+4>>2];a=v[a>>2];kb=c+32|0;nb=b;return a}function XQ(a,b){var c=0;c=kb-16|0;kb=c;ER(c+8|0,a);Ge(c,b);a=Qc(v[c+8>>2],v[c+12>>2],v[c>>2],v[c+4>>2]);kb=c+16|0;return a}function KK(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=wc(b-24|0);if((c|0)!=(b|0)){continue}break}return Jf(a)|0}function yo(a){v[a+32>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;return a}function ou(a,b,c){c=c&255;while(1){a:{if(!b){a=0;break a}if(pc(w[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function iM(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function SQ(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((w[a+b|0]-127&255)>>>0>160){continue}}break}return(b|0)==8}function I8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=kh(C(Yd(c,C(0))*C(127))),t[d|0]=e;Qs(a)}}function C9(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=kh(C(Yd(c,C(0))*C(255))),t[d|0]=e;Us(a)}}function BE(a,b){v[a>>2]=b;EH(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function $z(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function $ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);d=b+c|0;c=Sh(b,d);if(c){Ol(a,c);ku(a,b,d,c)}}function pe(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function Qo(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function vL(a,b,c){var d=0,e=0;d=bd(a);if(d>>>0>=c>>>0){Vx(a,Xh(Ac(a),b,c),c);return}e=a;a=Hb(a);ip(e,d,c-d|0,a,0,a,c,b)}function tP(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){pP(a,1);pP(a,0)}}function sP(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){rP(a,1);rP(a,0)}}function pQ(a){var b=0;if(!(w[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){v[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function oH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return ob[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function mS(a,b){var c=0;c=kb-16|0;kb=c;a:{if(!fg(a,4)){$S(b);break a}Kh(c+8|0,b);lA(c,a,v[c+8>>2],v[c+12>>2])}kb=c+16|0}function ah(a,b,c,d,e){var f=0;f=kb-16|0;kb=f;v[f+12>>2]=e;c=ki(f+8|0,c);a=Wr(a,b,d,v[f+12>>2]);ji(c);kb=f+16|0;return a}function F2(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((a|0)!=(b|0)){yh(v[c>>2],a);v[c>>2]=v[c>>2]+12;a=a+12|0;continue}break}}function xi(a,b,c){c=w[c|0];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=w[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function wt(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function kY(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return ob[a|0](h|b,c,d,e,b|f,g)|0}function Ol(a,b){var c=0,d=0,e=0;if(th(-1)>>>0<b>>>0){cd();L()}c=tc(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=b+c|0,v[d>>2]=e}function KR(a){var b=0;if(!(Sb(a,13765,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64))){b=(w[a+33|0]-1&255)>>>0<32}return b}function IT(a,b,c){var d=0;while(1){if(b){d=w[c|0]|w[c+1|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function GN(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Yb(v[a>>2]+((B((d^-1|-256)+b|0,c<<24>>24)|0)/2|0)|0,0,256),v[e>>2]=f}}function $e(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function rG(a,b,c){var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;b=ki(d+8|0,b);a=RG(a,9222,v[d+12>>2]);ji(b);kb=d+16|0;return a}function Ki(a){var b=0;while(1){a:{if((b|0)!=46){if(w[b+43760|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function EE(a,b,c){a=xe(a);a:{if(a>=b){break a}c=0;if(a<=0){break a}if(a<4294967296&a>=0){c=~~a>>>0;break a}}return c}function sV(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Ad(b);continue}break}v[a+4>>2]=c}function o7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=2){c=Yd(c,C(0));d=Eb(a+4208|0,b),e=c,z[d>>2]=e;FK(a)}}function l8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=5){c=Yd(c,C(0));d=Eb(a+4208|0,b),e=c,z[d>>2]=e;UK(a)}}function l0(a){a=a|0;var b=0,c=0;c=v[a+4>>2];b=v[a>>2];a=v[a+8>>2];b=b+(a>>1)|0;if(a&1){c=v[c+v[b>>2]>>2]}ob[c|0](b)}function g7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=3){c=Yd(c,C(0));d=Eb(a+4208|0,b),e=c,z[d>>2]=e;DK(a)}}function e8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=4){c=Yd(c,C(0));d=Eb(a+4208|0,b),e=c,z[d>>2]=e;QK(a)}}function Xo(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;jr(b);continue}break}v[a+4>>2]=c}function Og(a){var b=0;Em(a);b=Kt(v[a>>2],Fk(x[a+34>>1]));v[a+20>>2]=b;if(!b){return 0}return Ij(v[a>>2],x[a+34>>1])}function AP(a){v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function wO(a){var b=0,c=0,d=0;if(v[a>>2]){Lc(a);b=v[a>>2];hn(a);Nb(b);c=Gb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function th(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=Kb(b+12|0,b+8|0);kb=b+16|0;return v[a>>2]}function pu(a){var b=0,c=0,d=0;if(v[a>>2]){Lc(a);b=v[a>>2];Vh(a);Nb(b);c=Gb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function nP(a){var b=0,c=0,d=0;if(v[a>>2]){Lc(a);b=v[a>>2];Ym(a);Nb(b);c=Gb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function XL(a){var b=0,c=0,d=0;if(v[a>>2]){Lc(a);b=v[a>>2];Du(a);Nb(b);c=Gb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function WG(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function Iu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;Tm(d+8|0,b);v[d+4>>2]=v[d+8>>2];yu(a,d+4|0,c);kb=d+16|0}function Fi(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[Kb(b+12|0,b+8|0)>>2];kb=b+16|0;return a}function wV(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function uc(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function fR(a){var b=0;if(!(Sb(a+44|0,13774,4)|w[a+29|0]!=16)){b=((w[a+42|0]|w[a+43|0]<<8)-1&65535)>>>0<2}return b}function _H(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+((c+c)*d+(c*c-e))}function Ed(a,b){var c=0;c=b+4|0;eq(v[a>>2],v[a+4>>2],c);qc(a,c);qc(a+4|0,b+8|0);qc(Gb(a),Cc(b));v[b>>2]=v[b+4>>2]}function uH(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!pc(yH(c,b),-1)){break a}v[a>>2]=0}return a|0}function il(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function am(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}Ji(a,b);a=a+1|0;continue}}}function Tr(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}qc(a,b);a=a+4|0;continue}}}function PN(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function PK(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function fQ(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;v[a+8>>2]=b;continue}break}}function _3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=ob[v[v[b>>2]+8>>2]](b)|0;d=c,e=gg(a?a:21619),v[d>>2]=e}}function BQ(a){if(Sb(a,13747,4)){a=0}else{a=(cc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))|0)==1}return a}function ww(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(v[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function wm(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function cj(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function Um(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function N0(a,b){a=a|0;b=b|0;var c=0,d=0;ob[v[v[a>>2]+24>>2]](a)|0;b=Iw(b);v[a+36>>2]=b;c=a,d=An(b),t[c+44|0]=d}function G0(a,b){a=a|0;b=b|0;var c=0,d=0;ob[v[v[a>>2]+24>>2]](a)|0;b=Nw(b);v[a+36>>2]=b;c=a,d=An(b),t[c+44|0]=d}function _g(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!wi(v[a+4>>2],v[b+4>>2])}function Ze(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function TQ(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;b=a>>>0>c>>>0?b+1|0:b;nb=b;return c}function PL(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[Kb(b+12|0,b+8|0)>>1];kb=b+16|0;return a}function OE(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=Eb(c,a);a=a+1|0;v[d>>2]=a<<b;continue}break}}function Fu(a,b){var c=0;c=kb-16|0;kb=c;v[c+12>>2]=(B(a,b)>>>0)/255;pe(c+12|0,0,15);kb=c+16|0;return w[c+12|0]}function Dl(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[Kb(b+12|0,b+8|0)>>1];kb=b+16|0;return a}function AF(a,b){var c=0;c=kb-16|0;kb=c;a=Pk(c,a,1);xd(v[a+4>>2],w[b|0]);v[a+4>>2]=v[a+4>>2]+1;lc(a);kb=c+16|0}function oM(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function kw(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=lw(v[e>>2],h)}ob[v[v[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function kl(a,b,c,d){var e=0;e=kb-16|0;kb=e;v[e+12>>2]=d;v[e+8>>2]=c;hc(a,b,v[Kb(e+12|0,e+8|0)>>2]);kb=e+16|0}function HM(a,b){var c=0;c=kb-16|0;kb=c;a=Iz(c,a);gq(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;lc(a);kb=c+16|0}function Ep(a,b){var c=0;c=kb-32|0;kb=c;Kh(c+16|0,b);wn(c+24|0,a,v[c+16>>2],v[c+20>>2]);Kh(c+8|0,b);kb=c+32|0}function Bu(a){var b=0;b=kb-16|0;kb=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[Wc(b+14|0,b+12|0)|0];kb=b+16|0;return a}function lG(a,b,c,d,e){b=Yi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function iG(a,b,c,d,e){b=Xi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function dda(){var a=0;a=kb-16|0;kb=a;if(cb(a+12|0,4)|0){js(v[116064],12562);L()}kb=a+16|0;return v[a+12>>2]}function _O(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+20>>1]>>>6|x[b+22>>1]<<4)&65535)+29056|0]>>>x[a+68>>1]}function Zw(a,b){var c=0;if(b>>>0<=9999){return Yw(a,b)}c=a;a=(b>>>0)/1e4|0;return ej(Yw(c,a),B(a,-1e4)+b|0)}function AH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return ob[v[v[a>>2]+36>>2]](a)|0}return zf(t[b|0])}function zm(a,b){var c=0;c=kb-16|0;kb=c;v[c+8>>2]=a;a=c+8|0;v[a>>2]=v[a>>2]+(b<<2);kb=c+16|0;return v[a>>2]}function tha(a,b){a=a|0;b=b|0;if(!NS(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function pI(a,b,c,d){z[d+4>>2]=a+c;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=b+a}function ml(a,b,c,d){a=a&65535;c=c&65535;a=(a|0)==(c|0)?0:a>>>0<c>>>0?-1:1;if(xj(a)){a=vO(b,d)}return gf(a)}function bS(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(b>=0){A[a+8>>3]=b;v[a+16>>2]=3}return a}function _x(a,b){a=Tb(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Tb(a+24|0);Mb(a+36|0);v[a+48>>2]=b;return a}function Ml(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[Kb(b+12|0,b+8|0)|0];kb=b+16|0;return a}function zR(a){var b=0;if(!(Sb(a,17800,4)|w[a+5|0]!=16|(w[a+54|0]-33&255)>>>0<224)){b=w[a+4|0]>95}return b}function r4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return bF(a,b,c,d,e,f,g,12897,1040)|0}function nka(a,b){a=a|0;b=b|0;var c=0;b=kb-80|0;kb=b;c=-1;if(gV(a,b+8|0)){c=fV(b+8|0)}kb=b+80|0;return c|0}function mt(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Tn(a);continue}break}return a}function kha(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=-1;if(Rj(a,b+8|0)){c=zS(b+8|0)}kb=b+16|0;return c|0}function jv(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function hr(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,pd(a)+zd(v[a+4>>2],w[a+11|0])|0)>>2];kb=b+16|0;return a}function F4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return bF(a,b,c,d,e,f,g,12829,1033)|0}function Yk(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return ob[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function Kr(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=lw(v[d>>2],g)}ob[v[v[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function KV(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=-1;if(Rj(a,b+8|0)){c=OB(b+8|0)}kb=b+16|0;return c|0}function EO(a,b){var c=0;c=v[a+484344>>2];if(ye(c,v[a+484348>>2],b)){a=v[Zb(c,b)+12>>2]}else{a=1}return a}function DF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function zO(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;We(c);continue}break}v[a+4>>2]=b}function uC(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;Bb(c);continue}break}v[a+4>>2]=b}function tga(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){iq(a,b);Ho(a,b,c)}return a|0}function ke(a,b){a=Ql(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];Ql(a+12|0,v[b+12>>2],v[b+16>>2]);return a}function hP(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;rl(c);continue}break}v[a+4>>2]=b}function Rb(a,b,c){var d=0;c=v[a+4>>2]+c|0;d=b;b=v[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;v[a>>2]=b;v[a+4>>2]=c}function QM(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;hl(c);continue}break}v[a+4>>2]=b}function GQ(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;FQ(c);continue}break}v[a+4>>2]=b}function yT(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){mu(a,b);NA(a,b,c)}return a|0}function rW(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){Bk(a,b);xC(a,b,c)}return a|0}function fO(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}A[a>>3]=d}}function YY(){if(w[468316]){return v[117078]}xp(468308,JK());t[468316]=1;v[117078]=468308;return 468308}function Pm(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){Ol(a,b);No(a,b,c)}return a|0}function MU(a){a:{if(Sb(a,14137,4)){break a}if(Sb(a+8|0,14118,4)){break a}return 1}return!Sb(a,14118,4)}function EF(a){var b=0,c=0;b=kb-16|0;kb=b;a=ki(b+8|0,a);c=v[v[116090]>>2];ji(a);kb=b+16|0;return c?4:1}function zX(a){a=a|0;var b=0,c=0;b=kb-32|0;kb=b;c=-1;if(ZD(a,b+8|0)){c=YD(b+8|0)}kb=b+32|0;return c|0}function tB(a,b){if(b>>>0<=126){ef(((b<<5)+a|0)+480280|0);fo((B(b,872)+a|0)+1074992|0,a,b,134217728)}}function rB(a){var b=0,c=0;if(v[a>>2]){Lc(a);Nb(v[a>>2]);b=Gb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function cB(a){a=a|0;var b=0;u[a+34>>1]=0;b=a+43|0;pm(b,b+22|0,62364);v[a+20>>2]=0;nd(a,0);return a|0}function Ub(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function UW(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;c=-1;if(Rj(a,b+8|0)){c=tD(b+8|0)}kb=b+16|0;return c|0}function TP(a){if(((w[a+68|0]|w[a+69|0]<<8)-128&65535)>>>0>=65409){a=Sb(a,17648,17)}else{a=1}return!a}function Rq(a,b,c){var d=0;d=kb-16|0;kb=d;if(b){t[d+15|0]=0;qM(a+36|0,b,xi(b,b+c|0,d+15|0))}kb=d+16|0}function JT(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c,e=Ib(b&65535),u[d+14>>1]=e;_J(a,c+14|0);kb=c+16|0}function rT(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){pT(c+52|0);Ab(c+40|0);wc(c+16|0);wc(c+4|0);Nb(c)}}function lS(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function YM(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3;return a}function VP(a){Zd(a+140|0);Bb(a+120|0);Bb(a+100|0);Bb(a+80|0);Bb(a+60|0);Bb(a+40|0);Bb(a+20|0);Bb(a)}function Tj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function Su(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function Hj(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;if(Po(a,b+8|0)){c=Ib(x[b+8>>1])}kb=b+16|0;return c|0}function FW(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;Vm(c+8|0,b);br(a,v[c+8>>2],v[c+12>>2]);kb=c+16|0}function EW(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;ok(a+8|0,0);_q(a,127);YC(a,127,w[b|0]);return a|0}function Co(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;if(So(a,b+8|0)){c=cc(v[b+8>>2])}kb=b+16|0;return c|0}function A2(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;fC(c+8|0,b);br(a,v[c+8>>2],v[c+12>>2]);kb=c+16|0}function w2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Jz(Cx(v[a+32>>2],b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function gT(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]+B((b|0)/-6|0,6)|0;v[d>>2]=c;if((b|0)>0){uc(c,a,b)}}function c9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=lj(a);if(a){ob[v[v[a>>2]+88>>2]](a,b,c,d,e)}}function ad(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];tE(b);return a}function BM(a,b){if(b>>>0<=255){a=v[((b<<2)+a|0)+900380>>2];a=a?a+492|0:21619}else{a=21619}return a}function mg(a,b,c){var d=0;d=c;c=v[a>>2];d=v[a+4>>2]-(d+(c>>>0<b>>>0)|0)|0;v[a>>2]=c-b;v[a+4>>2]=d}function lv(a){a=a|0;var b=0;b=kb-16|0;kb=b;a=Ag(a,b+15|0);kb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function _8(a,b,c){a=a|0;b=b|0;c=c|0;a=lj(a);if(!a){return 0}return ob[v[v[a>>2]+104>>2]](a,b,c)|0}function Yga(a){a=a|0;var b=0;b=kb-16|0;kb=b;a=Po(a,b+8|0);kb=b+16|0;return(a?x[b+8>>1]:0)<<16>>16}function X3(a,b){a=a|0;b=b|0;var c=0;b=Mc(b);c=v[a+4>>2];if(c){ob[c|0](b,v[a+8>>2]);return}Os(b,a)}function FF(a,b,c,d,e){var f=0;f=kb-16|0;kb=f;e=ki(f+8|0,e);a=Xr(a,b,c,d);ji(e);kb=f+16|0;return a}function CO(a,b,c){var d=0;d=kb-16|0;kb=d;a=v[fc(d+8|0,uO(b,c,Td(a),jc(a)))>>2];kb=d+16|0;return a}function Bga(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=-1;if(vB(a,b)){c=UR(b)}kb=b+16|0;return c|0}function ox(a,b,c){b=(B(B(mx(a),nx(a,b)),125)>>>0)/(wI(a,b)>>>0)|0;a=(a&6)==6?b&-4:b;return a?a:c}function K6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;ob[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;xp(d,a);gK(a,c)}function wn(a,b,c,d){var e=0;e=kb-16|0;kb=e;$g(e+8|0,c,d);hG(a,b,v[e+8>>2],v[e+12>>2]);kb=e+16|0}function tw(a,b,c,d){var e=0;e=kb-16|0;kb=e;gc(e+8|0,c,d);hG(a,b,v[e+8>>2],v[e+12>>2]);kb=e+16|0}function t1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function r1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function q1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function p1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function o1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function n1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function mi(a,b,c){if(c){while(1){v[a>>2]=v[b>>2];a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}}function Zz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){v[a>>2]=v[c>>2];b=b-1|0;a=a+4|0;continue}break}}function ZE(a,b,c){var d=0;d=kb-16|0;kb=d;c=Nc(d,c);a=sc(a,c);zb(c);v[a>>2]=b;kb=d+16|0;return a}function M4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return hF(a,b,c,d,e,f,10569,1030)|0}function K5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return hF(a,b,c,d,e,f,10614,1004)|0}function Gp(a,b){var c=0;c=kb-16|0;kb=c;v[c+8>>2]=v[a>>2];a=v[fB(c+8|0,b)>>2];kb=c+16|0;return a}function vv(a,b){a=nD(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];nD(a+12|0,v[b+12>>2],v[b+16>>2])}function kW(a){a=a|0;var b=0;b=v[a+76>>2];if(pc(-1,b)){b=_C(a,32);v[a+76>>2]=b}return b<<24>>24}function Y0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ob[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function XB(a,b){a=a|0;b=b|0;if(!Ou(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0}}function QV(a,b){a=a|0;b=b|0;if(!Ou(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function Pha(a){a=a|0;var b=0;b=kb-16|0;kb=b;a=So(a,b+8|0);kb=b+16|0;return C(a?z[b+8>>2]:C(0))}function MR(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}v[a>>2]=b}}function Laa(a,b){a=a|0;b=b|0;ui(a);ui(a);a:{if(b>>>0>=60){_b(a,4);break a}ui(a)}return ui(a)|0}function F3(a){a=a|0;var b=0;b=kb-16|0;kb=b;a=v[Mf(b+8|0,wl(tc(12),a))>>2];kb=b+16|0;return a|0}function DY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(_g(a,v[b+8>>2],f)){ow(b,c,d,e)}}function Bt(a,b){b=Oka(a,a>>31,b,b>>31)+5e5|0;a=nb;return Ic(Pka(b,b>>>0<5e5?a+1|0:a,1e6,0),nb)}function rea(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){Bk(a,b);Ct(a,b)}return a|0}function kV(a){var b=0;if(!(Sb(a,26324,20)|(w[a+25|0]-9&255)>>>0<248)){b=t[a+47|0]>=0}return b}function hB(a,b){var c=0;c=kb-16|0;kb=c;v[c+8>>2]=a;a=v[lU(c+8|0,0-b|0)>>2];kb=c+16|0;return a}function fw(a,b,c,d){var e=0;v[a>>2]=v[b>>2];e=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<d)+e;return a}function cI(a){var b=0;b=+((a&2097151)>>>0);return C(Vj(+C((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function KG(a){var b=0;b=v[116090];if(a){v[116090]=(a|0)==-1?468100:a}return(b|0)==468100?-1:b}function $U(a,b){return(Yb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((B(a&15,b)>>>0)/15|0,1,15))&255}function sB(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);if(b){Ol(a,b);sE(a,b)}return a|0}function pm(a,b,c){b=b-a|0;while(1){if((b|0)>0){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function mY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=ob[a|0](b,c,d,e)|0;ra(nb|0);return a|0}function Uk(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,Ac(a)+(Hb(a)<<2)|0)>>2];kb=b+16|0;return a}function Sf(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=a;a=yc(c,b);ad(d,a);Ab(a);kb=c+16|0}function Ku(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=a;a=Nc(c,b);ad(d,a);zb(a);kb=c+16|0}function IC(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;nb=a;return b}function DQ(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function l1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return ob[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function eB(a){var b=0,c=0;b=kb-16|0;kb=b;if(Po(a,b+8|0)){c=qe(u[b+8>>1])}kb=b+16|0;return c}function ZQ(a){var b=0,c=0;b=kb-16|0;kb=b;if(YQ(a,b+8|0)){c=cc(v[b+8>>2])}kb=b+16|0;return c}function LG(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function Jga(a){a=a|0;var b=0,c=0;b=kb-32|0;kb=b;c=a;a=Jh(b+8|0);xS(c,a,0,0);Bb(a);kb=b+32|0}function CW(a){a=a|0;var b=0;b=kb-16|0;kb=b;a=Ag(a,b+8|0);kb=b+16|0;return(a?w[b+8|0]:0)&255}function BF(a){a=a|0;var b=0;v[a>>2]=83244;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Nb(b)}return a|0}function vR(a){a:{if(Sb(a,17593,4)){break a}if(Sb(a+8|0,14175,4)){break a}return 1}return 0}function nx(a,b){a=a&255;return w[(B(a>>>1&3,15)+B(a>>>3&1,45)+((b&240)>>>4)|0)+64705|0]<<1}function lga(a){a=a|0;var b=0;b=kb-16|0;kb=b;a=Ih(a,b+8|0);kb=b+16|0;return+(a?A[b+8>>3]:0)}function ag(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){tB(a,c);b=b+1|0;continue}break}}function Wy(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function WC(a,b){if((a&4088)>>>0>=520){b=ov(0-Ska(b^1230262859,25)|0,4)^1247037516}return b}function BJ(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=aL(d);b=b+1|0}gJ(a,b,c,d,e)}function zH(a){var b=0;b=v[a>>2];if(b){if(!pc(AH(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function qw(a,b,c){var d=0;d=kb-16|0;kb=d;c=ki(d+8|0,c);a=$w(a,b);ji(c);kb=d+16|0;return a}function nD(a,b,c){var d=0;d=kb-16|0;kb=d;b=Ql(d+8|0,b,c);SD(b,a);me(b);kb=d+16|0;return a}function a7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;Ax(a,b,c,d,e,0,0,f,g)}function _P(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;nb=a;return b}function Wv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+21620>>2]}else{b=9692}yc(a,b)}function Wl(a,b,c){var d=C(0);if(b>>>0<=c>>>0){d=z[Eb(a+4208|0,b)>>2]}else{d=C(0)}return d}function Rf(a,b){var c=0;c=kb-16|0;kb=c;v[c+8>>2]=a;a=v[fB(c+8|0,b)>>2];kb=c+16|0;return a}function Ng(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function LK(a,b){var c=0;c=v[a+12>>2];if((c|0)>0){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function pr(a){var b=0;while(1){if(!pc(w[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function lY(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ob[a|0](b,c,d,e,f,g)}function hL(a,b){a=a|0;b=b|0;var c=0;c=Hb(a);if(c>>>0<b>>>0){Ju(a,b-c|0,0);return}FL(a,b)}function e9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=lj(a);if(a){ob[v[v[a>>2]+76>>2]](a,b,c,d)}}function d9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=lj(a);if(a){ob[v[v[a>>2]+84>>2]](a,b,c,d)}}function b9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=lj(a);if(a){ob[v[v[a>>2]+92>>2]](a,b,c,d)}}function ZJ(a){a=a|0;var b=0;v[a>>2]=49120;b=v[a+4>>2];if(b){Nb(b);v[a+4>>2]=0}return a|0}function WU(a,b,c){var d=0;d=kb-16|0;kb=d;Zh(d+8|0,b,c);kb=d+16|0;return v[d+8>>2]==(a|0)}function Ska(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function Sg(a){var b=0;b=kb-16|0;kb=b;a=Po(a,b+8|0);kb=b+16|0;return(a?x[b+8>>1]:0)&65535}function Kp(a,b,c){a=a+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function Gw(a,b,c,d){var e=0;e=kb-16|0;kb=e;v[e+12>>2]=d;a=Wr(a,b,c,d);kb=e+16|0;return a}function zh(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,Ac(a)+Hb(a)|0)>>2];kb=b+16|0;return a}function xz(a,b){a=wl(a,b);ad(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function tN(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|64;v[a+852>>2]=v[a+852>>2]+b}}function qt(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,Mc(a)+Hb(a)|0)>>2];kb=b+16|0;return a}function pY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[a|0](b,c,d,e,f)|0}function _s(a,b){var c=0;c=Mc(a);if(c>>>0<=b>>>0){a=Hb(a)+c>>>0>=b>>>0}else{a=0}return a}function ZM(a){var b=0;b=a+4e4|0;while(1){b=yy(b-160|0);if((b|0)!=(a|0)){continue}break}}function Vx(a,b,c){var d=0;d=kb-16|0;kb=d;Rh(a,c);t[d+15|0]=0;je(b+c|0,d+15|0);kb=d+16|0}function Me(a){var b=0;b=kb-16|0;kb=b;a=Ag(a,b+15|0);kb=b+16|0;return(a?w[b+15|0]:0)&255}function Lv(){var a=0,b=0;a=kb-16|0;kb=a;b=Mf(a+8|0,Tb(tc(12)));kb=a+16|0;return v[b>>2]}function ER(a,b){var c=0;c=kb-16|0;kb=c;Vm(c+8|0,b);lT(a,v[c+8>>2],v[c+12>>2]);kb=c+16|0}function As(a){if(JJ(a)){a=ba(4)|0;v[a>>2]=0;a=lm(a);v[a>>2]=92472;ha(a|0,92508,26);L()}}function $M(a){a=Mb(a);Mb(a+12|0);Mb(a+24|0);Mb(a+36|0);Mb(a+48|0);v[a+60>>2]=0;return a}function ug(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function pH(a){var b=0;b=v[a>>2];if(b){if(!Dn(Yk(b))){return!v[a>>2]}v[a>>2]=0}return 1}function lq(a,b,c){var d=C(0);d=z[a>>2];if(!gu(d,z[b>>2])){b=gu(z[c>>2],d)?c:a}return b}function gn(a){var b=0;b=Fv(a+4|0);if((b|0)==-1){ob[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function g9(a,b){a=a|0;b=b|0;a=lj(a);if(!a){return 1}return ob[v[v[a>>2]+68>>2]](a,b)|0}function cX(a){a=a|0;var b=0;b=v[a+4>>2];return(ob[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function YL(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){hj(c,a,d)}return B((d|0)/6|0,6)+c|0}function Xv(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function UA(a){var b=0;b=Hz(a);while(1){if((a|0)!=(b|0)){tV(a);a=a+32|0;continue}break}}function Rp(a,b,c){a=jl(a)-v[a+16>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function QG(a,b){var c=0;c=kb-16|0;kb=c;v[c+12>>2]=b;a=RG(a,11096,b);kb=c+16|0;return a}function Kx(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=aL(d);b=b+1|0}Gx(a,b,c,d)}function wI(a,b){a=a&255;return v[(b&12)+64708>>2]>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function nS(a){var b=0;b=a+24|0;while(1){b=zb(b-12|0);if((b|0)!=(a|0)){continue}break}}function mQ(a){var b=0;b=a+36|0;while(1){b=zb(b-12|0);if((b|0)!=(a|0)){continue}break}}function av(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;t[c+15|0]=b;eK(a,c+15|0);kb=c+16|0}function UO(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function TD(a,b){var c=0;c=kb-16|0;kb=c;b=Dg(c+8|0,b);SD(b,a);me(b);kb=c+16|0;return a}function PB(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+26272|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function KX(){var a=0;a:{if(cE(19988498)){break a}if(bE()){break a}a=aE()^1}return a|0}function K4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return gF(a,b,c,d,e,12285,1031)|0}function I5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return gF(a,b,c,d,e,12385,1005)|0}function H$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return RE(b,c,d,e,f,1)|0}
function Dc(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;Vm(d,a);Nl(d,b);kb=c+16|0;return a}function tE(a){var b=0;while(1){if((b|0)!=3){v[(b<<2)+a>>2]=0;b=b+1|0;continue}break}}function tA(a,b,c,d){var e=0;e=kb-16|0;kb=e;a=Bh(e,a,d);ju(b,c,a+4|0);lc(a);kb=e+16|0}function p4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return aF(a,b,c,d,e,9648,1041)|0}function ku(a,b,c,d){var e=0;e=kb-16|0;kb=e;a=Pk(e,a,d);ju(b,c,a+4|0);lc(a);kb=e+16|0}function kt(a,b){if(!(t[b+851|0]&1&v[a+480180>>2]==8)){ny(a,b,0);ny(a,b,1);ny(a,b,2)}}function fP(a,b,c,d){var e=0;e=kb-16|0;kb=e;a=$h(e,a,d);ju(b,c,a+4|0);lc(a);kb=e+16|0}function eu(a,b){var c=0;c=kb-16|0;kb=c;u[c+14>>1]=b;au(a+236|0,128,c+14|0);kb=c+16|0}function eq(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>0){uc(c,a,b)}}function eZ(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+81744>>2]}return b<<24>>24}function cm(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function cZ(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+80208>>2]}return b<<24>>24}function ZZ(a){a=a|0;a=469608;while(1){a=Gc(a-12|0);if((a|0)!=469584){continue}break}}function YZ(a){a=a|0;a=469536;while(1){a=Gc(a-12|0);if((a|0)!=469248){continue}break}}function XZ(a){a=a|0;a=468936;while(1){a=Gc(a-12|0);if((a|0)!=468768){continue}break}}function St(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function R$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return TE(b,c,d,e,f,1)|0}function P$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return TE(b,c,d,e,f,0)|0}function Os(a,b){a=a|0;b=b|0;b=kb-16|0;kb=b;v[b>>2]=a;qK(17822,b);Ms(93888);kb=b+16|0}function M1(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function LZ(a){a=a|0;a=469576;while(1){a=zb(a-12|0);if((a|0)!=469552){continue}break}}function KZ(a){a=a|0;a=469232;while(1){a=zb(a-12|0);if((a|0)!=468944){continue}break}}function K1(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function Jl(a,b,c){a=a|0;b=b|0;c=c|0;if(Rc(a,b)>>>0<=c>>>0){gv();L()}return(c<<1)+a|0}function JZ(a){a=a|0;a=468760;while(1){a=zb(a-12|0);if((a|0)!=468592){continue}break}}function F$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return RE(b,c,d,e,f,0)|0}function D4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return aF(a,b,c,d,e,9576,1034)|0}function $F(a,b){var c=0,d=0;_e(a,ce(b));b=jc(b);c=jc(a),d=v[b>>2],v[c>>2]=d;return a}function ye(a,b,c){if(Rm(a,b,c)){a=bg(a,c);a=Pb(v[a>>2],v[a+4>>2])}else{a=0}return a}function kQ(a,b,c,d,e,f){a=fc(a,b);fc(a+4|0,c);fc(a+8|0,d);fc(a+12|0,e);fc(a+16|0,f)}function ew(a,b){var c=0;while(1){if((b|0)!=(c|0)){Dh(a+c|0);c=c+1|0;continue}break}}function df(a){a=a|0;var b=0;b=v[a>>2];return(ob[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function Tz(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Tn(a){var b=0;b=a;a=v[a>>2];v[b>>2]=B(a,214013)+2531011;return a>>>16&32767}function RF(a,b){a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=Ci(b)}return a}function Jj(a,b,c){var d=0;d=v[a>>2];if(!lp(d,v[b>>2])){b=lp(v[c>>2],d)?c:a}return b}function Hg(a,b,c){var d=0;d=A[a>>3];if(!UP(d,A[b>>3])){b=UP(A[c>>3],d)?c:a}return b}function Fj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;ug(a)}function zp(a){a=a|0;v[a+56>>2]=77976;v[a>>2]=77956;Js(a+4|0);$k(a+56|0);return a|0}function xO(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[jc(a)+4|0]){yO(b+16|0)}Nb(b)}}function sf(a){a=a|0;v[a+60>>2]=78140;v[a>>2]=78120;Js(a+8|0);$k(a+60|0);return a|0}function nT(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[jc(a)+4|0]){KA(b+16|0)}Nb(b)}}function jM(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[jc(a)+4|0]){bc(b+16|0)}Nb(b)}}function Xd(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=49288;io(a,49184,b+12|0);kb=b+16|0}function R0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=hH(a,c,d,b);v[a>>2]=78316;return a|0}function NG(a){return(a|0)!=0&(a|0)!=89968&(a|0)!=89992&(a|0)!=468016&(a|0)!=468040}function J6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return oK(a,b,c,d,0,0,0,0,e)|0}function H8(a,b){a=a|0;b=b|0;return C(b>>>0<=2?C(C(w[(a+b|0)+4232|0])/C(127)):C(0))}function GF(a){a=a|0;v[a>>2]=84328;if(v[a+8>>2]!=(Hd()|0)){MG(v[a+8>>2])}return a|0}function Dg(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function Bl(a,b){var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=Qe(ni(b)*+(c>>>0)),v[d+24>>2]=e}function B9(a,b){a=a|0;b=b|0;return C(b>>>0<=3?C(C(w[(a+b|0)+4264|0])/C(255)):C(0))}function xy(a){var b=0;b=kb-16|0;kb=b;fc(b+8|0,a+116|0);a=PM(a);kb=b+16|0;return a}function t9(a){a=a|0;t[a+4202|0]=1;v[a+4232>>2]=v[v[a+16>>2]+24620>>2];Us(a);sL(a)}function fI(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function ep(a,b,c,d){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<d);return a}function bp(a,b,c,d){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,d);return a}function W7(a){a=a|0;t[a+4202|0]=1;v[a+4256>>2]=v[v[a+16>>2]+24620>>2];OK(a);NK(a)}function NN(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function Gt(a,b){a=Ib(a&65535);b=Ib(b&65535);return(a|0)==(b|0)?0:a>>>0<b>>>0?-1:1}function Cg(a){var b=0;b=kb-16|0;kb=b;a=So(a,b+8|0);kb=b+16|0;return a?v[b+8>>2]:0}function ko(a,b){a=uc(a,b,34);u[a+34>>1]=x[b+34>>1];uc(a+36|0,b+36|0,68);return a}function au(a,b,c){while(1){if(b){u[a>>1]=x[c>>1];b=b-1|0;a=a+2|0;continue}break}}function IL(a,b,c){while(1){if(b){z[a>>2]=z[c>>2];b=b-1|0;a=a+4|0;continue}break}}function $P(a){if((w[a+14|0]-53&255)>>>0>=252){a=Sb(a,15539,14)}else{a=1}return!a}function xk(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;kc(a+8|0,b+8|0)}function xf(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,Zf(a))>>2];kb=b+16|0;return a}function rt(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,Mc(a))>>2];kb=b+16|0;return a}function qK(a,b){var c=0;c=kb-16|0;kb=c;v[c+12>>2]=b;RH(93888,a,b,0,0);kb=c+16|0}function ie(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,Ac(a))>>2];kb=b+16|0;return a}function gha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return hw(a,b,c,d,e,571)|0}function Zf(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,jc(a))>>2];kb=b+16|0;return a}function Pi(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,pd(a))>>2];kb=b+16|0;return a}function Gi(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,Fb(a))>>2];kb=b+16|0;return a}function rD(a,b,c){while(1){if(b){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function qr(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return hw(a,b,c,d,e,169)|0}function qZ(a,b,c){a=a|0;b=b|0;c=c|0;return(v[(c<<2)+83296>>2]&b)!=0&c>>>0<=127}function nY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[a|0](b,c,d,e,f)}function ai(a){return(Qj(v[a>>2],v[a+4>>2])|0)!=(0-Qj(v[a+12>>2],v[a+16>>2])|0)}function Yf(a){var b=0,c=0;Hc(a+4|0);ok(a+8|0,0);b=a,c=jc(a),v[b>>2]=c;return a}function L_(){var a=0,b=0,c=0;a=Vd(469664);v[a>>2]=84328;b=a,c=Hd(),v[b+8>>2]=c}function GU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return hw(a,b,c,d,e,333)|0}function $v(a,b){b=a+b|0;while(1){b=Ab(b-12|0);if((b|0)!=(a|0)){continue}break}}function jo(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function iY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ob[a|0](b,c,d,e)|0}function gy(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[Gb(a)>>2]){HM(a,b);return}kA(a,b)}function gY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ob[v[v[b>>2]+16>>2]](a,b,c,d,1,8)}function f_(a){a=a|0;if(!w[468544]){sn(468532,84564);t[468544]=1}return 468532}function d_(a){a=a|0;if(!w[468576]){sn(468564,84648);t[468576]=1}return 468564}function d2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return FI(a-88|0,b,c,d,e)|0}function b_(a){a=a|0;if(!w[468480]){sn(468468,84492);t[468480]=1}return 468468}function _aa(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[Gb(a)>>2]){HM(a,b);return}kA(a,b)}function Yu(a,b){return Qe(ni((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function TZ(a){a=a|0;if(!w[468528]){Nc(468516,13401);t[468528]=1}return 468516}function NZ(a){a=a|0;if(!w[468496]){Nc(468484,13655);t[468496]=1}return 468484}function CU(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[Gb(a)>>2]){AF(a,b);return}yF(a,b)}function $Z(a){a=a|0;if(!w[468512]){sn(468500,84528);t[468512]=1}return 468500}function pO(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function nA(a){if(gf(w[a+11|0])){xd(v[a>>2],0);Gd(a,0);return}xd(a,0);de(a,0)}function fj(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Nb(b)}function ej(a,b){var c=0;c=a;a=(b>>>0)/100|0;return ks(ks(c,a),B(a,-100)+b|0)}function ZP(a,b){a=pR(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function Wx(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function RZ(a){a=a|0;if(!w[468560]){Nc(468548,9213);t[468560]=1}return 468548}function QY(a,b,c){a=a|0;b=b|0;c=c|0;if(!w[470112]){t[470112]=1}hc(a,c,94340)}function Pn(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function PZ(a){a=a|0;if(!w[468464]){Nc(468452,5268);t[468464]=1}return 468452}function IY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(_g(a,v[b+8>>2],0)){mw(b,c,d)}}function Hl(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;fC(d,a);Nl(d,b);kb=c+16|0}function Ce(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;pv(d,a);Nl(d,b);kb=c+16|0}function $y(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function x4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nn(a,b,c,d,12860,1037)|0}function uG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ob[v[v[a>>2]+32>>2]](a,b,c,d)|0}function qG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ob[v[v[a>>2]+48>>2]](a,b,c,d)|0}function pN(a,b,c){var d=0;return!b|!(w[a+35|0]&4?!a|(c|0)!=1:1)?d:w[b+34|0]}function ae(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];_b(b,c);Iv(a,b,d,c)}function Y7(a,b){a=a|0;b=b|0;return C(b>>>0<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function XY(a,b){a=a|0;b=b|0;a=lm(a);v[a>>2]=93e3;pw(a+4|0,Mc(b));return a|0}function WF(a){var b=0;b=kb-16|0;kb=b;v[b+8>>2]=a;kb=b+16|0;return v[b+8>>2]}function Je(a){var b=0;b=kb-16|0;kb=b;Uu(b+8|0,a);kb=b+16|0;return v[b+8>>2]}function Fb(a){var b=0;b=kb-16|0;kb=b;a=v[fc(b+8|0,a)>>2];kb=b+16|0;return a}function B4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nn(a,b,c,d,12786,1035)|0}function Aj(a){var b=0;b=kb-16|0;kb=b;a=v[Mf(b+8|0,a)>>2];kb=b+16|0;return a}function z4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nn(a,b,c,d,9531,1036)|0}function v4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nn(a,b,c,d,9609,1038)|0}function t4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nn(a,b,c,d,9411,1039)|0}function mZ(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+81744>>2]}return b|0}function mH(a,b,c,d,e,f,g,h){return ob[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function kZ(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+80208>>2]}return b|0}function dL(a){a=a|0;v[a>>2]=46284;wc(a+4276|0);wc(a+4264|0);return Jf(a)|0}function as(a,b,c,d,e,f,g,h){return ob[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function T$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return UE(b,c,d,e,1)|0}function S0(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){jH(a,c);return}Nc(a,7880)}function Rz(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function Q$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return UE(b,c,d,e,0)|0}function Pk(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function PO(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);IO(a,b,0,0,b+-1,0)}function MT(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function J$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return SE(b,c,d,e,1)|0}function H4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nn(a,b,c,d,9380,1032)|0}function G$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return SE(b,c,d,e,0)|0}function zg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function lk(a){var b=0;b=x[a+172>>1];a=x[a+156>>1];return(WP(a)?b:a)&65535}function ks(a,b){b=x[(b<<1)+77104>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function Yg(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function TY(a,b,c){a=a|0;b=b|0;c=c|0;return pc(a,v[b+4>>2])&v[b>>2]==(c|0)}function Ev(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){hj(c,a,d)}return c+d|0}function sl(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function pd(a){var b=0,c=0,d=0;return b=v[a>>2],c=a,d=gf(w[a+11|0]),d?b:c}function nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Jo(a,b),v[d>>2]=e}function mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=kv(a,b),u[d>>1]=e}function ju(a,b,c){b=b-a|0;if((b|0)>0){uc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function hd(a,b){a=TD(a,b);v[a+8>>2]=v[b+8>>2];TD(a+12|0,b+12|0);return a}function dG(a,b){var c=0,d=0;c=fc(a,v[v[b>>2]-12>>2]+b|0),d=b,v[c+4>>2]=d}function cS(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function _c(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function Xk(a,b,c){a=a|0;b=b|0;c=c|0;return ob[v[v[a>>2]+12>>2]](a,b,c)|0}function U8(a,b){a=a|0;b=b|0;a=v[a+20>>2];t[a+24|0]=w[a+24|0]&253|(b?2:0)}function Qm(a,b,c){a=a|0;b=b|0;c=c|0;return ob[v[v[a>>2]+48>>2]](a,b,c)|0}function Qb(a,b,c){a=a|0;b=b|0;c=c|0;return ob[v[v[a>>2]+32>>2]](a,b,c)|0}function JD(a,b){a=Dg(a,b);v[a+8>>2]=v[b+8>>2];Dg(a+12|0,b+12|0);return a}function Qia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;DE(a,b,c,d,e,113)}
function Kw(a,b){var c=0;c=Ns(a+4|0);v[a>>2]=78768;v[c>>2]=78788;Kn(c,b)}function KD(a,b){a=a|0;b=b|0;a=lm(a);v[a>>2]=93e3;pw(a+4|0,b);return a|0}function Jw(a,b){var c=0;c=bH(a+4|0);v[a>>2]=79136;v[c>>2]=79156;Kn(c,b)}function HH(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Yg(a,-1,-1)}function $l(a,b){t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function yl(a){if(gf(w[a+11|0])){a=vu(v[a+8>>2])-1|0}else{a=10}return a}function yB(a,b,c){var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function wc(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];Vh(a);Nb(b)}return a}function vfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;DE(a,b,c,d,e,139)}function rc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=yg(b),v[c+4>>2]=d;return a}function jp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function ex(a){return((wh(a)+(wh(a)<<8)|0)+(wh(a)<<16)|0)+(wh(a)<<24)|0}function aP(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function ZK(a){a=a|0;return C(C(C(z[Eb(a+4208|0,5)>>2]*C(198))+C(-99)))}function Xf(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];Br(a);Nb(b)}return a}function XU(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function Vc(a){var b=0;if(v[a>>2]){uC(a,v[a>>2]);b=v[a>>2];vC(a);Nb(b)}}function VO(a){if(a>>>0<=8){return w[a+29184|0]}return w[a+29175|0]|256}function OI(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function JQ(a){var b=0;if(v[a>>2]){GQ(a,v[a>>2]);b=v[a>>2];Wj(a);Nb(b)}}function pl(a,b){a=w[Lb(a+62|0,b)|0];return(a<<24>>24>=0?a&127:-1)&255}function nw(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function ir(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function fy(a,b){if(b){fy(a,v[b>>2]);fy(a,v[b+4>>2]);bc(b+16|0);Nb(b)}}function cz(a,b){if(b){cz(a,v[b>>2]);cz(a,v[b+4>>2]);xm(b+16|0);Nb(b)}}function ZV(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){va();L()}}function Xp(a,b){if(b){Xp(a,v[b>>2]);Xp(a,v[b+4>>2]);yO(b+16|0);Nb(b)}}function UR(a){if(Sb(a,13769,4)){a=1}else{a=Sb(a+8|0,13822,4)}return!a}function Tk(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function My(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function Mg(){var a=0;a=nm(ba(4)|0);v[a>>2]=92884;ha(a|0,92960,26);L()}function LA(a,b){if(b){LA(a,v[b>>2]);LA(a,v[b+4>>2]);KA(b+16|0);Nb(b)}}function JA(a,b){if(b){JA(a,v[b>>2]);JA(a,v[b+4>>2]);KA(b+16|0);Nb(b)}}function It(a,b){a=a&255;b=b&255;return(a|0)==(b|0)?0:a>>>0<b>>>0?-1:1}function Bz(a,b){a=Tb(a);Mb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function rw(a){a=a|0;if(v[a+8>>2]!=(Hd()|0)){MG(v[a+8>>2])}return a|0}function qY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ob[a|0](b,c,d,e)}function mM(a,b,c,d){if((b|0)==(d|0)){a=bN(a,b,c,d)}else{a=1}return!a}function lQ(a,b,c,d,e){a=fc(a,b);fc(a+4|0,c);fc(a+8|0,d);fc(a+12|0,e)}function SJ(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Hn(c+120|0);Nb(c)}}function Qc(a,b,c,d){if((b|0)==(d|0)){a=kT(a,b,c,d)}else{a=1}return!a}function NM(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function BY(a){a=a|0;if(!a){return 0}return(Ky(a,92556,92700)|0)!=0|0}function m0(a){a=a|0;var b=0;b=v[117080]+1|0;v[117080]=b;v[a+4>>2]=b}function jY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ob[a|0](b,c,d)|0}function dm(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function XP(a,b){a=Xz(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function S_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;yh(a,f)}function MS(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];kc(a+8|0,b+8|0)}function Lu(a,b){var c=0;c=kb-16|0;kb=c;VC(c,a,64);ZC(c,b);kb=c+16|0}function KB(a,b){var c=0;c=kb-16|0;kb=c;VC(c,a,32);ZC(c,b);kb=c+16|0}function y4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $E(a,b,c,d,2)|0}function w4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _E(a,b,c,d,4)|0}function u4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _E(a,b,c,d,2)|0}function sN(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|64}function jE(a,b){return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function Zq(a,b){return nv(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function WS(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function VB(a,b){return Ar(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function Pc(a,b,c){if(vc(a,b)>>>0<=c>>>0){gv();L()}return(c<<2)+a|0}function GM(a,b){var c=0;c=kb-16|0;kb=c;aA(c,1,b);Fc(a,c);kb=c+16|0}function A4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $E(a,b,c,d,4)|0}function uP(a,b){var c=0,d=0;c=fc(a,v[b>>2]),d=w[b+4|0],t[c+4|0]=d}function nF(a,b,c,d){b=Qa(961,a|0,b|0,c|0,d|0)|0;nb=O()|0;return b}function hZ(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function VL(a,b){if((a|0)!=(b|0)){AS(a,v[b>>2],v[b+4>>2])}return a}function TF(a,b,c){a:{if((a|0)==(b|0)){t[b+120|0]=0;break a}Nb(b)}}function Saa(a,b){a=a|0;b=b|0;if(!v[23588]){v[23589]=b;v[23588]=a}}function xS(a,b,c,d){a=ke(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function tr(a,b){a=a|0;b=b|0;return ob[v[v[a>>2]+32>>2]](a,0,b)|0}function qn(a,b){if(y[a+4>>2]<y[Gb(a)>>2]){AF(a,b);return}yF(a,b)}function pJ(a,b,c){a=a|0;b=b|0;c=c|0;return lJ(a,b,Mc(c),Hb(c))|0}function mh(a,b,c){a=fc(a,b);OT(a+4|0,v[c>>2],v[c+4>>2]);return a}function j7(a,b,c){a=a|0;b=b|0;c=c|0;return Ui(a,b,c,931,86224)|0}function eX(a){a=a|0;a=v[a+4>>2];return ob[v[v[a>>2]+12>>2]](a)|0}function dX(a){a=a|0;a=v[a+4>>2];return ob[v[v[a>>2]+16>>2]](a)|0}function YH(a,b){a=WH(a-1|0);if(!a){a=WH(b);a=a?a+32|0:0}return a}function Sm(a,b){v[a>>2]=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];return a}function Mc(a){var b=0,c=0,d=0;return b=v[a>>2],c=a,d=ff(a),d?b:c}function MI(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function Gj(a,b){if(rg(v[a>>2],v[a+4>>2])>>>0>b>>>0){t[a+16|0]=b}}function r7(a,b,c){a=a|0;b=b|0;c=c|0;return Ui(a,b,c,930,4276)|0}function q9(a,b,c){a=a|0;b=b|0;c=c|0;return Ui(a,b,c,904,4304)|0}function q8(a,b,c){a=a|0;b=b|0;c=c|0;return Ui(a,b,c,923,4280)|0}function kd(a){a=(a|0)<32767?a:32767;return(a|0)>-32768?a:-32768}function jq(a,b,c){a=Ib(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function h8(a,b,c){a=a|0;b=b|0;c=c|0;return Ui(a,b,c,924,4276)|0}function fX(a){a=a|0;a=v[a+4>>2];return ob[v[v[a>>2]+8>>2]](a)|0}function a8(a,b,c){a=a|0;b=b|0;c=c|0;return Ui(a,b,c,925,4268)|0}function Uja(a,b){a=a|0;b=b|0;a=zu(a,b);v[a>>2]=93156;return a|0}function Tia(a,b){a=a|0;b=b|0;a=zu(a,b);v[a>>2]=93208;return a|0}function QD(a,b,c){a=en(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=62268}function M7(a,b,c){a=a|0;b=b|0;c=c|0;return Ui(a,b,c,927,4228)|0}function K8(a,b,c){a=a|0;b=b|0;c=c|0;return Ui(a,b,c,920,4236)|0}function GK(a){return C(C(z[Eb(a+4208|0,11)>>2]*C(19980))+C(20))}function G9(a,b,c){a=a|0;b=b|0;c=c|0;return Ui(a,b,c,896,4268)|0}function Cy(a){Ab(a+48|0);Ab(a+36|0);Ab(a+24|0);Ab(a+12|0);Ab(a)}function C7(a,b,c){a=a|0;b=b|0;c=c|0;return Ui(a,b,c,928,5048)|0}function Ar(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function zz(a){var b=0;if(v[a>>2]){iP(a);b=v[a>>2];lo(a);Nb(b)}}function xQ(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];Bv(a);Nb(b)}}function vk(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];Du(a);Nb(b)}}function tC(a){if(a>>>0>=214748365){Mg();L()}return tc(B(a,20))}function sZ(a){a=a|0;a=v[a+8>>2];if(!a){return 1}return EF(a)|0}function re(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];hn(a);Nb(b)}}function od(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];Ym(a);Nb(b)}}function nv(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function nO(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];ez(a);Nb(b)}}function mo(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];TS(a);Nb(b)}}function hja(a,b){a=a|0;b=b|0;a=LT(a,b);if(!a){KT(b)}return a|0}function dE(a){if(a>>>0>=357913942){Mg();L()}return tc(B(a,12))}function _M(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];PU(a);Nb(b)}}function _6(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function Zd(a){var b=0;if(v[a>>2]){sV(a);b=v[a>>2];IB(a);Nb(b)}}function WO(a,b){a=a|0;b=b|0;a=zu(a,b);v[a>>2]=93020;return a|0}function UH(a){var b=0;b=kb-16|0;z[b+12>>2]=a;return z[b+12>>2]}function Rt(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];Gb(a);Nb(b)}}function Rs(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];Sx(a);Nb(b)}}function Rn(a,b,c,d){a=It(a,c);if(xj(a)){a=vO(b,d)}return gf(a)}function RM(a){var b=0;if(v[a>>2]){et(a);b=v[a>>2];dt(a);Nb(b)}}function Pt(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];Sz(a);Nb(b)}}function Mba(a,b){a=a|0;b=b|0;a=RS(a,b);if(!a){QS(b)}return a|0}function Kl(a,b){a=a|0;b=b|0;return ob[v[v[a>>2]+28>>2]](a,b)|0}function KM(a){var b=0;if(v[a>>2]){Xo(a);b=v[a>>2];Bv(a);Nb(b)}}function Jr(a){var b=0;b=kb-16|0;A[b+8>>3]=a;return A[b+8>>3]*a}function HK(a){return C(C(z[Eb(a+4208|0,0)>>2]*C(1e4))+C(-1e4))}function Gc(a){var b=0;if(ff(a)){b=v[a>>2];Ll(a);Nb(b)}return a}function FQ(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];Wj(a);Nb(b)}}function FO(a){var b=0;if(v[a>>2]){AO(a);b=v[a>>2];Wj(a);Nb(b)}}function Ei(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];lo(a);Nb(b)}}function Ee(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Vs(b)}return a}function Dp(a,b,c){if(!b){return 0}return Ws(a,zf(c<<24>>24),b)}function Cm(a){var b=0;if(v[a>>2]){Lc(a);b=v[a>>2];Nt(a);Nb(b)}}function Bw(a,b){a=a|0;b=b|0;return ob[v[v[a>>2]+12>>2]](a,b)|0}function $r(a,b){a=a|0;b=b|0;return ob[v[v[a>>2]+44>>2]](a,b)|0}function xv(a,b){a=a|0;b=b|0;a=mD(a,b);if(!a){gr(b)}return a|0}function wM(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function wA(a,b){a=a|0;b=b|0;a=So(a,b);if(!a){Om(b)}return a|0}function vo(a,b){a=a|0;b=b|0;a=IU(a,b);if(!a){LU(b)}return a|0}function ur(a,b){a=a|0;b=b|0;a=uD(a,b);if(!a){Nv(b)}return a|0}function rV(a,b){if(!b){return-1}b=Dp(a,b,0);return b?b-a|0:-1}function j$(a,b){a=a|0;b=b|0;qN(a,Tw(v[b>>2])<<24>>24,v[b>>2])}function iO(a,b){a=a|0;b=b|0;a=YU(a,b);if(!a){Eu(b)}return a|0}function fg(a,b){return ob[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function fT(a){if(a>>>0>=715827883){Mg();L()}return tc(B(a,6))}function dr(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function di(a,b){a=a|0;b=b|0;a=Ih(a,b);if(!a){Tj(b)}return a|0}function cc(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function cR(a){return w[a+15|0]<<12|w[a+14|0]<<4|w[a+13|0]<<20}function br(a,b,c){a=a|0;b=b|0;c=c|0;Uh(a,b,xi(b,b+c|0,62364))}function _B(a,b){a=a|0;b=b|0;a=Nu(a,b);if(!a){Su(b)}return a|0}function Zt(a,b){a=a|0;b=b|0;a=JU(a,b);if(!a){Cu(b)}return a|0}function XK(a){a=a|0;return kk(C(z[Eb(a+4208|0,4)>>2]*C(4)))|0}function SL(a){if(a>>>0>=82595525){Mg();L()}return tc(B(a,52))}function SA(a,b){a=a|0;b=b|0;a=cT(a,b);if(!a){FA(b)}return a|0}function P3(a,b,c){a=a|0;b=b|0;c=c|0;CP(a,0,v[b+1298404>>2],c)}function Jv(a,b){a=a|0;b=b|0;a=BD(a,b);if(!a){AD(b)}return a|0}function Av(a,b){a=ad(a,b);kc(a+12|0,b+12|0);eg(a+32|0,b+32|0)}function zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;FE(a,b,c,d,462)}function vh(a,b,c){return(v[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function rk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){jc(a);Nb(b)}}function qka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;IE(a,b,c,d,139)}function cJ(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function V7(a,b,c){a=a|0;b=b|0;c=c|0;return jw(a,b,c,0,926)|0}function UD(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Nb(ic(c))}}function SM(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Nb(zj(c))}}function Ql(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){cn(c)}return a}function N7(a,b,c){a=a|0;b=b|0;c=c|0;return jw(a,b,c,1,926)|0}function Ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;FE(a,b,c,d,355)}function Fg(a,b,c,d,e,f){return Sa(a|0,b|0,c|0,d|0,e|0,f|0)|0}function Ci(a){if(a>>>0>=1073741824){Mg();L()}return tc(a<<2)}function CM(a,b){return b>>>0<4e3?((b<<5)+a|0)+946304|0:21619}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;IE(a,b,c,d,113)}function A8(a,b,c){a=a|0;b=b|0;c=c|0;return jw(a,b,c,0,922)|0}function r8(a){a=a|0;return C(C(z[Eb(a+4208|0,6)>>2]*C(20)))}function qc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function ly(a,b){var c=0;c=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=c}function eba(a){a=a|0;a=zu(a,21619);v[a>>2]=93100;return a|0}function eQ(a){if(a>>>0>=268435456){Mg();L()}return tc(a<<4)}function aQ(a){if(a>>>0>=134217728){Mg();L()}return tc(a<<5)}function YW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gc(a,v[d>>2],0)}function YK(a){a=a|0;return C(C(z[Eb(a+4208|0,2)>>2]*C(10)))}function WM(a){v[a>>2]=0;Tb(a+4|0);Ub(a+16|0,0,144);return a}function WH(a){return t[(B(0-a&a,124511785)>>>27|0)+73744|0]}function Tg(a,b,c,d){nb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function QI(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function Nx(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function Js(a){a=a|0;v[a>>2]=77440;zb(a+32|0);return Ln(a)|0}function CD(a){if(a>>>0>=536870912){Mg();L()}return tc(a<<3)}function $8(a){a=a|0;a=lj(a);if(a){ob[v[v[a>>2]+100>>2]](a)}}function zu(a,b){a=lm(a);v[a>>2]=92980;pw(a+4|0,b);return a}function z5(a,b){a=a|0;b=b|0;return C(dF(a,b,6177,1075835))}function y5(a,b){a=a|0;b=b|0;return C(eF(a,b,6133,1075835))}function xI(a,b){a=a|0;b=+b;WE(a,b,1e4,1074420,9323,512,32)}function vS(a){var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b}function vA(a,b){if(b){vA(a,v[b>>2]);vA(a,v[b+4>>2]);Nb(b)}}function ux(a,b,c,d,e,f){return YE(a,b,c,d,e,f,57860,58656)}function tx(a,b,c,d,e,f){return YE(a,b,c,d,e,f,58736,59500)}function pha(a,b,c){a=a|0;b=b|0;c=c|0;return KE(a,b,c,37)|0}function oY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ob[a|0](b,c,d)}function lZ(a,b,c){a=a|0;b=b|0;c=c|0;return QE(b,c,81744)|0}function ki(a,b){var c=0,d=0;c=a,d=KG(b),v[c>>2]=d;return a}function jt(a,b){if(b){jt(a,v[b>>2]);jt(a,v[b+4>>2]);Nb(b)}}function jZ(a,b,c){a=a|0;b=b|0;c=c|0;return QE(b,c,80208)|0}function it(a,b){if(b){it(a,v[b>>2]);it(a,v[b+4>>2]);Nb(b)}}function fV(a){return!Sb(a,14123,4)&(w[a+4|0]-1&255)>>>0<10}function dZ(a,b,c){a=a|0;b=b|0;c=c|0;return PE(b,c,81744)|0}function bl(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Nb(Xf(b))}}function bZ(a,b,c){a=a|0;b=b|0;c=c|0;return PE(b,c,80208)|0}function _A(a,b){if(b){_A(a,v[b>>2]);_A(a,v[b+4>>2]);Nb(b)}}function Pz(a,b){if(b){Pz(a,v[b>>2]);Pz(a,v[b+4>>2]);Nb(b)}}function Oz(a,b){if(b){Oz(a,v[b>>2]);Oz(a,v[b+4>>2]);Nb(b)}}function O7(a){a=a|0;return C(C(z[Eb(a+4208|0,6)>>2]*C(4)))}function ND(a,b){return TA(a,pd(b),zd(v[b+4>>2],w[b+11|0]))}function Mn(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function LH(a,b){if(b>>>0<=9){return KH(a,b)}return ks(a,b)}function KW(a){a=a|0;a=LD(a,13238);v[a>>2]=26076;return a|0}function Fv(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function FJ(a,b){a=a|0;b=b|0;return Sh(v[b>>2],v[b+4>>2])|0}function Eq(a){return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function EJ(a,b){a=a|0;b=b|0;return $d(v[b>>2],v[b+4>>2])|0}function C5(a,b){a=a|0;b=b|0;return C(eF(a,b,6232,1075834))}function AN(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Nb(Ny(b))}}function A5(a,b){a=a|0;b=b|0;return C(dF(a,b,6275,1075834))}function $A(a,b){if(b){$A(a,v[b>>2]);$A(a,v[b+4>>2]);Nb(b)}}function rX(a){a=a|0;a=LD(a,8664);v[a>>2]=30500;return a|0}function po(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function cy(a,b,c){A[a>>3]=A[a>>3]+b;A[a+8>>3]=A[a+8>>3]+c}function ZX(a){a=a|0;a=WO(a,7916);v[a>>2]=41832;return a|0}function V3(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,lJ(c,0,b,yg(b)))}function P0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb=0;return 0}function N3(a){a=a|0;aK(a,2,100);Gj(v[a+24>>2]+484360|0,0)}function Hb(a){if(ff(a)){return v[a+4>>2]}return w[a+11|0]}function HR(a){var b=0;a=a+8|0;b=a>>>0<8?1:b;nb=b;return a}function Bq(a,b,c){if((a|0)!=(b|0)){b=b-a|0;hj(c-b|0,a,b)}}function Bn(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function $Y(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function uE(a,b,c){a=a|0;b=b|0;c=c|0;xu(a,b,c);return a|0}function tq(a,b){if(gf(w[a+11|0])){Gd(a,b);return}de(a,b)}function pV(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0];return a}function kia(a,b,c){a=a|0;b=b|0;c=c|0;Uh(a,b,fd(b,c)+b|0)}function kI(a){while(1){if((qs(a)|0)!=-1){continue}break}}function jx(a,b){return v[((a>>>24^b)<<2)+463232>>2]^a<<8}function ho(a){v[a>>2]=0;v[a+4>>2]=0;ok(a+8|0,0);return a}function Uo(a){a=RD(a);v[a+8>>2]=0;v[a>>2]=89892;return a}function Uf(a){var b=0;fQ(a);b=v[a>>2];if(b){Kz(a);Nb(b)}}function UF(a){if(v[a>>2]){Lc(a);TF(sw(a),v[a>>2],Vh(a))}}function RJ(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Vs(c)}}function Qp(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function Pw(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function NI(a,b){a=a|0;b=+b;WE(a,b,256,1074456,11672,1,0)}function Ic(a,b){return LE(a,b,2147483647,-2147483648,-1)}function HA(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Nb(c)}}function wN(a,b){a=vN(a,b);vN(a+12|0,b+12|0);t[a+24|0]=1}function uh(a,b,c){t[a|0]=w[a|0]|b;v[a+4>>2]=v[a+4>>2]|c}function tX(a,b,c){a=a|0;b=b|0;c=c|0;Iv(a,b,v[b+8>>2],c)}function pB(a,b){t[v[a>>2]]=w[b|0];t[v[a+4>>2]]=w[b+1|0]}function nz(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function n5(a,b){a=a|0;b=b|0;return on(a,b,11702,1013)|0}function l5(a,b){a=a|0;b=b|0;return jF(a,b,13210,1014)|0}function gj(a){return $e(a)|$e(a)<<8|$e(a)<<16|$e(a)<<24}function gK(a,b){cn(v[b>>2]);gn(v[a>>2]);v[a>>2]=v[b>>2]}function du(a){wc(a+88|0);wc(a+68|0);wc(a+48|0);return a}function a5(a,b){a=a|0;b=b|0;return on(a,b,11737,1021)|0}function Z4(a,b){a=a|0;b=b|0;return on(a,b,11767,1023)|0}function R4(a,b){a=a|0;b=b|0;return on(a,b,11863,1026)|0}function R1(a,b,c){a=a|0;b=b|0;c=c|0;return Pd(B(b,c))|0}function Om(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function OF(a){a=a|0;v[a>>2]=84416;zb(a+16|0);return a|0}function O4(a,b){a=a|0;b=b|0;return on(a,b,11831,1027)|0}function NF(a){a=a|0;v[a>>2]=84376;zb(a+12|0);return a|0}function Mt(a,b){qc(a,b);qc(a+4|0,b+4|0);qc(Gb(a),Gb(b))}function Ji(a,b){var c=0;c=w[a|0];t[a|0]=w[b|0];t[b|0]=c}function GH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Yg(a,-1,-1)}function G5(a,b){a=a|0;b=b|0;return on(a,b,11799,1006)|0}function $I(a){a=a|0;v[a>>2]=61612;ic(a+12|0);return a|0}function zU(a){a=a|0;v[a>>2]=92980;tF(a+4|0);return a|0}function ys(a){a=a|0;v[a>>2]=49332;vx(a+4|0);return a|0}function vI(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function tF(a){a=px(v[a>>2]);if((Fv(a+8|0)|0)<0){Nb(a)}}function t8(a){a=a|0;return z[Eb(a+4208|0,3)>>2]<C(1)|0}function lF(a,b,c,d,e){return Ja(a|0,b|0,c|0,d|0,e|0)|0}function io(a,b,c){v[a>>2]=b;v[a+4>>2]=v[c>>2];return a}function gB(a){a=a&255;return $c(a)^1|(a-49&255)>>>0<36}function es(a){a=a|0;v[a>>2]=77376;ac(a+4|0);return a|0}function eJ(a){a=a|0;v[a>>2]=62076;ic(a+4|0);return a|0}function cM(a){return(a|0)==1179012417|(a|0)==538987841}function bd(a){if(ff(a)){a=Ll(a)-1|0}else{a=10}return a}function Wo(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function Tb(a){v[a>>2]=0;v[a+4>>2]=0;Hc(a+8|0);return a}function SF(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){gn(b)}}function Q7(a){a=a|0;return z[Eb(a+4208|0,1)>>2]<C(1)|0}function Ln(a){a=a|0;v[a>>2]=77312;ac(a+4|0);return a|0}function HD(a){a=a|0;v[a>>2]=43104;me(a+4|0);return a|0}function Fba(a,b,c){a=a|0;b=b|0;c=c|0;wE(a,b,c,796,795)}function F7(a){a=a|0;MK(a);t[a+4202|0]=1;v[a+4224>>2]=0}function EG(a,b,c){a=fc(a,b);fc(a+4|0,v[c>>2]);return a}function Dd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function Aaa(a,b,c){a=a|0;b=b|0;c=c|0;wE(a,b,c,867,866)}function xH(a){a=a|0;return fs(v[v[a>>2]-12>>2]+a|0)|0}function wh(a){var b=0;b=qs(a);v[a+1396>>2]=0;return b}function vO(a,b){return(a|0)==(b|0)?0:a>>>0<b>>>0?-1:1}function un(a){if(ff(a)){a=Ll(a)-1|0}else{a=1}return a}function u0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Uh(a,c,d)}function tp(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function ria(a,b){a=a|0;b=b|0;Vl(a,b,101,1042,-1332,2)}function rY(a){a=a|0;a=ob[a|0]()|0;ra(nb|0);return a|0}function r0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;HG(a,c,d)}function oea(a,b){a=a|0;b=b|0;if(!FR(a,b)){Ub(b,0,40)}}function mx(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function mF(a,b,c,d,e,f){Oa(a|0,b|0,c|0,d|0,e|0,f|0,1)}function jia(a,b){a=a|0;b=b|0;return Nc(a,b?b:21619)|0}function gM(a,b){return B(b&65535,a&65535)+7>>>3&65535}function em(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function ch(a,b){a=a|0;b=b|0;ob[v[v[b>>2]+20>>2]](a,b)}function c$(a,b){a=a|0;b=b|0;hc(a,oH(v[b>>2]),v[b>>2])}function _L(a,b){return(b>>>0<=15?t[a+b|0]:63)<<24>>24}function ZL(a,b){return(b>>>0<=45?t[a+b|0]:63)<<24>>24}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function X0(a){a=a|0;return zp(v[v[a>>2]-12>>2]+a|0)|0}function V0(a){a=a|0;return sf(v[v[a>>2]-12>>2]+a|0)|0}function Pia(a,b){a=a|0;b=b|0;Vl(a,b,405,1042,-1332,2)}function Ph(a,b){a=a|0;b=b|0;ob[v[v[b>>2]+24>>2]](a,b)}function Oh(a,b){a=a|0;b=b|0;ob[v[v[b>>2]+28>>2]](a,b)}function Hv(a){a=a|0;v[a>>2]=93e3;tF(a+4|0);return a|0}function H6(a,b){a=a|0;b=b|0;return jF(a,b,6435,954)|0}function DH(a){a=a|0;return gs(v[v[a>>2]-12>>2]+a|0)|0}function Afa(a,b){a=a|0;b=b|0;Vl(a,b,259,1042,-1332,2)}function z0(a,b){a=a|0;b=b|0;Vl(a,b,101,1025,-1284,4)}function yc(a,b){a=a|0;b=b|0;PD(a,b,pr(b));return a|0}function xn(a,b){return ob[v[v[a>>2]+36>>2]](a,b,0)|0}function wB(a,b){a=ke(a,b);Ub(a+20|0,0,1040);return a}function w0(a,b){a=a|0;b=b|0;Vl(a,b,101,1025,-1284,2)}function vn(a,b){return ob[v[v[a>>2]+52>>2]](a,b,0)|0}function s9(a,b,c){a=a|0;b=b|0;c=c|0;hc(a,b+4260|0,8)}function rr(a,b){a=kc(a,b);Ub(a+20|0,0,1040);return a}function rha(a,b,c){a=a|0;b=b|0;c=c|0;AS(a,b,Eb(b,c))}function qf(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function lha(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,pJ(c,0,b))}function lL(a){wc(a+36|0);wc(a+24|0);Rs(a+12|0);Rs(a)}function ic(a){if(v[a>>2]){Lc(a);Nb(v[a>>2])}return a}function d3(a,b){a=a|0;b=b|0;hO(v[a>>2],b);return a|0}function bj(a){a=a|0;return ob[v[v[a>>2]+16>>2]](a)|0}function aj(a){a=a|0;return ob[v[v[a>>2]+12>>2]](a)|0}function Wg(a){a=a|0;return ob[v[v[a>>2]+24>>2]](a)|0}function TV(a,b){a=a|0;b=b|0;Vl(a,b,259,1025,-1284,2)}function Qf(a,b,c,d){b=b+d|0;nb=a+c>>>0<c>>>0?b+1|0:b}function Ny(a){Tp(a+223860|0);ic(a+223848|0);return a}function Nc(a,b){a=a|0;b=b|0;xu(a,b,yg(b));return a|0}function Dv(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){cn(c)}}function CG(a,b,c){a=IG(a,b,c,0,-2147483648);return a}function C8(a,b,c){a=a|0;b=b|0;c=c|0;hc(a,b+4228|0,7)}function Ab(a){if(gf(w[a+11|0])){Nb(v[a>>2])}return a}function yga(a,b,c){a=a|0;b=b|0;c=c|0;CE(a,b,c,14,2)}function xD(a,b,c,d){return cp(a,b,c,d,36,119304648)}function wv(a){a=a|0;return ob[v[v[a>>2]+8>>2]](a)|0}function tL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function oE(a,b,c,d){return cp(a,b,c,d,24,178956971)}function mV(a,b,c,d){return cp(a,b,c,d,28,153391690)}function gD(a,b){return(w[b+34|0]&8)>>>3&(a&2050)==2}function ee(a,b,c){t[a|0]=b;t[a+1|0]=w[c|0];return a}function dY(a,b){a=a|0;b=b|0;Vl(a,b,12,1058,-1332,2)}function Z8(a){a=a|0;t[a+4202|0]=1;Ss(a);Mx(a);mL(a)}function SU(a,b,c,d){return cp(a,b,c,d,40,107374183)}function Nka(a){if(a){return 31-E(a-1^a)|0}return 32}function Ez(a){a=Tb(a);v[a+12>>2]=0;u[a+16>>1]=65280}function Cq(a,b,c,d,e){hc(a,b+d|0,(e|0)==-1?c-d|0:e)}function $s(a){a=a|0;a=Jh(a);v[a+20>>2]=0;return a|0}function xp(a,b){b=v[b>>2];v[a>>2]=b;cn(b);return a}function wj(a){if(!a){return 0}return v[a+44>>2]!=0}function tn(a,b,c){v[a>>2]=b;v[a+4>>2]=c-b;return a}function s8(a){a=a|0;return C(z[Eb(a+4208|0,1)>>2])}function qj(a){if(!a){return 0}return vj(w[a+31|0])}function p_(){Vd(469896);QF(469904);v[117474]=87264}function oha(a,b,c){a=a|0;b=b|0;c=c|0;HE(a,b,c,256)}function n_(){Vd(469912);QF(469920);v[117478]=87420}function mga(a,b){a=a|0;b=b|0;return ei(a,b,1030)|0}function mO(a,b,c,d){return cp(a,b,c,d,7,613566757)}function is(a,b){v[a>>2]=b;v[a+4>>2]=b>>31;return a}function iia(a){a=a|0;zj(94384);zj(94376);zb(94364)}function h2(a,b,c){a=a|0;b=b|0;c=c|0;JI(a-88|0,b,c)}function fD(a){return VH(a,C(2524354896707238e-44))}function f2(a,b,c){a=a|0;b=b|0;c=c|0;HI(a-88|0,b,c)}function dga(a,b){a=a|0;b=b|0;return Hr(a,b,1100)|0}function ce(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function bx(a){if(!a){return 0}v[116064]=a;return-1}function _K(a){a=a|0;return C(z[Eb(a+4208|0,0)>>2])}function We(a){var b=0;b=v[a>>2];if(b){Gb(a);Nb(b)}}function W3(a){a=a|0;a=v[a+4>>2];return(a?a:5014)|0}function VC(a,b,c){t[a+8|0]=1;v[a+4>>2]=c;v[a>>2]=b}function To(a){a=a|0;a=Cc(a);ob[v[v[a>>2]>>2]](a)|0}function Pv(a,b){a=a|0;b=b|0;return TA(a,b,pr(b))|0}function P7(a){a=a|0;return C(z[Eb(a+4208|0,3)>>2])}function Oga(a,b,c){a=a|0;b=b|0;c=c|0;CE(a,b,c,5,3)}function NO(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function Mz(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function Mp(a,b,c){if(!c){return 0}return Sb(a,b,c)}function Mo(a,b,c){hc(a,(c>>>3&536870908)+b|0,c&31)}function Kka(a,b){a=a|0;b=b|0;aw(a,b,259,274,-1332)}function GD(a){return VH(a,C(15845632502852868e13))}function Eea(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,Pv(b,c))}function Db(a,b,c){hc(a,(c>>>3&536870908)+b|0,1<<c)}function $C(a){if((a|0)<0){Mg();L()}return tc(a<<1)}function xka(a,b,c){a=a|0;b=b|0;c=c|0;Fr(a,b,c,80)}function xaa(a,b){a=a|0;b=b|0;return ei(a,b,225)|0}function um(a){pj(a+724|0);pj(a+732|0);pj(a+740|0)}function uaa(a,b){a=a|0;b=b|0;return ei(a,b,326)|0}function j2(a,b,c){a=a|0;b=b|0;c=+c;LI(a-88|0,b,c)}function h1(a,b){a=a|0;b=b|0;return dp(a,b,1103)|0}function gE(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,ND(b,c))}function g2(a,b){a=a|0;b=b|0;return II(a-88|0,b)|0}function fja(a,b){a=a|0;b=b|0;return ei(a,b,308)|0}function fha(a,b){a=a|0;b=b|0;return ei(a,b,422)|0}function e2(a,b){a=a|0;b=b|0;return GI(a-88|0,b)|0}function e1(a,b){a=a|0;b=b|0;return dp(a,b,1101)|0}function b1(a,b){a=a|0;b=b|0;return dp(a,b,1102)|0}function aha(a,b){a=a|0;b=b|0;return ei(a,b,826)|0}function Y1(a,b,c){a=a|0;b=b|0;c=+c;BI(a-92|0,b,c)}function W1(a,b,c){a=a|0;b=b|0;c=+c;zI(a-92|0,b,c)}function Oia(a,b,c){a=a|0;b=b|0;c=c|0;Dr(a,b,c,85)}function Lga(a,b,c){a=a|0;b=b|0;c=c|0;Fr(a,b,c,79)}function Kga(a,b,c){a=a|0;b=b|0;c=c|0;Fr(a,b,c,78)}function G3(a,b){a=a|0;b=b|0;return dp(a,b,1098)|0}function F1(a,b){a=a|0;b=b|0;return dp(a,b,1099)|0}function Ek(a,b){return(a&65535)>>>0<(b&65535)>>>0}function Cl(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function BS(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,oF(b,c))}function $n(a,b,c){if((a|0)!=(b|0)){hj(c,a,b-a|0)}}function zaa(a,b){a=a|0;b=b|0;return ei(a,b,73)|0}function z2(a,b,c){a=a|0;b=b|0;c=c|0;Fr(a,b,c,74)}function ym(a,b,c){v[a+4>>2]=c;u[a>>1]=b;return a}function vga(a,b){a=a|0;b=b|0;if(!Nu(a,b)){Su(b)}}function vC(a){return(v[Gb(a)>>2]-v[a>>2]|0)/20|0}function v7(a,b){a=a|0;b=b|0;return C(Wl(a,b,12))}function v2(a,b,c){a=a|0;b=b|0;c=c|0;zE(a,b,c,72)}function saa(a,b){a=a|0;b=b|0;return ei(a,b,60)|0}function s5(a){a=a|0;return iw(a,12717,1074416)|0}function rR(a){return(v[Gb(a)>>2]-v[a>>2]|0)/56|0}function rF(a){return(a<<1)+16777216>>>0<16777217}function ol(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function n0(a,b,c){a=a|0;b=b|0;c=c|0;Dr(a,b,c,86)}function mja(a,b){a=a|0;b=b|0;if(!LT(a,b)){KT(b)}}function lja(a,b){a=a|0;b=b|0;return ei(a,b,78)|0}function hka(a,b){a=a|0;b=b|0;if(!YU(a,b)){Eu(b)}}function hc(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function eY(a,b){a=a|0;b=b|0;aw(a,b,12,290,-1332)}function dt(a){return(v[Gb(a)>>2]-v[a>>2]|0)/52|0}function dM(a,b){return(a|0)==1179011410&b>>>0>80}function _2(a,b,c){a=a|0;b=b|0;c=c|0;zE(a,b,c,61)}function Zr(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function XG(a){return(ak(a)|0)!=0|(a|32)-97>>>0<6}function Wj(a){return(v[Gb(a)>>2]-v[a>>2]|0)/12|0}function Vp(a,b){v[a+4>>2]=256;v[a>>2]=b;return a}function Vfa(a,b){a=a|0;b=b|0;return ei(a,b,71)|0}function TS(a){return(v[Gb(a)>>2]-v[a>>2]|0)/33|0}function Rh(a,b){if(ff(a)){Gd(a,b);return}de(a,b)}function RD(a){v[a+4>>2]=0;v[a>>2]=92452;return a}function PU(a){return(v[Gb(a)>>2]-v[a>>2]|0)/40|0}function OV(a,b,c){a=a|0;b=b|0;c=c|0;Dr(a,b,c,81)}function N1(a,b,c){a=a|0;b=b|0;c=c|0;yE(a,b,c,72)}function M2(a,b,c){a=a|0;b=b|0;c=c|0;yE(a,b,c,61)}function LD(a,b){a=KD(a,b);v[a>>2]=93260;return a}function L1(a,b,c){a=a|0;b=b|0;c=c|0;xE(a,b,c,72)}function JX(a,b){a=a|0;b=b|0;aw(a,b,12,257,-1284)}function JW(a,b,c){a=a|0;b=b|0;c=c|0;Dr(a,b,c,87)}function JC(a){return!Sb(a,26160,25)&w[a+34|0]<65}function Iha(a,b){a=a|0;b=b|0;return ei(a,b,91)|0}function IB(a){return(v[Gb(a)>>2]-v[a>>2]|0)/28|0}function Faa(a,b){a=a|0;b=b|0;if(!uD(a,b)){Nv(b)}}function Dha(a,b){a=a|0;b=b|0;if(!RS(a,b)){QS(b)}}function DT(a){if(!(a&255)){return 1}return $c(a)}function Bv(a){return(v[Gb(a)>>2]-v[a>>2]|0)/36|0}function Br(a){return(v[Gb(a)>>2]-v[a>>2]|0)/24|0}function B2(a,b,c){a=a|0;b=b|0;c=c|0;xE(a,b,c,61)}function yx(a,b){v[a>>2]=v[b>>2];ad(a+4|0,b+4|0)}function xo(a,b){a=a|0;b=b|0;if(!Ih(a,b)){Tj(b)}}function x8(a,b){a=a|0;b=b|0;return C(Wl(a,b,6))}function w5(a){a=a|0;return cF(a,8756,1074448)|0}function vJ(a,b){a=a|0;b=b|0;Nk(a,b,58696,58704)}function uka(a,b){a=a|0;b=b|0;return Ju(a,1,b)|0}function uJ(a,b){a=a|0;b=b|0;Nk(a,b,58712,58720)}function tz(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function t5(a){a=a|0;return iw(a,5322,1074424)|0}function rL(a){a=a|0;ic(a+4208|0);return Jf(a)|0}function qN(a,b,c){v[a+4>>2]=c;t[a|0]=b;return a}function qJ(a,b){a=a|0;b=b|0;Nk(a,b,59516,59524)}function oJ(a,b){a=a|0;b=b|0;Nk(a,b,59532,59540)}function nJ(a,b){a=a|0;b=b|0;Nk(a,b,60344,60352)}function n7(a,b){a=a|0;b=b|0;return C(Wl(a,b,2))}function mP(a,b){v[a>>2]=v[a>>2]+(b<<1);return a}function mJ(a,b){a=a|0;b=b|0;Nk(a,b,60360,60368)}function lU(a,b){v[a>>2]=v[a>>2]+B(b,6);return a}function lT(a,b,c){hc(a,b,xi(b,b+c|0,62364)-b|0)}function k8(a,b){a=a|0;b=b|0;return C(Wl(a,b,5))}function jd(a,b,c,d){return Id(a,B(Qg(b),c)+d|0)}function iJ(a,b){a=a|0;b=b|0;Nk(a,b,61172,61180)}function i2(a,b){a=a|0;b=b|0;return+KI(a-88|0,b)}function hJ(a,b){a=a|0;b=b|0;Nk(a,b,61188,61196)}function fga(a,b){a=a|0;b=b|0;fp(a,b,623,622,8)}
function f7(a,b){a=a|0;b=b|0;return C(Wl(a,b,3))}function ez(a){return(v[Gb(a)>>2]-v[a>>2]|0)/7|0}function eV(a,b){a=OU(a,b);if(!a){EB(b)}return a}function d8(a,b){a=a|0;b=b|0;return C(Wl(a,b,4))}function ZB(a,b){a=a|0;b=b|0;if(!BD(a,b)){AD(b)}}function Xu(a,b){a=a|0;b=b|0;if(!Po(a,b)){Go(b)}}function Xs(a){a=a|0;wc(a+4208|0);return Jf(a)|0}function X1(a,b){a=a|0;b=b|0;return+AI(a-92|0,b)}function Vo(a,b,c){a=fe(a);v[a+4>>2]=c;v[a>>2]=b}function VK(a){a=a|0;wc(a+4256|0);return Jf(a)|0}function V1(a,b){a=a|0;b=b|0;return+yI(a-92|0,b)}function UT(a,b){a=a|0;b=b|0;if(!mD(a,b)){gr(b)}}function KU(a,b){a=a|0;b=b|0;if(!JU(a,b)){Cu(b)}}function H7(a,b){a=a|0;b=b|0;return C(Wl(a,b,1))}function Du(a){return(v[Gb(a)>>2]-v[a>>2]|0)/6|0}function Al(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function AA(a,b){a=a|0;b=b|0;if(!cT(a,b)){FA(b)}}function $g(a,b,c){var d=0;d=a;a=b;tn(d,a,a+c|0)}function $V(a,b){a=a|0;b=b|0;if(!dC(a,b)){Tu(b)}}function zB(a,b,c){if(b){Ub(a,zf(c),b)}return a}function u5(a){a=a|0;return cF(a,7113,480214)|0}function td(a,b){return lp(v[b>>2],v[a>>2])?b:a}function rS(a){var b=0;b=v[a>>2];He(a);return b}function om(a,b){return gu(z[b>>2],z[a>>2])?b:a}function oaa(a,b,c){a=a|0;b=b|0;c=c|0;vL(a,b,c)}function le(a,b){return Ek(x[a>>1],x[b>>1])?b:a}function hu(a,b){a=a|0;b=b|0;return Qb(a,b,1)^1}function aC(a,b){return(b&255)==2&(a&255)>>>0<3}function Zc(a,b){return qo(v[a>>2],v[b>>2])?b:a}function Z3(a){a=a|0;return ZE(a,49080,12441)|0}function Xy(a){if(w[a+24|0]){BN(a);t[a+24|0]=0}}function XS(a){return!Sb(a,13827,4)&w[a+4|0]<32}function Wc(a,b){return Ek(x[b>>1],x[a>>1])?b:a}function S4(a){a=a|0;return iw(a,5819,480272)|0}function Qk(a){return ob[v[v[a>>2]+36>>2]](a)|0}function Qja(a,b){a=a|0;b=b|0;fp(a,b,354,353,8)}function QF(a){var b=0,c=0;b=a,c=Hd(),v[b>>2]=c}function Pfa(a,b){a=a|0;b=b|0;fp(a,b,654,653,8)}function Pe(a,b){return lp(v[a>>2],v[b>>2])?b:a}function NH(a,b){if(!a){return 0}return $w(a,b)}function Lh(a,b,c){return Ka(966,a|0,b|0,c|0)|0}function Kha(a,b){a=a|0;b=b|0;fp(a,b,505,504,6)}function Kb(a,b){return qo(v[b>>2],v[a>>2])?b:a}function Jx(a,b){return gu(z[a>>2],z[b>>2])?b:a}function IH(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function BW(a,b){a=a|0;b=b|0;Yp(a,b);return a|0}function An(a){return ob[v[v[a>>2]+28>>2]](a)|0}function zt(a){return(a>>>0<9?a:a-9|256)&65535}function tf(a,b,c){if(!(w[a|0]&32)){NB(b,c,a)}}function t7(a){a=a|0;IK(a);Ex(a);t[a+4202|0]=1}function nh(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function lg(a,b,c){a=Pka(a,b,c,c>>31);return a}function i8(a){a=a|0;t[a+4202|0]=1;SK(a);UK(a)}function faa(a,b){a=a|0;b=b|0;uy(VL(a+24|0,b))}function ega(a,b){a=a|0;b=b|0;return FR(a,b)|0}function cV(a,b,c){a=a|0;b=b|0;c=c|0;eC(a,b,c)}function b8(a){a=a|0;t[a+4202|0]=1;QK(a);PK(a)}function Y3(a){a=a|0;return ZE(a,49100,8151)|0}function VY(a,b,c){a=a|0;b=b|0;c=c|0;hc(a,c,b)}function SO(a){oz(a);Ub(a+27|0,0,255);return a}function Ok(a,b,c,d,e){Ta(a|0,b|0,c|0,d|0,e|0)}function OB(a){return!Sb(a,15443,4)&w[a+4|0]<4}function OA(a,b,c){a=a|0;b=b|0;c=c|0;bC(a,b,c)}function MB(a,b,c){a=a|0;b=b|0;c=c|0;uV(a,b,c)}function Lr(a,b){return(a&255)>>>0<(b&255)>>>0}function Jz(a){return a>>>0<=45?w[a+43680|0]:0}function IV(a,b){a=a|0;b=b|0;fp(a,b,295,294,8)}function Hi(a,b){return(B(b,104)+a|0)+484380|0}function H3(a,b){a=a|0;b=b|0;ad(a,$J(b,17608))}function FP(a){v[a>>2]=0;v[a+4>>2]=-1;return a}function zb(a){if(ff(a)){Nb(v[a>>2])}return a}function xc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function wH(a){a=a|0;Sw(v[v[a>>2]-12>>2]+a|0)}function vU(a){nb=0;a=(a&65535)-98|0;return a}function ul(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function tka(a,b){a=a|0;b=b|0;JE(a,b,301,300)}function rK(a,b){a=a|0;b=b|0;return $J(a,b)|0}function qV(a,b){a=a|0;b=b|0;return oF(a,b)|0}function pp(a,b){a=a|0;b=b|0;return BH(a,b)^1}function nm(a){a=lm(a);v[a>>2]=92864;return a}function lu(a,b){a=a|0;b=b|0;return Jk(a,b)|0}function kf(a,b){return Lr(w[a|0],w[b|0])?b:a}function jX(a){a=a|0;v[a>>2]=62132;return a|0}function j5(a){a=a|0;return fF(a,6594,1018)|0}function iR(a){a=Oka(a&65535,0,80,0);return a}function fe(a){v[a>>2]=0;v[a+4>>2]=0;return a}function ds(a,b){a=a|0;b=b|0;return qH(a,b)^1}function dj(a,b){a=a|0;b=b|0;return BH(a,b)|0}function bja(a,b){a=a|0;b=b|0;dw(a,b,17,3,16)}function bi(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function bV(a){t[a+12|0]=w[a+12|0]|2;return a}function _X(a,b){a=a|0;b=b|0;return fE(a,b)|0}function Zm(a){return(a>>>0>127?a^128:-1)&255}function ZW(a){a=a|0;v[a>>2]=42968;return a|0}function YJ(a){a=a|0;v[a>>2]=49164;return a|0}function Xb(a,b){return Lr(w[b|0],w[a|0])?b:a}function XW(a){a=a|0;v[a>>2]=42728;return a|0}function W0(a){a=a|0;lH(v[v[a>>2]-12>>2]+a|0)}function Vd(a){a=RD(a);v[a>>2]=84704;return a}function VF(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function U0(a){a=a|0;kH(v[v[a>>2]-12>>2]+a|0)}function Sx(a){return v[Gb(a)>>2]-v[a>>2]>>11}function Rka(a,b,c,d){a=Mka(a,b,c,d);return a}function Q2(a){a=a|0;v[a>>2]=61712;return a|0}function PG(a,b){a=a|0;b=b|0;return ND(a,b)|0}function Ns(a){a=fK(a);v[a>>2]=78608;return a}function MX(a,b){a=a|0;b=b|0;return Pv(a,b)|0}function KQ(a){return Qe(443250/+(a>>>0)*1e4)}function Jka(a,b){a=a|0;b=b|0;dw(a,b,44,2,44)}function I2(a){a=a|0;v[a>>2]=61212;return a|0}function GV(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Fja(a,b){a=a|0;b=b|0;JE(a,b,358,357)}function Ff(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function E5(a){a=a|0;return fF(a,7057,1010)|0}function CH(a){a=a|0;Uw(v[v[a>>2]-12>>2]+a|0)}function Aw(a,b,c){a=IG(a,b,c,-1,-1);return a}function $j(a,b){a=a|0;b=b|0;return qH(a,b)|0}function zd(a,b){if(!gf(b)){a=zf(b)}return a}function z_(a){a=a|0;be(a,469800,Wd(468208))}function y_(a){a=a|0;be(a,469808,Wd(468216))}function x_(a){a=a|0;be(a,469816,Wd(468224))}function w_(a){a=a|0;be(a,469824,Wd(468232))}function wF(a,b,c){a=a|0;b=b|0;c=c|0;jH(a,c)}function v_(a){a=a|0;be(a,469832,Wd(468240))}function u_(a){a=a|0;be(a,469840,Wd(468248))}function t_(a){a=a|0;be(a,469848,Wd(468256))}function s_(a){a=a|0;be(a,469856,Wd(468264))}function r_(a){a=a|0;be(a,469864,Wd(468176))}function q_(a){a=a|0;be(a,469880,Wd(468184))}function o_(a){a=a|0;be(a,469896,Wd(468192))}function m_(a){a=a|0;be(a,469912,Wd(468200))}function lo(a){return v[Gb(a)>>2]-v[a>>2]>>5}function l_(a){a=a|0;be(a,469928,Wd(468272))}function kk(a){return AE(a,C(4294967296),-1)}function k_(a){a=a|0;be(a,469936,Wd(468280))}function kF(a){a=Ha(a|0)|0;nb=O()|0;return a}function hn(a){return v[Gb(a)>>2]-v[a>>2]>>3}function ck(a){a=a&255;return(a|0)==255?-1:a}function bH(a){a=fK(a);v[a>>2]=79e3;return a}function Ym(a){return v[Gb(a)>>2]-v[a>>2]>>1}function W2(a){a=a|0;dJ(a);return v[a+16>>2]}function Vh(a){return v[Gb(a)>>2]-v[a>>2]>>2}function Sz(a){return v[Gb(a)>>2]-v[a>>2]>>8}function Ro(a,b,c,d){a=Pka(a,b,c,d);return a}function Q_(a){a=a|0;be(a,469616,Wd(468128))}function P_(a){a=a|0;be(a,469624,Wd(468136))}function Ox(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function O_(a){a=a|0;be(a,469632,Wd(468332))}function Nt(a){return v[Gb(a)>>2]-v[a>>2]>>4}function N_(a){a=a|0;be(a,469648,Wd(468324))}function M_(a){a=a|0;be(a,469656,Wd(468340))}function Ly(a){t[a+24|0]=0;t[a|0]=0;return a}function Kz(a){return v[Cc(a)>>2]-v[a>>2]>>2}function K_(a){a=a|0;be(a,469664,Wd(468348))}function J_(a){a=a|0;be(a,469680,Wd(468356))}function I_(a){a=a|0;be(a,469688,Wd(468372))}function I1(a){a=a|0;return jb(v[a+60>>2])|0}function H_(a){a=a|0;be(a,469696,Wd(468364))}function G_(a){a=a|0;be(a,469704,Wd(468380))}function Fx(a){return C(C(a*C(7900))+C(100))}function F_(a){a=a|0;be(a,469712,Wd(468388))}function E_(a){a=a|0;be(a,469736,Wd(468396))}function D_(a){a=a|0;be(a,469768,Wd(468144))}function Cw(){ha(nm(ba(4)|0)|0,92948,26);L()}function Ch(a){return v[v[a+8>>2]>>2]==(a|0)}function C_(a){a=a|0;be(a,469776,Wd(468152))}function B_(a){a=a|0;be(a,469784,Wd(468160))}function A_(a){a=a|0;be(a,469792,Wd(468168))}function yJ(a){t[a+4|0]=0;t[a|0]=0;return a}function wf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function we(a,b,c){if(c){uc(a,b,c)}return a}function wK(a){return Th(C(yK(a)*C(32768)))}function tl(a,b){return a<<24>>24<b<<24>>24}function ri(a,b){a=a|0;b=b|0;return C(C(0))}function nk(a,b){return a<<16>>16<b<<16>>16}function kp(a){return v[Gb(a)>>2]-v[a>>2]|0}function hea(a,b){a=a|0;b=b|0;Gr(a,b,572,3)}function fm(a){a=a|0;Tw(v[a>>2]);return a|0}function fB(a,b){v[a>>2]=v[a>>2]+b;return a}function Xh(a,b,c){if(c){hj(a,b,c)}return a}function XF(a,b,c){return Ev(WF(a),WF(b),c)}function X2(a){a=a|0;dJ(a);return v[a+4>>2]}function Vs(a){a=a|0;ob[v[v[a>>2]+4>>2]](a)}function Rm(a,b,c){return Bf(a,b)>>>0>c>>>0}function Im(a,b){u[a>>1]=b;u[a+2>>1]=b>>>16}function Cn(a){a=a|0;oH(v[a>>2]);return a|0}function Bka(a,b){a=a|0;b=b|0;Gr(a,b,293,2)}function Ac(a){if(ff(a)){a=v[a>>2]}return a}function xw(a){a=a|0;return Eh(a,468396)|0}function w9(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function vQ(a,b,c,d){hc(a,b,(d|0)==-1?c:d)}function u1(a){a=a|0;return Eh(a,468144)|0}function ts(a){return(a|0)<=65535&(a|0)>=0}function sA(a,b){a=a|0;b=b|0;Gr(a,b,572,2)}function rN(a,b){return NE(a,b,2147483647)}function qd(a,b){a=a|0;b=b|0;vL(a,b,yg(b))}function pX(a){a=a|0;return v[a+4>>2]!=0|0}function mq(a){v[a>>2]=v[a>>2]+12;return a}function m1(a){a=a|0;return Eh(a,468160)|0}function lf(a,b,c){a=Oka(c,0,a,b);return a}function kfa(a,b){a=a|0;b=b|0;GE(a,b,2,31)}function jr(a){sr(a+32|0);Bb(a+12|0);Ab(a)}function iv(a){a=a|0;return Eh(a,468332)|0}function hl(a){zb(a+36|0);wc(a+24|0);vk(a)}function fq(a){v[a>>2]=v[a>>2]+16;return a}function Vaa(a,b){a=a|0;b=b|0;Zo(a+40|0,b)}function VH(a,b){return C(UH(a?C(-b):b)*b)}function Tt(a){We(a+24|0);ic(a+12|0);ic(a)}function T8(a,b,c){a=a|0;b=b|0;c=c|0;fe(a)}function Sk(a,b){ob[v[v[b>>2]+44>>2]](a,b)}function Rk(a,b){ob[v[v[b>>2]+32>>2]](a,b)}function Qw(a){a=a|0;return Eh(a,468324)|0}function Nw(a){a=a|0;return Eh(a,468340)|0}function Nm(a){v[a>>2]=v[a>>2]+28;return a}function Nf(a){v[a>>2]=v[a>>2]+20;return a}function Mr(a,b){ob[v[v[b>>2]+40>>2]](a,b)}function MM(a){v[a>>2]=v[a>>2]+52;return a}function Ll(a){return v[a+8>>2]&2147483647}function Iw(a){a=a|0;return Eh(a,468348)|0}function Hka(a,b){a=a|0;b=b|0;Zo(a+12|0,b)}function Em(a){Cz(v[a+20>>2]);v[a+20>>2]=0}function Dw(a){a=a|0;return Eh(a,468388)|0}function Dka(a,b){a=a|0;b=b|0;Nq(a+36|0,b)}function BK(a){return C(C(a*C(96))+C(-96))}function Az(a){v[a>>2]=v[a>>2]+32;return a}function $t(a,b){a=a|0;b=b|0;Gr(a,b,573,2)}function zka(a,b){a=a|0;b=b|0;fi(a,b,136)}function vt(a){v[a>>2]=v[a>>2]+8;return a}function vp(a){a=a|0;Ks(a+8|0);return a|0}function uga(a,b){a=a|0;b=b|0;fi(a,b,274)}function s2(a,b){a=a|0;b=b|0;TI(a-88|0,b)}function r2(a,b){a=a|0;b=b|0;SI(a-88|0,b)}function qe(a){return Ib(a&65535)<<16>>16}function pga(a,b){a=a|0;b=b|0;fi(a,b,106)}function oF(a,b){return Ir(a,Mc(b),Hb(b))}function mj(a,b){v[a>>2]=v[b>>2];return a}function lP(a){v[a>>2]=v[a>>2]-2;return a}function gs(a){a=a|0;$k(a+8|0);return a|0}function fs(a){a=a|0;$k(a+4|0);return a|0}function fka(a,b){a=a|0;b=b|0;GE(a,b,3,8)}function eO(a,b){if(z[a>>2]>b){z[a>>2]=b}}function c2(a,b){a=a|0;b=b|0;EI(a-88|0,b)}function _9(a,b){a=a|0;b=b|0;yh(a,b+36|0)}function _1(a,b){a=a|0;b=b|0;DI(a-92|0,b)}function Zk(a){a=a|0;return AH(a)<<24>>24}function Z1(a,b){a=a|0;b=b|0;CI(a-92|0,b)}function Yr(a){a=a|0;gw(a,168,93308,1007)}function Se(a){v[a>>2]=v[a>>2]+2;return a}function On(a,b){return v[a>>2]-v[b>>2]|0}function Le(a){v[a>>2]=v[a>>2]+4;return a}function KH(a,b){t[a|0]=b+48;return a+1|0}function He(a){v[a>>2]=v[a>>2]+1;return a}function HZ(a,b){a=a|0;b=b|0;yh(a,b+16|0)}function DI(a,b){a=a|0;b=b|0;VE(a,b,2048)}function Ck(a){v[a>>2]=v[a>>2]+6;return a}function CK(a){a=a|0;Ub(a+4296|0,0,81928)}function CI(a,b){a=a|0;b=b|0;VE(a,b,4096)}function C2(a,b){a=a|0;b=b|0;Jk(a,b+12|0)}function BZ(a,b){a=a|0;b=b|0;yh(a,b+12|0)}function At(a){pm(a,go(a),62364);return a}function Af(a){a=a|0;Jh(a+8|0);return a|0}function $ia(a,b){a=a|0;b=b|0;fi(a,b,282)}function zi(a,b){return v[a>>2]!=v[b>>2]}function zZ(a,b){a=a|0;b=b|0;Nc(a,11317)}function y7(a){a=a|0;return v[a+4260>>2]}function u2(a){a=a|0;return vp(a-88|0)|0}function q2(a,b){a=a|0;b=+b;RI(a-88|0,b)}function pj(a){u[a+4>>1]=65535;v[a>>2]=0}function o2(a,b){a=a|0;b=+b;PI(a-88|0,b)}function nha(a,b){a=a|0;b=b|0;fi(a,b,42)}function nga(a,b){a=a|0;b=b|0;fi(a,b,72)}function m2(a,b){a=a|0;b=+b;NI(a-88|0,b)}function lc(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function cs(a,b){v[a+24>>2]=v[a+24>>2]+b}function cf(a,b){v[a+8>>2]=b|-2147483648}function b2(a){a=a|0;return vp(a-92|0)|0}function aja(a,b){a=a|0;b=b|0;Rq(a,b,17)}function _d(a,b){return(b|0)!=0&(a|0)!=0}function Wk(a){return(a|0)==32|a-9>>>0<5}function U1(a){a=a|0;return vp(a-96|0)|0}function Tf(a,b){a=Pka(0,a,b,0);return a}function SD(a,b){qc(a,b);qc(a+4|0,b+4|0)}function S1(a,b){a=a|0;b=+b;xI(a-96|0,b)}function QJ(a){return(Ac(a)+Hb(a)|0)-1|0}function OT(a,b,c){v[a>>2]=b;v[a+4>>2]=c}function Lja(a,b){a=a|0;b=b|0;fi(a,b,34)}function Kj(a,b){t[a|0]=b;t[a+1|0]=b>>>8}function GZ(a,b){a=a|0;b=b|0;sn(a,84448)}function GS(a,b){a=a|0;b=b|0;fi(a,b,284)}function Fk(a){return B(_m(a),Ld(a))&255}function FZ(a,b){a=a|0;b=b|0;sn(a,84468)}function D8(a){a=a|0;t[a+4202|0]=1;fL(a)}function AZ(a,b){a=a|0;b=b|0;Nc(a,11200)}function v9(a){a=a|0;return w[a+4201|0]}function uT(a,b){a=a|0;b=b|0;Rq(a,b,32)}function u9(a){a=a|0;return w[a+4202|0]}function tu(a,b,c){return a<b?b:a>c?c:a}function pW(a,b){a=a|0;b=b|0;fi(a,b,59)}function nR(a,b,c,d){return ul(c,d,a,b)}function kN(a,b){return(pl(a,b)|0)!=255}function hk(a,b){return Vy(a&255,b&255)}function fn(a){a=v[a+8>>2];if(a){Nb(a)}}function fG(a,b){a=a|0;b=b|0;pf(a,1,45)}function eG(a,b){a=a|0;b=b|0;oG(a,1,45)}function dW(a,b){a=a|0;b=b|0;Rq(a,b,11)}function cx(a){return(p(a),j(2))>>>20|0}function bU(a){return EE(a,65535,65535)}function az(a,b,c){return a<b?b:a>c?c:a}function ZH(a){v[a+4>>2]=v[a+4>>2]|8192}function Yh(a){return(a&65535)>>>0<3999}function Y6(a){a=a|0;return(a|0)==277|0}function VV(a){a=a|0;return v[a+12>>2]}
function Jg(a,b,c){t[a+4|0]=c;v[a>>2]=b}function Ib(a){return(a<<8|a>>>8)&65535}function Cha(a,b){a=a|0;b=b|0;gC(a,b,8)}function CV(a,b){a=a|0;b=b|0;fi(a,b,50)}function CF(a,b){a=a|0;b=b|0;return b|0}function wL(a){a=a|0;return 1869112133}function se(a,b,c){tn(a,b,fd(b,c)+b|0)}function p2(a){a=a|0;return+QI(a-88|0)}function n2(a){a=a|0;return+OI(a-88|0)}function lE(a,b,c){return bp(a,b,c,24)}function l2(a){a=a|0;return+MI(a-88|0)}function kh(a){return AE(a,C(255),255)}function h7(a){a=a|0;return-2013527448}function gea(a){a=a|0;dR(a);return a|0}function dv(a,b,c){return bp(a,b,c,20)}function bz(a,b){return LE(a,b,-1,0,0)}function bX(a){a=a|0;return v[a+16>>2]}function bB(a,b,c){tq(a,c);xd(b+c|0,0)}function Zi(a,b){v[a+4>>2]=1;v[a>>2]=b}function Xj(a,b){v[a+4>>2]=2;v[a>>2]=b}function Vv(a,b){v[a+4>>2]=4;v[a>>2]=b}function VU(a,b,c){return bp(a,b,c,40)}function Ud(a){v[v[a+8>>2]>>2]=v[a>>2]}function Qt(a,b,c){return bp(a,b,c,12)}function Ov(a,b){v[a+4>>2]=3;v[a>>2]=b}function Nr(a){a=a|0;return 2147483647}function NT(a,b,c){Al(a,b&65535,c&255)}function NJ(a){return a?(a|0)==2?3:2:1}function IP(a,b,c){return KE(a,b,c,42)}function Ai(a,b){return Ac(a)+(b<<2)|0}function z8(a){a=a|0;return-270114148}function z7(a){a=a|0;return-275227023}function wo(a,b){u[a+8>>1]=b;return a}function wJ(a){v[a>>2]=58680;return a}function vka(a,b){a=a|0;b=b|0;yt(a,b)}function vj(a){return(a-1&255)>>>0<17}function uS(a){oI(a);De(v[a+80>>2],a)}function sK(a,b){a=a|0;b=b|0;return 0}function rba(a,b){a=a|0;b=b|0;ON(a,b)}function qH(a,b){return pH(a)^pH(b)^1}function p7(a){a=a|0;return 302837129}function oi(a,b,c){ad(ad(a,b)+12|0,c)}function n8(a){a=a|0;return-285139079}function m9(a){a=a|0;return 542066252}function lr(a,b,c){return ep(a,b,c,3)}function lm(a){v[a>>2]=93560;return a}function ji(a){a=v[a>>2];if(a){KG(a)}}function hs(a,b){a=a|0;b=b|0;return-1}function ff(a){return w[a+11|0]>>>7|0}function fK(a){v[a>>2]=78636;return a}function f8(a){a=a|0;return-284078960}function en(a){v[a>>2]=61664;return a}function cQ(a,b,c){return fw(a,b,c,5)}function bM(a,b){_c(a,b&4?16:8,1,0,0)}function _N(a,b){return(0-b|0)!=(a|0)}function _7(a){a=a|0;return-281111764}function Z6(a,b){a=a|0;b=b|0;return 2}function YS(a,b,c){gc(a,b,vc(b,c)<<2)}function XI(a){v[a>>2]=62976;return a}function Wm(a,b,c){return fw(a,b,c,2)}function WP(a){return(a&65535)==65534}function Vq(a){a=a|0;return v[a+4>>2]}function VI(a){v[a>>2]=63080;return a}function Ue(a,b){v[a+4>>2]=b;return a}function UI(a){v[a>>2]=63120;return a}function T7(a){a=a|0;return-271958638}function S2(a){a=a|0;return w[a+40|0]}function Px(a,b){a=a|0;b=b|0;return 1}function Oo(a,b,c){return fw(a,b,c,1)}function OD(a){a=a|0;return v[a+8>>2]}function MJ(a){a=C(a-a);return C(a/a)}function Lz(a,b,c){return ep(a,b,c,5)}function Km(a){return(a&740327453)!=0}function K7(a){a=a|0;return-620920304}function J0(a){a=a|0;return _G(a,0)|0}function I0(a){a=a|0;return _G(a,1)|0}function Gq(a,b,c){return bp(a,b,c,6)}function Ft(a,b,c){return ep(a,b,c,4)}function ED(a,b,c){gc(a,b,Vg(b,c)<<3)}function Df(a,b,c){return jd(a,b,c,0)}function DJ(a){v[a>>2]=49412;return a}function C0(a){a=a|0;return YG(a,0)|0}function Bh(a,b,c){return ep(a,b,c,2)}function Bf(a,b){return yk(a,b)&65535}function BH(a,b){return zH(a)^zH(b)^1}function B0(a){a=a|0;return YG(a,1)|0}function $h(a,b,c){return ep(a,b,c,1)}function $J(a,b){return Ir(a,b,yg(b))}function $6(a,b){a=a|0;b=b|0;return 3}function zK(a){v[a>>2]=0;v[a+4>>2]=0}function xba(a){a=a|0;return Wg(a)|0}function xX(a){a=a|0;aD(Mc(a),Hb(a))}function uu(a,b){return w[a+b|0]!=63}function uja(a){a=a|0;return eB(a)|0}function uQ(a,b){return B(b,872)+a|0}function uL(a,b,c){a=a|0;b=b|0;c=c|0}function qT(a,b){a=a|0;b=b|0;lu(a,b)}function qB(a,b,c){fc(fc(a,b)+4|0,c)}function pi(a,b){a=a|0;b=b|0;yh(a,b)}function pL(a,b){a=a|0;b=b|0;pi(a,b)}function nK(a){a=a|0;iF(a,48944,955)}function mn(a,b){a=a|0;b=b|0;dK(a,b)}function lh(a){Xf(a+52|0);ic(a+40|0)}function fS(a,b){if(!$R(a,b)){eA(b)}}function dK(a,b){a=a|0;b=b|0;Es(a,b)}function cn(a){v[a+4>>2]=v[a+4>>2]+1}function aR(a){return(a|0)<120?a:120}function _Q(a){return(a&255)>>>0<129}function Zja(a){a=a|0;return FU(a)|0}function Xq(a,b){a=a|0;b=b|0;zv(a,b)}function WI(a){v[a>>2]=63e3;return a}function RP(a,b,c,d){OP(hc(a,b,c),d)}function Qg(a){return x[a+480188>>1]}function Oaa(a){a=a|0;return ui(a)|0}function N2(a){a=a|0;return w[a+8|0]}function Mea(a){a=a|0;return Ci(a)|0}function Md(a,b){return B(b,160)+a|0}function Li(a,b){a=a|0;b=b|0;FV(a,b)}function LX(a,b){a=a|0;b=b|0;iE(a,b)}function Jq(a,b){a=a|0;b=b|0;pL(a,b)}function Ix(a,b){a=a|0;b=b|0;hL(a,b)}function IN(a){return(a+5&255)>>>0<2}function Hs(a){return x[a+480192>>1]}function Gs(a){return x[a+480190>>1]}function GA(a,b){a=a|0;b=b|0;_J(a,b)}function Es(a,b){a=a|0;b=b|0;Jk(a,b)}function Dt(a){return v[Gb(a)>>2]<<5}function DZ(a){a=a|0;return t[a+8|0]}function CZ(a){a=a|0;return t[a+9|0]}function $X(a,b){a=a|0;b=b|0;FN(a,b)}function yk(a,b){return(b-a|0)/52|0}function yd(a,b){return(b-a|0)/12|0}function wX(a){a=a|0;return Cg(a)|0}function tk(a){return EE(a,255,255)}function te(a,b,c){return EG(a,b,c)}function sj(a,b){return rg(a,b)&255}function sS(a,b){return Rf(a,0-b|0)}function rv(a){t[a+2|0]=0;u[a>>1]=0}function qo(a,b){return a>>>0<b>>>0}function pc(a,b){return(a|0)==(b|0)}function oq(a){return(a&255)==1?1:2}function og(a){return C(D(a))==C(N)}function mf(a,b){return B(b,24)+a|0}function kr(a,b){return(b-a|0)/36|0}function kK(a){a=a|0;return $k(a)|0}function hq(a,b){return(b-a|0)/56|0}function gt(a){return!(a&204473357)}function gH(a){a=a|0;return Hv(a)|0}function fx(a){return!Sb(a,93876,6)}function fu(a,b){return(b-a|0)/33|0}function fc(a,b){v[a>>2]=b;return a}function eg(a,b){return ok(a,ce(b))}function dD(a){a=a|0;return Sg(a)|0}function d1(a){a=a|0;return Yk(a)|0}function by(a,b){return B(b,28)+a|0}function bg(a,b){return B(b,52)+a|0}function aaa(a){a=a|0;Rq(a,21619,1)}function Yz(a,b){return B(b,56)+a|0}function Wb(a,b){return ze(a,b&255)}function WW(a){a=a|0;vD(Ub(a,0,36))}function VW(a){a=a|0;return Jh(a)|0}function VA(a,b,c){return Ws(a,b,c)}function US(a,b){return B(b,33)+a|0}function Tp(a){if(w[a+24|0]){BN(a)}}function Rv(a,b,c){return Sb(a,b,c)}function Ri(a,b){return(b-a|0)/24|0}function Qq(a){a=a|0;return Me(a)|0}function Qi(a,b,c){return Ev(a,b,c)}function Pg(a,b){return B(b,20)+a|0}function Ot(a,b){return B(b,36)+a|0}function Nd(a,b){return B(b,12)+a|0}function Mk(a,b,c){return uE(a,b,c)}function Lp(a){return XU(a,251,255)}function Kq(a,b){return(b-a|0)/28|0}function Fq(a,b){return(b-a|0)/40|0}function FV(a,b){EV(a,v[a+16>>2]|b)}function FB(a){a=a|0;return tc(a)|0}function El(a,b){return Dl(Rc(a,b))}function E7(a){a=a|0;v[a+4224>>2]=0}function Dx(a){a=a|0;iF(a,49e3,957)}function DV(a){a=a|0;return wv(a)|0}function Cf(a,b){return(b-a|0)/20|0}function zD(a,b){return Pk(a,b,36)}function vu(a){return a&2147483647}function qm(a){return C(D(a))<C(N)}function qk(a,b){return(b-a|0)/6|0}function qi(a){a=a|0;t[a+4202|0]=0}function oV(a,b){return Pk(a,b,28)}function lp(a,b){return(a|0)<(b|0)}function hU(a){return w[a+1|0]!=63}function gf(a){return(a&128)>>>7|0}function er(a,b){return(b<<11)+a|0}function dz(a,b){return(b-a|0)/7|0}function dl(a,b){return(a+b|0)-1|0}function cja(a){a=a|0;return+vH(a)}function cK(a,b,c,d){bw(a,b,c,d,2)}function bo(a,b){return(b<<13)+a|0}function bG(a){return Eh(a,468216)}function aG(a){return Eh(a,468208)}function _F(a){return Eh(a,468232)}function Zv(a,b){return!(b>>>31|0)}function Zs(a,b){return(a-b|0)/6|0}function ZF(a){return Eh(a,468224)}function Tv(a,b){return Pk(a,b,12)}function RS(a,b){return Hr(a,b,18)}function QX(a){a=a|0;jn(a,1,13360)}function Q1(a,b){a=a|0;b=b|0;Nb(b)}function Ow(a){return pc(a,-1)?0:a}function Mh(a,b){a=a|0;b=b|0;Mb(a)}function Lk(a){return(a&255)>>>0>1}function LT(a,b){return Hr(a,b,56)}function JN(a){re(a+8|0);AN(a+4|0)}function JJ(a){return(ck(a)|0)==-1}function In(a,b){v[a+1298464>>2]=b}function Ij(a,b){return B(Fk(b),a)}function Id(a,b){return B(b,6)+a|0}function IJ(a,b){a=a|0;b=b|0;ic(b)}function HJ(a,b){a=a|0;b=b|0;Gm(b)}function Gx(a,b,c,d){bw(a,b,c,d,9)}function Go(a){t[a|0]=0;t[a+1|0]=0}function Ge(a,b){hc(a,Mc(b),Hb(b))}function Ec(a,b){return NE(a,b,-1)}function Bx(a,b,c,d){bw(a,b,c,d,4)}function BD(a,b){return Hr(a,b,20)}function ze(a,b){return(b<<5)+a|0}function zY(a){a=a|0;return 12944}function yy(a){ic(a+4|0);return a}function yq(a,b){return ve(a,b)^1}function yY(a){a=a|0;return 10730}function xx(a,b){return iM(a,b)^1}function tH(a){return BE(a,77376)}function rO(a,b){return Pk(a,b,8)}function oe(a,b){return!Sb(a,b,4)}function lw(a,b){return v[a+b>>2]}function hg(a,b){return Mc(a)+b|0}function eD(a){return(a&16)>>>4|0}function dc(a,b){return(b<<1)+a|0}function bf(a,b){return(b<<3)+a|0}function ak(a){return a-48>>>0<10}function Zaa(a){a=a|0;vg(a,tj(a))}function Ux(a){v[a>>2]=v[a>>2]+24}function Un(a){return a+1074328|0}function Td(a){return v[jc(a)>>2]}function Tc(a,b){return Ac(a)+b|0}function T0(a){a=a|0;return 10356}function SY(a){a=a|0;return 13058}function RY(a){a=a|0;return 10236}function Pb(a,b){return pc(a,b)^1}function Nfa(a){a=a|0;ES(a,65535)}function Mm(a){v[a>>2]=2;return a}function Mga(a){a=a|0;Sf(a,16784)}function Kf(a){return a!=a?C(0):a}function Kd(a,b){return(b<<4)+a|0}function Iz(a,b){return Pk(a,b,4)}function Is(a){return BE(a,77312)}function Hc(a){v[a>>2]=0;return a}function Fh(a){v[a>>2]=1;return a}function FG(a,b){return EG(a,0,b)}function Eb(a,b){return(b<<2)+a|0}function Cz(a){if(a){Nb(a+-64|0)}}function Am(a,b){return(b<<8)+a|0}function Ak(a){u[a>>1]=0;return a}function Aia(a){a=a|0;Sf(a,16153)}function $c(a){return XU(a,1,120)}function xia(a){a=a|0;Sf(a,4487)}function xY(a){a=a|0;return 5723}function wfa(a){a=a|0;Sf(a,4168)}function vV(a){gw(a,25,93188,24)}function uq(a){gw(a,25,93240,27)}function rU(a,b,c){ME(a,b,c,256)}function qia(a){a=a|0;Sf(a,4381)}function pg(a,b){fc(Hc(a)+4|0,b)}function ov(a,b){return Ska(a,b)}function jL(a){return(a&8)>>>3|0}function hv(a,b,c){ME(a,b,c,128)}function eha(a){a=a|0;Ku(a,3883)}function eH(a){v[a+72>>2]=467144}function cha(a){a=a|0;Ku(a,4890)}function cg(a,b,c,d){qf(a,c,d,b)}function cH(a){v[a+72>>2]=467228}function Zg(a){return!v[a+16>>2]}function YI(a,b){return Vg(a,b)}
function Vja(a){a=a|0;Sf(a,3892)}function OY(a){a=a|0;return 6869}function Nga(a){a=a|0;Sf(a,3988)}function LC(a){pm(a,Yo(a),62364)}function Iq(a,b,c){HE(a,b,c,128)}function FX(a){a=a|0;Sf(a,16811)}function FS(a,b){uc(a,b+4|0,256)}function Cr(a){t[a|0]=0;return a}function BX(a){a=a|0;aD(a,yg(a))}function AY(a){a=a|0;return 9795}function zl(a){return Jm(xe(a))}function zj(a){HA(a,0);return a}function yj(a,b){return ze(a,b)}function yi(a,b){return(a|b)!=0}function yf(a){a=a|0;return a|0}function xm(a){zb(a+12|0);zb(a)}function wp(a,b){return Eb(a,b)}function uk(a,b,c){qf(a,c,12,b)}function t2(a){a=a|0;ss(a-88|0)}function sw(a){return Gb(a+8|0)}function sh(a,b){return!zd(a,b)}function rl(a){Ab(a+12|0);od(a)}function rM(a,b){return oM(a,b)}function qy(a){u[a+480214>>1]=0}function qp(a){return a<<24>>24}function ok(a,b){return fc(a,b)}function of(a,b){return Ag(a,b)}function nt(a){BO(a+12|0);FO(a)}function no(a,b){return Ek(a,b)}function ng(a){return Bi(a)?0:a}function nE(a,b){Er(a,b,24,-24)}function mv(a,b){return SC(a,b)}function mC(a){return(a&255)==1}function kc(a,b){return JD(a,b)}function gh(a){return IN(a&255)}function fz(a,b){return Rc(a,b)}function e_(a){a=a|0;Gc(468532)}function eE(a,b){return ad(a,b)}function cw(a,b){return eh(a,b)}function c_(a){a=a|0;Gc(468564)}function a_(a){a=a|0;Gc(468468)}function aA(a,b,c){qf(a,c,64,b)}function a2(a){a=a|0;ss(a-92|0)}function _h(a,b,c){qf(a,c,13,b)}function _Z(a){a=a|0;Gc(468500)}function Zb(a,b){return bg(a,b)}function Ys(a,b){return nk(a,b)}function YT(a,b,c){qf(a,c,24,b)}function UV(a){a=a|0;Sf(a,4361)}function UC(a,b){return RC(a,b)}function Ti(a,b){return a>>>b&1}function T1(a){a=a|0;ss(a-96|0)}function Sn(a,b){return Lr(a,b)}function Sh(a,b){return fd(a,b)}function Sc(a,b,c){hc(a,b,1<<c)}function SZ(a){a=a|0;zb(468516)}function RU(a,b){Er(a,b,40,-40)}function Qj(a,b){return b-a>>11}function Qe(a){return Aq(xe(a))}function Qd(a){return(a&255)!=0}function QZ(a){a=a|0;zb(468548)}function PT(a,b){return qo(a,b)}function Or(a){a=a|0;return 127}function OZ(a){a=a|0;zb(468452)}function Ne(a,b,c){qf(a,c,32,b)}function Mf(a,b){return ok(a,b)}function MZ(a){a=a|0;zb(468484)}function MG(a){if(NG(a)){Nb(a)}}function LB(a,b,c){qf(a,c,30,b)}function Kc(a,b){return er(a,b)}function Il(a,b,c){qf(a,c,22,b)}function Ii(a,b,c){qf(a,c,28,b)}function Ig(a,b){return Pb(a,b)}function IQ(a,b){Er(a,b,12,-12)}function Hh(a,b){return jv(a,b)}function HB(a,b){return zo(b,a)}function Gk(a,b){return zd(a,b)}function GX(a){a=a|0;Sf(a,4535)}function GG(a,b){return yd(a,b)}function Ef(a){Ab(a+20|0);Ab(a)}function EU(a,b){return so(b,a)}function Dj(a,b,c){qf(a,c,20,b)}function Cb(a,b){return(a&b)!=0}function Bb(a){me(a+12|0);me(a)}function BN(a){zN(a+12|0);yN(a)}function $d(a,b){return vc(a,b)}function zx(a){a=a|0;Nb(ZJ(a))}function zo(a,b){return a-b>>1}function z3(a){a=a|0;Nb(ys(a))}function yZ(a){a=a|0;Nb(GF(a))}function x7(a){a=a|0;return 13}function wQ(a){return a+4096|0}function vc(a,b){return b-a>>2}function ss(a){a=a|0;Nb(vp(a))}function sR(a,b){dw(a,b,5,3,4)}function rg(a,b){return b-a>>5}function o8(a){a=a|0;Nb(VK(a))}function n9(a){a=a|0;Nb(rL(a))}function mk(a,b){return b-a>>4}function ln(a){a=a|0;Nb(zU(a))}function lH(a){a=a|0;Nb(zp(a))}function kH(a){a=a|0;Nb(sf(a))}function je(a,b){t[a|0]=w[b|0]}function gX(a){a=a|0;Nb(HD(a))}function fZ(a){a=a|0;Nb(BF(a))}function ec(a,b){v[a+100>>2]=b}function dn(a){a=a|0;Nb(Hv(a))}function dT(a,b){tn(a,b,wd(b))}function cu(a,b){return a-b>>2}function cL(a){a=a|0;Nb(dL(a))}function ZY(a){a=a|0;Nb(zF(a))}function Z0(a){a=a|0;Nb(Js(a))}function Y2(a){a=a|0;Nb(eJ(a))}function XC(a){return tc(a<<2)}function Ww(a){a=a|0;Nb($k(a))}function Vy(a,b){return a<<8|b}function Vw(a){a=a|0;Nb(Ln(a))}function Vt(a){return a>>>27^a}function Vg(a,b){return b-a>>3}function Uw(a){a=a|0;Nb(gs(a))}function Sw(a){a=a|0;Nb(fs(a))}function Rx(a){a=a|0;Nb(Xs(a))}function Rw(a){a=a|0;Nb(es(a))}function Rc(a,b){return b-a>>1}function Ps(a){a=a|0;Nb(Jf(a))}function PF(a){a=a|0;Nb(rw(a))}function O2(a){a=a|0;Nb($I(a))}function MD(a){return a+1024|0}function Ld(a){return a&64?2:1}function JH(){return(hb()|0)>0}function IZ(a){a=a|0;Nb(OF(a))}function Hz(a){return a+4896|0}function Fl(a){return a>>>0<11}function FL(a,b){Vx(a,Ac(a),b)}function EZ(a){a=a|0;Nb(NF(a))}function Dn(a){return(a|0)==-1}function De(a,b){if(!a){Nb(b)}}function Ah(a,b){return b-a>>8}function A7(a){a=a|0;Nb(KK(a))}function zq(a){return a+256|0}function xj(a){return!(a&255)}function uR(a,b){qf(a,b,33,1)}function so(a,b){return a-b|0}function sU(a,b){qf(a,b,40,2)}function nf(a){return D(a)==N}function mc(a){a=a|0;return 0}function m8(a){a=a|0;return 6}function lO(a,b){Er(a,b,7,-7)}function l9(a){a=a|0;return 9}function jk(a){return Fd(a)^1}function hM(a,b,c){ol(a,b,-c)}function gd(a,b){xp(a,b+28|0)}function gL(a){a=a|0;return 3}function fk(a){return a+4e4|0}function fd(a,b){return b-a|0}function fA(a,b){gc(a,b,1024)}function dA(a){return a+128|0}function cr(a,b){qf(a,b,26,3)}function co(a,b){v[a+36>>2]=b}function bL(a){a=a|0;return 7}function _w(){return pb()<<16}function _m(a){return a&1?2:1}function _k(a){return(a&5)!=0}function _S(a){yo(Ub(a,0,40))}function W6(){return 19988498}function Vr(a){return a>>>0<2}function Ve(a,b){u[a+28>>1]=b}function SB(a,b){gc(a,b,1954)}function RK(a){a=a|0;return 5}function Nn(a){a=a|0;return 4}function Mb(a){tE(a);return a}function Lb(a,b){return a+b|0}function Io(a){return a>>>0<5}function Ie(a){a=a|0;return 1}function GR(a,b){gc(a,b,1108)}function Fe(a){a=a|0;return 2}function Fd(a){return(a|0)!=0}function FH(a){a=a|0;return-1}function EA(a,b){gc(a,b,4896)}function Cs(a,b){v[a+32>>2]=b}function $u(a){return!v[a>>2]}function xT(a){return a+36|0}function xM(a){return a-32|0}function wd(a){return a+16|0}function sQ(a,b){uc(a,b,128)}function ro(a){return a+14|0}function rA(a,b){HA(a,ce(b))}function qh(a,b,c){Ev(a,b,c)}function qP(a,b,c){nl(a,c,b)}function qO(a,b,c){Zr(a,b,c)}function px(a){return a-12|0}function nI(a,b,c){Ub(a,c,b)}function mm(a,b){v[a+8>>2]=b}function mU(a,b){gc(a,b,218)}function mN(a,b,c){OT(a,b,c)}function ld(a,b){return a>>b}function lR(a,b){gc(a,b,146)}function kq(a,b){return a<<b}function jy(a,b){t[a+34|0]=b}function jV(a,b){gc(a,b,610)}function jU(a,b){gc(a,b,157)}function iy(a,b){t[a+32|0]=b}function iP(a){hP(a,v[a>>2])}function iB(a,b){qf(a,b,8,2)}function hy(a,b){t[a+35|0]=b}function hR(a,b){gc(a,b,608)}function gz(a){t[a+6152|0]=0}function go(a){return a+32|0}function gc(a,b,c){hc(a,b,c)}function f1(a){a=a|0;FV(a,1)}function et(a){QM(a,v[a>>2])}function eU(a,b){gc(a,b,206)}function eP(a,b,c){ql(a,c,b)}function de(a,b){t[a+11|0]=b}function ci(a,b,c){rD(a,b,c)}function bs(a,b){xp(a,b+4|0)}function aT(a,b){gc(a,b,128)}function _T(a,b){gc(a,b,236)}function _R(a,b){gc(a,b,130)}function ZA(a){return a-28|0}function Yo(a){return a+20|0}function YR(a,b){gc(a,b,600)}function WT(a){return a+10|0}function Uj(a){return a-36|0}function ST(a,b){gc(a,b,102)}function SR(a,b){gc(a,b,126)}function OC(a,b){gc(a,b,497)}function NP(a,b){gc(a,b,263)}function Mu(a,b){gc(a,b,512)}function Mq(a,b){gc(a,b,192)}function MQ(a,b){gc(a,b,204)}function Lc(a){Gd(a,v[a>>2])}function Kv(a,b){UD(a,ce(b))}function Ke(a,b){a=a|0;b=b|0}function KP(a){return a+48|0}function Jp(a,b){z[a+8>>2]=b}function Ip(a,b){z[a+4>>2]=b}function Hp(a,b){t[a+33|0]=b}function Gd(a,b){v[a+4>>2]=b}function FT(a,b){gc(a,b,576)}function Dm(a,b,c){Mo(a,b,c)}function Cc(a){return a+12|0}function CT(a,b){gc(a,b,674)}function Ao(a,b){ke(a,b+8|0)}function AO(a){zO(a,v[a>>2])}function zy(a){Ub(a,0,4096)}function zf(a){return a&255}function xL(a){Ub(a,0,2048)}function wR(a,b){gc(a,b,96)}function uU(a,b){gc(a,b,98)}function uA(a,b){gc(a,b,40)}function sk(){uq(10955);L()}function pv(a,b){hc(a,b,22)}function pU(a,b){gc(a,b,48)}function kC(a,b){gc(a,b,11)}function jf(){vV(10955);L()}function jc(a){return a+4|0}function gu(a,b){return a<b}function gS(a,b){gc(a,b,30)}function fr(a,b){gc(a,b,36)}function fC(a,b){hc(a,b,20)}function dg(a,b){t[a+3|0]=b}function cv(a,b){gc(a,b,65)}function cC(a,b){gc(a,b,17)}function bv(a,b){gc(a,b,16)}function bT(a,b){gc(a,b,80)}function aL(a){return 0-a|0}function XT(a){return a+6|0}function XD(a,b){gc(a,b,24)}function Vm(a,b){hc(a,b,32)}function V6(){return 458752}function UU(a,b){uc(a,b,40)}function UP(a,b){return a<b}function Te(a){return a+2|0}function Re(a){return!Hb(a)}function RO(a,b){gc(a,b,27)}function RB(a){Ub(a,0,1954)}function Op(a){Ub(a,0,8192)}function Oc(a){return a+1|0}function Mi(a){return a+3|0}function LR(a,b){gc(a,b,32)}function Ko(a,b){t[a+1|0]=b}function JS(a,b){gc(a,b,52)}function Hu(a,b){gc(a,b,64)}function HC(a,b){gc(a,b,38)}function Gu(a,b){gc(a,b,66)}function Gb(a){return a+8|0}function FC(a,b){fi(a,b,37)}function Dq(a,b){gc(a,b,12)}function Do(a){v[a+12>>2]=0}function DC(a,b){gc(a,b,41)}function CA(a,b){gc(a,b,33)}function Bj(a){return a-4|0}function Au(a,b){gc(a,b,22)}function $q(a){return a&127}function zc(a){v[a+8>>2]=0}function zT(a){Ub(a,0,192)}function zN(a){it(a,Td(a))}function yv(a,b){gc(a,b,3)}function yN(a){jt(a,Td(a))}function xr(a){a=a|0;yr(a)}function vl(a,b){Mo(a,b,0)}function vd(a,b){v[a>>2]=b}function tba(a){a=a|0;kb=a}function sT(a){JA(a,Td(a))}function ru(a){_A(a,Td(a))}function qC(a,b){ci(a,2,b)}function pT(a){LA(a,Td(a))}function oQ(a){Oz(a,Td(a))}function oB(a,b){gc(a,b,6)}function nQ(a){Pz(a,Td(a))}function ll(a){cz(a,Td(a))}function lM(a){fy(a,Td(a))}function kR(a){Ub(a,0,146)}function jW(a){a=a|0;Jh(a)}function iV(a){Ub(a,0,610)}function iU(a){Ub(a,0,157)}function iQ(a){Ub(a,0,256)}function gv(){uq(7678);L()}function gR(a){Ub(a,0,608)}function ek(a,b){z[a>>2]=b}function eA(a){Ub(a,0,130)}function dU(a){Ub(a,0,206)}function cd(){vV(7678);L()}function bu(a){vA(a,Td(a))}function bn(a,b){gc(a,b,8)}function ac(a){gn(v[a>>2])}function ZT(a){Ub(a,0,236)}function Yq(a,b){gc(a,b,1)}function Xm(a,b){gc(a,b,2)}function XR(a){Ub(a,0,600)}function Wba(){return kb|0}function RR(a){Ub(a,0,126)}function QT(a){$A(a,Td(a))}function Ni(a,b){u[a>>1]=b}function NC(a){Ub(a,0,497)}function LQ(a){Ub(a,0,204)}function Kh(a,b){gc(a,b,4)}function Jc(a){a=a|0;Nb(a)}function Fo(a,b){gc(a,b,7)}function Eo(a,b){gc(a,b,5)}function ET(a){Ub(a,0,576)}function Bi(a){return a!=a}function BO(a){Xp(a,Td(a))}function $K(a,b){IL(a,3,b)}function yL(a){Ul(a,2048)}function xd(a,b){t[a|0]=b}function xR(a){Ub(a,0,96)}function tv(a){return a&1}function tU(a){Ub(a,0,98)}function qU(a){Ub(a,0,48)}function km(a){zb(a+16|0)}function gr(a){Ub(a,0,36)}function c4(){return 2048}function Pj(a){Ab(a+16|0)}function OS(a){Ub(a,0,33)}function KT(a){Ub(a,0,56)}function IS(a){Ub(a,0,52)}function GC(a){Ub(a,0,38)}function FA(a){Ub(a,0,80)}function EB(a){Ub(a,0,66)}function Cu(a){Ub(a,0,64)}function CC(a){Ub(a,0,41)}function yO(a){re(a+8|0)}function st(a,b){zM(a,b)}function nB(a,b){kc(a,b)}function ii(a,b){Nh(a,b)}function gq(a,b){fc(a,b)}function gP(a,b){hP(a,b)}function cP(a,b){Wf(a,b)}function ap(a,b){eE(a,b)}function VR(a){ew(a,512)}function Uu(a,b){hC(a,b)}function Ug(a){a=a|0;L()}function Uc(a){ic(a+8|0)}function UL(a,b){QM(a,b)}function UB(a,b){eK(a,b)}function Tx(a,b){eg(a,b)}function Tl(a,b){EV(a,b)}function Od(a,b){Gd(a,b)}function KA(a){Ab(a+4|0)}function GB(a,b){xk(a,b)}function Ds(a){zb(a+4|0)}function CQ(a,b){wl(a,b)}function BR(a,b){ke(a,b)}function BA(a,b){MS(a,b)}function Ad(a){Bb(a+8|0)}function wr(a){$v(a,36)}function uo(a){OE(a,16)}function pC(a){ew(a,16)}function mE(a){Ul(a,24)}function hE(a){$v(a,48)}function Xg(a){$v(a,24)}function Rha(){va();L()}function QU(a){Ul(a,40)}function Lo(a){OE(a,11)}function Dh(a){t[a|0]=0}function vF(){wa();L()}function uM(a){XM(a,0)}function sr(a){UD(a,0)}function sg(a){rT(a,0)}function mr(a){Ul(a,8)}function kj(a){TJ(a,0)}function kO(a){Ul(a,7)}function jj(a){RJ(a,0)}function hT(a){Ul(a,6)}function Xc(a){_e(a,0)}function Oi(a){Ul(a,2)}function NY(){vF();L()}function By(a){TM(a,0)}function Bs(a){SJ(a,0)}function Ay(a){SM(a,0)}function $S(a){ew(a,4)}function yQ(a){Le(a)}function xJ(a){He(a)}function uf(a){a=a|0}function tO(a){ho(a)}function rE(a){Cr(a)}function rC(a){Ak(a)}function bc(a){Ab(a)}function bA(a){Ck(a)}function PP(a){Hc(a)}function Gm(a){wc(a)}function EQ(a){Tb(a)}function $o(a){Cc(a)}function $b(a){zb(a)}
// EMSCRIPTEN_END_FUNCS
e=w;var ob=c([null,yc,gE,Jk,SX,jn,JX,BX,WD,xX,sX,iD,JW,uW,kW,Uq,Li,ZV,$,iv,Kl,uH,Wg,Qm,Uja,zU,yf,Tia,iia,aia,Rha,Qha,Oha,zA,pha,jha,pea,Ega,NR,C1,B1,js,NR,dda,uca,WO,yt,Yp,Rba,Oba,rba,pba,FB,qM,yh,Nc,Qaa,oaa,pL,hL,Ix,pi,JK,s7,l7,c7,P6,K6,m1,l1,Q0,dK,I4,FN,O3,I3,E3,pJ,_2,M2,B2,v2,k2,$1,P1,O1,N1,L1,pi,J1,F1,z1,v1,s1,h1,e1,b1,z0,PG,w0,o0,n0,j0,TA,Tw,va,Qb,gY,fY,eY,dY,cY,bY,mn,aY,$X,PG,_X,ZX,ha,XX,WX,VX,Es,UX,TX,RX,bE,aE,QX,Qv,PX,_o,MX,xr,Zo,Rl,Sf,IX,_o,LX,KX,HX,OX,GX,_D,FX,_D,NX,$D,EX,DX,CX,mn,AX,dd,Qb,wX,Jv,vX,Wg,uX,VD,tX,Hk,VD,qr,rX,Hv,Gv,WW,qX,iX,hX,VW,Si,QW,PW,wv,vD,OW,Maa,Naa,hO,Kaa,Laa,gy,$s,_b,Oaa,ae,sD,LW,KW,dD,HW,GW,dD,CW,lv,BW,baa,df,Rga,yba,IW,Qq,Of,NV,xba,eka,laa,aaa,AC,zC,sW,rW,yC,qW,wg,pW,oW,Fc,nW,mW,xg,ph,lW,jW,gW,iC,fW,eW,dW,Zu,CP,MC,sJ,cW,bW,aW,$V,_V,av,YV,_B,Bd,Nq,UV,TV,Ru,Qu,SV,RV,QV,ZB,PV,YB,_u,OV,ev,IV,Lq,Lka,Ob,_f,Sf,Kka,MB,Jka,qd,Hj,Ika,Hka,Gka,DV,CV,nd,Fka,Co,Eka,Dka,Cka,zV,yV,Si,Ku,Bka,Aka,kca,zka,Rg,yka,xka,tka,Ej,wka,vka,qV,uka,Ih,Af,qka,pka,oka,dV,lka,Ej,Cj,kka,jka,Hq,ika,BB,cV,hka,gka,fka,NU,KU,bka,_ja,rn,Yja,vg,hV,Zja,Zu,GU,Xja,Wja,uB,Vja,Gv,Tja,sB,CU,cU,Qja,Lq,to,Pja,Oja,CV,Nja,Mja,Lja,yU,Kja,Tm,Jja,Ija,Hja,Fja,Ej,xU,Gja,Ih,Af,AB,Aja,xja,AC,tja,sja,rja,oja,Lq,nja,mja,xo,yU,lja,kja,Sf,jja,ija,hja,gja,fja,VT,eja,dja,uE,cja,bja,aja,XB,UT,$ia,_ia,Zia,oca,Yia,TT,Xia,TT,uja,Wia,Ej,Ih,Af,Gh,Qia,Pia,Oia,Lia,Kia,Jia,Iia,Hia,xo,Gia,Fia,Eia,SA,DW,Dia,Cia,Bia,Aia,zia,AW,yia,xia,wia,via,sB,yT,uia,tia,Sf,sia,ria,DB,Ria,qia,pia,Sia,oia,nia,mia,PA,PA,OA,lia,kia,wT,PA,jia,hY,hia,gia,fia,eia,dia,cia,bia,tT,ud,oo,Pha,GA,$ha,O9,N9,M9,L9,K9,J9,_ha,Zha,Wf,Yha,Xha,Wha,Vha,gE,jca,hca,Z9,jaa,kaa,Uha,Tha,Sha,Xaa,H9,qT,fca,eca,dca,cca,Kha,Jha,Iha,Hha,Gha,Fha,Eha,Dha,Cha,Bha,Aha,yha,xha,zha,NS,Af,GS,AA,uha,yA,tha,sha,rha,qha,xA,oha,lv,yC,nha,ES,DS,br,wA,mha,pf,lha,BS,xo,Xu,xo,UT,Xq,Sf,dV,xo,rn,hha,gha,fha,eha,sA,$t,dha,cha,bha,aha,$ga,_ga,BC,Zga,Yga,Xga,Wga,Vga,Uga,Tga,Sga,MA,Qga,Pga,Oga,Sf,vT,uT,WA,Nga,Mga,Ru,Gv,Lga,Kga,Qba,Jq,Jga,Pm,Iu,Uh,wba,Vba,tt,oO,vba,uba,aO,ot,XN,sba,MN,XO,qba,qz,rj,di,zga,yga,Zt,Hga,hu,vga,Pm,uga,tga,PR,oo,sga,rga,OR,qga,pga,oga,Yt,nga,mga,lga,kga,fga,_z,ega,dga,cga,Ej,Ih,Af,di,$fa,_fa,Zfa,Yfa,yA,Vfa,Ufa,Yt,Tfa,maa,Qfa,Pfa,Cj,CR,_z,_u,Ofa,Nfa,Mfa,Lfa,Wt,Kfa,Wt,Jfa,tr,EW,Gfa,Ej,Hfa,Ifa,Wz,pR,Ih,Af,Zt,Dfa,Afa,AA,zfa,wfa,vfa,dR,OR,SA,ufa,Ru,Sf,lfa,kfa,ZB,jfa,ifa,hfa,gfa,cB,Co,dfa,cfa,bfa,afa,$ea,_ea,Bm,zQ,Zea,Yea,Xea,Wea,Vea,Uea,Tea,Sea,Rea,Qea,Pea,Oea,Nea,yA,Lea,Kea,Jea,hu,Iea,Hea,Lq,Hba,Jv,DV,Pba,Nba,Lq,Mba,di,Jv,Lba,Kba,Jba,Eea,Dea,Cea,Bea,Aea,zea,_q,wea,vea,uea,tea,sea,rea,qea,oea,nea,mea,lea,YX,iE,kea,Sf,jea,iea,Jl,Sba,pca,FB,jP,mca,lca,ica,gca,bca,YO,$ba,_ba,QO,Zba,Yba,Xba,ao,DO,Uba,Tba,vo,Fba,Cj,iO,ur,Jaa,Iaa,Haa,oba,FW,Gaa,xv,ur,_B,Faa,iO,Dba,Eaa,Iba,Ej,Ih,Af,Gba,Ej,Ih,Af,Eba,Ej,Ih,Af,Bba,qV,Jq,nba,mba,lba,kba,jba,iba,nca,gea,QP,hba,tc,fba,eaa,eba,zX,UW,NW,SW,cba,bba,MW,TW,yX,RW,JM,aba,$aa,_aa,IM,wy,Zaa,Yaa,aca,Waa,Vaa,Uaa,Taa,QL,X9,Pv,fE,pE,gy,Paa,qT,Ju,Tq,Aba,Cba,Baa,Aaa,Cj,zaa,_z,yaa,xaa,waa,Zt,vaa,di,uaa,taa,saa,raa,qaa,Ej,Ih,Af,Caa,iaa,haa,gaa,faa,Nh,bm,daa,caa,$9,V9,U9,T9,S9,R9,ML,Y9,Fp,LL,Kk,Nh,Wf,P9,I9,Q9,W9,F9,E9,X8,D9,dk,zL,Vf,JL,p9,Y8,Zl,S8,R8,P8,O8,N8,gy,Q8,ih,lu,lu,jh,M8,L8,J8,ty,eL,p8,g8,$7,U7,L7,B7,D7,q7,i7,tK,Os,b7,a7,a3,c3,T6,S6,Q6,rK,Raa,e3,M6,tK,L6,K3,A3,N3,I6,H2,nK,Dx,G6,Z3,ZJ,Y3,OJ,E6,o9,B6,S7,C6,I7,z6,uE,V3,x6,H3,lK,BS,jK,iK,hK,n6,l6,nK,Dx,i6,h6,g6,f6,e6,d6,c6,b6,a6,$5,_5,Z5,Y5,X5,W5,V5,U5,T5,S5,R5,Q5,P5,O5,N5,M5,J5,H5,F5,KD,A2,P3,D5,o5,F3,m5,k5,fl,D2,E2,i5,G2,b5,$4,_9,Y4,Dx,T4,Q4,N4,Jn,C2,L4,J4,G4,E4,C4,A4,y4,w4,u4,s4,q4,o4,bK,j4,h4,EM,_t,aK,e4,d4,b4,a4,$3,_3,Bp,zba,vr,xN,T3,R3,ON,M3,gba,J3,WY,Ir,G3,D3,B3,dba,L3,U3,Q3,Wv,aa,d3,VJ,UJ,b3,fJ,$2,Z2,P2,F2,z2,y2,yM,hea,R1,Q1,M1,K1,E1,D1,hH,gH,YY,u1,t1,r1,q1,p1,o1,n1,g1,Wg,f1,yf,PY,XY,R0,gH,O0,ar,sH,Nw,Iw,y0,x0,Dw,Ph,Oh,Ur,Nb,Cw,pp,dj,Zk,Bw,fm,m0,l0,bj,ch,uG,aj,Qw,xw,Ph,Oh,Sr,ds,$j,d1,Kl,Cn,bj,ch,qG,aj,S$,N$,nH,I$,$r,Qm,D$,Pr,uf,l$,Yr,k$,j$,i$,cG,g$,e$,d$,Xk,c$,cG,a$,$_,Z_,Y_,V_,U_,Q_,P_,O_,N_,M_,L_,K_,J_,I_,H_,G_,F_,E_,D_,C_,B_,A_,z_,y_,x_,w_,v_,u_,t_,s_,r_,q_,p_,o_,n_,m_,l_,k_,j_,XZ,YZ,ZZ,e_,c_,a_,_Z,JZ,KZ,LZ,SZ,QZ,OZ,MZ,FB,Mea,vF,dn,Vq,fea,eea,dea,cea,bea,aea,$da,_da,Zda,Yda,Xda,Wda,Vda,Uda,Tda,Sda,Rda,Qda,Pda,Oda,Nda,Mda,Lda,Kda,Jda,Ida,Hda,Gda,Fda,Eda,Dda,Cda,Bda,Ada,zda,yda,xda,wda,vda,uda,tda,sda,rda,qda,pda,oda,nda,mda,lda,kda,jda,ida,hda,gda,fda,eda,cda,bda,ada,$ca,_ca,Zca,Yca,Xca,Wca,Vca,Uca,Tca,Sca,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,vca,tca,sca,rca,qca,dn,yea,xea,Nia,Mia,yfa,xfa,rfa,qfa,wha,vha,jga,iga,Mha,Lha,KV,JV,Eja,Dja,iW,hW,XV,WV,bga,aga,Cfa,Bfa,Gea,Fea,nka,mka,dka,cka,xW,wW,vW,tW,Sfa,Rfa,Ffa,Efa,xga,wga,Nha,GV,zja,yja,Via,Uia,ska,rka,Sja,Rja,Xfa,Wfa,Daa,paa,naa,qja,pja,wja,vja,Bga,Aga,ffa,efa,hga,gga,Cja,Bja,tfa,sfa,nfa,mfa,aka,$ja,pfa,ofa,Iga,Dga,Cga,zW,yW,MV,LV,kha,iha,Gga,Fga,ln,Vq,XW,Jc,To,sK,Jc,yf,Jc,mc,Ie,Ie,mc,mc,YW,lX,kX,ZW,Jc,To,Jc,HD,gX,fX,eX,dX,cX,bX,aX,$W,_W,Xs,Rx,Vs,wL,mc,uf,mc,mc,mc,Ke,Nn,C9,B9,A9,z9,y9,ri,Px,Px,Ox,uL,Ox,tL,Ox,tL,uf,GV,x9,w9,v9,u9,t9,qi,sL,U8,mc,mc,Ie,Nx,Fe,Fe,Ie,s9,r9,Ke,uf,Ke,uf,rL,n9,m9,mc,uf,mc,mc,mc,Ke,l9,qL,k9,j9,i9,h9,ri,g9,f9,e9,d9,c9,b9,a9,$8,_8,Z8,qi,mL,mc,mc,Ie,Fe,Fe,Ie,oL,nL,Jf,Ug,NY,W8,Qx,V8,mc,T8,uL,A8,q8,h8,a8,V7,M7,C7,r7,j7,N7,G9,q9,K8,Xs,Rx,wL,mc,uf,mc,mc,mc,Ke,gL,I8,H8,G8,F8,E8,ri,D8,qi,fL,mc,mc,Ie,Fe,Fe,Ie,C8,B8,VK,o8,n8,mc,uf,mc,mc,mc,Ke,m8,l8,k8,j8,ri,i8,qi,SK,mc,mc,Ie,Fe,Fe,Ps,f8,mc,uf,mc,mc,mc,Ke,RK,e8,d8,c8,ri,b8,qi,PK,mc,mc,Ie,Fe,Fe,Xs,Rx,_7,mc,uf,mc,mc,mc,Ke,RK,Z7,Y7,X7,ri,W7,qi,NK,mc,mc,Ie,Fe,Fe,dL,cL,T7,mc,uf,mc,mc,mc,Ke,bL,R7,x8,w8,ri,v8,qi,u8,mc,mc,Ie,Fe,Fe,Ke,uf,_K,Q7,P7,ZK,O7,YK,XK,cL,z8,bL,y8,_K,t8,s8,ZK,r8,YK,XK,Ps,K7,mc,uf,mc,mc,mc,Ke,Fe,J7,H7,G7,ri,F7,qi,E7,mc,mc,Ie,Fe,Fe,KK,A7,z7,mc,uf,mc,mc,y7,Ke,x7,w7,v7,u7,ri,t7,qi,Ex,mc,mc,Ie,Fe,Fe,Ke,uf,Ps,p7,mc,uf,mc,mc,mc,Ke,gL,o7,n7,m7,ri,k7,qi,EK,mc,mc,Ie,Fe,Fe,Ps,h7,mc,uf,mc,mc,mc,Ke,Nn,g7,f7,e7,ri,d7,qi,CK,mc,mc,Ie,Fe,Fe,YJ,Jc,X3,zx,W3,zx,zx,Ug,ys,z3,S3,yf,Ug,yf,Jc,y3,x3,Ug,FJ,EJ,FJ,EJ,Ke,zs,Ke,zs,IJ,HJ,IJ,HJ,Jc,C3,yf,Jc,w3,v3,Jc,vJ,uJ,Ug,s3,rJ,r3,rJ,u3,tJ,t3,tJ,Jc,q3,p3,Jc,qJ,oJ,vs,vs,vs,vs,o3,sx,sx,sx,Jc,n3,m3,Jc,nJ,mJ,j3,jJ,i3,jJ,l3,kJ,k3,kJ,Jc,h3,g3,Jc,iJ,hJ,us,us,us,us,f3,rx,rx,rx,I2,Jc,To,Jc,$I,O2,Ie,Ie,N2,L2,Vq,K2,J2,Ug,Ug,Q2,Jc,To,Jc,eJ,Y2,Ie,mc,Ie,X2,W2,V2,U2,T2,S2,R2,Ug,jX,Jc,To,Jc,Jc,pX,Ie,Ie,Vq,OD,oX,nX,mX,Ke,zs,Ke,zs,vp,ss,x2,w2,TI,SI,RI,QI,PI,OI,NI,MI,LI,KI,JI,II,HI,GI,FI,EI,DI,CI,BI,AI,zI,yI,xI,u2,t2,s2,r2,q2,p2,o2,n2,m2,l2,j2,i2,h2,g2,f2,e2,d2,c2,b2,a2,_1,Z1,Y1,X1,W1,V1,U1,T1,S1,yf,Ug,yf,Ug,yf,Ug,yf,Ug,I1,H1,G1,Ln,Vw,Ke,IH,HH,GH,mc,mc,y1,FH,x1,hs,w1,hs,es,Rw,Ke,IH,HH,GH,mc,mc,k1,FH,j1,hs,i1,hs,Js,Z0,_0,Y0,c1,a1,$0,zp,lH,X0,W0,fs,Sw,xH,wH,sf,kH,V0,U0,gs,Uw,DH,CH,yf,Jc,T0,VY,UY,TY,S0,dn,A1,mc,P0,Vw,D0,C0,B0,A0,kK,Ww,$k,Ww,Vw,G0,aH,F0,E0,Rw,K0,J0,I0,H0,gs,Uw,DH,CH,kK,Ww,Rw,N0,aH,M0,L0,fs,Sw,xH,wH,zF,ZY,Vs,BF,fZ,eZ,dZ,cZ,bZ,CF,aZ,$Y,_Y,GF,yZ,xZ,wZ,vZ,uZ,mc,tZ,sZ,NF,EZ,DZ,CZ,BZ,AZ,zZ,OF,IZ,OD,VV,HZ,GZ,FZ,yf,Jc,Jc,qZ,pZ,oZ,nZ,mZ,lZ,kZ,jZ,CF,iZ,hZ,gZ,Jc,DF,DF,jp,Ie,Ie,rZ,Ie,Jc,JF,IF,jp,mc,mc,HF,Nn,Jc,JF,IF,jp,mc,mc,HF,Nn,Jc,MF,LF,jp,mc,mc,KF,Nn,Jc,MF,LF,jp,mc,mc,KF,Nn,yf,Jc,v0,u0,t0,yf,Jc,s0,r0,q0,Jc,p0,k0,i0,h0,yG,yG,g0,f0,e0,d0,c0,Jc,b0,a0,$$,_$,pG,pG,Z$,Y$,X$,W$,V$,Jc,U$,T$,R$,Q$,P$,O$,M$,L$,Jc,K$,J$,H$,G$,F$,E$,C$,B$,yf,Jc,Fe,A$,z$,y$,x$,w$,v$,WZ,VZ,UZ,TZ,RZ,PZ,NZ,yf,Jc,Fe,u$,t$,s$,r$,q$,p$,i_,h_,g_,f_,d_,b_,$Z,rw,PF,o$,rw,PF,n$,Jc,Or,Or,Mh,Mh,Mh,fG,mc,Tk,Tk,Jc,Or,Or,Mh,Mh,Mh,fG,mc,Tk,Tk,Jc,Nr,Nr,Mh,Mh,Mh,eG,mc,Tk,Tk,Jc,Nr,Nr,Mh,Mh,Mh,eG,mc,Tk,Tk,Jc,m$,h$,Jc,f$,b$,Jc,__,X_,Jc,W_,T_,Jc,VF,S_,Ke,Jc,VF,R_,Ke,yf,Ug,Jc,SY,wF,Jc,RY,QY,wF,dn,Ug,Jc,OY,wa,yf,Jc,uf,uf,MY,EY,GY,HY,Jc,zY,Jc,yY,ln,dn,ln,ln,ln,ln,dn,Jc,xY,Jc,DY,FY,IY,Jc,LY,KY,JY,Jc,AY]);function pb(){return s.byteLength/65536|0}function ub(vb){vb=vb|0;var qb=pb()|0;var rb=qb+vb|0;if(qb<rb&&rb<65536){var sb=new ArrayBuffer(B(rb,65536));var tb=new Int8Array(sb);tb.set(t);t=new Int8Array(sb);u=new Int16Array(sb);v=new Int32Array(sb);w=new Uint8Array(sb);x=new Uint16Array(sb);y=new Uint32Array(sb);z=new Float32Array(sb);A=new Float64Array(sb);s=sb;r.buffer=s;e=w}return qb}return{"za":HV,"Aa":V6,"Ba":W6,"Ca":Jc,"Da":Nb,"Ea":U6,"Fa":R6,"Ga":O6,"Ha":Os,"Ia":Ke,"Ja":Y6,"Ka":X6,"La":$6,"Ma":Px,"Na":Z6,"Oa":sK,"Pa":_6,"Qa":yf,"Ra":vK,"Sa":uK,"Ta":vK,"Ua":c4,"Va":wY,"Wa":vY,"Xa":uY,"Ya":N6,"Za":pK,"_a":J6,"$a":oK,"ab":t6,"bb":l4,"cb":m4,"db":r6,"eb":q6,"fb":p6,"gb":s6,"hb":n4,"ib":P4,"jb":f4,"kb":S4,"lb":p5,"mb":i4,"nb":V4,"ob":k4,"pb":U4,"qb":g4,"rb":t4,"sb":p4,"tb":r4,"ub":H4,"vb":D4,"wb":F4,"xb":v4,"yb":x4,"zb":z4,"Ab":B4,"Bb":j5,"Cb":l5,"Db":x5,"Eb":s5,"Fb":r5,"Gb":q5,"Hb":w5,"Ib":v5,"Jb":t5,"Kb":u5,"Lb":B5,"Mb":C5,"Nb":y5,"Ob":A5,"Pb":z5,"Qb":c5,"Rb":h5,"Sb":f5,"Tb":e5,"Ub":g5,"Vb":d5,"Wb":O4,"Xb":G5,"Yb":a5,"Zb":Z4,"_b":n5,"$b":R4,"ac":_4,"bc":X4,"cc":W4,"dc":I5,"ec":K4,"fc":K5,"gc":M4,"hc":E5,"ic":H6,"jc":F6,"kc":tY,"lc":D6,"mc":A6,"nc":y6,"oc":w6,"pc":sY,"qc":v6,"rc":u6,"sc":o6,"tc":m6,"uc":k6,"vc":L5,"wc":j6,"xc":Pd,"yc":ob,"zc":Saa,"Ac":Wba,"Bc":tba,"Cc":CY,"Dc":BY,"Ec":rY,"Fc":qY,"Gc":pY,"Hc":oY,"Ic":nY,"Jc":mY,"Kc":jY,"Lc":lY,"Mc":kY,"Nc":jY,"Oc":iY,"Pc":iY}}return wb(yb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


